# localization

# region common
l_on = {
    'ru': "вкл",
    'en': "on",
    'es': "en",
    'fr': "y compris",
    'zh': "包括",
    'ar': "بما في ذلك",
}
l_off = {
    'ru': "выкл",
    'en': "off",
    'es': "de",
    'fr': "de",
    'zh': "离开",
    'ar': "عن",
}
l_yes = {
    'ru': "да",
    'en': "yes",
    'es': "sí",
    'fr': "oui",
    'zh': "是的",
    'ar': "نعم",
}
l_no = {
    'ru': "нет",
    'en': "no",
    'es': "no",
    'fr': "non",
    'zh': "不",
    'ar': "لا",
}
l_yes_percent = {
    'ru': "👩🏽‍💻 Да, 100%",
    'en': "👩🏽‍💻 Yes, 100%",
    'es': "👩🏽‍💻 Sí, 100%",
    'fr': "👩🏽‍💻 Oui, 100%",
    'zh': "👩🏽‍💻 是的，100%",
    'ar': "👩🏽‍💻 نعم 100%",
}
l_no_percent = {
    'ru': "👩🏽‍💻 Нет, 0%",
    'en': "👩🏽‍💻 No, 0%",
    'es': "👩🏽‍💻 No, 0%",
    'fr': "👩🏽‍💻 Non, 0%",
    'zh': "👩🏽‍💻 不，0%",
    'ar': "👩🏽‍💻 لا، 0%",
}
l_creturn_text = {
    'ru': "✖️ <b>Сбросить</b> настройки по умолчанию (до рекомендуемых) для [<b>{0}</b>]?",
    'en': "✖️ <b>Reset</b> default settings (to recommended) for [<b>{0}</b>]?",
    'es': "✖️ ¿<b>Restablecer</b> la configuración predeterminada (a la recomendada) para [<b>{0}</b>]?",
    'fr': "✖️ <b>Réinitialiser</b> les paramètres par défaut (aux valeurs recommandées) pour [<b>{0}</b>] ?",
    'zh': "✖️ <b>重置</b> [<b>{0}</b>] 的默认设置（推荐）？",
    'ar': "✖️ <b>إعادة تعيين</b> الإعدادات الافتراضية (للموصى بها) لـ [<b>{0}</b>]؟",
}
l_all_ans = {
    'ru': "все",
    'en': "all",
    'es': "todo",
    'fr': "tous",
    'zh': "全部",
    'ar': "الجميع",
}
l_menu = {
    'ru': "🔙 Menu",
    'en': "🔙 Menu",
    'es': "🔙 Menú",
    'fr': "🔙Menus",
    'zh': "🔙 菜单",
    'ar': "🔙 القائمة",
}
l_back = {
    'ru': "🔙 Назад",
    'en': "🔙Back",
    'es': "🔙Volver",
    'fr': "🔙Retour",
    'zh': "🔙返回",
    'ar': "🔙رجوع",
}
l_forever = {
    'ru': "навсегда",
    'en': "forever",
    'es': "para siempre",
    'fr': "pour toujours",
    'zh': "永远",
    'ar': "للأبد",
}
l_members = {
    'ru': "участ.",
    'en': "participation.",
    'es': "participación.",
    'fr': "participation.",
    'zh': "参与。",
    'ar': "مشاركة.",
}
l_add = {
    'ru': "✅ Добавить",
    'en': "✅Add",
    'es': "✅Agregar",
    'fr': "✅Ajouter",
    'zh': "✅添加",
    'ar': "✅إضافة",
}
l_remove = {
    'ru': "🚫 Удалить",
    'en': "🚫Delete",
    'es': "🚫Eliminar",
    'fr': "🚫Supprimer",
    'zh': "🚫删除",
    'ar': "🚫حذف",
}
l_try_again = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> или попробуй позже",
    'en': "👩🏽‍💻 <b>Error</b> or try again later",
    'es': "👩🏽‍💻 <b>Error</b> o inténtalo de nuevo más tarde",
    'fr': "👩🏽‍💻 <b>Erreur</b> ou réessayez plus tard",
    'zh': "👩🏽‍💻<b>错误</b>或稍后重试",
    'ar': "👩🏽‍💻 <b>خطأ</b> أو حاول مرة أخرى لاحقًا",
}
l_please_subscribe = {
    'ru': "👩🏽‍💻 Оформи ежемесячную 💨Подписку",
    'en': "👩🏽‍💻 Sign up for a monthly 💨Subscription",
    'es': "👩🏽‍💻 Regístrate para obtener una 💨Suscripción mensual",
    'fr': "👩🏽‍💻 Inscrivez-vous pour un 💨abonnement mensuel",
    'zh': "👩🏽‍💻 订阅每月💨订阅",
    'ar': "👩🏽‍💻 سجل للحصول على اشتراك 💨 شهري",
}
l_please_subscribe_need = {
    'ru': "👩🏽‍💻 <b>Необходимо</b> 💨Подписка",
    'en': "👩🏽‍💻 <b>It is necessary</b> to subscribe 💨!",
    'es': "👩🏽‍💻 <b>Es necesario</b> suscribirse 💨!",
    'fr': "👩🏽‍💻 <b>Il est nécessaire</b> de s'abonner 💨 !",
    'zh': "👩🏽‍💻<b>有必要</b>订阅💨！",
    'ar': "👩🏽‍💻 <b>ضروري</b> الاشتراك 💨!",
}
l_subscribe_spoiler = {
    'ru': "оформи 💨Подписку",
    'en': "subscribe 💨",
    'es': "suscríbete 💨",
    'fr': "abonnez-vous 💨",
    'zh': "订阅💨",
    'ar': "اشترك 💨",
}
l_subscribe_channel_for_post = {
    'ru': "👩🏽‍💻 <b>Подпишись</b> на @{0}, чтобы продолжитть",
    'en': "👩🏽‍💻 <b>Follow</b> @{0} to continue",
    'es': "👩🏽‍💻 <b>Seguir</b> @{0} para continuar",
    'fr': "👩🏽‍💻 <b>Suivez</b> @{0} pour continuer",
    'zh': "👩🏽‍💻<b>关注</b>@{0}继续",
    'ar': "👩🏽‍💻 <b>متابعة</b> @{0} للمتابعة",
}
l_sound = {
    'ru': "Звук",
    'en': "Sound",
    'es': "Sonido",
    'fr': "Son",
    'zh': "声音",
    'ar': "صوت",
}
l_date = {
    'ru': "Дата",
    'en': "Date",
    'es': "Fecha",
    'fr': "Date",
    'zh': "日期",
    'ar': "تاريخ",
}
l_timer = {
    'ru': "Таймер",
    'en': "Timer",
    'es': "Temporizador",
    'fr': "Minuteur",
    'zh': "定时器",
    'ar': "الموقت",
}
l_media = {
    'ru': "Медиа",
    'en': "Media",
    'es': "Medios de comunicación",
    'fr': "Médias",
    'zh': "媒体",
    'ar': "وسائط",
}
l_week = {
    'ru': "неделя",
    'en': "sunday",
    'es': "domingo",
    'fr': "dimanche",
    'zh': "星期日",
    'ar': "الأحد",
}
l_subscribers = {
    'ru': "подписчики",
    'en': "subscribers",
    'es': "suscriptores",
    'fr': "les abonnés",
    'zh': "订户",
    'ar': "مشتركين",
}
l_sec = {
    'ru': "сек",
    'en': "sec",
    'es': "segundo",
    'fr': "seconde",
    'zh': "秒",
    'ar': "ثانية",
}
l_min = {
    'ru': "мин",
    'en': "i",
    'es': "i",
    'fr': "je",
    'zh': "我",
    'ar': "أنا",
}
l_hours = {
    'ru': "часов",
    'en': "hours",
    'es': "horas",
    'fr': "heures",
    'zh': "小时",
    'ar': "ساعات",
}
l_days = {
    'ru': "дней",
    'en': "days",
    'es': "días",
    'fr': "jours",
    'zh': "天",
    'ar': "أيام",
}

l_choose_direction = {
    'ru': "👇🏽 <b>Выбери</b> направление",
    'en': "👇🏽 <b>Choose</b> direction",
    'es': "👇🏽 <b>Elige</b> dirección",
    'fr': "👇🏽 <b>Choisissez</b> la direction",
    'zh': "👇🏽<b>选择</b>方向",
    'ar': "👇🏽 <b>اختر</b> الاتجاه",
}
l_about = {
    'ru': "<b>👩🏽‍💻 Ferey проекты</b>:\n\n<blockquote>▪️проекты: <a href='https://t.me/FereyDemoBot?start=about'>@FereyDemoBot</a>\n▪️конструктор: <a href='https://t.me/FereyBotBot?start=about'>@FereyBotBot</a>\n▪️приватные посты: <a href='https://t.me/FereyPostBot?start=about'>@FereyPostBot</a>\n▪️публичные медиа: <a href='https://t.me/FereyMediaBot?start=about'>@FereyMediaBot</a>\n▪️администрирование: <a href='https://t.me/FereyChannelBot?start=about'>@FereyChannelBot</a>\n▪️модерация: <a href='https://t.me/FereyGroupBot?start=about'>@FereyGroupBot</a>\n▪️поиск: <a href='https://t.me/FereyFindBot?start=about'>@FereyFindBot</a>\n▪️таргет: <a href='https://t.me/FereyTargetBot?start=about'>@FereyTargetBot</a>\n▪️инструменты: <a href='https://t.me/FereyToolsBot?start=about'>@FereyToolsBot</a>\n▪️стикеры/эмоджи: <a href='https://t.me/FereyStickerBot?start=about'>@FereyStickerBot</a>\n▪️ai: <a href='https://t.me/FereyAIBot?start=about'>@FereyAIBot</a>\n▪️автоматизация: <a href='https://t.me/FereyUserBot?start=about'>@FereyUserBot</a>\n▪️блокчейн NFT/FT: <a href='https://t.me/FereyTONestBot?start=about'>@FereyTONestBot</a>\n▪️вакансии: <a href='https://t.me/FereyWorkBot?start=about'>@FereyWorkBot</a></blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "<b>👩🏽‍💻 Ferey projects</b>:\n\n▪️projects: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️private posts: @FereyPostBot\n▪️public media: @FereyMediaBot\n▪️administration: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderation: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️search: @FereyFindBot\n▪️target: @FereyTargetBot\n▪️tools : @FereyToolsBot\n▪️vpn: @FereyVPNBot\n▪️ai: @FereyAIBot\n▪️automation: <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️vacancies: @FereyWorkBot\n▪️advertising: @FereyAdsBot\n\n❗️<b>Regularly</b>-updated /content",
    'es': "<b>👩🏽‍💻 Proyectos de Ferey</b>:\n\n▪️proyectos: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️publicaciones privadas: @FereyPostBot\n▪️medios públicos: @FereyMediaBot\n▪️administración: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderación: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️búsqueda: @FereyFindBot\n▪️objetivo: @FereyTargetBot\n▪️herramientas : @FereyToolsBot\n▪️vpn: @FereyVPNBot\n▪️ai: @FereyAIBot\n▪️automatización: <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️vacantes: @FereyWorkBot\n▪️publicidad: @FereyAdsBot\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "<b>👩🏽‍💻 @FereyBotBot Ferey</b> :\ n @FereyDemoBot nwithout </a>\n▪️posts privés : @FereyPostBot\n▪️médias publics : @FereyMediaBot\nnoyance️administration : <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️modération : <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️recherche : @FereyFindBot\nnoyancetarget : @FereyTargetBot\nnoyancetools : @FereyToolsBot\nƒ️vpn : @FereyVPNBot\nƒ️ai : @FereyAIBot\nƒ️automation : <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️postes vacants : @FereyWorkBot\n▪️publicité : @FereyAdsBot\n\n❗️<b>Régulièrement</b>-mis à jour / contenu",
    'zh': "<b>👩🏽‍💻 Ferey 项目</b>：\n\n▪️项目： @FereyDemoBot\n▪️构造函数： <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️私人帖子： @FereyPostBot\n▪️公共媒体： @FereyMediaBot\n▪️管理： <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️审核： <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️搜索： @FereyFindBot\n▪️目标： @FereyTargetBot\n▪️工具： @FereyToolsBot\n▪️vpn： @FereyVPNBot\n▪️ai： @FereyAIBot\n▪️自动化： <a href=' https://t.me/FereyUserBot?start=isfree '> @FereyUserBot </a>\n▪️职位空缺： @FereyWorkBot\n▪️广告： @FereyAdsBot\n\n❗️<b>定期</b>-更新/内容",
    'ar': "<b>👩🏽‍💻 مشاريع فيري</b>:\n\n▪️المشاريع: @FereyDemoBot\n▪️constructor: <a href=' https://t.me/FereyBotBot?start=isfree '> @FereyBotBot </a>\n▪️المشاركات الخاصة: @FereyPostBot\n▪️وسائل الإعلام العامة: @FereyMediaBot\n▪️administration: <a href=' https://t.me/FereyChannelBot?start=isfree '> @FereyChannelBot </a >\n▪️moderation: <a href=' https://t.me/FereyGroupBot?start=isfree '> @FereyGroupBot </a>\n▪️search: @FereyFindBot\n▪️target: @FereyTargetBot\n▪️tools @FereyToolsBot @FereyVPNBot @FereyAIBot _ @FereyUserBot ▪️الوظائف الشاغرة: @FereyWorkBot\n▪️advertising: @FereyAdsBot\n\n❗️<b>بانتظام</b>-يتم التحديث /المحتوى",
}
l_subscribe_btn = {
    'ru': "👩🏽‍💻 Я подписался",
    'en': "👩🏽‍💻 I subscribed",
    'es': "👩🏽‍💻 Me suscribí",
    'fr': "👩🏽‍💻 Je me suis abonné",
    'zh': "👩🏽‍💻我订阅了",
    'ar': "👩🏽‍💻 اشتركت",
}
l_subscribe_all = {
    'ru': "¹ Все боты и проекты",
    'en': "¹ All bots and projects",
    'es': "¹ Todos los bots y proyectos",
    'fr': "¹ Tous les robots et projets",
    'zh': "¹ 所有机器人和项目",
    'ar': "¹ جميع الروبوتات والمشاريع",
}
l_subscribe_already = {
    'ru': "👩🏽‍💻 У вас уже есть активная 💨Подписка",
    'en': "👩🏽‍💻 You already have an active 💨Subscription",
    'es': "👩🏽‍💻 Ya tienes una 💨Suscripción activa",
    'fr': "👩🏽‍💻 Vous avez déjà un 💨Abonnement actif",
    'zh': "👩🏽‍💻 您已经有一个活跃的💨订阅",
    'ar': "👩🏽‍💻 لديك بالفعل 💨اشتراك نشط",
}
l_subscribe_wait = {
    'ru': "👩🏽‍💻 Обработка @donate..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Processing @donate ..\n\n#duration 1 min",
    'es': "👩🏽‍💻 Procesando @donate ..\n\n#duración 1 min",
    'fr': "👩🏽‍💻 Traitement @donate ..\n\n#durée 1 min",
    'zh': "👩🏽‍💻 处理@donate ..\n\n#duration 1 分钟",
    'ar': "👩🏽‍💻 معالجة @donate ..\n\n#المدة دقيقة واحدة",
}
l_subscribe_success = {
    'ru': "👩🏽‍💻 <b>Успешный</b> донат!",
    'en': "👩🏽‍💻 <b>Successful</b> donation!",
    'es': "👩🏽‍💻 ¡Donación <b>exitosa</b>!",
    'fr': "👩🏽‍💻 Don <b>réussi</b> !",
    'zh': "👩🏽‍💻 <b>捐款成功</b>！",
    'ar': "👩🏽‍💻<b>تبرع ناجح</b>!",
}
l_subscribe_balance = {
    'ru': "👩🏽‍💻 Текущий /balance {0}{1}",
    'en': "👩🏽‍💻 Current /balance {0}{1}",
    'es': "👩🏽‍💻 Actual/saldo {0}{1}",
    'fr': "👩🏽‍💻 Actuel/solde {0}{1}",
    'zh': "👩🏽‍💻 当前/余额 {0}{1}",
    'ar': "👩🏽‍💻 الرصيد الحالي/الرصيد {0}{1}",
}
l_subscribe_deposit = {
    'ru': "² Донат на баланс",
    'en': "² Balance Donut",
    'es': "² Donut de equilibrio",
    'fr': "² Beignet équilibré",
    'zh': "² 平衡甜甜圈",
    'ar': "² التوازن دونات",
}

l_language_get = {
    'ru': "🌏 <b>Выбери</b> один из доступных языков",
    'en': "🌏 <b>Select</b> one of the available languages",
    'es': "🌏 <b>Seleccione</b> uno de los idiomas disponibles",
    'fr': "🌏 <b>Sélectionnez</b> une des langues disponibles",
    'zh': "🌏<b>选择</b>一种可用语言",
    'ar': "🌏 <b>اختر</b> إحدى اللغات المتاحة",
}
l_language_set = {
    'ru': "{0} Текущий язык: {1}\n\n👩🏽‍💻 Жми /start",
    'en': "{0} Current language: {1}",
    'es': "{0} Idioma actual: {1}",
    'fr': "{0} Langue actuelle : {1}",
    'zh': "{0}当前语言：{1}",
    'ar': "{0} اللغة الحالية: {1}",
}
l_ferey_like = {
    'ru': "💔 Like",
    'en': "💔 Like",
    'es': "💔 Me gusta",
    'fr': "💔 J'aime",
    'zh': "💔 喜欢",
    'ar': "💔 مثل",
}
# endregion


# region post
l_post_media = {
    'ru': "✏️ 1. <b>Прикрепи медиа</b> контент для поста: <i>фото/гиф/видео/аудио/документ/стикер</i> или запиши <i>голосовое/видео-заметку</i> в кружке\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_post_media_wait = {
    'ru': "👩🏽‍💻 <b>Обработка</b> {0}..\n#длительность {1}мин",
    'en': "👩🏽‍💻 <b>Processing</b> {0}..\n#duration {1}min",
    'es': "👩🏽‍💻 <b>Procesando</b> {0}..\n#duración {1}min",
    'fr': "👩🏽‍💻 <b>Traitement</b> {0}..\n#durée {1}min",
    'zh': "👩🏽‍💻 <b>正在处理</b> {0}..\n#duration {1} 分钟",
    'ar': "👩🏽‍💻 <b>المعالجة</b> {0}..\n#duration {1}min",
}
l_post_media_toobig = {
    'ru': "👩🏽‍💻 Файл больше 20 Мб, загрузи меньший обьем",
    'en': "👩🏽‍💻 The file is more than 20 MB, upload a smaller volume",
    'es': "👩🏽‍💻 El archivo pesa más de 20 MB, sube un volumen menor",
    'fr': "👩🏽‍💻 Le fichier fait plus de 20 Mo, téléchargez un volume plus petit",
    'zh': "👩🏽‍💻 文件超过 20 MB，请上传较小的体积",
    'ar': "👩🏽‍💻 حجم الملف أكبر من 20 ميجا، قم بتحميل مجلد أصغر",
}
l_media_isvideonote = {
    'ru': "👩🏽‍💻 <b>Использовать</b> это квадратное видео как <b>телескоп</b> <i>(круглая видео-заметка)</i>?",
    'en': "👩🏽‍💻 <b>Use</b> this square video as a <b>telescope</b> <i>(round video note)</i>?",
    'es': "👩🏽‍💻 ¿<b>Usar</b> este vídeo cuadrado como <b>telescopio</b> <i>(nota de vídeo redonda)</i>?",
    'fr': "👩🏽‍💻 <b>Utiliser</b> cette vidéo carrée comme <b>télescope</b> <i>(note vidéo ronde)</i> ?",
    'zh': "👩🏽‍💻<b>使用</b>这个方形视频作为<b>望远镜</b><i>（圆形视频笔记）</i>？",
    'ar': "👩🏽‍💻 <b>هل تستخدم</b> هذا الفيديو المربع باعتباره <b>تلسكوبًا</b> <i>(ملاحظة فيديو مستديرة)</i>؟",
}
l_post_text = {
    'ru': "✏️ 2. <b>Введи текст</b> (<i>не забудь использовать форматирование</i>)\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 2. <b>Enter your text</b> (<i>don’t forget to use formatting</i>)\n\n(<i>or click “➡️️/Next” to skip this step</i> )",
    'es': "✏️ 2. <b>Ingresa tu texto</b> (<i>no olvides usar el formato</i>)\n\n(<i>o haz clic en “➡️️/Siguiente” para omitir este paso< /i> )",
    'fr': "✏️ 2. <b>Saisissez votre texte</b> (<i>n'oubliez pas d'utiliser le formatage</i>)\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape< /je> )",
    'zh': "✏️ 2.<b>输入您的文字</b>（<i>不要忘记使用格式</i>）\n\n（<i>或点击“➡️️/下一步”跳过此步骤< /i> )",
    'ar': "✏️ 2. <b>أدخل النص</b> (<i>لا تنس استخدام التنسيق</i>)\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة< /أنا> )",
}
l_post_text_limit = {
    'ru': "❗️ <b>Количество символов</b> текста (<i>включая форматирование</i>): <u>{0}</u> больше 1024",
    'en': "❗️ <b>Number of characters</b> of text (<i>including formatting</i>): <u>{0}</u> more than 1024",
    'es': "❗️ <b>Número de caracteres</b> de texto (<i>formato incluido</i>): <u>{0}</u> más de 1024",
    'fr': "❗️ <b>Nombre de caractères</b> du texte (<i>formatage compris</i>) : <u>{0}</u> supérieur à 1 024",
    'zh': "❗️ 文本<b>字符数</b>（<i>包括格式</i>）：<u>{0}</u> 超过 1024",
    'ar': "❗️ <b>عدد الأحرف</b> في النص (<i>بما في ذلك التنسيق</i>): <u>{0}</u> أكثر من 1024",
}
l_post_tgph = {
    'ru': "✏️ *2. Использовать загруженный <b>media</b>-контент в виде <u>предпросмотра</u> внизу поста (работает только с <i>jpg|png|gif|mp4</i>-файлами до 5Mb)?\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ *2. Use downloaded <b>media</b> content as a <u>preview</u> at the bottom of the post (only works with <i>jpg|png|gif|mp4</i> files up to 5Mb)?\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ *2. Utilice el contenido <b>media</b> descargado como una <u>vista previa</u> en la parte inferior de la publicación (solo funciona con archivos <i>jpg|png|gif|mp4</i> de hasta 5 MB) ?\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️*2. Utiliser le contenu <b>média</b> téléchargé comme <u>aperçu</u> au bas de la publication (fonctionne uniquement avec les fichiers <i>jpg|png|gif|mp4</i> jusqu'à 5 Mo) ?\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️*2。在帖子底部使用下载的<b>媒体</b>内容作为<u>预览</u>（仅适用于最大5Mb的<i>jpg|png|gif|mp4</i>文件） ?\n\n(<i>或点击“➡️️/下一步”跳过此步骤</i>)",
    'ar': "✏️*2. استخدم محتوى <b>الوسائط</b> الذي تم تنزيله ك<u>معاينة</u> أسفل المشاركة (يعمل فقط مع ملفات <i>jpg|png|gif|mp4</i> التي يصل حجمها إلى 5 ميجابايت) ?\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_post_tgph_yes = {
    'ru': "✅ Да",
    'en': "✅ Yes",
    'es': "✅ Sí",
    'fr': "✅ Oui",
    'zh': "✅ 是的",
    'ar': "✅ نعم",
}
l_post_tgph_no = {
    'ru': "☑️ Нет",
    'en': "☑️ No",
    'es': "☑️No",
    'fr': "☑️ Non",
    'zh': "☑️ 没有",
    'ar': "☑️ لا",
}
l_post_button = {
    'ru': "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 3. <b>Enter names</b> for buttons and <b>links</b> in the format (one or more; click on the example below to copy):\n\n<code>[🐳 Link | {0}]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n(<i>or click “➡️️/Next” to skip this step</i> )",
    'es': "✏️ 3. <b>Ingrese nombres</b> para botones y <b>enlaces</b> en el formato (uno o más; haga clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Enlace | {0}]\n\n[❤️ Me gusta][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i> )",
    'fr': "✏️ 3. <b>Entrez les noms</b> des boutons et des <b>liens</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Lien | {0}]\n\n[❤️ J'aime][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i> )",
    'zh': "✏️ 3. <b>输入按钮和<b>链接</b>的名称</b>，格式为（一个或多个；点击下面的示例进行复制）：\n\n<code>[🐳 链接| {0}]\n\n[❤️ 喜欢][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n(<i>或点击“➡️️/下一步”跳过此步骤</i>)",
    'ar': "✏️ 3. <b>أدخل أسماء</b> للأزرار و<b>الروابط</b> بالتنسيق (واحد أو أكثر؛ انقر على المثال أدناه للنسخ):\n\n<code>[🐳 الرابط | {0}]\n\n[❤️ لايك][🔗 | https://t.me/share/url?url={0}&text=™️]</code>\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i> )",
}
l_post_button_chn = {
    'ru': "✏️ 3. <b>Введи названия</b> для кнопок и <b>ссылки</b> в формате (одну или несколько; кликни на образец ниже, чтобы скопировать):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 3. <b>Enter names</b> for buttons and <b>links</b> in the format (one or more; click on the example below to copy):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Like][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>or click “➡️️/Next” to skip this step</i> )",
    'es': "✏️ 3. <b>Ingrese nombres</b> para botones y <b>enlaces</b> en el formato (uno o más; haga clic en el siguiente ejemplo para copiar):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ Me gusta][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i> )",
    'fr': "✏️ 3. <b>Entrez les noms</b> des boutons et des <b>liens</b> au format (un ou plusieurs ; cliquez sur l'exemple ci-dessous pour copier) :\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ J'aime][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i> )",
    'zh': "✏️ 3. <b>输入按钮和<b>链接</b>的名称</b>，格式如下（一个或多个；点击下面的示例进行复制）：\n\n<code>[🐳 B​​oost | https://t.me/{0}?boost]\n\n[❤️ 喜欢][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>或点击“➡️️/下一步”跳过此步骤</i>)",
    'ar': "✏️ 3. <b>أدخل أسماء</b> للأزرار و<b>الروابط</b> بالتنسيق (واحد أو أكثر؛ انقر على المثال أدناه للنسخ):\n\n<code>[🐳 Boost | https://t.me/{0}?boost]\n\n[❤️ لايك][🔗 | https://t.me/share/url?url={1}&text=™️]</code>\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i> )",
}
l_post_button_urlinvalid = {
    'ru': "🔗 Ссылка {0} не действительна",
    'en': "🔗 Link {0} is not valid",
    'es': "🔗 El enlace {0} no es válido",
    'fr': "🔗 Le lien {0} n'est pas valide",
    'zh': "🔗 链接 {0} 无效",
    'ar': "🔗 الرابط {0} غير صالح",
}
l_post_date = {
    'ru': "✏️ <b>Выбери дату</b> на календаре\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    'en': "✏️ <b>Select a date</b> on the calendar\n\n(<i>or click “➡️️/Next” to not specify a date</i>)",
    'es': "✏️ <b>Seleccione una fecha</b> en el calendario\n\n(<i>o haga clic en “➡️️/Siguiente” para no especificar una fecha</i>)",
    'fr': "✏️ <b>Sélectionnez une date</b> sur le calendrier\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ne pas spécifier de date</i>)",
    'zh': "✏️<b>在日历上选择日期</b>\n\n（<i>或点击“➡️️/下一步”不指定日期</i>）",
    'ar': "✏️ <b>حدد تاريخًا</b> في التقويم\n\n(<i>أو انقر على '➡️️/التالي' لعدم تحديد تاريخ</i>)",
}
l_post_timer = {
    'ru': "✏️ <b>Выбери дату</b> на календаре для <b>авто-удаления</b> поста\n\n<blockquote>или жми «➡️️/Next», чтобы не указывать дату</blockquote>",
    'en': "✏️ <b>Select a date</b> on the calendar for <b>auto-deleting</b> post\n\n(<i>or click “➡️️/Next” to not specify the date</i>)",
    'es': "✏️ <b>Seleccione una fecha</b> en el calendario para la <b>eliminación automática</b> de la publicación\n\n(<i>o haga clic en “➡️️/Siguiente” para no especificar la fecha</i >)",
    'fr': "✏️ <b>Sélectionnez une date</b> sur le calendrier pour la <b>suppression automatique</b> de la publication\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ne pas spécifier la date</i >)",
    'zh': "✏️ 在日历上<b>选择日期</b><b>自动删除</b>帖子\n\n（<i>或点击“➡️️/下一步”不指定日期</i >)",
    'ar': "✏️ <b>حدد تاريخًا</b> في التقويم <b>للحذف التلقائي</b> لمنشور\n\n(<i>أو انقر على '➡️️/التالي' لعدم تحديد التاريخ</i >)",
}
l_post_window = {
    'ru': "✏️ *<b>Введи</b> текст для <i>диалогового окна</i> при нажатии на <u>кнопки</u> <b>поста</b>\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ *<b>Enter</b> text for the <i>dialog box</i> when clicking the <u>button</u> <b>post</b>\n\n(<i>or click '➡️️/Next' to skip this step</i>)",
    'es': "✏️ *<b>Ingrese</b> texto para el <i>cuadro de diálogo</i> al hacer clic en el <u>botón</u> <b>publicación</b>\n\n(<i>o haga clic en '➡️/Siguiente' para omitir este paso</i>)",
    'fr': "✏️ *<b>Entrez</b> le texte pour la <i>boîte de dialogue</i> lorsque vous cliquez sur le <u>bouton</u> <b>publier</b>\n\n(<i>ou cliquez sur '➡️️/Suivant' pour ignorer cette étape</i>)",
    'zh': "✏️ *点击<u>按钮</u>时<b>在<i>对话框</i>中输入</b>文本<b>发布</b>\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ *<b>أدخل</b> نص <i>مربع الحوار</i> عند النقر فوق الزر <u>الزر</u> <b>النشر</b>\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_post_window_limit = {
    'ru': "❗️ <b>Количество символов</b> диалогового окна: <u>{0}</u> больше допустимых 200",
    'en': "❗️ <b>Number of characters</b> of the dialog box: <u>{0}</u> more than the allowed 200",
    'es': "❗️ <b>Número de caracteres</b> del cuadro de diálogo: <u>{0}</u> más de los 200 permitidos",
    'fr': "❗️ <b>Nombre de caractères</b> de la boîte de dialogue : <u>{0}</u> supérieur aux 200 autorisés",
    'zh': "❗️ 对话框的<b>字符数</b>：<u>{0}</u>超过允许的200个",
    'ar': "❗️ <b>عدد الأحرف</b> في مربع الحوار: <u>{0}</u> أكثر من 200 حرف المسموح به",
}
l_post_finish = {
    'ru': "✅ <b>Пост готов</b>\n\n<i>Нажми «➡️️/Next», чтобы подтвердить, а затем на кнопку: [🔗 Публикация]</i>",
    'en': "✅ <b>The post is ready</b>\n\n<i>Click “➡️️/Next” to confirm, and then click the button: [🔗 Publish]</i>",
    'es': "✅ <b>La publicación está lista</b>\n\n<i>Haga clic en “➡️️/Siguiente” para confirmar y luego haga clic en el botón: [🔗 Publicar]</i>",
    'fr': "✅ <b>La publication est prête</b>\n\n<i>Cliquez sur « ➡️️/Suivant » pour confirmer, puis cliquez sur le bouton : [🔗 Publier]</i>",
    'zh': "✅ <b>帖子已准备就绪</b>\n\n<i>点击“➡️️/下一步”确认，然后点击按钮：[🔗发布]</i>",
    'ar': "✅ <b>المنشور جاهز</b>\n\n<i>انقر على “➡️️/التالي” للتأكيد، ثم انقر على الزر: [🔗 نشر]</i>",
}
l_switch_pm_text = {
    'ru': "🔗 Создать пост с кнопкой",
    'en': "🔗 Create a post with a button",
    'es': "🔗 Crea una publicación con un botón",
    'fr': "🔗 Créer une publication avec un bouton",
    'zh': "🔗 使用按钮创建帖子",
    'ar': "🔗 إنشاء مشاركة بزر",
}
l_post_new = {
    'ru': "⛰ Создать",
    'en': "⛰ Create",
    'es': "⛰ Crear",
    'fr': "⛰ Créer",
    'zh': "⛰ 创建",
    'ar': "⛰ إنشاء",
}
l_post_delete = {
    'ru': "🚫 Удалить",
    'en': "🚫Delete",
    'es': "🚫Eliminar",
    'fr': "🚫Supprimer",
    'zh': "🚫删除",
    'ar': "🚫حذف",
}
l_post_change = {
    'ru': "♻️ Изменить",
    'en': "♻️ Edit",
    'es': "♻️ Editar",
    'fr': "♻️ Modifier",
    'zh': "♻️编辑",
    'ar': "♻️ تحرير",
}
l_post_creation = {
    'ru': "<b>Дата создания</b>",
    'en': "<b>Date of creation</b>",
    'es': "<b>Fecha de creación</b>",
    'fr': "<b>Date de création</b>",
    'zh': "<b>创建日期</b>",
    'ar': "<b>تاريخ الإنشاء</b>",
}

l_post_publish = {
    'ru': "🔗 Публикация",
    'en': "🔗 Post",
    'es': "🔗 Publicar",
    'fr': "🔗 Publier",
    'zh': "🔗 发帖",
    'ar': "🔗 مشاركة",
}
l_post_pub = {
    'ru': "👩🏽‍💻 Пост опубликован",
    'en': "👩🏽‍💻 Post published",
    'es': "👩🏽‍💻 Publicación publicada",
    'fr': "👩🏽‍💻 Article publié",
    'zh': "👩🏽‍💻 帖子已发布",
    'ar': "👩🏽‍💻 تم نشر المنشور",
}
l_post_error = {
    'ru': "👩🏽‍💻 Ошибка опубликации",
    'en': "👩🏽‍💻 Posting error",
    'es': "👩🏽‍💻 Error de publicación",
    'fr': "👩🏽‍💻 Erreur de publication",
    'zh': "👩🏽‍💻 发帖错误",
    'ar': "👩🏽‍💻 خطأ في النشر",
}
l_post_btn_answer = {
    'ru': "✅ <b>Пользователь</b> <b>{0}</b> (username={1}, id={2}) <i>нажал</i> на [<b>{3}</b>] в посте #<u>{4}</u>",
    'en': "✅ <b>User</b> <b>{0}</b> (username={1}, id={2}) <i>clicked</i> on [<b>{3}</ b>] in post #<u>{4}</u>",
    'es': "✅ <b>Usuario</b> <b>{0}</b> (nombre de usuario={1}, id={2}) <i>hizo clic</i> en [<b>{3}</ b>] en la publicación #<u>{4}</u>",
    'fr': "✅ <b>Utilisateur</b> <b>{0}</b> (nom d'utilisateur={1}, id={2}) <i>cliqué</i> sur [<b>{3}</ b>] dans le message n°<u>{4}</u>",
    'zh': "✅ <b>用户</b> <b>{0}</b>（用户名={1}，id={2}）<i>点击了</i> [<b>{3}</ b>] 帖子#<u>{4}</u>",
    'ar': "✅ <b>المستخدم</b> <b>{0}</b> (اسم المستخدم={1}, المعرف={2}) <i>النقر</i> على [<b>{3}</ ب>] في المشاركة #<u>{4}</u>",
}
l_post_datetime = {
    'ru': "<b>Дата</b>",
    'en': "<b>Date</b>",
    'es': "<b>Fecha</b>",
    'fr': "<b>Date</b>",
    'zh': "<b>日期</b>",
    'ar': "<b>التاريخ</b>",
}
l_post_preview = {
    'ru': "<b>Превью</b>",
    'en': "<b>Preview</b>",
    'es': "<b>Vista previa</b>",
    'fr': "<b>Aperçu</b>",
    'zh': "<b>预览</b>",
    'ar': "<b>معاينة</b>",
}
l_post_buttons = {
    'ru': "<b>Кнопки</b>",
    'en': "<b>Buttons</b>",
    'es': "<b>Botones</b>",
    'fr': "<b>Boutons</b>",
    'zh': "<b>按钮</b>",
    'ar': "<b>الأزرار</b>",
}
l_post_pins = {
    'ru': "<b>Закреп</b>",
    'en': "<b>Secure</b>",
    'es': "<b>Seguro</b>",
    'fr': "<b>Sécurisé</b>",
    'zh': "<b>安全</b>",
    'ar': "<b>آمن</b>",
}

l_btn = {
    'ru': "кнопки",
    'en': "buttons",
    'es': "botones",
    'fr': "boutons",
    'zh': "纽扣",
    'ar': "أزرار",
}
l_default = {
    'ru': "по умолчанию",
    'en': "default",
    'es': "por defecto",
    'fr': "défaut",
    'zh': "默认",
    'ar': "تقصير",
}
l_silence = {
    'ru': "тихо",
    'en': "quiet",
    'es': "tranquilo",
    'fr': "calme",
    'zh': "安静的",
    'ar': "هادئ",
}
l_pin = {
    'ru': "закреп",
    'en': "secured",
    'es': "asegurado",
    'fr': "sécurisé",
    'zh': "安全的",
    'ar': "مؤمن",
}
l_preview = {
    'ru': "превью",
    'en': "preview",
    'es': "avance",
    'fr': "aperçu",
    'zh': "预览",
    'ar': "معاينة",
}
l_spoiler = {
    'ru': "спойлер",
    'en': "spoiler",
    'es': "revelación",
    'fr': "divulgacher",
    'zh': "剧透",
    'ar': "المفسد",
}
l_podcast = {
    'ru': "подкаст",
    'en': "podcast",
    'es': "podcast",
    'fr': "podcast",
    'zh': "播客",
    'ar': "تدوين صوتي",
}
l_album = {
    'ru': "альбом",
    'en': "album",
    'es': "álbum",
    'fr': "album",
    'zh': "专辑",
    'ar': "الألبوم",
}
l_gallery = {
    'ru': "галерея",
    'en': "gallery",
    'es': "galería",
    'fr': "galerie",
    'zh': "画廊",
    'ar': "صالة عرض",
}
l_format = {
    'ru': "формат",
    'en': "format",
    'es': "formato",
    'fr': "format",
    'zh': "格式",
    'ar': "شكل",
}
l_reaction = {
    'ru': "реакция",
    'en': "реакция",
    'es': "formato",
    'fr': "format",
    'zh': "格式",
    'ar': "شكل",
}
l_effect = {
    'ru': "эффект",
    'en': "реакция",
    'es': "formato",
    'fr': "format",
    'zh': "格式",
    'ar': "شكل",
}

l_blog = {
    'ru': "блог",
    'en': "blog",
    'es': "blog",
    'fr': "blog",
    'zh': "博客",
    'ar': "مدونة",
}
l_web = {
    'ru': "веб",
    'en': "web",
    'es': "web",
    'fr': "la toile",
    'zh': "网络",
    'ar': "الويب",
}
l_notice = {
    'ru': "нотис",
    'en': "notice",
    'es': "aviso",
    'fr': "avis",
    'zh': "注意",
    'ar': "يلاحظ",
}
l_window = {
    'ru': "окно",
    'en': "window",
    'es': "ventana",
    'fr': "fenêtre",
    'zh': "窗户",
    'ar': "نافذة او شباك",
}
l_remoji = {
    'ru': "Эмоджи",
    'en': "Emoji",
    'es': "Emojis",
    'fr': "Émoji",
    'zh': "表情符号",
    'ar': "الرموز التعبيرية",
}
l_theme = {
    'ru': "Тема",
    'en': "Topic",
    'es': "Tema",
    'fr': "Sujet",
    'zh': "话题",
    'ar': "عنوان",
}
l_destruct = {
    'ru': "Самоуничтожение контента",
    'en': "Self-destruct photo/video",
    'es': "Foto/video de autodestrucción",
    'fr': "Photo/vidéo d'autodestruction",
    'zh': "自毁照片/视频",
    'ar': "صورة/فيديو التدمير الذاتي",
}
l_tag = {
    'ru': "@tag",
    'en': "@tag",
    'es': "@etiqueta",
    'fr': "@étiqueter",
    'zh': "@标签",
    'ar': "@بطاقة شعار",
}
l_via = {
    'ru': "@via",
    'en': "@via",
    'es': "@a través de",
    'fr': "@via",
    'zh': "@通过",
    'ar': "@عبر",
}

l_buttons_text = {
    'ru': "👩🏽‍💻 Режим [✅ кнопки] доступен, если создана хотя бы 1 кнопка при создании поста",
    'en': "👩🏽‍💻 [✅ buttons] mode is available if at least 1 button is created when creating a post",
    'es': "👩🏽‍💻 El modo [✅ botones] está disponible si se crea al menos 1 botón al crear una publicación",
    'fr': "👩🏽‍💻 Le mode [✅ boutons] est disponible si au moins 1 bouton est créé lors de la création d'une publication",
    'zh': "👩🏽‍💻 创建帖子时至少创建 1 个按钮即可使用 [✅ 按钮] 模式",
    'ar': "👩🏽‍💻 يتوفر وضع [✔ الأزرار] في حالة إنشاء زر واحد على الأقل عند إنشاء منشور",
}
l_preview_text = {
    'ru': "👩🏽‍💻 Режим [✅ превью] используется с jpg|png|gif|mp4-файлами до 5Mb",
    'en': "👩🏽‍💻 [✅ preview] mode is used with jpg|png|gif|mp4 files up to 5Mb",
    'es': "👩🏽‍💻 El modo [✅ vista previa] se usa con archivos jpg|png|gif|mp4 de hasta 5Mb",
    'fr': "👩🏽‍💻 Le mode [✅ aperçu] est utilisé avec les fichiers jpg|png|gif|mp4 jusqu'à 5 Mo",
    'zh': "👩🏽‍💻 [✅预览]模式适用于最大5Mb的jpg|png|gif|mp4文件",
    'ar': "👩🏽‍💻 يُستخدم وضع [✅ المعاينة] مع ملفات jpg|png|gif|mp4 التي يصل حجمها إلى 5 ميجابايت",
}
l_gallery_text = {
    'ru': "👩🏽‍💻 Режим [✅ галерея] доступен для 2 и более медиа файлов",
    'en': "👩🏽‍💻 [✅ gallery] mode is available for 2 or more media files",
    'es': "👩🏽‍💻 El modo [✅ galería] está disponible para 2 o más archivos multimedia",
    'fr': "👩🏽‍💻 Le mode [✅ galerie] est disponible pour 2 fichiers multimédias ou plus",
    'zh': "👩🏽‍💻 [✅ 图库] 模式适用于 2 个或更多媒体文件",
    'ar': "👩🏽‍💻 وضع ​​[✔ المعرض] متاح لملفين وسائط أو أكثر",
}
l_spoiler_text = {
    'ru': "👩🏽‍💻 Режим [✅ спойлер] доступен для photo/gif/video контента",
    'en': "👩🏽‍💻 [✅ spoiler] mode is available for photo/gif/video content",
    'es': "👩🏽‍💻 El modo [✅ spoiler] está disponible para contenido de foto/gif/video",
    'fr': "👩🏽‍💻 Le mode [✅ spoiler] est disponible pour le contenu photo/gif/vidéo",
    'zh': "👩🏽‍💻 [✅剧透]模式适用于照片/gif/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ المفسد] متاح لمحتوى الصور / GIF / الفيديو",
}
l_podcast_call = {
    'ru': "👩🏽‍💻 Режим [✅ подкаст] доступен для audio/voice/video контента или youtube-ссылок в тексте",
    'en': "👩🏽‍💻 [✅ podcast] mode is available for audio/voice/video content",
    'es': "👩🏽‍💻 El modo [✅ podcast] está disponible para contenido de audio/voz/vídeo",
    'fr': "👩🏽‍💻 Le mode [✅ podcast] est disponible pour le contenu audio/voix/vidéo",
    'zh': "👩🏽‍💻 [✅ 播客] 模式可用于音频/语音/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ البودكاست] متاح لمحتوى الصوت/الصوت/الفيديو",
}
l_window_text = {
    'ru': "👩🏽‍💻 Режим [окно] доступен для постов с кнопками без ссылок",
    'en': "👩🏽‍💻 [Window] mode is available for posts with buttons without links",
    'es': "👩🏽‍💻 El modo [Ventana] está disponible para publicaciones con botones sin enlaces",
    'fr': "👩🏽‍💻 Le mode [Fenêtre] est disponible pour les publications avec des boutons sans liens",
    'zh': "👩🏽‍💻 [窗口]模式适用于带有按钮但没有链接的帖子",
    'ar': "👩🏽‍💻 وضع ​​[النافذة] متاح للمشاركات التي تحتوي على أزرار بدون روابط",
}
l_tag_text = {
    'ru': "👩🏽‍💻 Режим [✅ @tag] доступен для текста без режима @via-бот",
    'en': "👩🏽‍💻 [✅ @tag] mode is available for text without @via-bot mode",
    'es': "👩🏽‍💻 El modo [✅ @tag] está disponible para texto sin el modo @via-bot",
    'fr': "👩🏽‍💻 [✅ Le mode @tag] est disponible pour le texte sans le mode @via-bot",
    'zh': "👩🏽‍💻 [✅ @tag] 模式适用于没有 @via-bot 模式的文本",
    'ar': "👩🏽‍💻 وضع ​​[✅ @tag] متاح للنص بدون وضع @via-bot",
}
l_destruct_text = {
    'ru': "👩🏽‍💻 Режим [✅ Самоуничтожение] доступен для фото/видео/голосовое/телескоп-контента без режима @via-бот",
    'en': "👩🏽‍💻 [✅ Self-destruction] mode is available for photo/video content without @via-bot mode",
    'es': "👩🏽‍💻 [✅ El modo Autodestrucción] está disponible para contenido de foto/vídeo sin el modo @via-bot",
    'fr': "👩🏽‍💻 Le mode [✅ Autodestruction] est disponible pour le contenu photo/vidéo sans le mode @via-bot",
    'zh': "👩🏽‍💻 [✅自毁]模式适用于没有@via-bot模式的照片/视频内容",
    'ar': "👩🏽‍💻 وضع ​​[✅ التدمير الذاتي] متاح لمحتوى الصور/الفيديو بدون وضع @via-bot",
}
l_post_has_restricted = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> отправки видео-заметки/голосового для premium-аккаунта! В настройках <b>[Конфиденциальность]</b> добавь @{0} в <i>исключения</i> для <b>[Голосовые сообщения]</b>, чтобы отобразить видео-заметку/голосовое",
    'en': "👩🏽‍💻 You have a premium account! In <b>[Privacy]</b> settings, add @{0} to <i>exceptions</i> for <b>[Voice messages]</b> to display video note/voice",
    'es': "👩🏽‍💻 ¡Tienes una cuenta premium! En la configuración de <b>[Privacidad]</b>, agregue @{0} a las <i>excepciones</i> para <b>[Mensajes de voz]</b> para mostrar notas de video/voz.",
    'fr': "👩🏽‍💻 Vous disposez d'un compte premium ! Dans les paramètres <b>[Confidentialité]</b>, ajoutez @{0} aux <i>exceptions</i> pour <b>[Messages vocaux]</b> afin d'afficher la note vidéo/la voix.",
    'zh': "👩🏽‍💻 您有一个高级帐户！在<b>[隐私]</b>设置中，将@{0}添加到<b>[语音消息]</b>的<i>例外</i>中，以显示视频注释/语音",
    'ar': "👩🏽‍💻 لديك حساب مميز! في إعدادات <b>[الخصوصية]</b>، أضف @{0} إلى <i>الاستثناءات</i> لـ <b>[الرسائل الصوتية]</b> لعرض ملاحظة/صوت الفيديو",
}
l_post_tz = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 La <b>zona horaria</b> de la geolocalización está configurada\n\n🕐 Hora <b>actual</b>: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Le fuseau horaire</b> de la géolocalisation est défini\n\n🕐 <b>Heure actuelle</b> : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 地理位置的<b>时区</b>已设置\n\n🕐<b>当前</b>时间：<u>{0}</u>（{1}{2} GMT）",
    'ar': "📍 تم ضبط <b>المنطقة الزمنية</b> للموقع الجغرافي\n\n🕐 التوقيت <b>الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت جرينتش)",
}
l_post_time_future = {
    'ru': "🕒 <b>Укажи</b> дату и время в будущем",
    'en': "🕒 <b>Specify</b> a date and time in the future",
    'es': "🕒 <b>Especifique</b> una fecha y hora en el futuro",
    'fr': "🕒 <b>Spécifiez</b> une date et une heure dans le futur",
    'zh': "🕒<b>指定</b>未来的日期和时间",
    'ar': "🕒 <b>حدد</b> التاريخ والوقت في المستقبل",
}
l_me = {
    'ru': "👤 Себе",
    'en': "👤 Yourself",
    'es': "👤 Tú mismo",
    'fr': "👤 Vous-même",
    'zh': "👤 你自己",
    'ar': "👤 نفسك",
}
l_all = {
    'ru': "👥 Всем",
    'en': "👥 Everyone",
    'es': "👥 Todos",
    'fr': "👥 Tout le monde",
    'zh': "👥 大家",
    'ar': "👥 الجميع",
}
l_usr = {
    'ru': "👩🏽‍💻 Юзер",
    'en': "👩🏽‍💻 User",
    'es': "👩🏽‍💻 Usuario",
    'fr': "👩🏽‍💻 Utilisateur",
    'zh': "👩🏽‍💻 用户",
    'ar': "👩🏽‍💻 المستخدم",
}
l_username = {
    'ru': "👩🏽‍💻 @username",
    'en': "👩🏽‍💻 @username",
    'es': "👩🏽‍💻 @username",
    'fr': "👩🏽‍💻 @username",
    'zh': "👩🏽‍💻 @username",
    'ar': "👩🏽‍💻 @username",
}
l_bot = {
    'ru': "👩🏽‍💻 Бот",
    'en': "👩🏽‍💻 Bot",
    'es': "👩🏽‍💻 robot",
    'fr': "👩🏽‍💻 Bot",
    'zh': "👩🏽‍💻 机器人",
    'ar': "👩🏽‍💻 بوت",
}
l_channel = {
    'ru': "👩🏽‍💻 Канал",
    'en': "👩🏽‍💻 Channel",
    'es': "👩🏽‍💻 Canal",
    'fr': "👩🏽‍💻 Chaîne",
    'zh': "👩🏽‍💻频道",
    'ar': "👩🏽‍💻 القناة",
}
l_group = {
    'ru': "👩🏽‍💻 Группа",
    'en': "👩🏽‍💻 Group",
    'es': "👩🏽‍💻 Grupo",
    'fr': "👩🏽‍💻 Groupe",
    'zh': "👩🏽‍💻组",
    'ar': "👩🏽‍💻 المجموعة",
}

l_user = {
    'ru': "👩🏽‍💻 Пользователи",
    'en': "👩🏽‍💻 Users",
    'es': "👩🏽‍💻 Usuarios",
    'fr': "👩🏽‍💻 Utilisateurs",
    'zh': "👩🏽‍💻 用户",
    'ar': "👩🏽‍💻 المستخدمين",
}
l_ids = {
    'ru': "🙌🏽 По id",
    'en': "🙌🏽 By id",
    'es': "🙌🏽 Por identificación",
    'fr': "🙌🏽 Par pièce d'identité",
    'zh': "🙌🏽 通过 ID",
    'ar': "🙌🏽 عن طريق الهوية",
}
l_recipient = {
    'ru': "👩🏽‍💻 <b>Выбери</b> получателя",
    'en': "👩🏽‍💻 <b>Choose</b> recipient",
    'es': "👩🏽‍💻 <b>Elegir</b> destinatario",
    'fr': "👩🏽‍💻 <b>Choisissez</b> le destinataire",
    'zh': "👩🏽‍💻<b>选择</b>收件人",
    'ar': "👩🏽‍💻 <b>اختر</b> المستلم",
}
l_enter = {
    'ru': "👩🏽‍💻 <b>Введи</b> Ids получателей через <i>пробелы/раздели</i>",
    'en': "👩🏽‍💻 <b>Enter</b> Recipients' Ids separated by <i>spaces/separate</i>",
    'es': "👩🏽‍💻 <b>Ingrese</b> los ID de los destinatarios separados por <i>espacios/separados</i>",
    'fr': "👩🏽‍💻 <b>Entrez</b> les identifiants des destinataires séparés par <i>espaces/séparés</i>",
    'zh': "👩🏽‍💻<b>输入</b>收件人 ID，以<i>空格/分隔</i>分隔",
    'ar': "👩🏽‍💻 <b>أدخل</b> معرفات المستلمين مفصولة <i>بمسافات/منفصلة</i>",
}
l_enter_username = {
    'ru': "👩🏽‍💻 <b>Введи</b> @username получателя",
    'en': "👩🏽‍💻 <b>Enter</b> @username of the recipient",
    'es': "👩🏽‍💻 <b>Ingrese</b> @username del destinatario",
    'fr': "👩🏽‍💻 <b>Entrez</b> @username utilisateur du destinataire",
    'zh': "👩🏽‍💻<b>输入</b>收件人的@username",
    'ar': "👩🏽‍💻 <b>أدخل</b> @username للمستلم",
}
l_post_time_zone = {
    'ru': "📍 <b>Часовой пояс</b> геопозиции установлен\n\n🕐 <b>Текущее</b> время: <u>{0}</u> ({1}{2} по Гринвичу)",
    'en': "📍 <b>Time zone</b> of the geolocation is set\n\n🕐 <b>Current</b> time: <u>{0}</u> ({1}{2} GMT)",
    'es': "📍 La <b>zona horaria</b> de la geolocalización está configurada\n\n🕐 Hora <b>actual</b>: <u>{0}</u> ({1}{2} GMT)",
    'fr': "📍 <b>Le fuseau horaire</b> de la géolocalisation est défini\n\n🕐 <b>Heure actuelle</b> : <u>{0}</u> ({1}{2} GMT)",
    'zh': "📍 地理位置的<b>时区</b>已设置\n\n🕐<b>当前</b>时间：<u>{0}</u>（{1}{2} GMT）",
    'ar': "📍 تم ضبط <b>المنطقة الزمنية</b> للموقع الجغرافي\n\n🕐 التوقيت <b>الحالي</b>: <u>{0}</u> ({1}{2} بتوقيت جرينتش)",
}
l_broadcast_plan = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована",
    'en': "👩🏽‍💻 <b>Done!</b> Mailing scheduled",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Envío programado",
    'fr': "👩🏽‍💻 <b>Fait !</b> Mailing prévu",
    'zh': "👩🏽‍💻 <b>完成！</b> 已安排邮寄",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة المراسلة",
}
l_broadcast_plan_bot = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Рассылка запланирована в @{0}",
    'en': "👩🏽‍💻 <b>Done!</b> Newsletter scheduled at @{0}",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Boletín programado en @{0}",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Newsletter programmée à @{0}",
    'zh': "👩🏽‍💻 <b>完成！</b> 时事通讯定于@{0}",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة النشرة الإخبارية في @{0}",
}
l_broadcast_plan_ent = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Публикация запланирована: {0}",
    'en': "👩🏽‍💻 <b>Done!</b> Publication scheduled: {0}",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Publicación programada: {0}",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Publication prévue : {0}",
    'zh': "👩🏽‍💻<b>完成！</b>计划发布：{0}",
    'ar': "👩🏽‍💻 <b>تم!</b> تمت جدولة النشر: {0}",
}
l_broadcast_start = {
    'ru': "📧 <b>Старт</b> рассылки..\n#длительность {0}min",
    'en': "📧 <b>Start</b> mailings..\n#duration {0}min",
    'es': "📧 <b>Iniciar</b> envíos de correo..\n#duración {0}min",
    'fr': "📧 <b>Démarrer</b> les mailings..\n#durée {0}min",
    'zh': "📧<b>开始</b>邮件..\n#duration {0}分钟",
    'ar': "📧 <b>ابدأ</b> المراسلات البريدية..\n#duration {0}min",
}
l_broadcast_process = {
    'ru': "📧 <b>Рассылка</b>..{0}%",
    'en': "📧 <b>Newsletter</b>..{0}%",
    'es': "📧 <b>Boletín</b>..{0}%",
    'fr': "📧 <b>Newsletter</b>..{0}%",
    'zh': "📧<b>时事通讯</b>..{0}%",
    'ar': "📧 <b>النشرة الإخبارية</b>..{0}%",
}
l_broadcast_finish = {
    'ru': "🏁 <b>Рассылка</b> завершена\n\n📧 <b>Количество</b> пользователей, получивших сообщение: <u>{0}</u>",
    'en': "🏁 <b>Mail mailing</b> completed\n\n📧 <b>Number</b> of users who received the message: <u>{0}</u>",
    'es': "🏁 <b>Envío de correo</b> completado\n\n📧 <b>Número</b> de usuarios que recibieron el mensaje: <u>{0}</u>",
    'fr': "🏁 <b>Envoi du courrier</b> terminé\n\n📧 <b>Nombre</b> d'utilisateurs ayant reçu le message : <u>{0}</u>",
    'zh': "🏁 <b>邮件发送</b>已完成\n\n📧 收到消息的<b>用户数量</b>：<u>{0}</u>",
    'ar': "🏁 <b>اكتمل إرسال البريد</b>\n\n📧 <b>عدد</b> المستخدمين الذين تلقوا الرسالة: <u>{0}</u>",
}
l_post_del_timer = {
    'ru': "👩🏽‍💻 <b>Пост</b> #{0} удален по таймеру в {1}",
    'en': "👩🏽‍💻 <b>Post</b> #{0} deleted by timer in {1}",
    'es': "👩🏽‍💻 <b>Publicación</b> #{0} eliminada por el temporizador en {1}",
    'fr': "👩🏽‍💻 <b>Post</b> #{0} supprimé par minuterie dans {1}",
    'zh': "👩🏽‍💻 <b>帖子</b> #{0} 已被计时器在 {1} 删除",
    'ar': "👩🏽‍💻 <b>المنشور</b> #{0} تم حذفه بواسطة المؤقت في {1}",
}

l_generate_calendar_time = {
    'ru': "🕒 <b>Отправь время</b> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "🕒 <b>Send the time</b> of the post to {0} in {1} format. Current time: <u>{2}</u> ({3} Greenwich Mean Time)\n\n📍 We came to <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "🕒 <b>Envía la hora</b> de la publicación a {0} en formato {1}. Hora actual: <u>{2}</u> ({3} hora media de Greenwich)\n\n📍 Vinimos a la <b>geolocalización</b> para <i>automáticamente</i> determinar la zona horaria",
    'fr': "🕒 <b>Envoyer l'heure</b> de la publication à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} heure moyenne de Greenwich)\n\n📍 Nous sommes passés à la <b>géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    'zh': "🕒 <b>以 {1} 格式将帖子时间发送到 {0}。当前时间：<u>{2}</u>（{3}格林威治标准时间）\n\n📍我们来到<b>地理位置</b>来<i>自动</i>确定时区",
    'ar': "🕒 <b>أرسل وقت</b> المنشور إلى {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} توقيت غرينتش)\n\n📍 وصلنا إلى <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}
l_time_timer = {
    'ru': "🕒 <b>Отправь время</b> <i>авто-удаления</i> поста на {0} в формате {1}. Текущее время: <u>{2}</u> ({3} по Гринвичу)\n\n📍 Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "🕒 <b>Send the time</b> <i>auto-deleting</i> post to {0} in {1} format. Current time: <u>{2}</u> ({3} Greenwich Mean Time)\n\n📍 We came to <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "🕒 <b>Envía la publicación de <i>eliminación automática</i> de la hora</b> a {0} en formato {1}. Hora actual: <u>{2}</u> ({3} hora media de Greenwich)\n\n📍 Vinimos a la <b>geolocalización</b> para <i>automáticamente</i> determinar la zona horaria",
    'fr': "🕒 <b>Envoyer l'heure</b> à la publication <i>à suppression automatique</i> à {0} au format {1}. Heure actuelle : <u>{2}</u> ({3} heure moyenne de Greenwich)\n\n📍 Nous sommes passés à la <b>géolocalisation</b> pour <i>déterminer automatiquement</i> le fuseau horaire",
    'zh': "🕒 <b>以 {1} 格式将时间</b><i>自动删除</i>帖子发送到 {0}。当前时间：<u>{2}</u>（{3}格林威治标准时间）\n\n📍我们来到<b>地理位置</b>来<i>自动</i>确定时区",
    'ar': "🕒 <b>أرسل وقت</b> <i>الحذف التلقائي</i> للمنشور إلى {0} بتنسيق {1}. الوقت الحالي: <u>{2}</u> ({3} توقيت غرينتش)\n\n📍 وصلنا إلى <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}
l_month_1 = {
    'ru': "Янв",
    'en': "Jan",
    'es': "Ene",
    'fr': "Jan",
    'zh': "扬",
    'ar': "يناير",
}
l_month_2 = {
    'ru': "Фев",
    'en': "Feb",
    'es': "Feb",
    'fr': "Fév",
    'zh': "二月",
    'ar': "فبراير",
}
l_month_3 = {
    'ru': "Мар",
    'en': "Mar",
    'es': "Mar",
    'fr': "Mar",
    'zh': "三月",
    'ar': "مارس",
}
l_month_4 = {
    'ru': "Апр",
    'en': "Apr",
    'es': "Abr",
    'fr': "Avr",
    'zh': "四月",
    'ar': "أبريل",
}
l_month_5 = {
    'ru': "Май",
    'en': "Maybe",
    'es': "Tal vez",
    'fr': "Peut être",
    'zh': "或许",
    'ar': "ربما",
}
l_month_6 = {
    'ru': "Июн",
    'en': "June",
    'es': "Junio",
    'fr': "Juin",
    'zh': "六月",
    'ar': "يونيو",
}
l_month_7 = {
    'ru': "Июл",
    'en': "July",
    'es': "Julio",
    'fr': "Juillet",
    'zh': "七月",
    'ar': "يوليو",
}
l_month_8 = {
    'ru': "Авг",
    'en': "Aug",
    'es': "Ago",
    'fr': "Août",
    'zh': "八月",
    'ar': "أغسطس",
}
l_month_9 = {
    'ru': "Сен",
    'en': "You",
    'es': "Tú",
    'fr': "Toi",
    'zh': "你",
    'ar': "أنت",
}
l_month_10 = {
    'ru': "Окт",
    'en': "Oct",
    'es': "Oct",
    'fr': "Octobre",
    'zh': "十月",
    'ar': "أكتوبر",
}
l_month_11 = {
    'ru': "Ноя",
    'en': "But I",
    'es': "Pero yo",
    'fr': "Mais je",
    'zh': "但是我",
    'ar': "لكن أنا",
}
l_month_12 = {
    'ru': "Дек",
    'en': "Dec",
    'es': "Dic",
    'fr': "Déc",
    'zh': "十二月",
    'ar': "ديسمبر",
}

l_weekday_1 = {
    'ru': "пн",
    'en': "mon",
    'es': "lun",
    'fr': "lun",
    'zh': "周一",
    'ar': "الاثنين",
}
l_weekday_2 = {
    'ru': "вт",
    'en': "tue",
    'es': "mar",
    'fr': "mar",
    'zh': "星期二",
    'ar': "الثلاثاء",
}
l_weekday_3 = {
    'ru': "ср",
    'en': "sr",
    'es': "señor",
    'fr': "sr",
    'zh': "高级",
    'ar': "ريال سعودى",
}
l_weekday_4 = {
    'ru': "чт",
    'en': "ch",
    'es': "ch",
    'fr': "ch",
    'zh': "ch",
    'ar': "الفصل",
}
l_weekday_5 = {
    'ru': "пт",
    'en': "pt",
    'es': "pt",
    'fr': "pt",
    'zh': "点",
    'ar': "نقطة",
}
l_weekday_6 = {
    'ru': "сб",
    'en': "coll",
    'es': "colear",
    'fr': "coll",
    'zh': "科尔",
    'ar': "كول",
}
l_weekday_7 = {
    'ru': "вс",
    'en': "vs",
    'es': "vs",
    'fr': "contre",
    'zh': "与",
    'ar': "ضد",
}

l_inline_demo = {
    'ru': "демо проектов",
    'en': "about projects",
    'es': "sobre proyectos",
    'fr': "à propos des projets",
    'zh': "关于项目",
    'ar': "حول المشاريع",
}
l_inline_bot = {
    'ru': "нейро-конструктор ботов",
    'en': "bot constructor",
    'es': "constructor de robots",
    'fr': "constructeur de robots",
    'zh': "机器人构造函数",
    'ar': "منشئ الروبوت",
}
l_inline_post = {
    'ru': "приватный постинг",
    'en': "private posts",
    'es': "publicaciones privadas",
    'fr': "messages privés",
    'zh': "私人帖子",
    'ar': "المشاركات الخاصة",
}
l_inline_media = {
    'ru': "публичные медиа",
    'en': "public media",
    'es': "medios publicos",
    'fr': "médias publics",
    'zh': "公共媒体",
    'ar': "وسائل الإعلام العامة",
}
l_inline_channel = {
    'ru': "администрирование каналов",
    'en': "channel administration",
    'es': "administración del canal",
    'fr': "administration des canaux",
    'zh': "渠道管理",
    'ar': "إدارة القناة",
}
l_inline_group = {
    'ru': "модерация групп",
    'en': "moderation group",
    'es': "grupo de moderación",
    'fr': "groupe de modération",
    'zh': "审核组",
    'ar': "مجموعة الاعتدال",
}
l_inline_find = {
    'ru': "премиум поиск",
    'en': "premium search",
    'es': "búsqueda premium",
    'fr': "recherche premium",
    'zh': "高级搜索",
    'ar': "بحث متميز",
}
l_inline_ai = {
    'ru': "нейро-генерация контента",
    'en': "neural network",
    'es': "red neuronal",
    'fr': "réseau neuronal",
    'zh': "神经网络",
    'ar': "الشبكة العصبية",
}
l_inline_ads = {
    'ru': "телеграм реклама",
    'en': "advertisement",
    'es': "anuncio",
    'fr': "publicité",
    'zh': "广告",
    'ar': "إعلان",
}
l_inline_vpn = {
    'ru': "vpn настройки",
    'en': "VPN",
    'es': "Vpn",
    'fr': "VPN",
    'zh': "VPN",
    'ar': "VPN",
}
l_inline_sticker = {
    'ru': "стикеры/эмоджи",
    'en': "VPN",
    'es': "Vpn",
    'fr': "VPN",
    'zh': "VPN",
    'ar': "VPN",
}
l_inline_target = {
    'ru': "телеграмм таргет",
    'en': "target",
    'es': "objetivo",
    'fr': "cible",
    'zh': "目标",
    'ar': "هدف",
}
l_inline_user = {
    'ru': "нейро-автоматизация аккаунтов",
    'en': "user automation",
    'es': "automatización de usuarios",
    'fr': "automatisation des utilisateurs",
    'zh': "用户自动化",
    'ar': "أتمتة المستخدم",
}
l_inline_tools = {
    'ru': "телеграм инструменты",
    'en': "tools",
    'es': "herramientas",
    'fr': "outils",
    'zh': "工具",
    'ar': "أدوات",
}
l_inline_work = {
    'ru': "вакансии проекта",
    'en': "vacancies/competitions",
    'es': "vacantes/concursos",
    'fr': "postes vacants/concours",
    'zh': "职位空缺/竞争",
    'ar': "الشواغر / المسابقات",
}
l_inline_tonest = {
    'ru': "блокчейн проекты",
    'en': "vacancies/competitions",
    'es': "vacantes/concursos",
    'fr': "postes vacants/concours",
    'zh': "职位空缺/竞争",
    'ar': "الشواغر / المسابقات",
}
l_inline_support = {
    'ru': "служба заботы",
    'en': "vacancies/competitions",
    'es': "vacantes/concursos",
    'fr': "postes vacants/concours",
    'zh': "职位空缺/竞争",
    'ar': "الشواغر / المسابقات",
}
# endregion


# region FereyBotBot
l_bot_btn1 = {
    'ru': "👩🏽‍💻 Боты",
    'en': "👩🏽‍💻 Boots",
    'es': "👩🏽‍💻 Botas",
    'fr': "👩🏽‍💻 Bottes",
    'zh': "👩🏽‍💻 靴子",
    'ar': "👩🏽‍💻حذاء",
}
l_bot_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_bot_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в #нейро-конструктор <b>Telegram</b>-приложений:\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️авто-<b>перевод/оповещения</b>\n▪️<b>интеграции</b> и платежи\n▪️#нейро-<b>генерация/клон</b> бота\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>\n\n❗️<b>Смотри</b>: <a href='{1}'>инструкция</a> и /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> neuro-constructor of <b>Telegram</b>-bots:\n\n▪️<b>collection/ban /analytics</b>subscribers\n▪️auto-<b>translation/alerts</b>\n▪️<b>integration</b> and payments\n▪️neuro-<b>generation/clone</b> bot\n▪️<b>web app/neuro</b>-posting\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> neuroconstructor de <b>Telegram</b>-bots:\n\n▪️<b>colección/ban /analytics</b>suscriptores\n▪️auto-<b>traducción/alertas</b>\n▪️<b>integración</b> y pagos\n▪️neuro-<b>generación/clon</b> bot\n▪️<b>aplicación web/neuro</b>-publicación\n\n❗️<b>actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue dans le neuro-constructeur <i>landing bot</i> des <b>Telegram</b>-bots :\n\nnoyer<b>collection/ban /analytics</b>abonnés\nwithout-<b>traduction/alertes</b>\nnoyer</b>intégration</b> et paiements\nnouncementneuro-<b>génération/clone</b> bot\n▪️<b>application web/neuro</b>-publication\n\n❗️<b>Régulièrement</b>-mis à jour/contenu",
    'zh': "🌱 <b>{0}</b>，欢迎来到 <b>Telegram</b>-bots 的<i>登陆机器人</i>神经构造器：\n\n▪️<b>收藏/禁止/分析</b>订阅者\n▪️自动-<b>翻译/提醒</b>\n▪️<b>集成</b>和付款\n▪️神经-<b>生成/克隆</b>机器人\n▪️<b>网络应用/神经元</b>-发布\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> المنشئ العصبي لـ <b>Telegram</b>-bots:\n\n▪️<b>collection/ban /التحليلات</b>المشتركون\n▪️auto-<b>الترجمة/التنبيهات</b>\n▪️<b>التكامل</b> والمدفوعات\n▪️neuro-<b>الجيل/الاستنساخ</b> bot\n▪️<b>تطبيق ويب/neuro</b>-النشر\n\n❗️<b>بانتظام</b>-تحديث /محتوى",
}
l_bot_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyBotBot-11-13',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}

l_subscribe_bot = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>добавление</b> нескольких ботов\n▪️<b>авто-перевод</b>\n(<i>в том числе текста кнопок</i>)\n▪️<b>#нейро-ответ/постинг</b>\n(<i>на основе контента блоков/постов</i>)\n▪️<b>#нейро-генерация</b> бота\n(<i>через текстовый запрос</i>)\n▪️<b>клонирование</b> ботов конкурентов</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>adding</b> several bots\n▪️<b>auto-translation</b>\n(<i>including button text</i>)\n▪️<b>neuro-response/posting</b>\n(<i>based on the content of blocks/posts</i>)\n▪️<b>neuro-generation</b> bot\n(<i> via text request</i>)\n▪️<b>cloning</b> competitors' bots\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>agregando</b> varios bots\n▪️<b>traducción automática</b>\n(<i>incluido el texto del botón</i>)\n▪️ <b>neuro-respuesta/publicación</b>\n(<i>basado en el contenido de bloques/publicaciones</i>)\n▪️<b>bot de neurogeneración</b>\n(<i > mediante solicitud de texto</i>)\n▪️<b>clonación</b> de bots de la competencia\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>ajout</b> de plusieurs robots\nnoyer️<b>traduction automatique</b>\n(<i>y compris le texte du bouton</i>)\n▪️ <b>neuro-réponse/publication</b>\n(<i>basé sur le contenu des blocs/posts</i>)\nnoyer<b>bot de neuro-génération</b>\n(<i > via demande SMS</i>)\nnoyance<b>clonage</b> des robots des concurrents\n\n👩🏽‍💻 /balance",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>添加</b>多个机器人\n▪️<b>自动翻译</b>\n（<i>包括按钮文本</i>）\n▪️ <b>神经响应/发布</b>\n（<i>基于块/帖子的内容</i>）\n▪️<b>神经生成</b>机器人\n（<i > 通过文本请求</i>)\n▪️<b>克隆</b>竞争对手的机器人\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إضافة</b> عدة روبوتات\n▪️<b>ترجمة تلقائية</b>\n(<i>بما في ذلك نص الزر</i>)\n▪️ <b>الاستجابة العصبية/النشر</b>\n(<i>استنادًا إلى محتوى الكتل/المشاركات</i>)\n▪️<b>الجيل العصبي</b> bot\n(<i > عبر طلب نصي</i>)\n▪️<b>استنساخ</b> روبوتات المنافسين\n\n👩🏽‍💻 /balance",
}
l_subscribe_isfree = {
    'ru': "👩🏽‍💻 <b>Расширенный</b> период использования @{0}-бота завершился\n\n👩🏽‍💻 <b>Оформи</b> <a href='{1}'>💨Подписку</a>, чтобы продолжить использование",
    'en': "👩🏽‍💻 <b>Extended</b> period of use of @{0}-bot has ended\n\n👩🏽‍💻 <b>Subscribe</b> <a href='{1}'>💨Subscribe< /a> to continue using",
    'es': "👩🏽‍💻 El período <b>extendido</b> de uso de @{0}-bot ha finalizado\n\n👩🏽‍💻 <b>Suscríbete</b> <a href='{1}'> 💨Suscríbete< /a> para seguir usando",
    'fr': "👩🏽‍💻 <b>La période prolongée</b> d'utilisation de @{0}-bot est terminée\n\n👩🏽‍💻 <b>Abonnez-vous</b> <a href='{1}'> 💨Abonnez-vous< /a> pour continuer à utiliser",
    'zh': "👩🏽‍💻 <b>@{0}-bot 的延长</b>使用期已结束\n\n👩🏽‍💻 <b>订阅</b> <a href='{1}'> 💨订阅</a>以继续使用",
    'ar': "👩🏽‍💻 انتهت فترة <b>الممتدة</b> من استخدام @{0}-bot\n\n👩🏽‍💻 <b>الاشتراك</b> <a href='{1}'> 💨اشترك< /a> لمواصلة الاستخدام",
}
l_cmd_txt_bot = {
    'ru': "👩🏽‍💻 <b>Жми</b> [➕ Добавить бота]",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add bot]",
    'es': "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar bot]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un bot]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加机器人]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة روبوت]",
}

l_add_bot_button = {
    'ru': "➕ Добавить бота",
    'en': "➕ Add a bot",
    'es': "➕ Agregar un robot",
    'fr': "➕ Ajouter un robot",
    'zh': "➕ 添加机器人",
    'ar': "➕ إضافة بوت",
}
l_add_bot_call = {
    'ru': "➕ Оформи 💨Подписку для >1 бота или открепи активного бота, чтобы добавить нового",
    'en': "➕ Subscribe 💨for >1 bot or unpin an active bot to add a new one",
    'es': "➕ Suscríbete 💨para obtener >1 bot o desancla un bot activo para agregar uno nuevo",
    'fr': "➕ Abonnez-vous 💨pour >1 bot ou désépinglez un bot actif pour en ajouter un nouveau",
    'zh': "➕ 订阅 💨>1 个机器人或取消固定活动机器人以添加新机器人",
    'ar': "➕ اشترك 💨 مقابل أكثر من روبوت واحد أو قم بإزالة تثبيت روبوت نشط لإضافة روبوت جديد",
}
l_test_bot_desc = {
    'ru': "🫥 Описание @{0}-бота:\n\n▪️телеграф-блог\n▪️авто-перевод\n(в том числе текста кнопок)\n▪️оповещения и utm-рефералы\n▪️нейросети: графика и текст бота\n▪️интеграции и платежи",
    'en': "🫥 Description of @{0}-bot:\n\n▪️telegraph blog\n▪️auto-translation\n(including button text)\n▪️alerts and utm-referrals\n▪️neural networks: graphics and text of the bot\n▪️integrations and payments",
    'es': "🫥 Descripción de @{0}-bot:\n\n▪️blog de telégrafo\n▪️traducción automática\n(incluido el texto del botón)\n▪️alertas y referencias utm\n▪️redes neuronales: gráficos y texto del bot\n▪️integraciones y pagos",
    'fr': "🫥 Description de @{0}-bot :\n\nnoyerblog télégraphique\nnoyertraduction automatique\n(y compris le texte du bouton)\nnoyer️alertes et références utm\nnoyerréseaux neuronaux : graphiques et texte du bot\n▪️intégrations et paiements",
    'zh': "🫥 @{0}-bot 的描述：\n\n▪️telegraph 博客\n▪️自动翻译\n（包括按钮文本）\n▪️警报和 utm-referrals\n▪️神经网络：机器人的图形和文本\n▪️集成和支付",
    'ar': "🫥 وصف @{0}-bot:\n\n▪️مدونة التلغراف\n▪️الترجمة التلقائية\n(بما في ذلك نص الزر)\n▪️التنبيهات وإحالات utm\n▪️الشبكات العصبية: رسومات ونص الروبوت\n▪️عمليات التكامل والمدفوعات",
}
l_clone_bot_button = {
    'ru': "©️ Клонировать бота",
    'en': "©️ Clone bot",
    'es': "©️ Clonar robot",
    'fr': "©️ Cloner le robot",
    'zh': "©️ 克隆机器人",
    'ar': "©️ استنساخ بوت",
}
l_clone_bot_call = {
    'ru': "©️ Оформи 💨Подписку, чтобы склонировать бота конкурента",
    'en': "©️ Subscribe 💨 to clone your competitor's bot",
    'es': "©️ Suscríbete 💨 para clonar el bot de tu competidor",
    'fr': "©️ Abonnez-vous 💨 pour cloner le bot de votre concurrent",
    'zh': "©️ 订阅 💨 克隆竞争对手的机器人",
    'ar': "©️ اشترك 💨 لاستنساخ بوت منافسك",
}
l_clone_bot_text = {
    'ru': "©️ <b>Вставь</b> корректную ссылку на бота, чтобы склонировать его",
    'en': "©️ <b>Insert</b> the correct link to the bot to clone it",
    'es': "©️ <b>Inserta</b> el enlace correcto al bot para clonarlo",
    'fr': "©️ <b>Insérer</b> le lien correct vers le bot pour le cloner",
    'zh': "©️ <b>插入</b>机器人的正确链接以克隆它",
    'ar': "©️ <b>أدخل</b> الرابط الصحيح للبوت لاستنساخه",
}
l_clone_bot_wait = {
    'ru': "©️ <b>Клонирование</b> бота\n#длительность 1мин",
    'en': "©️ <b>Cloning</b> bot\n\n#duration 1 min",
    'es': "©️ <b>Clonación</b> bot\n\n#duración 1 min",
    'fr': "©️ Bot de <b>Clonage</b>\n\n#durée 1 min",
    'zh': "©️ <b>克隆</b>机器人\n\n#duration 1 分钟",
    'ar': "©️ <b>الاستنساخ</b> الروبوت\n\n#duration 1 دقيقة",
}
l_clone_bot_blocks = {
    'ru': "©️ <b>Начинаем</b> клонирование блоков..",
    'en': "©️ <b>Cloning</b> bot\n\n#duration 1 min",
    'es': "©️ <b>Clonación</b> bot\n\n#duración 1 min",
    'fr': "©️ Bot de <b>Clonage</b>\n\n#durée 1 min",
    'zh': "©️ <b>克隆</b>机器人\n\n#duration 1 分钟",
    'ar': "©️ <b>الاستنساخ</b> الروبوت\n\n#duration 1 دقيقة",
}
l_clone_bot_cmds = {
    'ru': "👩🏽‍💻 <b>Команды:</b>",
    'en': "©️ <b>Cloning</b> bot\n\n#duration 1 min",
    'es': "©️ <b>Clonación</b> bot\n\n#duración 1 min",
    'fr': "©️ Bot de <b>Clonage</b>\n\n#durée 1 min",
    'zh': "©️ <b>克隆</b>机器人\n\n#duration 1 分钟",
    'ar': "©️ <b>الاستنساخ</b> الروبوت\n\n#duration 1 دقيقة",
}

l_addbot_handler = {
    'ru': "➕ <b>Отправь</b> корректный <b>ТОКЕН</b> @tg-бота, полученный с помощью @botFather-бота\n\n<blockquote>👩🏽‍💻 <b>Например</b>, 117783159:BBADKz2h8AQtHYiVtuyyASdMN</blockquote>",
    'en': "➕ <b>Received</b> the correct <b>TOKEN</b> Telegram bot, received using @botFather-bot\n\n👩🏽‍💻 For example, 117783159:BBAD2Kz2h8AQtHYiVtuyyASdMN",
    'es': "➕ <b>Recibió</b> el bot de Telegram <b>TOKEN</b> correcto, recibido usando @botFather-bot\n\n👩🏽‍💻 Por ejemplo, 117783159:BBAD2Kz2h8AQtHYiVtuyyASdMN",
    'fr': "➕ <b>Reçu</b> le bon <b>TOKEN</b> Bot Telegram, reçu en utilisant @botFather-bot\n\n👩🏽‍💻 Par exemple, 117783159:BBAD2Kz2h8AQtHYiVtuyyASdMN",
    'zh': "➕<b>收到</b>正确的<b>TOKEN</b>电报机器人，使用@botFather-bot\n\n👩🏽‍💻接收，例如，117783159:BBAD2Kz2h8AQtHYiVtuyyASdMN",
    'ar': "➕ <b>تم استلام</b> بوت Telegram <b>TOKEN</b> الصحيح، والذي تم استلامه باستخدام @botFather-bot\n\n👩🏽‍💻 على سبيل المثال، 117783159:BBAD2Kz2h8AQtHYiVtuyyASdMN",
}
l_wait_for_translate_bot = {
    'ru': "👩🏽‍💻 <b>Перевод</b> {0}-бота на <i>{1}</i>-язык\n\n#длительность 0мин",
    'en': "👩🏽‍💻 <b>Translation</b> {0}-bot into <i>{1}</i>-language\n\n#duration 0 min",
    'es': "👩🏽‍💻 <b>Traducción</b> {0}-bot al <i>{1}</i>-idioma\n\n#duration 0 min",
    'fr': "👩🏽‍💻 <b>Traduction</b> {0}-bot en <i>{1}</i>-langue\n\n#durée 0 min",
    'zh': "👩🏽‍💻 <b>翻译</b> {0}-bot 为 <i>{1}</i>-语言\n\n#duration 0 分钟",
    'ar': "👩🏽‍💻 <b>الترجمة</b> {0}-bot إلى <i>{1}</i>-language\n\n#duration 0 min",
}
l_template_is_ready = {
    'ru': "👩🏽‍💻 <b>Шаблон</b> для @{0} готов!",
    'en': "👩🏽‍💻 <b>Template</b> for @{0} is ready!",
    'es': "👩🏽‍💻 ¡La <b>plantilla</b> para @{0} está lista!",
    'fr': "👩🏽‍💻 Le <b>Modèle</b> pour @{0} est prêt !",
    'zh': "@{0} 的👩🏽‍💻<b>模板</b>已准备就绪！",
    'ar': "👩🏽‍💻 <b>القالب</b> لـ @{0} جاهز!",
}
l_payment_successful = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} 💰Внес оплату в размере {1} {2}",
    'en': "👩🏽‍💻 <b>User</b> {0} 💰Paid a payment of {1} {2}",
    'es': "👩🏽‍💻 <b>Usuario</b> {0} 💰Pagó un pago de {1} {2}",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} 💰A payé un paiement de {1} {2}",
    'zh': "👩🏽‍💻 <b>用户</b> {0} 💰支付了 {1} {2} 的付款",
    'ar': "👩🏽‍💻 <b>مستخدم</b> {0} 💰تم دفع مبلغ قدره {1} {2}",
}
l_promocode_activated = {
    'ru': "👩🏽‍💻 *Промокод*: `{txt}` активирован",
    'en': "👩🏽‍💻 *Promotional code*: `{txt}` activated",
    'es': "👩🏽‍💻 *Código promocional*: `{txt}` activado",
    'fr': "👩🏽‍💻 *Code promotionnel* : `{txt}` activé",
    'zh': "👩🏽‍💻 *促销代码*：`{txt}`已激活",
    'ar': "👩🏽‍💻 *الرمز الترويجي*: `{txt}` مفعل",
}
l_create_view_web = {
    'ru': "👩🏽‍💻 <b>Скрытая</b> ссылка на веб-страницу: <a href='https://t.me/{0}/web?startapp={1}_{2}'>@{3}/web</a>\n\n👩🏽‍💻 <b>Подлинная</b> телеграм-ссылка: <code>https://t.me/{0}/web?startapp={1}_{2}</code>",
    'en': "👩🏽‍💻 <b>Hidden</b> link to web page: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3}/web</a>\n\n👩🏽‍💻 <b>Genuine</b> telegram link: <code> https://t.me/{0}/web?startapp={1} _{2} </code>",
    'es': "👩🏽‍💻 Enlace <b>oculto</b> a la página web: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Enlace de Telegram <b>genuino</b>: <code> https://t.me/{0}/web?startapp={1} _ 2} </código>",
    'fr': "👩🏽‍💻 Lien <b>caché</b> vers la page Web : <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Lien télégramme <b>authentique</b> : <code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'zh': "👩🏽‍💻 <b>隐藏</b>网页链接： <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 <b>正版</b>电报链接：<code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'ar': "👩🏽‍💻 الرابط <b>المخفي</b> لصفحة الويب: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 رابط التليجرام <b>الحقيقي</b>: <code> https://t.me/{0}/web?startapp={1} _{ 2} </كود>",
}
l_admin_answer = {
    'ru': "👩🏽‍💻 <b>Администратор</b>: {0} to {1}:\n\n{2}",
    'en': "👩🏽‍💻 <b>Admin</b>: {0} to {1}:\n\n{2}",
    'es': "👩🏽‍💻 Enlace <b>oculto</b> a la página web: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Enlace de Telegram <b>genuino</b>: <code> https://t.me/{0}/web?startapp={1} _ 2} </código>",
    'fr': "👩🏽‍💻 Lien <b>caché</b> vers la page Web : <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Lien télégramme <b>authentique</b> : <code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'zh': "👩🏽‍💻 <b>隐藏</b>网页链接： <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 <b>正版</b>电报链接：<code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'ar': "👩🏽‍💻 الرابط <b>المخفي</b> لصفحة الويب: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 رابط التليجرام <b>الحقيقي</b>: <code> https://t.me/{0}/web?startapp={1} _{ 2} </كود>",
}
l_bot_need_start = {
    'ru': "👩🏽‍💻 <b>Необходимо</b>: /start-запустить @{0}-бота перед началом работы",
    'en': "👩🏽‍💻 <b>Admin</b>: {0} to {1}:\n\n{2}",
    'es': "👩🏽‍💻 Enlace <b>oculto</b> a la página web: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Enlace de Telegram <b>genuino</b>: <code> https://t.me/{0}/web?startapp={1} _ 2} </código>",
    'fr': "👩🏽‍💻 Lien <b>caché</b> vers la page Web : <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Lien télégramme <b>authentique</b> : <code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'zh': "👩🏽‍💻 <b>隐藏</b>网页链接： <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 <b>正版</b>电报链接：<code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'ar': "👩🏽‍💻 الرابط <b>المخفي</b> لصفحة الويب: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 رابط التليجرام <b>الحقيقي</b>: <code> https://t.me/{0}/web?startapp={1} _{ 2} </كود>",
}
l_bot_user_balls = {
    'ru': "👩🏽‍💻 <b>Баллы:</b> {0}",
    'en': "👩🏽‍💻 <b>Admin</b>: {0} to {1}:\n\n{2}",
    'es': "👩🏽‍💻 Enlace <b>oculto</b> a la página web: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Enlace de Telegram <b>genuino</b>: <code> https://t.me/{0}/web?startapp={1} _ 2} </código>",
    'fr': "👩🏽‍💻 Lien <b>caché</b> vers la page Web : <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 Lien télégramme <b>authentique</b> : <code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'zh': "👩🏽‍💻 <b>隐藏</b>网页链接： <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 <b>正版</b>电报链接：<code> https://t.me/{0}/web?startapp={1} _{ 2} </code>",
    'ar': "👩🏽‍💻 الرابط <b>المخفي</b> لصفحة الويب: <a href=' https://t.me/{0}/web?startapp={1}_{2} '> @{ 3 }/web</a>\n\n👩🏽‍💻 رابط التليجرام <b>الحقيقي</b>: <code> https://t.me/{0}/web?startapp={1} _{ 2} </كود>",
}
l_bot_in_chn_added = {
    'ru': "👩🏽‍💻 <b>@{0}</b> успешно добавлен в <b>{1}</b>-канал и видит его подписчиков",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add bot]",
    'es': "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar bot]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un bot]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加机器人]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة روبوت]",
}
l_bot_in_grp_added = {
    'ru': "👩🏽‍💻 <b>@{0}</b> успешно добавлен в <b>{1}</b>-группу и видит ее участников",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add bot]",
    'es': "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar bot]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un bot]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加机器人]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة روبوت]",
}

# region commands
l_bot_commands_handler = {
    'ru': "⚙️ <b>Команды</b> /cmd для <b>@{0}</b> [<code>{1}</code>]\n\n<blockquote>/info информация о боте\n/stat статистика\n/status статус\n/on включение\n<code>/off</code> выключение\n<code>/restart</code> перезагрузка\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo промокод\n/short описание профиля¹²⁰\n/desc описание бота⁵¹²\n/admin администраторы\n/ban [id/@username] список\n/unban разбан\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{2}</i>",
    'en': "⚙️ <b>Commands</b> /cmd for <b>@{0}</b>\n\n/info <i>bot information</i>\n/stat <i>statistics</i >\n/status <i>status</i>\n/on <i>on</i>\n<code>/off</code> <i>off</i>\n<code>/ restart</code> <i>restart</i>\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo <i>promo code</i>\n/admin <i>administrators </i>\n/ban [id/ @username] <i>list</i>\n/unban <i>unban</i>\n/transfer <i>transfer of admin rights</i>\ n\n💨 <b>Subscription</b>: <i>{1}</i>",
    'es': "⚙️ <b>Comandos</b> /cmd para <b>@{0}</b>\n\n/info <i>información del bot</i>\n/stat <i>estadísticas</i >\n/status <i>estado</i>\n/on <i>on</i>\n<code>/off</code> <i>off</i>\n<code>/reiniciar </code> <i>reiniciar</i>\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo <i>código de promoción</i>\n/admin <i>administradores </i>\n/ban [id/ @username] <i>list</i>\n/unban <i>unban</i>\n/transfer <i>transferencia de derechos de administrador</i>\ n\n💨 <b>Suscripción</b>: <i>{1}</i>",
    'fr': "⚙️ <b>Commandes</b> /cmd pour <b>@{0}</b>\n\n/info <i>informations sur le robot</i>\n/stat <i>statistiques</i >\n/statut <i>statut</i>\n/on <i>on</i>\n<code>/off</code> <i>off</i>\n<code>/ redémarrage </code> <i>redémarrer</i>\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo <i>code promo</i>\n/admin <i>administrateurs </i>\n/ban [id/ @username] <i>list</i>\n/unban <i>unban</i>\n/transfer <i>transfert des droits d'administrateur</i>\ n\n💨 <b>Abonnement</b> : <i>{1}</i>",
    'zh': "⚙️ <b>命令</b> /cmd for <b>@{0}</b>\n\n/info <i>机器人信息</i>\n/stat <i>统计</i>\n/status <i>状态</i>\n/on <i>开</i>\n<code>/off</code> <i>关</i>\n<code>/重启</code> <i>重新启动</i>\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo <i>促销代码</i>\n/admin <i>管理员</i>\n/ban [id/ @username] <i>列表</i>\n/unban <i>解禁</i>\n/transfer <i>转让管理权限</i>\ n\n💨 <b>订阅</b>：<i>{1}</i>",
    'ar': "⚙️ <b>الأوامر</b> /cmd لـ <b>@{0}</b>\n\n/info <i>معلومات الروبوت</i>\n/stat <i>الإحصائيات</i >\n/status <i>status</i>\n/on <i>on</i>\n<code>/off</code> <i>off</i>\n<code>/ Restart </code> <i>إعادة التشغيل</i>\n\n/parse [premium|promo|utm|old|POST_ID]\n/promo <i>الرمز الترويجي</i>\n/admin <i>المسؤولين </i>\n/ban [id/ @username] <i>list</i>\n/unban <i>unban</i>\n/transfer <i>نقل حقوق المسؤول</i>\n\n💨 <b>الاشتراك</b>: <i>{1}</i>",
}
l_bot_info_handler = {
    'ru': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<code>{3}</code>, dt=<code>{4}</code>, tz=<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>Токен бота:</b> <code>{7}</code>\n<b>Токен <a href='{8}'>tgph</a>:</b> <code>{9}</code>\n<b>Крипто адрес:</b> <code>{10}</code>\n<b>Токен оплаты:</b> <code>{11}</code>\n<b>База данных:</b> {12}\n<b>Инлайн-режим:</b> {13}\n<b>Канал:</b> {14}\n<b>Группа:</b> {15}\n\n<b>/status</b> {16}\n<b>/parse</b> {17}\n<b>/promo</b> {18}\n{19}\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<code>{3}</code>, dt=<code>{4}</code>, tz =<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>Bot token:</b> <code>{7}</code>\ n<b>Token <a href='{8}'>tgph</a>:</b> <code>{9}</code>\n<b>Payment token:</b> <code> {10}</code>\n<b>Base:</b> {11}\n<b>Inline:</b> {12}\n<b>Channel:</b> {13}\ n<b>Group:</b> {14}\n\n<b>/status</b> {15}\n<b>/parse</b> {16}\n<b>/promo </b> {17}\n{18}\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<código>{3}</código>, dt=<código>{4}</código>, tz =<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>Token de robot:</b> <code>{7}</code>\ n<b>Token <a href='{8}'>tgph</a>:</b> <code>{9}</code>\n<b>Token de pago:</b> <code> {10}</code>\n<b>Base:</b> {11}\n<b>En línea:</b> {12}\n<b>Canal:</b> {13}\ n<b>Grupo:</b> {14}\n\n<b>/status</b> {15}\n<b>/parse</b> {16}\n<b>/promoción </b> {17}\n{18}\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<code>{3}</code>, dt=<code>{4}</code>, tz =<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>Jeton de robot :</b> <code>{7}</code>\ n<b>Jeton <a href='{8}'>tgph</a> :</b> <code>{9}</code>\n<b>Jeton de paiement :</b> <code> {10}</code>\n<b>Base :</b> {11}\n<b>Inline :</b> {12}\n<b>Canal :</b> {13}\ n<b>Groupe :</b> {14}\n\n<b>/status</b> {15}\n<b>/parse</b> {16}\n<b>/promo </b> {17}\n{18}\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<code>{3}</code>, dt=<code>{4}</code>, tz =<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>机器人令牌：</b> <code>{7}</code>\ n<b>令牌<a href='{8}'>tgph</a>：</b> <code>{9}</code>\n<b>付款令牌：</b> <code> {10}</code>\n<b>基础：</b> {11}\n<b>内嵌：</b> {12}\n<b>频道：</b> {13}\ n<b>组：</b> {14}\n\n<b>/status</b> {15}\n<b>/parse</b> {16}\n<b>/promo </b> {17}\n{18}\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>@{0}</b>,{1} {2} [id=<code>{3}</code>, dt=<code>{4}</code>, tz =<code>{5}</code>, lz=<code>{6}</code>]\n\n<b>الرمز المميز للبوت:</b> <code>{7}</code>\n<b>الرمز المميز <a href='{8}'>tgph</a>:</b> <code>{9}</code>\n<b>الرمز المميز للدفع:</b> <code> {10}</code>\n<b>الأساسية:</b> {11}\n<b>مضمنة:</b> {12}\n<b>القناة:</b> {13}\n<b>المجموعة:</b> {14}\n\n<b>/status</b> {15}\n<b>/parse</b> {16}\n<b>/promo </b> {17}\n{18}\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_bot_stat_handler = {
    'ru': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<code>{2}</code>, dt=<code>{3}</code>, tz=<code>{4}</code>, lz=<code>{5}</code>]\n\n<blockquote><b>Конверсия</b>\nТриггеры: <code>{6}</code> [{7}%]\nДействия: <code>{8}</code> [{9}%]\nСообщения: <code>{10}</code> [{11}%]\nЯзыки: <code>{12}</code> [{13}%]\nКнопки: <code>{14}</code>\nМедиа: <code>{15}</code>\n\nПользователи: <code>{16}</code>\nАдмины: <code>{17}</code>\nПромо: <code>{18}</code>\nUTM-метки: <code>{19}</code>\nПремиум: <code>{20}</code>\nБан: <code>{21}</code>\n\nАвто-перевод: {22}\nНейро-ответ: {23}\nАвто-постинг: {24} ({25})</blockquote>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<code>{2}</code>, dt=<code>{3}</code>, tz=<code >{4}</code>, lz=<code>{5}</code>]\n\n<i>Triggers:</i> <code>{6}</code> [{7}%]\n<i>Actions:</i> <code>{8}</code> [{9}%]\n<i>Messages:</i> <code>{10}</code> [{11}%]\n<i>Languages:</i> <code>{12}</code> [{13}%]\n<i>Buttons:</i> <code>{14}< /code>\n<i>Media:</i> <code>{15}</code>\n\n<i>Users:</i> <code>{16}</code>\n< i>Admins:</i> <code>{17}</code>\n<i>Promo:</i> <code>{18}</code>\n<i>UTM tags:</ i> <code>{19}</code>\n<i>Premium:</i> <code>{20}</code>\n<i>Ban:</i> <code>{21} </code>\n\n<i>Auto-translation:</i> {22}\n<i>Neuro-response:</i> {23}\n<i>Auto-posting:</i > {24} ({25})\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<código>{2}</código>, dt=<código>{3}</código>, tz=<código >{4}</code>, lz=<code>{5}</code>]\n\n<i>Activadores:</i> <code>{6}</code> [{7}%]\n<i>Acciones:</i> <code>{8}</code> [{9}%]\n<i>Mensajes:</i> <code>{10}</code> [{11}%]\n<i>Idiomas:</i> <code>{12}</code> [{13}%]\n<i>Botones:</i> <code>{14}< /code>\n<i>Medios:</i> <code>{15}</code>\n\n<i>Usuarios:</i> <code>{16}</code>\n< i>Administradores:</i> <code>{17}</code>\n<i>Promoción:</i> <code>{18}</code>\n<i>Etiquetas UTM:</ i > <code>{19}</code>\n<i>Premium:</i> <code>{20}</code>\n<i>Prohibición:</i> <code>{21} < /code>\n\n<i>Traducción automática:</i> {22}\n<i>Neurorespuesta:</i> {23}\n<i>Publicación automática:</i > {24} ({25})\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<code>{2}</code>, dt=<code>{3}</code>, tz=<code >{4}</code>, lz=<code>{5}</code>]\n\n<i>Déclencheurs :</i> <code>{6}</code> [{7}%]\n<i>Actions :</i> <code>{8}</code> [{9}%]\n<i>Messages :</i> <code>{10}</code> [{11}%]\n<i>Langues :</i> <code>{12}</code> [{13}%]\n<i>Boutons :</i> <code>{14}< /code>\n<i>Média :</i> <code>{15}</code>\n\n<i>Utilisateurs :</i> <code>{16}</code>\n< i>Administrateurs :</i> <code>{17}</code>\n<i>Promo :</i> <code>{18}</code>\n<i>Balises UTM :</ i > <code>{19}</code>\n<i>Premium :</i> <code>{20}</code>\n<i>Ban :</i> <code>{21} < /code>\n\n<i>Traduction automatique :</i> {22}\n<i>Réponse neurologique :</i> {23}\n<i>Publication automatique :</i > {24} ({25})\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<code>{2}</code>, dt=<code>{3}</code>, tz=<code >{4}</code>, lz=<code>{5}</code>]\n\n<i>触发器：</i> <code>{6}</code> [{7}%]\n<i>操作：</i> <code>{8}</code> [{9}%]\n<i>消息：</i> <code>{10}</code> [{11}%]\n<i>语言：</i> <code>{12}</code> [{13}%]\n<i>按钮：</i> <code>{14}< /code>\n<i>媒体：</i> <code>{15}</code>\n\n<i>用户：</i> <code>{16}</code>\n< i>管理员：</i> <code>{17}</code>\n<i>促销：</i> <code>{18}</code>\n<i>UTM 标签：</i > <code>{19}</code>\n<i>高级：</i> <code>{20}</code>\n<i>禁止：</i> <code>{21} < /code>\n\n<i>自动翻译：</i> {22}\n<i>神经反应：</i> {23}\n<i>自动发布：</i> {24} ({25})\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>@{0}</b>, {1} [id=<code>{2}</code>, dt=<code>{3}</code>, tz=<code> >{4}</code>, lz=<code>{5}</code>]\n\n<i>المشغلات:</i> <code>{6}</code> [{7}%]\n<i>الإجراءات:</i> <code>{8}</code> [{9}%]\n<i>الرسائل:</i> <code>{10}</code> [{11}%]\n<i>اللغات:</i> <code>{12}</code> [{13}%]\n<i>الأزرار:</i> <code>{14}< /code>\n<i>الوسائط:</i> <code>{15}</code>\n\n<i>المستخدمون:</i> <code>{16}</code>\n<<i>المسؤولون:</i> <code>{17}</code>\n<i>العرض الترويجي:</i> <code>{18}</code>\n<i>علامات UTM:</ i > <code>{19}</code>\n<i>بريميوم:</i> <code>{20}</code>\n<i>الحظر:</i> <code>{21} < /code>\n\n<i>الترجمة التلقائية:</i> {22}\n<i>الاستجابة العصبية:</i> {23}\n<i>النشر التلقائي:</i > {24} ({25})\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_bot_status_handler = {
    'ru': "👩🏽‍💻 <b>Статус</b> @{0}-@tg-приложения: {1}",
    'en': "👩🏽‍💻 <b>Status</b> @{0}-bot: {1}",
    'es': "👩🏽‍💻 <b>Estado</b> @{0}-bot: {1}",
    'fr': "👩🏽‍💻 <b>Statut</b> @{0}-bot : {1}",
    'zh': "👩🏽‍💻 <b>状态</b> @{0}-bot：{1}",
    'ar': "👩🏽‍💻 <b>الحالة</b> @{0}-bot: {1}",
}
l_bot_on_handler = {
    'ru': "👩🏽‍💻 <b>Запуск</b> @{0}-@tg-приложения..\n#длительность 0мин",
    'en': "👩🏽‍💻 <b>Launch</b> @{0}-bot..\n#duration 0 min",
    'es': "👩🏽‍💻 <b>Lanzar</b> @{0}-bot..\n#duration 0 min",
    'fr': "👩🏽‍💻 <b>Lancement</b> @{0}-bot..\n#durée 0 min",
    'zh': "👩🏽‍💻 <b>启动</b> @{0}-bot..\n#duration 0 分钟",
    'ar': "👩🏽‍💻 <b>الإطلاق</b> @{0}-bot..\n#duration 0 دقيقة",
}
l_bot_on_handler_done = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-@tg-приложение запущено",
    'en': "👩🏽‍💻 <b>@{0}</b>-bot launched",
    'es': "👩🏽‍💻 <b>@{0}</b>-bot lanzado",
    'fr': "👩🏽‍💻 <b>@{0}</b>-bot lancé",
    'zh': "👩🏽‍💻 <b>@{0}</b>-机器人已启动",
    'ar': "👩🏽‍💻 <b>@{0}</b>-تم إطلاق الروبوت",
}
l_bot_on_handler_already = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-@tg-приложение уже запущено",
    'en': "👩🏽‍💻 <b>@{0}</b>-bot is already running",
    'es': "👩🏽‍💻 <b>@{0}</b>-bot ya se está ejecutando",
    'fr': "👩🏽‍💻 <b>@{0}</b>-bot est déjà en cours d'exécution",
    'zh': "👩🏽‍💻 <b>@{0}</b>-机器人已在运行",
    'ar': "👩🏽‍💻 <b>@{0}</b>-البوت قيد التشغيل بالفعل",
}
l_bot_off_handler = {
    'ru': "👩🏽‍💻 <b>Остановка</b> @{0}-@tg-приложения..\n#длительность 0мин",
    'en': "👩🏽‍💻 <b>Stop</b> @{0}-bot..\n#duration 0 min",
    'es': "👩🏽‍💻 <b>Detener</b> @{0}-bot..\n#duration 0 min",
    'fr': "👩🏽‍💻 <b>Arrêter</b> @{0}-bot..\n#durée 0 min",
    'zh': "👩🏽‍💻 <b>停止</b> @{0}-bot..\n#duration 0 分钟",
    'ar': "👩🏽‍💻 <b>توقف</b> @{0}-bot..\n#duration 0 min",
}
l_bot_off_handler_already = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-@tg-приложение уже выключено",
    'en': "👩🏽‍💻 <b>@{0}</b>-bot is already turned off",
    'es': "👩🏽‍💻 <b>@{0}</b>-bot ya está desactivado",
    'fr': "👩🏽‍💻 <b>@{0}</b>-bot est déjà désactivé",
    'zh': "👩🏽‍💻 <b>@{0}</b>-机器人已关闭",
    'ar': "👩🏽‍💻 <b>@{0}</b>-تم إيقاف تشغيل الروبوت بالفعل",
}
l_bot_off_handler_done = {
    'ru': "👩🏽‍💻 <b>@{0}</b>-@tg-приложение выключено",
    'en': "👩🏽‍💻 <b>@{0}</b>-bot is turned off",
    'es': "👩🏽‍💻 <b>@{0}</b>-bot está desactivado",
    'fr': "👩🏽‍💻 <b>@{0}</b>-bot est désactivé",
    'zh': "👩🏽‍💻 <b>@{0}</b>-机器人已关闭",
    'ar': "👩🏽‍💻 <b>@{0}</b>-تم إيقاف تشغيل الروبوت",
}
l_bot_restart_handler = {
    'ru': "👩🏽‍💻 <b>Перезапуск</b> @{0}-@tg-приложения..\n#длительность 0мин",
    'en': "👩🏽‍💻 <b>Restart</b> @{0}-bot..\n#duration 0 min",
    'es': "👩🏽‍💻 <b>Reiniciar</b> @{0}-bot..\n#duration 0 min",
    'fr': "👩🏽‍💻 <b>Redémarrer</b> @{0}-bot..\n#durée 0 min",
    'zh': "👩🏽‍💻 <b>重新启动</b> @{0}-bot..\n#duration 0 分钟",
    'ar': "👩🏽‍💻 <b>إعادة التشغيل</b> @{0}-bot..\n#duration 0 min",
}
l_bot_update_users = {
    'ru': "👩🏽‍💻 <b>Загружено</b> пользователей в @{0}-бота: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Корректность</b> данных о пользователях обновляется: <i>автоматически, периодически и непрерывно</i></blockquote>",
    'en': "👩🏽‍💻 <b>Loaded</b> users into @{0}-bot: <u>{1}</u>\n\n👩🏽‍💻 <b>Correctness</b> of user data is being updated : <i>automatically, periodically and continuously</i>",
    'es': "👩🏽‍💻 Usuarios <b>cargados</b> en {0}-bot: <u>{1}</u>\n\n👩🏽‍💻 La <b>corrección</b> de los datos del usuario es siendo actualizado: <i>automática, periódicamente y continuamente</i>",
    'fr': "👩🏽‍💻 <b>Utilisateurs chargés</b> dans {0}-bot : <u>{1}</u>\n\n👩🏽‍💻 <b>L'exactitude</b> des données utilisateur est en cours de mise à jour : <i>automatiquement, périodiquement et continuellement</i>",
    'zh': "👩🏽‍💻 <b>已将</b>个用户加载到 {0}-bot 中：<u>{1}</u>\n\n👩🏽‍💻 用户数据的<b>正确性</b>为正在更新：<i>自动、定期、持续</i>",
    'ar': "👩🏽‍💻 <b>تم تحميل</b> المستخدمين إلى {0}-bot: <u>{1}</u>\n\n👩🏽‍💻 <b>صحة</b> بيانات المستخدم هي يتم تحديثه: <i>تلقائيًا ودوريًا ومستمرًا</i>",
}
l_bot_transfer_to = {
    'ru': "👩🏽‍💻 @{0}-@tg-приложение - успешно передано пользователю: <code>{1}</code>",
    'en': "👩🏽‍💻 @{0}-successfully transferred to the user: <code>{1}</code>",
    'es': "👩🏽‍💻 @{0}-transferido exitosamente al usuario: <code>{1}</code>",
    'fr': "👩🏽‍💻 @{0}-transféré avec succès à l'utilisateur : <code>{1}</code>",
    'zh': "👩🏽‍💻 @{0}-已成功转移给用户：<code>{1}</code>",
    'ar': "👩🏽‍💻 @{0}-تم النقل بنجاح إلى المستخدم: <code>{1}</code>",
}
l_bot_transfer_from = {
    'ru': "👩🏽‍💻 @{0}-@tg-приложение - успешно получено от пользователя: <code>{1}</code>",
    'en': "👩🏽‍💻 @{0}-successfully received from user: <code>{1}</code>",
    'es': "👩🏽‍💻 @{0}-recibido exitosamente del usuario: <code>{1}</code>",
    'fr': "👩🏽‍💻 @{0}-reçu avec succès de l'utilisateur : <code>{1}</code>",
    'zh': "👩🏽‍💻 @{0}-成功收到来自用户的消息：<code>{1}</code>",
    'ar': "👩🏽‍💻 @{0}-تم الاستلام بنجاح من المستخدم: <code>{1}</code>",
}
l_bot_transfer_text = {
    'ru': "👩🏽‍💻 <b>Для</b> передачи admin-прав в @{0}-боте используй команду:\n/transfer ID-ПОЛЬЗОВАТЕЛЯ, где пользователь: участник @{0}-бота и участник @{1}-бота (/id)\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>To</b> transfer admin rights to the @{0}-bot, use the command:\n/transfer USER-ID, where the user is: @{0}-bot member and @{1} member-bot (/id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador al @{0}-bot, utilice el comando:\n/transfer USER-ID, donde el usuario es: @{0}-bot member y @ {1} miembro-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur au @{0}-bot, utilisez la commande :\n/transfer USER-ID, où l'utilisateur est : @{0}-membre du bot et @ {1} membre-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>要将管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户是：@{0}-bot 成员和 @ {1} member-bot (/id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق المسؤول إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث يكون المستخدم: @{0}-bot member و@ {1} عضو-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}

l_bot_short_error = {
    'ru': "👩🏽‍💻 <b>Введи</b> текст <i>описания</i> (до 120 символов) профиля @{0}-бота c помощью команды: <code>/short TEXT</code>",
    'en': "👩🏽‍💻 <b>To</b> transfer admin rights to the @{0}-bot, use the command:\n/transfer USER-ID, where the user is: @{0}-bot member and @{1} member-bot (/id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador al @{0}-bot, utilice el comando:\n/transfer USER-ID, donde el usuario es: @{0}-bot member y @ {1} miembro-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur au @{0}-bot, utilisez la commande :\n/transfer USER-ID, où l'utilisateur est : @{0}-membre du bot et @ {1} membre-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>要将管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户是：@{0}-bot 成员和 @ {1} member-bot (/id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق المسؤول إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث يكون المستخدم: @{0}-bot member و@ {1} عضو-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_bot_short_success = {
    'ru': "👩🏽‍💻 <b>Текст описания</b> профиля @{0}-бота установлен:\n\n<code>{1}</code>",
    'en': "👩🏽‍💻 <b>To</b> transfer admin rights to the @{0}-bot, use the command:\n/transfer USER-ID, where the user is: @{0}-bot member and @{1} member-bot (/id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador al @{0}-bot, utilice el comando:\n/transfer USER-ID, donde el usuario es: @{0}-bot member y @ {1} miembro-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur au @{0}-bot, utilisez la commande :\n/transfer USER-ID, où l'utilisateur est : @{0}-membre du bot et @ {1} membre-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>要将管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户是：@{0}-bot 成员和 @ {1} member-bot (/id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق المسؤول إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث يكون المستخدم: @{0}-bot member و@ {1} عضو-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_bot_desc_error = {
    'ru': "👩🏽‍💻 <b>Введи</b> текст <i>описания</i> (до 512 символов) @{0}-бота перед /start-запуском c помощью команды: <code>/desc TEXT</code>",
    'en': "👩🏽‍💻 <b>To</b> transfer admin rights to the @{0}-bot, use the command:\n/transfer USER-ID, where the user is: @{0}-bot member and @{1} member-bot (/id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador al @{0}-bot, utilice el comando:\n/transfer USER-ID, donde el usuario es: @{0}-bot member y @ {1} miembro-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur au @{0}-bot, utilisez la commande :\n/transfer USER-ID, où l'utilisateur est : @{0}-membre du bot et @ {1} membre-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>要将管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户是：@{0}-bot 成员和 @ {1} member-bot (/id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق المسؤول إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث يكون المستخدم: @{0}-bot member و@ {1} عضو-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_bot_desc_success = {
    'ru': "👩🏽‍💻 <b>Текст описания</b> @{0}-бота перед /start-запуском установлен:\n\n<code>{1}</code>",
    'en': "👩🏽‍💻 <b>To</b> transfer admin rights to the @{0}-bot, use the command:\n/transfer USER-ID, where the user is: @{0}-bot member and @{1} member-bot (/id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador al @{0}-bot, utilice el comando:\n/transfer USER-ID, donde el usuario es: @{0}-bot member y @ {1} miembro-bot (/id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur au @{0}-bot, utilisez la commande :\n/transfer USER-ID, où l'utilisateur est : @{0}-membre du bot et @ {1} membre-bot (/id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>要将管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户是：@{0}-bot 成员和 @ {1} member-bot (/id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق المسؤول إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث يكون المستخدم: @{0}-bot member و@ {1} عضو-bot (/id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
# endregion


# region bot
l_bot_config = {
    ("cctor", "👩🏽‍💻", "☑"): {
        'ru': "Конструктор ᴺᴱᵂ",
        'en': "Constructor ᴺᴱᵂ",
        'es': "Constructor ᴺᴱᵂ",
        'fr': "Constructeur ᴺᴱᵂ",
        'zh': "构造函数ᴺᴱᵂ",
        'ar': "منشئ ᴺᴱᵂ",
    },
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自动禁止",
        'ar': "الحظر التلقائي",
    },
    ("ctranslate", "文", "☐"): {
        'ru': "Авто-перевод",
        'en': "Auto-translation",
        'es': "Traducción automática",
        'fr': "Traduction automatique",
        'zh': "自动翻译",
        'ar': "الترجمة التلقائية",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自动发布",
        'ar': "النشر التلقائي",
    },
    ("cneuro", "🦾", "☐"): {
        'ru': "Нейро-постинг",
        'en': "Neuro-posting",
        'es': "Neuropublicación",
        'fr': "Neuro-posting",
        'zh': "神经张贴",
        'ar': "النشر العصبي",
    },

    ("cpayment", "💳", "☐"): {
        'ru': "Платежи",
        'en': "Payments",
        'es': "Pagos",
        'fr': "Paiements",
        'zh': "付款方式",
        'ar': "المدفوعات",
    },
    ("cintegration", "🗝️", "☐"): {
        'ru': "Интеграции",
        'en': "Integrations",
        'es': "Integraciones",
        'fr': "Intégrations",
        'zh': "集成",
        'ar': "التكامل",
    },
    ("cnotification", "💬", "☑"): {
        'ru': "Оповещения",
        'en': "Alerts",
        'es': "Alertas",
        'fr': "Alertes",
        'zh': "警报",
        'ar': "التنبيهات",
    },
    ("cuser", "👥", "☑"): {
        'ru': "Пользователи",
        'en': "Users",
        'es': "Usuarios",
        'fr': "Utilisateurs",
        'zh': "用户",
        'ar': "المستخدمين",
    },
    ("cadmin", "👮🏽", "☑"): {
        'ru': "Администраторы",
        'en': "Administrators",
        'es': "Administradores",
        'fr': "Administrateurs",
        'zh': "管理员",
        'ar': "المسؤولين",
    },

    ("canswer", "💭", "☐"): {
        'ru': "Нейро-ответ",
        'en': "Neuro-response",
        'es': "Neuro-respuesta",
        'fr': "Neuro-réponse",
        'zh': "神经反应",
        'ar': "الاستجابة العصبية",
    },
}
l_remove_bot = {
    'ru': "🚫Убрать бота",
    'en': "🚫Remove bot",
    'es': "🚫Eliminar robot",
    'fr': "🚫Supprimer le bot",
    'zh': "🚫删除机器人",
    'ar': "🚫إزالة البوت",
}
l_show_bots = {
    'ru': "👩🏽‍💻 <b>Добавленные боты</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Added bots</b>\n\n[commands/cmd]",
    'es': "👩🏽‍💻 <b>Bots agregados</b>\n\n[commands/cmd]",
    'fr': "👩🏽‍💻 <b>Bots ajoutés</b>\n\n[commands/cmd]",
    'zh': "👩🏽‍💻<b>添加了机器人</b>\n\n[命令/cmd]",
    'ar': "👩🏽‍💻 <b>الروبوتات المضافة</b>\n\n[commands/cmd]",
}
l_wait_free_ip = {
    'ru': "👩🏽‍💻 <b>Ожидание</b> свободных ресурсов для создания @tg-приложения..\n#длительность 21мин",
    'en': "👩🏽‍💻 <b>Waiting</b> for free resources to create a bot..\n#duration 21 min",
    'es': "👩🏽‍💻 <b>Esperando</b> recursos gratuitos para crear un bot...\n#duration 21 min",
    'fr': "👩🏽‍💻 <b>En attente</b> de ressources gratuites pour créer un bot..\n#durée 21 min",
    'zh': "👩🏽‍💻 <b>等待</b>免费资源来创建机器人..\n#duration 21 分钟",
    'ar': "👩🏽‍💻 <b>في انتظار</b> الموارد المجانية لإنشاء روبوت..\n#المدة 21 دقيقة",
}
l_bot_token_taken = {
    'ru': "👩🏽‍💻 <b>Токен</b>: {0} уже используется другим пользователем\n\n👩🏽‍💻 <b>Необходимо</b> перевыпустить/отозвать токен в @BotFather",
    'en': "👩🏽‍💻 <b>Token</b>: {0} is already in use by another user\n\n👩🏽‍💻 <b>Need</b> to reissue/revoke the token in @BotFather",
    'es': "👩🏽‍💻 <b>Token</b>: {0} ya está en uso por otro usuario\n\n👩🏽‍💻 <b>Necesita</b> volver a emitir/revocar el token en @BotFather",
    'fr': "👩🏽‍💻 <b>Jeton</b> : {0} est déjà utilisé par un autre utilisateur\n\n👩🏽‍💻 <b>Besoin</b> de réémettre/révoquer le jeton dans @BotFather",
    'zh': "👩🏽‍💻<b>令牌</b>：{0}已被其他用户使用\n\n👩🏽‍💻<b>需要</b>在@BotFather中重新颁发/撤销令牌",
    'ar': "👩🏽‍💻 <b>الرمز المميز</b>: {0} قيد الاستخدام بالفعل من قبل مستخدم آخر\n\n👩🏽‍💻 <b>تحتاج</b> إلى إعادة إصدار/إلغاء الرمز المميز في @BotFather",
}

l_creturntext = {
    'ru': "✖️ <b>Сбросить</b> настройки по умолчанию (до рекомендуемых) для <b>{0}</b>-@tg-приложения?",
    'en': "✖️ <b>Reset</b> default settings (to recommended) for bot [<b>{0}</b>]?",
    'es': "✖️ ¿<b>Restablecer</b> la configuración predeterminada (a la recomendada) para el bot [<b>{0}</b>]?",
    'fr': "✖️ <b>Réinitialiser</b> les paramètres par défaut (aux valeurs recommandées) pour le bot [<b>{0}</b>] ?",
    'zh': "✖️ 为机器人 [<b>{0}</b>] <b>重置</b>默认设置（推荐）？",
    'ar': "✖️ <b>إعادة تعيين</b> الإعدادات الافتراضية (للموصى بها) للبوت [<b>{0}</b>]؟",
}
l_creturnanswer = {
    'ru': "✖️ <b>Настройки</b> <b>{0}</b>-@tg-приложения успешно сброшены!",
    'en': "✖️ <b>Settings</b> of the bot [<b>{0}</b>] have been successfully reset!",
    'es': "✖️ ¡La <b>configuración</b> del bot [<b>{0}</b>] se ha restablecido correctamente!",
    'fr': "✖️ Les <b>paramètres</b> du bot [<b>{0}</b>] ont été réinitialisés avec succès !",
    'zh': "✖️ 机器人 [<b>{0}</b>] 的<b>设置</b>已成功重置！",
    'ar': "✖️ تمت إعادة تعيين <b>إعدادات</b> الروبوت [<b>{0}</b>] بنجاح!",
}
l_cdeletetext = {
    'ru': "🚫 <b>Убрать</b> привязку <b>{0}</b>-@tg-приложения?",
    'en': "🚫 <b>Remove</b> bot binding [<b>{0}</b>]?",
    'es': "🚫 ¿<b>Eliminar</b> enlace de bot [<b>{0}</b>]?",
    'fr': "🚫 <b>Supprimer</b> la liaison du bot [<b>{0}</b>] ?",
    'zh': "🚫 <b>删除</b>机器人绑定 [<b>{0}</b>]？",
    'ar': "🚫 <b>إزالة</b> ربط الروبوت [<b>{0}</b>]؟",
}
l_cdeleteanswer = {
    'ru': "🚫 <b>Бот</b> успешно откреплен [<b>{0}</b>]",
    'en': "🚫 <b>Bot</b> successfully unpinned [<b>{0}</b>]",
    'es': "🚫 <b>Bot</b> se desancló correctamente [<b>{0}</b>]",
    'fr': "🚫 <b>Bot</b> désépinglé avec succès [<b>{0}</b>]",
    'zh': "🚫 <b>机器人</b>已成功取消固定 [<b>{0}</b>]",
    'ar': "🚫 تمت إزالة تثبيت <b>البوت</b> بنجاح [<b>{0}</b>]",
}
l_transfer_success = {
    'ru': "👩🏽‍💻 <b>Права</b> владения на @{0}-@tg-приложением успешно переданы @{1}-аккаунту!\n\n👩🏽‍💻 Теперь для передачи прав/настройки можно использовать @botfather-бота",
    'en': "👩🏽‍💻 <b>Ownership rights</b> for @{0}-bot have been successfully transferred to @{1}-account!\n\n👩🏽‍💻 Now you can use @botfather-bot to transfer rights/setup",
    'es': "👩🏽‍💻 ¡Los <b>derechos de propiedad</b> para @{0}-bot se han transferido exitosamente a @{1}-cuenta!\n\n👩🏽‍💻 Ahora puedes usar @botfather-bot para transferir derechos/configuración",
    'fr': "👩🏽‍💻 <b>Les droits de propriété</b> pour @{0}-bot ont été transférés avec succès vers le compte @{1} !\n\n👩🏽‍💻 Vous pouvez désormais utiliser @botfather-bot pour transférer droits/configuration",
    'zh': "👩🏽‍💻 <b>@{0}-bot 的所有权</b>已成功转移至@{1}-账户！\n\n👩🏽‍💻 现在您可以使用@botfather-bot 进行转移权限/设置",
    'ar': "👩🏽‍💻 <b>حقوق الملكية</b> لـ @{0}-bot تم نقلها بنجاح إلى @{1}-account!\n\n👩🏽‍💻 الآن يمكنك استخدام @botfather-bot للنقل الحقوق/الإعداد",
}
# endregion


# region config
# region cpost_
l_pstsound = {
    'ru': "🔈 <b>Жми</b> на ✅/🔘, чтобы <b>Вкл/Выкл</b> режим отправки со звуком <i>по умолчанию</i>/<i>тихий режим</i> без звука/<i>закреп-пин</i>\n\n<blockquote>[✅ Закреп] оповещает пользователя при отключенных уведомлениях</blockquote>",
    'en': "🔈 <b>Press</b> on ✅/🔘 to <b>On/Off</b> sending mode with sound <i>default</i>/<i>quiet mode</i> without sound/ <i>pinned-pin</i>\n\n📍 <b>Mode</b> [✅ Pinned]-allows you to notify the user even when notifications are turned off",
    'es': "🔈 <b>Presione</b> en ✅/🔘 para <b>Activar/Desactivar</b> modo de envío con sonido <i>predeterminado</i>/<i>modo silencioso</i> sin sonido/ < i>pinned-pin</i>\n\n📍 <b>Modo</b> [✅ Fijado]-le permite notificar al usuario incluso cuando las notificaciones están desactivadas",
    'fr': "🔈 <b>Appuyez</b> sur ✅/🔘 pour <b>On/Off</b> mode d'envoi avec son <i>par défaut</i>/<i>mode silencieux</i> sans son/ < i>épinglé-épinglé</i>\n\n📍 <b>Mode</b> [✅ Épinglé]-vous permet d'avertir l'utilisateur même lorsque les notifications sont désactivées",
    'zh': "🔈 <b>按</b> ✅/🔘 可以<b>开/关</b>有声音发送模式<i>默认</i>/<i>安静模式</i>无声音/< i>pinned-pin</i>\n\n📍<b>模式</b> [✅ Pinned]-即使通知关闭，您也可以通知用户",
    'ar': "🔈 <b>اضغط</b> على ✅/🔘 لـ <b>تشغيل/إيقاف</b> وضع الإرسال مع الصوت <i>الافتراضي</i>/<i>الوضع الهادئ</i> بدون صوت/ <<i>pinned-pin</i>\n\n📍 <b>Mode</b> [✅ Pinned]-يسمح لك بإعلام المستخدم حتى عند إيقاف تشغيل الإشعارات",
}
l_pstmedia_bot = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b>: <i>превью-предпросмотр</i>/<i>спойлер-скрытый</i>/<i>галерея</i>/<i>формат</i>/<i>реакция</i>\n\n<blockquote>[<b>✅ превью</b>] помещает медиа-контент под текстом\n[<b>✅ формат</b>] рандомные стили текста\n[<b>✅ реакция</b>] рандомная реакция\n[<b>✅ эффект</b>] рандомный эффект</blockquote>",
    'en': "👩🏽‍💻 <b>Press</b> on ✅/☑️ to <b>On/Off</b> post viewing mode: <i>preview</i>/<i>spoiler-hidden</ i>/<i>gallery</i>/<i>format</i>/<i>podcast</i>\n\n[✅ preview]-mode places media content <i>(jpg/gif /mp4 up to 5 MB)</i>under the text\n[✅ format]-mode applies random styles to the post",
    'es': "👩🏽‍💻 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> el modo de visualización de publicaciones: <i>vista previa</i>/<i>spoiler oculto</ i> /<i>galería</i>/<i>formato</i>/<i>podcast</i>\n\n[✅ vista previa]: el modo coloca el contenido multimedia <i>(jpg/gif /mp4 arriba a 5 MB)</i>bajo el modo texto\n[✅ formato] aplica estilos aleatorios a la publicación",
    'fr': "👩🏽‍💻 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode de visualisation des publications : <i>aperçu</i>/<i>spoiler caché</ i> /<i>galerie</i>/<i>format</i>/<i>podcast</i>\n\n[✅ aperçu]-le mode place le contenu multimédia <i>(jpg/gif /mp4 vers le haut à 5 Mo)</i>sous le mode texte\n[✅ format] applique des styles aléatoires à la publication",
    'zh': "👩🏽‍💻 <b>按</b> ✅/☑️ 可以<b>开启/关闭</b>帖子查看模式：<i>预览</i>/<i>剧透隐藏</ i> /<i>图库</i>/<i>格​​式</i>/<i>播客</i>\n\n[✅ 预览]-模式放置媒体内容<i>(jpg/gif /mp4到 5 MB）</i>在文本下\n[✅ 格式]-模式对帖子应用随机样式",
    'ar': "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> وضع عرض المنشور: <i>معاينة</i>/<i>سبويلر مخفي</<i> /<i>المعرض</i>/<i>التنسيق</i>/<i>بودكاست</i>\n\n[✅ معاينة]-وضع وضع محتوى الوسائط <i>(jpg/gif /mp4 up إلى 5 ميغابايت)</i>تحت النص\n[✅ format]-يطبق الوضع أنماطًا عشوائية على المنشور",
}
l_pstmedia = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b>: <i>превью-предпросмотр</i>/<i>спойлер-скрытый</i>/<i>галерея</i>/<i>формат</i>/<i>@tag</i>/<i>реакция</i>/<i>подкаст</i>\n\n<blockquote>[<b>✅ превью</b>] помещает медиа-контент под текстом\n[<b>✅ формат</b>] рандомные стили текста\n[<b>✅ @tag</b>] рандомное @упоминание\n[<b>✅ реакция</b>] рандомная реакция\n[<b>✅ эффект</b>] рандомный эффект\n[<b>✅ подкаст</b>] запуск подкаста с публикацией</blockquote>",
    'en': "👩🏽‍💻 <b>Press</b> on ✅/☑️ to <b>On/Off</b> post viewing mode: <i>preview</i>/<i>spoiler-hidden</ i>/<i>gallery</i>/<i>format</i>/<i>podcast</i>\n\n[✅ preview]-mode places media content <i>(jpg/gif /mp4 up to 5 MB)</i>under the text\n[✅ format]-mode applies random styles to the post",
    'es': "👩🏽‍💻 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> el modo de visualización de publicaciones: <i>vista previa</i>/<i>spoiler oculto</ i> /<i>galería</i>/<i>formato</i>/<i>podcast</i>\n\n[✅ vista previa]: el modo coloca el contenido multimedia <i>(jpg/gif /mp4 arriba a 5 MB)</i>bajo el modo texto\n[✅ formato] aplica estilos aleatorios a la publicación",
    'fr': "👩🏽‍💻 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode de visualisation des publications : <i>aperçu</i>/<i>spoiler caché</ i> /<i>galerie</i>/<i>format</i>/<i>podcast</i>\n\n[✅ aperçu]-le mode place le contenu multimédia <i>(jpg/gif /mp4 vers le haut à 5 Mo)</i>sous le mode texte\n[✅ format] applique des styles aléatoires à la publication",
    'zh': "👩🏽‍💻 <b>按</b> ✅/☑️ 可以<b>开启/关闭</b>帖子查看模式：<i>预览</i>/<i>剧透隐藏</ i> /<i>图库</i>/<i>格​​式</i>/<i>播客</i>\n\n[✅ 预览]-模式放置媒体内容<i>(jpg/gif /mp4到 5 MB）</i>在文本下\n[✅ 格式]-模式对帖子应用随机样式",
    'ar': "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> وضع عرض المنشور: <i>معاينة</i>/<i>سبويلر مخفي</<i> /<i>المعرض</i>/<i>التنسيق</i>/<i>بودكاست</i>\n\n[✅ معاينة]-وضع وضع محتوى الوسائط <i>(jpg/gif /mp4 up إلى 5 ميغابايت)</i>تحت النص\n[✅ format]-يطبق الوضع أنماطًا عشوائية على المنشور",
}
l_mode_spoiler = {
    'ru': "👩🏽‍💻 Режим [✅ спойлер] доступен для фото/гиф/видео-форматов",
    'en': "👩🏽‍💻 [✅ spoiler] mode is available for photo/GIF/video formats",
    'es': "👩🏽‍💻 El modo [✅ spoiler] está disponible para formatos de foto/GIF/vídeo",
    'fr': "👩🏽‍💻 Le mode [✅ spoiler] est disponible pour les formats photo/GIF/vidéo",
    'zh': "👩🏽‍💻【✅剧透】模式适用于照片/GIF/视频格式",
    'ar': "👩🏽‍💻 وضع ​​[✅ المفسد] متاح لتنسيقات الصور / GIF / الفيديو",
}
l_mode_album = {
    'ru': "👩🏽‍💻 Режим [✅ альбом] доступен для фото/видео/аудио/документов",
    'en': "👩🏽‍💻 [✅ album] mode available for photos/videos/audio/documents",
    'es': "👩🏽‍💻 Modo [✅ álbum] disponible para fotos/videos/audio/documentos",
    'fr': "👩🏽‍💻 Mode [✅ album] disponible pour les photos/vidéos/audio/documents",
    'zh': "👩🏽‍💻【✅相册】模式可用于照片/视频/音频/文档",
    'ar': "👩🏽‍💻 وضع ​​[✅ الألبوم] متاح للصور/مقاطع الفيديو/الصوت/المستندات",
}
l_mode_gallery = {
    'ru': "👩🏽‍💻 Режим [✅ галерея] доступен для фото/видео/аудио/документов",
    'en': "👩🏽‍💻 [✅ gallery] mode available for photos/videos/audio/documents",
    'es': "👩🏽‍💻 Modo [✅ galería] disponible para fotos/videos/audio/documentos",
    'fr': "👩🏽‍💻 Mode [✅ galerie] disponible pour les photos/vidéos/audio/documents",
    'zh': "👩🏽‍💻 [✅ 图库] 模式可用于照片/视频/音频/文档",
    'ar': "👩🏽‍💻 وضع ​​[✔ المعرض] متاح للصور/مقاطع الفيديو/الصوت/المستندات",
}
# endregion


# region ctranslate_
l_ctranslate_text = {
    'ru': "文 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-перевод для <i>исходящих</i> сообщений бота на язык пользователя при /start-запуске бота\n(<i>в том числе текста кнопок</i>)",
    'en': "文 <b>Press</b> on ✅/☑️ to <b>On/Off</b> automatic translation for <i>outgoing</i> bot messages into the user’s language when /starting the bot\n( <i>including button text</i>)",
    'es': "文 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> la traducción automática de los mensajes del bot <i>salientes</i> al idioma del usuario al iniciar el bot\n( < i>incluido el texto del botón</i>)",
    'fr': "文 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la traduction automatique des messages <i>sortants</i> du bot dans la langue de l'utilisateur lors du /démarrage du bot\n( < i>y compris le texte du bouton</i>)",
    'zh': "文<b>按</b> ✅/☑️ 可以<b>开启/关闭</b>在/启动机器人时将<i>传出</i>机器人消息自动翻译为用户的语言\n( < i>包括按钮文本</i>)",
    'ar': "文 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الترجمة التلقائية لرسائل الروبوت <i>الصادرة</i> إلى لغة المستخدم عند /بدء تشغيل الروبوت\n( < أنا>بما في ذلك نص الزر</i>)",
}
l_ctranslate_in_on = {
    'ru': "✅☑Вкл перевод входящих",
    'en': "✅☑On inbox translation",
    'es': "✅☑En la traducción de la bandeja de entrada",
    'fr': "✅☑Sur la traduction de la boîte de réception",
    'zh': "✅☑关于收件箱翻译",
    'ar': "✅☑في ترجمة البريد الوارد",
}
l_ctranslate_in_off = {
    'ru': "☑️☐Выкл перевод входящих",
    'en': "☑️☐Disable inbox transfer",
    'es': "☑️☐Desactivar transferencia de bandeja de entrada",
    'fr': "☑️☐Désactiver le transfert de la boîte de réception",
    'zh': "☑️️禁用收件箱传输",
    'ar': "☑️☐تعطيل نقل البريد الوارد",
}
l_ctranslate_out_on = {
    'ru': "✅☑Вкл перевод исходящих",
    'en': "✅☑On outgoing transfer",
    'es': "✅☑En transferencia saliente",
    'fr': "✅☑Sur virement sortant",
    'zh': "✅☑关于汇出转账",
    'ar': "✅☑عند التحويل الصادر",
}
l_ctranslate_out_off = {
    'ru': "☑️☐Выкл перевод исходящих",
    'en': "☑️☐Disable outgoing transfer",
    'es': "☑️☐Desactivar transferencia saliente",
    'fr': "☑️☐Désactiver le transfert sortant",
    'zh': "☑️️禁用传出转账",
    'ar': "☑️☐تعطيل النقل الصادر",
}
# endregion


# region canswer_
l_canswer_text = {
    'ru': "💭 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим #нейро-ответа на сообщения пользователя в @{0} с помощью нейросети\n\n<blockquote>на основе описания/постов/контента всех блоков</blockquote>",
    'en': "💭 <b>Press</b> on ✅/☑️ to <b>On/Off</b> neuro-response mode to user messages in @{0} using a neural network (based on the description/posts/content of all blocks)",
    'es': "💭 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el modo de neurorespuesta a los mensajes de usuario en @{0} usando una red neuronal (según la descripción/publicaciones/contenido de todos los bloques)",
    'fr': "💭 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode de neuro-réponse aux messages des utilisateurs dans @{0} en utilisant un réseau neuronal (en fonction de la description/des publications/du contenu de tous les blocs)",
    'zh': "💭 <b>按</b> ✅/☑️ 以<b>开/关</b>神经响应模式使用神经网络对 @{0} 中的用户消息（基于描述/帖子/内容）所有块）",
    'ar': "💭 <b>اضغط</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> وضع الاستجابة العصبية لرسائل المستخدم في @{0} باستخدام الشبكة العصبية (استنادًا إلى الوصف/المشاركات/محتوى جميع الكتل)",
}
l_canswer_user_text = {
    'ru': "💭 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим #нейро-ответа на сообщения пользователя с помощью нейросети\n\n<blockquote>на основе описания/постов/контента всех блоков</blockquote>",
    'en': "💭 <b>Press</b> on ✅/☑️ to <b>On/Off</b> neuro-response mode to user messages using a neural network (based on the description/posts/content of all blocks)",
    'es': "💭 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el modo de neurorespuesta a los mensajes de los usuarios usando una red neuronal (basado en la descripción/publicaciones/contenido de todos los bloques)",
    'fr': "💭 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode neuro-réponse aux messages des utilisateurs utilisant un réseau neuronal (en fonction de la description/des publications/du contenu de tous les blocs)",
    'zh': "💭 <b>按</b> ✅/☑️ 可以<b>开/关</b>使用神经网络对用户消息进行神经响应模式（基于所有块的描述/帖子/内容）",
    'ar': "💭 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> وضع الاستجابة العصبية لرسائل المستخدم باستخدام الشبكة العصبية (استنادًا إلى الوصف/المشاركات/محتوى جميع الكتل)",
}
# endregion


# region cneuro_
l_cneuro_text = {
    'ru': "🦾 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> #нейро-постинг. Генерация текста/медиа на основе постов/описания/контента: <b>{0}</b>",
    'en': "🦾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> neuro-posting. Generate photo/text based on posts/descriptions/content: <b>{0}</b>",
    'es': "🦾 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> la neuropublicación. Generar foto/texto basado en publicaciones/descripciones/contenido: <b>{0}</b>",
    'fr': "🦾 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> le neuro-posting. Générez une photo/un texte basé sur des publications/descriptions/contenu : <b>{0}</b>",
    'zh': "🦾 <b>按</b> ✅/☑️ 可<b>开/关</b>神经发布。根据帖子/描述/内容生成照片/文本：<b>{0}</b>",
    'ar': "🦾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> النشر العصبي. أنشئ صورة/نصًا استنادًا إلى المشاركات/الأوصاف/المحتوى: <b>{0}</b>",
}
l_cneuro_media = {
    'ru': "🦾 1. <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> генерацию медиа на основе постов/описания/контента в <b>{0}</b>\n\n👩🏽‍💻 <b>Напиши</b> экстра-промпт, если необходимо\n\n<blockquote>жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    'en': "🦾 1. <b>Press</b> on ✅/☑️ to <b>On/Off</b> <u>photo</u> generation based on posts/descriptions/content in <b>{0}< /b>\n\n👩🏽‍💻 <b>Write</b> an extra prompt if necessary\n\n(<i>click “➡️️/Next” to go to the next step</i> )",
    'es': "🦾 1. <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la generación de <u>foto</u> basada en publicaciones/descripciones/contenido en <b>{0}< /b>\n\n👩🏽‍💻 <b>Escribe</b> un mensaje adicional si es necesario\n\n(<i>haz clic en “➡️️/Siguiente” para ir al siguiente paso</i>)",
    'fr': "🦾 1. <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la génération de <u>photo</u> en fonction des publications/descriptions/contenus dans <b>{0}< /b>\n\n👩🏽‍💻 <b>Écrivez</b> une invite supplémentaire si nécessaire\n\n(<i>cliquez sur « ➡️️/Suivant » pour passer à l'étape suivante</i> )",
    'zh': "🦾 1. <b>按</b> ✅/☑️ 可<b>开启/关闭</b><u>照片</u>根据<b>{0}<中的帖子/描述/内容生成/b>\n\n👩🏽‍💻<b>如有必要请编写</b>额外提示\n\n（<i>点击“➡️️/下一步”进入下一步</i>）",
    'ar': "🦾 1. <b>اضغط</b> على ✅/☑️ لتشغيل <b>تشغيل/إيقاف</b> <u>صورة</u> بناءً على المنشورات/الأوصاف/المحتوى في <b>{0}< /b>\n\n👩🏽‍💻 <b>اكتب</b> مطالبة إضافية إذا لزم الأمر\n\n(<i>انقر فوق '➡️️/التالي' للانتقال إلى الخطوة التالية</i> )",
}
l_cneuro_process = {
    'ru': "🦾 <b>Генерация</b> <i>{0}</i>..\n#длительность 0мин",
    'en': "🦾 <b>Generation</b> <i>{0}</i>..\n#duration 0 min",
    'es': "🦾 <b>Generación</b> <i>{0}</i>..\n#duración 0 min",
    'fr': "🦾 <b>Génération</b> <i>{0}</i>..\n#durée 0 min",
    'zh': "🦾 <b>一代</b> <i>{0}</i>..\n#duration 0 分钟",
    'ar': "🦾 <b>الجيل</b> <i>{0}</i>..\n#duration 0 min",
}
l_cneuro_error = {
    'ru': "🦾 <b>Ошибка</b> генерации: попробуй еще раз или повтори позже",
    'en': "🦾 <b>Error</b> generation: try again or try again later",
    'es': "🦾 Generación de <b>Error</b>: inténtalo de nuevo o inténtalo más tarde",
    'fr': "🦾 Génération de <b>Erreur</b> : réessayez ou réessayez plus tard",
    'zh': "🦾<b>错误</b>生成：重试或稍后重试",
    'ar': "🦾 جيل <b>الخطأ</b>: حاول مرة أخرى أو حاول مرة أخرى لاحقًا",
}
l_cneuro_caption = {
    'ru': "🦾 2. <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> генерацию <u>текста</u> на основе описания/контента в <b>{0}</b>\n\n👩🏽‍💻 <b>Напиши</b> экстра-промпт, если необходимо\n\n<blockquote>жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    'en': "🦾 2. <b>Press</b> on ✅/☑️ to <b>On/Off</b> generation of <u>text</u> based on the description and content of the account <b>{0}</b >\n\n👩🏽‍💻 <b>Write</b> an extra prompt, if necessary\n\n(<i>click “➡️️/Next” to go to the next step</i>)",
    'es': "🦾 2. <b>Presiona</b> en ✅/☑️ para <b>activar/desactivar</b> la generación de <u>texto</u> según la descripción y el contenido de la cuenta <b>{0 }</b >\n\n👩🏽‍💻 <b>Escribe</b> un mensaje adicional, si es necesario\n\n(<i>haz clic en “➡️️/Siguiente” para ir al siguiente paso</ yo>)",
    'fr': "🦾 2. <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> la génération de <u>texte</u> en fonction de la description et du contenu du compte <b>{0 </b>\n\n👩🏽‍💻 <b>Écrivez</b> une invite supplémentaire, si nécessaire\n\n(<i>cliquez sur « ➡️️/Suivant » pour passer à l'étape suivante</ je>)",
    'zh': "🦾 2. <b>按</b> ✅/☑️ 可根据帐户的描述和内容<b>打开/关闭</b>生成<u>文本</u><b>{0 }</b >\n\n👩🏽‍💻 <b>编写</b>额外的提示（如有必要）\n\n（<i>点击“➡️️/下一步”进入下一步</我>)",
    'ar': "🦾 2. <b>اضغط</b> على ✅/☑️ لتشغيل <b>تشغيل/إيقاف</b> إنشاء <u>نص</u> بناءً على وصف الحساب ومحتواه <b>{0 }</b >\n\n👩🏽‍💻 <b>اكتب</b> مطالبة إضافية، إذا لزم الأمر\n\n(<i>انقر فوق '➡️️/التالي' للانتقال إلى الخطوة التالية</ أنا>)",
}
l_cneuro_isnotpaid = {
    'ru': "🦾 Без подписки доступна генерация:\nтекст/аудио/голосовое",
    'en': "🦾 <b>Error</b> generation: try again or try again later",
    'es': "🦾 Generación de <b>Error</b>: inténtalo de nuevo o inténtalo más tarde",
    'fr': "🦾 Génération de <b>Erreur</b> : réessayez ou réessayez plus tard",
    'zh': "🦾<b>错误</b>生成：重试或稍后重试",
    'ar': "🦾 جيل <b>الخطأ</b>: حاول مرة أخرى أو حاول مرة أخرى لاحقًا",
}
# endregion


# region cpayment_
l_cpayment_alert_crypto = {
    'ru': "💎️ Жми на [💎 Крипто], чтобы настроить крипто-адрес",
    'en': "💳️ You need to ⚙️Set up at least one payment token",
    'es': "💳️ Debes ⚙️Configurar al menos un token de pago",
    'fr': "💳️ Vous devez ⚙️Configurer au moins un jeton de paiement",
    'zh': "💳️您需要⚙️设置至少一个支付令牌",
    'ar': "💳️ تحتاج إلى ⚙️ إعداد رمز دفع واحد على الأقل",
}
l_cpayment_alert_token = {
    'ru': "💳️ Жми на [💳️ Карта банка], чтобы настроить платежный токен",
    'en': "💳️ You need to ⚙️Set up at least one payment token",
    'es': "💳️ Debes ⚙️Configurar al menos un token de pago",
    'fr': "💳️ Vous devez ⚙️Configurer au moins un jeton de paiement",
    'zh': "💳️您需要⚙️设置至少一个支付令牌",
    'ar': "💳️ تحتاج إلى ⚙️ إعداد رمز دفع واحد على الأقل",
}
l_cpayment_text = {
    'ru': "💳️ <b>Жми</b> на [💎 Крипто-кошелек]/[💳 Карта банка], чтобы настроить платежи в @{0}-боте {3}\n\n<blockquote>💎 <b>Текущий</b> крипто-адрес:\n<code>{1}</code></blockquote>\n\n<blockquote>💳 <b>Текущий</b> платежный токен:\n<code>{2}</code></blockquote>",
    'en': "💳️ <b>Click</b> on ✅/☑️ to <b>On/Off</b> payments in @{0}-bot\n\n👩🏽‍💻 <b>Current</b> payment token :\n{1}",
    'es': "💳️ <b>Haga clic</b> en ✅/☑️ para <b>activar/desactivar</b> pagos en @{0}-bot\n\n👩🏽‍💻 Token de pago <b>actual</b> :\n{1}",
    'fr': "💳️ <b>Cliquez<l_cpayment_text_landing/b> sur ✅/☑️ pour <b>Activer/Désactiver</b> les paiements dans @{0}-bot\n\n👩🏽‍💻 Jeton de paiement <b>Actuel</b> :\n{1}",
    'zh': "💳️ <b>点击</b> ✅/☑️ 在 @{0}-bot 中<b>开启/关闭</b>付款\n\n👩🏽‍💻 <b>当前</b>付款令牌:\n{1}",
    'ar': "💳️ <b>انقر</b> على ✅/☑️ <b>تشغيل/إيقاف</b> الدفعات في رمز الدفع @{0}-bot\n\n👩🏽‍💻 <b>الحالي</b> :\n{1}",
}
l_cpayment_text_landing = {
    'ru': "\n\n<blockquote><a href='https://t.me/FereyBotBot/web?startapp={0}_donations'>💎 Ссылка на веб3ᵀᴼᴺ-донаты</a></blockquote>",
    'en': "💳️ <b>Click</b> on ✅/☑️ to <b>On/Off</b> payments in @{0}-bot\n\n👩🏽‍💻 <b>Current</b> payment token :\n{1}",
    'es': "💳️ <b>Haga clic</b> en ✅/☑️ para <b>activar/desactivar</b> pagos en @{0}-bot\n\n👩🏽‍💻 Token de pago <b>actual</b> :\n{1}",
    'fr': "💳️ <b>Cliquez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> les paiements dans @{0}-bot\n\n👩🏽‍💻 Jeton de paiement <b>Actuel</b> :\n{1}",
    'zh': "💳️ <b>点击</b> ✅/☑️ 在 @{0}-bot 中<b>开启/关闭</b>付款\n\n👩🏽‍💻 <b>当前</b>付款令牌:\n{1}",
    'ar': "💳️ <b>انقر</b> على ✅/☑️ <b>تشغيل/إيقاف</b> الدفعات في رمز الدفع @{0}-bot\n\n👩🏽‍💻 <b>الحالي</b> :\n{1}",
}
l_cpayment_btn_crypto = {
    'ru': "💎 Крипто-кошелек",
    'en': "💳️ You need to ⚙️Set up at least one payment token",
    'es': "💳️ Debes ⚙️Configurar al menos un token de pago",
    'fr': "💳️ Vous devez ⚙️Configurer au moins un jeton de paiement",
    'zh': "💳️您需要⚙️设置至少一个支付令牌",
    'ar': "💳️ تحتاج إلى ⚙️ إعداد رمز دفع واحد على الأقل",
}
l_cpayment_btn_card = {
    'ru': "💳 Карта банка",
    'en': "💳️ You need to ⚙️Set up at least one payment token",
    'es': "💳️ Debes ⚙️Configurar al menos un token de pago",
    'fr': "💳️ Vous devez ⚙️Configurer au moins un jeton de paiement",
    'zh': "💳️您需要⚙️设置至少一个支付令牌",
    'ar': "💳️ تحتاج إلى ⚙️ إعداد رمز دفع واحد على الأقل",
}
l_cpayment_crypto = {
    'ru': "💎 <b>Вставь</b> адрес TON-кошелька\n\n<blockquote>👩🏽‍💻 <b>Например</b>\n<code>UQeG...KnNM</code>\n\n👩🏽‍💻 <b>Текущий</b> крипто-адрес:\n<code>{0}</code></blockquote>",
    'en': "💳️ <b>Insert</b> payment token received from @BotFather-bot\n\n👩🏽‍💻 <b>For example</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Current</b>token:\n{0}",
    'es': "💳️ <b>Insertar</b> token de pago recibido de @BotFather-bot\n\n👩🏽‍💻 <b>Por ejemplo</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Token</b>actual:\n{0}",
    'fr': "💳️ <b>Insérer</b> le jeton de paiement reçu de @BotFather-bot\n\n👩🏽‍💻 <b>Par exemple</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Jeton</b>actuel :\n{0}",
    'zh': "💳️ <b>插入</b>从@BotFather-bot\n\n👩🏽‍💻 <b>例如</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >当前</b>令牌：\n{0}",
    'ar': "💳️ <b>أدخل</b> رمز الدفع المستلم من @BotFather-bot\n\n👩🏽‍💻 <b>على سبيل المثال</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >الرمز</b>الحالي:\n{0}",
}
l_cpayment_token = {
    'ru': "💳️ <b>Вставь</b> платежный токен, полученный из @BotFather-бота\n\n<blockquote>👩🏽‍💻 <b>Например</b>\n<code>401643678:7049d0b3-f0267096c4a1</code>\n\n👩🏽‍💻 <b>Текущий</b> токен:\n<code>{0}</code></blockquote>",
    'en': "💳️ <b>Insert</b> payment token received from @BotFather-bot\n\n👩🏽‍💻 <b>For example</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Current</b>token:\n{0}",
    'es': "💳️ <b>Insertar</b> token de pago recibido de @BotFather-bot\n\n👩🏽‍💻 <b>Por ejemplo</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Token</b>actual:\n{0}",
    'fr': "💳️ <b>Insérer</b> le jeton de paiement reçu de @BotFather-bot\n\n👩🏽‍💻 <b>Par exemple</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >Jeton</b>actuel :\n{0}",
    'zh': "💳️ <b>插入</b>从@BotFather-bot\n\n👩🏽‍💻 <b>例如</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >当前</b>令牌：\n{0}",
    'ar': "💳️ <b>أدخل</b> رمز الدفع المستلم من @BotFather-bot\n\n👩🏽‍💻 <b>على سبيل المثال</b>\n401643678:7049d0b3-f0267096c4a1\n\n👩🏽‍💻 <b >الرمز</b>الحالي:\n{0}",
}
l_cpayment_crypto_done = {
    'ru': "💎 <b>Готово!</b>\n\n👩🏽‍💻 <b>Текущий</b> крипто-адрес для @{0}-бота:\n\n<code>{1}</code>",
    'en': "💳️ <b>Done!</b>\n\n👩🏽‍💻 <b>Current</b> payment token for @{0}-bot:\n\n{1}",
    'es': "💳️ <b>¡Listo!</b>\n\n👩🏽‍💻 Token de pago <b>actual</b> para @{0}-bot:\n\n{1}",
    'fr': "💳️ <b>Terminé !</b>\n\n👩🏽‍💻 <b>Jeton de paiement actuel</b> pour @{0}-bot :\n\n{1}",
    'zh': "💳️ <b>完成！</b>\n\n👩🏽‍💻 @{0}-bot 的<b>当前</b>付款令牌：\n\n{1}",
    'ar': "💳️ <b>تم!</b>\n\n👩🏽‍💻 رمز الدفع <b>الحالي</b> لـ @{0}-bot:\n\n{1}",
}
l_cpayment_token_done = {
    'ru': "💳️ <b>Готово!</b>\n\n👩🏽‍💻 <b>Текущий</b> платежный токен для @{0}-бота:\n\n<code>{1}</code>",
    'en': "💳️ <b>Done!</b>\n\n👩🏽‍💻 <b>Current</b> payment token for @{0}-bot:\n\n{1}",
    'es': "💳️ <b>¡Listo!</b>\n\n👩🏽‍💻 Token de pago <b>actual</b> para @{0}-bot:\n\n{1}",
    'fr': "💳️ <b>Terminé !</b>\n\n👩🏽‍💻 <b>Jeton de paiement actuel</b> pour @{0}-bot :\n\n{1}",
    'zh': "💳️ <b>完成！</b>\n\n👩🏽‍💻 @{0}-bot 的<b>当前</b>付款令牌：\n\n{1}",
    'ar': "💳️ <b>تم!</b>\n\n👩🏽‍💻 رمز الدفع <b>الحالي</b> لـ @{0}-bot:\n\n{1}",
}
# endregion


# region cintegration_
l_cintegration_alert = {
    'ru': "🗝️ Нужно ⚙️Настроить ССЫЛКУ доступа",
    'en': "🗝️ You need to ⚙️Set up an access LINK",
    'es': "🗝️ Necesitas ⚙️Configurar un ENLACE de acceso",
    'fr': "🗝️ Vous devez ⚙️Mettre en place un LIEN d'accès",
    'zh': "🗝️您需要⚙️设置访问LINK",
    'ar': "🗝️ أنت بحاجة إلى ⚙️ إعداد رابط الوصول",
}
l_cintegration_text = {
    'ru': "🗝️ <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> crm-интеграцию базы пользователей с <i><b>google</b></i>\n\n<blockquote>[<b>{0}</b>] интеграция базы пользователей с <i>google-crm</i></blockquote>",
    'en': "🗝️ <b>Press</b> on ✅/☑️ to <b>On/Off</b> crm-integration of the user base with <i><b>google</b>/<b>airtable</b> </i>\n\n👩🏽‍💻 For example, the [<b>{0}</b>] option means the ability to integrate the user database with <i>google-crm</i>",
    'es': "🗝️ <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> integración crm de la base de usuarios con <i><b>google</b>/<b>airtable</ b> </i>\n\n👩🏽‍💻 Por ejemplo, la opción [<b>{0}</b>] significa la capacidad de integrar la base de datos de usuarios con <i>google-crm</i>",
    'fr': "🗝️ <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> l'intégration CRM de la base d'utilisateurs avec <i><b>google</b>/<b>airtable</ b> </i>\n\n👩🏽‍💻 Par exemple, l'option [<b>{0}</b>] signifie la possibilité d'intégrer la base de données des utilisateurs avec <i>google-crm</i>",
    'zh': "🗝️ <b>按</b> ✅/☑️ <b>开启/关闭</b>用户群与 <i><b>google</b>/<b>airtable</b> 的 crm 集成b> </i>\n\n👩🏽‍💻 例如，[<b>{0}</b>] 选项表示能够将用户数据库与 <i>google-crm</i> 集成",
    'ar': "🗝️ <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> تكامل crm لقاعدة المستخدمين مع <i><b>google</b>/<b>airtable</ b> </i>\n\n👩🏽‍💻 على سبيل المثال، الخيار [<b>{0}</b>] يعني القدرة على دمج قاعدة بيانات المستخدم مع <i>google-crm</i>",
}

l_cintegration_google_on = {
    'ru': "✅☑Вкл google-crm",
    'en': "✅☑Includes google-crm",
    'es': "✅☑Incluye google crm",
    'fr': "✅☑Comprend google-crm",
    'zh': "✅☑包括 google-crm",
    'ar': "✅☑يتضمن google-crm",
}
l_cintegration_google_off = {
    'ru': "☑️☐Выкл google-crm",
    'en': "☑️☐Выкл google-crm",
    'es': "☑️☐Выкл google crm",
    'fr': "☑️☐Выкл google-crm",
    'zh': "☑️ Выкл 谷歌-crm",
    'ar': "☑️☐Выкл google-crm",
}
l_cintegration_airtable_on = {
    'ru': "✅☑Вкл airtable-crm",
    'en': "✅☑Includes airtable-crm",
    'es': "✅☑Incluye airtable-crm",
    'fr': "✅☑Comprend airtable-crm",
    'zh': "✅☑包括airtable-crm",
    'ar': "✅☑يتضمن طاولة هوائية crm",
}
l_cintegration_airtable_off = {
    'ru': "☑️☐Выкл airtable-crm",
    'en': "☑️☐Выкл airtable-crm",
    'es': "☑️☐Выкл airtable-crm",
    'fr': "☑️☐Выкл airtable-crm",
    'zh': "☑️ Выкл Airtable-crm",
    'ar': "☑️☐Выкл airtable-crm",
}

l_cintegration_google = {
    'ru': "🗝️ <b>Вставь ссылку</b> на пустую google-таблицу (<i>с открытым доступом для редактирования</i>) для интеграции с базой пользователей @{0}-бота\n\n<blockquote>👩🏽‍💻 <b>Например</b>, https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{1}</blockquote>",
    'en': "🗝️ <b>Insert a link</b> into an empty Google spreadsheet (<i>with open access for editing</i>) to integrate with the @{0}-bot user base\n\n👩🏽‍💻 <b >For example</b>, https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing\n\n👩🏽‍💻 <b>Current</b> link:\n{1 }",
    'es': "🗝️ <b>Inserte un enlace</b> en una hoja de cálculo de Google vacía (<i>con acceso abierto para editar</i>) para integrarlo con la base de usuarios del @{0}-bot\n\n👩🏽‍💻 <b >Por ejemplo</b>, https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing\n\n👩🏽‍💻 Enlace <b>Actual</b>:\ norte{1}",
    'fr': "🗝️ <b>Insérez un lien</b> dans une feuille de calcul Google vide (<i>avec accès ouvert pour l'édition</i>) pour l'intégrer à la base d'utilisateurs @{0}-bot\n\n👩🏽‍💻 <b >Par exemple</b>, https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing\n\n👩🏽‍💻 Lien <b>actuel</b> :\ n{1 }",
    'zh': "🗝️ <b>插入链接</b>到空的 Google 电子表格（<i>具有开放编辑权限</i>），以与 @{0}-bot 用户群集成\n\n👩🏽‍💻 <b>例如</b>， https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit ?usp=sharing\n\n👩🏽‍💻<b>当前</b>链接：\ n{1}",
    'ar': "🗝️ <b>أدخل رابطًا</b> في جدول بيانات Google فارغًا (<i>مع إمكانية الوصول المفتوح للتحرير</i>) للتكامل مع قاعدة مستخدمي @{0}-bot\n\n👩🏽‍💻 <b >على سبيل المثال</b>، https://docs.google.com/spreadsheets/d/1aWGYLL0WWZP/edit?usp=sharing\n\n👩🏽‍💻 الرابط <b>الحالي</b>:\ ن{1 }",
}
l_cintegration_airtable = {
    'ru': "🗝️ <b>Вставь ссылку</b> на пустую airtable-таблицу (<i>с открытым доступом для редактирования и любого e-mail</i>) для интеграции с базой пользователей @{0}-бота\n\n👩🏽‍💻 <b>Например</b>, https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{1}",
    'en': "🗝️ <b>Insert a link</b> into an empty airtable table (<i>with open access for editing and any e-mail</i>) for integration with the @{0}-bot user base\n\n👩 🏽‍💻 <b>For example</b>, https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻 <b>Current</b> link:\ n{1}",
    'es': "🗝️ <b>Inserte un enlace</b> en una tabla airtable vacía (<i>con acceso abierto para edición y cualquier correo electrónico</i>) para la integración con la base de usuarios @{0}-bot\n\ n👩 🏽‍💻 <b>Por ejemplo</b>, https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻 <b>Actual</b> enlace:\n{1}",
    'fr': "🗝️ <b>Insérez un lien</b> dans une table airtable vide (<i>avec accès ouvert pour l'édition et tout e-mail</i>) pour l'intégration avec la base d'utilisateurs @{0}-bot\n\ n👩 🏽‍💻 <b>Par exemple</b>, https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻 <b>Actuel</b> lien :\ n{1}",
    'zh': "🗝️ <b>插入链接</b>到空的airtable表格中（<i>具有开放的编辑权限和任何电子邮件</i>），以便与@{0}-bot用户群集成\n\ n👩 🏽‍💻 <b>例如</b>， https://airtable.com/invite/l? inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻<b>当前</b>链接：\n{1}",
    'ar': "🗝️ <b>أدخل رابطًا</b> في جدول هوائي فارغ (<i>مع إمكانية الوصول المفتوح للتحرير وأي بريد إلكتروني</i>) للتكامل مع قاعدة مستخدمي @{0}-bot\n\n👩 🏽‍💻 <b>على سبيل المثال</b>، https://airtable.com/invite/l?inviteId=inv4VGM&inviteToken=f1d31f9aba6b&utm_medium=email\n\n👩🏽‍💻 <b>الحالي</b> الرابط:\ ن{1}",
}
l_cintegration_done = {
    'ru': "🗝️ <b>Готово!</b>\n\n👩🏽‍💻 <b>Текущая</b> ссылка:\n{0}",
    'en': "🗝️ <b>Done!</b>\n\n👩🏽‍💻 <b>Current</b> link:\n{0}",
    'es': "🗝️ <b>¡Listo!</b>\n\n👩🏽‍💻 Enlace <b>Actual</b>:\n{0}",
    'fr': "🗝️ <b>Terminé !</b>\n\n👩🏽‍💻 Lien <b>actuel</b> :\n{0}",
    'zh': "🗝️ <b>完成！</b>\n\n👩🏽‍💻<b>当前</b>链接：\n{0}",
    'ar': "🗝️ <b>تم!</b>\n\n👩🏽‍💻 الرابط <b>الحالي</b>:\n{0}",
}
# endregion


# region cnotification_
l_cnotification_text = {
    'ru': "💬 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> оповещения о <i><b>/start-stop</b> запуске/блокировке бота пользователем и попадании пользователя в <b>/ban</b>-список/<b>нажатии</b> на кнопки пользователем/<b>диалоге</b> с администраторами/<b>всех</b> действиях пользователя</i>\n\n<blockquote>[<b>{0}</b>] пересылка сообщения пользователя администраторам бота (/admin) с возможностью <i>реплай-ответа</i></blockquote>",
    'en': "💬 <b>Press</b> on ✅/☑️ to <b>On/Off</b> notifications about <i><b>/start-stop</b> the user starts/blocks the bot and the user gets into < b>/ban</b>-list/<b>clicking</b> buttons by the user/<b>dialog</b> with administrators/<b>all</b> user actions</i>\n\n👩🏽‍💻 [<b>{0}</b>] means displaying messages from the user to bot administrators (/admin) with the ability to <i>replay-reply</i> to messages",
    'es': "💬 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> notificaciones sobre <i><b>/start-stop</b> el usuario inicia/bloquea el bot y el usuario entra en < b>/ban</b>-lista/<b>haciendo clic</b> en los botones del usuario/<b>diálogo</b> con los administradores/<b>todas</b> las acciones del usuario</ i>\n\n👩🏽‍💻 [<b>{0}</b>] significa mostrar mensajes del usuario a los administradores del bot (/admin) con la capacidad de <i>reproducir-responder</i> a mensajes",
    'fr': "💬 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> les notifications concernant <i><b>/start-stop</b> l'utilisateur démarre/bloque le bot et l'utilisateur entre dans la < b>/ban</b>-list/<b>clic</b> sur les boutons par l'utilisateur/<b>dialogue</b> avec les administrateurs/<b>toutes</b> les actions de l'utilisateur</ i>\n\n👩🏽‍💻 [<b>{0}</b>] signifie afficher les messages de l'utilisateur aux administrateurs de robots (/admin) avec la possibilité de <i>rejouer-répondre</i> à messages",
    'zh': "💬 <b>按</b> ✅/☑️ 可<b>开/关</b>有关<i><b>/start-stop</b>用户启动/阻止机器人和用户的通知进入<b>/ban</b>-列表/<b>单击</b>用户按钮/<b>与管理员对话</b>/<b>所有</b>用户操作</ i>\n\n👩🏽‍💻 [<b>{0}</b>] 表示将用户发送给机器人管理员 (/admin) 的消息显示为能够<i>重播回复</i>消息",
    'ar': "💬 <b>اضغط</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> إشعارات حول <i><b>/start-stop</b> يقوم المستخدم بتشغيل/حظر الروبوت والمستخدم الدخول إلى < b>/ban</b>-list/<b>النقر</b> على الأزرار بواسطة المستخدم/<b>مربع الحوار</b> مع المسؤولين/<b>جميع</b> إجراءات المستخدم</<i>\n\n👩🏽‍💻 [<b>{0}</b>] يعني عرض الرسائل من المستخدم إلى مسؤولي الروبوت (/admin) مع إمكانية <i>إعادة التشغيل والرد</i> على رسائل",
}
l_cnotification_start_on = {
    'ru': "✅☑Вкл /start-stop-/ban",
    'en': "✅☑On /start-stop-/ban",
    'es': "✅☑Activado /start-stop-/ban",
    'fr': "✅☑On/start-stop-/ban",
    'zh': "✅☑开启/开始-停止-/禁止",
    'ar': "✅☑تشغيل/بدء-إيقاف-/حظر",
}
l_cnotification_start_off = {
    'ru': "☑️☐Выкл /start-stop-/ban",
    'en': "☑️☐Выкл /start-stop-/ban",
    'es': "☑️☐Выкл /start-stop-/ban",
    'fr': "☑️☐Выкл /start-stop-/ban",
    'zh': "☑️ Выкл /开始-停止-/禁止",
    'ar': "☑️☐Выкл /start-stop-/ban",
}
l_cnotification_push_on = {
    'ru': "✅☑Вкл нажатие на кнопки",
    'en': "✅☑Turn on by pressing buttons",
    'es': "✅☑Enciende presionando botones",
    'fr': "✅☑Allumez en appuyant sur les boutons",
    'zh': "✅☑按下按钮即可开启",
    'ar': "✅☑يتم التشغيل عن طريق الضغط على الأزرار",
}
l_cnotification_push_off = {
    'ru': "☑️☐Выкл нажатие на кнопки",
    'en': "☑️☐Off pressing buttons",
    'es': "☑️☐Apagado presionando botones",
    'fr': "☑️☐Arrêt d'appuyer sur les boutons",
    'zh': "☑️️关闭按钮",
    'ar': "☑️☐إيقاف الضغط على الأزرار",
}

l_cnotification_dialog_on = {
    'ru': "✅☑Вкл диалог",
    'en': "✅☑Dialogue included",
    'es': "✅☑Diálogo incluido",
    'fr': "✅☑Dialogue inclus",
    'zh': "✅☑包含对话",
    'ar': "✅☑الحوار متضمن",
}
l_cnotification_dialog_off = {
    'ru': "☑️☐Выкл диалог",
    'en': "☑️☐Disable dialogue",
    'es': "☑️☐Desactivar diálogo",
    'fr': "☑️☐Désactiver les dialogues",
    'zh': "☑️️禁用对话",
    'ar': "☑️☐تعطيل الحوار",
}
l_cnotification_all_on = {
    'ru': "✅☑Вкл все действия",
    'en': "✅☑Including all actions",
    'es': "✅☑Incluyendo todas las acciones",
    'fr': "✅☑Y compris toutes les actions",
    'zh': "✅☑包括所有行动",
    'ar': "✅☑شامل جميع الإجراءات",
}
l_cnotification_all_off = {
    'ru': "☑️☐Выкл все действия",
    'en': "☑️☐Turn off all actions",
    'es': "☑️☐Desactiva todas las acciones",
    'fr': "☑️☐Désactivez toutes les actions",
    'zh': "☑️️关闭所有操作",
    'ar': "☑️☐ قم بإيقاف جميع الإجراءات",
}

l_cnotification_dialog = {
    'ru': "💬 <b>Пользователь</b>: {0} [<b>id</b>={1}] написал в @{2}-боте:",
    'en': "💬 <b>User</b>: {0} [<b>id</b>={1}] wrote in @{2}-bot:",
    'es': "💬 <b>Usuario</b>: {0} [<b>id</b>={1}] escribió en @{2}-bot:",
    'fr': "💬 <b>Utilisateur</b> : {0} [<b>id</b>={1}] a écrit dans @{2}-bot :",
    'zh': "💬 <b>用户</b>：{0} [<b>id</b>={1}] 在@{2}-bot 中写道：",
    'ar': "💬 <b>المستخدم</b>: {0} [<b>id</b>={1}] كتب في @{2}-bot:",
}
# endregion


# region cuser_
l_cuser_text2 = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>авто-замену голосовых/телескопов на <b>audio/video</b> (*рекомендуется, если premium-пользователи установили такой запрет)/сервисные <b>статусы</b> бота (печатает..записывает видео..)/ведение списка <b>/utm-рефералов</b></i>\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse - вывести всех пользователей\n/utm - вывести utm-рефералов</blockquote>",
    'en': "👥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>auto-replacement of voice/telescopes with <b>audio/video</b> (*recommended if premium-users have set such a ban)/service <b>statuses</b> of the bot (types..records video..)/maintaining a list of <b>/utm-referrals</b></i>\n\n👩🏽 ‍💻 <b>Commands</b>:\n/cmd-all commands\n/parse-display all users\n/utm-display utm referrals\n/link-create a referral /utm link",
    'es': "👥 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>reemplazo automático de voz/telescopios con <b>audio/vídeo</b> (*recomendado si es premium-los usuarios han establecido dicha prohibición)/servicio <b>estados</b> del bot (tipos... graba vídeo...)/mantenimiento de una lista de <b>/utm-referrals</b></i>\n\n👩🏽 ‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/parse-mostrar todos los usuarios\n/utm-mostrar referencias utm\n/link-crear una referencia /utm enlace",
    'fr': "👥 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <i>remplacement automatique de la voix/télescopes par <b>audio/vidéo</b> (*recommandé si premium-les utilisateurs ont défini une telle interdiction)/service <b>statuts</b> du bot (types..enregistre la vidéo..)/maintien d'une liste de <b>/références utm</b></i>\n\n👩🏽 ‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/parse-afficher tous les utilisateurs\n/utm-afficher les références utm\n/lien-créer une référence /utm lien",
    'zh': "👥 <b>按</b> ✅/☑️ <b>开/关</b> <i>用<b>音频/视频</b>自动替换语音/望远镜（*推荐如果高级-用户已设置此类禁令）/机器人的服务<b>状态</b>（类型..记录视频..）/维护<b>/utm-referrals</b></i>列表\n\n👩🏽 ‍💻 <b>命令</b>：\n/cmd-所有命令\n/parse-显示所有用户\n/utm-显示 utm 引用\n/link-创建引用 /utm关联",
    'ar': "👥 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>الاستبدال التلقائي للصوت/التلسكوبات بـ <b>الصوت/الفيديو</b> (*يوصى به إذا كان الإصدار المميز-لقد وضع المستخدمون مثل هذا الحظر)/<b>حالات</b> خدمة الروبوت (الأنواع..تسجيلات الفيديو..)/الاحتفاظ بقائمة <b>/utm-referrals</b></i>\n\n👩🏽 ‍💻 <b>الأوامر</b>:\n/cmd-كافة الأوامر\n/parse-عرض كافة المستخدمين\n/utm-عرض إحالات utm\n/link-إنشاء إحالة /utm وصلة",
}
l_cuser_restricted_on = {
    'ru': "✅☑Вкл audio/video замена",
    'en': "✅☑Includes audio/video replacement",
    'es': "✅☑Incluye reemplazo de audio/video",
    'fr': "✅☑Comprend le remplacement audio/vidéo",
    'zh': "✅☑包括音频/视频替换",
    'ar': "✅☑يتضمن استبدال الصوت/الفيديو",
}
l_cuser_restricted_off = {
    'ru': "☑️☐Выкл audio/video замена",
    'en': "☑️☐Off audio/video replacement",
    'es': "☑️☐Desactivado reemplazo de audio/vídeo",
    'fr': "☑️☐Hors remplacement audio/vidéo",
    'zh': "☑️☐关闭音频/视频替换",
    'ar': "☑️☐إيقاف تشغيل استبدال الصوت/الفيديو",
}
l_cuser_status_on = {
    'ru': "✅☑Вкл сервисные статусы",
    'en': "✅☑On service statuses",
    'es': "✅☑Sobre estados de servicio",
    'fr': "✅☑Sur les statuts de service",
    'zh': "✅☑关于服务状态",
    'ar': "✅☑في حالات الخدمة",
}
l_cuser_status_off = {
    'ru': "☑️☐Выкл сервисные статусы",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐Estados fuera de servicio",
    'fr': "☑️☐Statuts hors service",
    'zh': "☑️️关闭服务状态",
    'ar': "☑️☐حالات خارج الخدمة",
}
l_cuser_utm_on = {
    'ru': "✅☑Вкл utm-рефералы",
    'en': "✅☑On utm referrals",
    'es': "✅☑En referencias utm",
    'fr': "✅☑Sur les référencements utm",
    'zh': "✅☑关于 utm 推荐",
    'ar': "✅☑في إحالات UTM",
}
l_cuser_utm_off = {
    'ru': "☑️☐Выкл utm-рефералы",
    'en': "☑️☐Off utm referrals",
    'es': "☑️☐Referencias fuera de utm",
    'fr': "☑️☐Hors référencements utm",
    'zh': "☑️️Off utm 推荐",
    'ar': "☑️☐ خارج الإحالات",
}
l_bot_is_off = {
    'ru': "👩🏽‍💻 <b>@{0}-@tg-приложение</b> выключено\n\n/on - включить @tg-приложение",
    'en': "👩🏽‍💻 <b>@{0}-bot</b> disabled\n\n/on-enable bot",
    'es': "👩🏽‍💻 <b>@{0}-bot</b> deshabilitado\n\n/on-habilitar bot",
    'fr': "👩🏽‍💻 <b>@{0}-bot</b> désactivé\n\n/activé-activer le bot",
    'zh': "👩🏽‍💻 <b>@{0}-bot</b> 已禁用\n\n/on-启用机器人",
    'ar': "👩🏽‍💻 <b>@{0}-bot</b> معطل\n\n/on-تمكين الروبوت",
}
l_cuser_utm = {
    'ru': "👥 <b>Готово!</b> <b>/utm-список</b> реферальных пользователей @{0}-бота\n\n👩🏽‍💻 <b>Вывести</b> рефералов конкретного пользователя можно командой:\n/utm id или /utm @username\n\n👩🏽‍💻 <b>Текущее</b> число utm-рефералов: <u>{1}</u>",
    'en': "👥 <b>Done!</b> <b>/utm-list</b> of @{0}-bot referral users\n\n👩🏽‍💻 <b>You can display</b> referrals of a specific user using the command :\n/utm id or /utm @username\n\n👩🏽‍💻 <b>Current</b> number of utm referrals: <u>{1}</u>",
    'es': "👥 <b>¡Listo!</b> <b>/utm-list</b> de usuarios de referencia de @{0}-bot\n\n👩🏽‍💻 <b>Puedes mostrar</b> referencias de un usuario específico usando el comando :\n/utm id o /utm @username\n\n👩🏽‍💻 Número <b>actual</b> de referencias utm: <u>{1}</u>",
    'fr': "👥 <b>Terminé !</b> <b>/utm-list</b> des utilisateurs référents de @{0}-bot\n\n👩🏽‍💻 <b>Vous pouvez afficher</b> les références de un utilisateur spécifique utilisant la commande :\n/utm id ou /utm @username\n\n👩🏽‍💻 <b>Nombre actuel</b> de références utm : <u>{1}</u>",
    'zh': "👥 <b>完成！</b> <b>/utm-list</b> @{0}-bot 推荐用户\n\n👩🏽‍💻 <b>您可以显示</b> 的推荐使用命令的特定用户：\n/utm id 或 /utm @username\n\n👩🏽‍💻 <b>当前</b> utm 推荐数量：<u>{1}</u>",
    'ar': "👥 <b>تم!</b> <b>/utm-list</b> لمستخدمي إحالة @{0}-bot\n\n👩🏽‍💻 <b>يمكنك عرض</b> إحالات مستخدم محدد يستخدم الأمر :\n/utm id أو /utm @username\n\n👩🏽‍💻 <b>العدد الحالي</b> لإحالات utm: <u>{1}</u>",
}
l_cuser_link_done = {
    'ru': "👥 <b>Готово!</b> Реферальная /utm ссылка на @{0}-бота (размести ее на любой площадке, чтобы понимать, что пользователи перешли в бота с этой площадки):\n\n{1}",
    'en': "👥 <b>Done!</b> Referral /utm link to @{0}-bot (place it on any site to understand that users switched to the bot from this site):\n\n{1}",
    'es': "👥 <b>¡Listo!</b> Enlace de referencia /utm a @{0}-bot (colóquelo en cualquier sitio para comprender que los usuarios cambiaron al bot desde este sitio):\n\n{1}",
    'fr': "👥 <b>Terminé !</b> Lien de référence/utm vers @{0}-bot (placez-le sur n'importe quel site pour comprendre que les utilisateurs sont passés au bot depuis ce site) :\n\n{1}",
    'zh': "👥 <b>完成！</b> 指向 @{0}-bot 的推荐 /utm 链接（将其放置在任何网站上以了解用户从该网站切换到机器人）：\n\n{1}",
    'ar': "👥 <b>تم!</b> رابط الإحالة /utm إلى @{0}-bot (ضعه على أي موقع لتفهم أن المستخدمين تحولوا إلى الروبوت من هذا الموقع):\n\n{1}",
}
l_cuser_link_start = {
    'ru': "👥 <b>Придумай</b> название для /utm ссылки (*после ?start= может быть <u>любое</u> имя источника из цифр и/или латинских букв)\n\n<blockquote>👩🏽‍💻 <b>Например</b>, ссылки /utm-рефералов для отслеживания:\nhttps://t.me/{0}?start={1} - <i>реферальных пользователей</i> {1}-<i>пользователя</i>\nhttps://t.me/{0}?start=instagram - <i>пользователей из instagram</i></blockquote>",
    'en': "👥 <b>Come up with</b> a name for the /utm link (*after ?start= there can be <u>any</u> source name from numbers and/or Latin letters)\n\n👩🏽‍💻 <b >For example</b>, /utm-referral links for tracking:\nhttps://t.me/{0}?start={1}-<i>referral users</i> {1}-<i> user</i>\nhttps://t.me/{0}?start=instagram-<i>users from instagram</i>",
    'es': "👥 <b>Crea</b> un nombre para el enlace /utm (*después de ?start= puede haber <u>cualquier</u> nombre de fuente formado por números y/o letras latinas)\n\n👩 🏽‍💻 <b >Por ejemplo</b>, enlaces /utm-referral para seguimiento:\nhttps://t.me/{0}?start={1}-<i>usuarios recomendados</i> { 1}-<i> usuario</i>\nhttps://t.me/{0}?start=instagram-<i>usuarios de instagram</i>",
    'fr': "👥 <b>Trouvez</b> un nom pour le lien /utm (*après ?start= il peut y avoir <u>n'importe quel</u> nom de source à partir de chiffres et/ou de lettres latines)\n\n👩 🏽‍💻 <b >Par exemple</b>, liens de référence /utm pour le suivi :\nhttps://t.me/{0}?start={1}-<i>utilisateurs référents</i> { 1}-<i>utilisateur</i>\nhttps://t.me/{0}?start=instagram-<i>utilisateurs d'Instagram</i>",
    'zh': "👥 <b>为 /utm 链接起一个名称</b>（*在 ?start= 之后可以有<u>任何</u>来自数字和/或拉丁字母的源名称）\n\n👩 🏽‍💻 <b >例如</b>，用于跟踪的 /utm-referral 链接：\nhttps://t.me/{0}?start={1}-<i>推荐用户</i> { 1}-<i> 用户</i>\nhttps://t.me/{0}?start=instagram-<i>来自 Instagram 的用户</i>",
    'ar': "👥 <b>ابتكر</b> اسمًا للرابط /utm (*بعد ?start= يمكن أن يكون هناك <u>أي</u> اسم مصدر من أرقام و/أو أحرف لاتينية)\n\n👩 🏽‍💻 <b >على سبيل المثال</b>، روابط /utm-referral للتتبع:\nhttps://t.me/{0}?start={1}-<i>مستخدمو الإحالة</i> { 1}-<i> مستخدم</i>\nhttps://t.me/{0}?start=instagram-<i>مستخدمون من instagram</i>",
}
l_promo_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> <i>Текущий /promo-код</i>:\n<code>{0}</code>\n👩🏽‍💻 <i>Удалить /promo-код</i>: <code>/promo 0</code>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Done!</b> <i>Current /promo code</i>:\n{0}\n👩🏽‍💻 <i>Delete /promo code</i>: <code>/promo 0</code>\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>¡Listo!</b> <i>Código promocional/actual</i>:\n{0}\n👩🏽‍💻 <i>Eliminar/código promocional</i>: <código >/promo 0</code>\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Terminé !</b> <i>Code promo/actuel</i> :\n{0}\n👩🏽‍💻 <i>Supprimer/code promo</i> : <code >/promo 0</code>\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>完成！</b> <i>当前/促销代码</i>：\n{0}\n👩🏽‍💻 <i>删除/促销代码</i>：<code >/promo 0</code>\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>تم!</b> <i>الرمز الترويجي الحالي</i>:\n{0}\n👩🏽‍💻 <i>حذف /الرمز الترويجي</i>: <code >/promo 0</code>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_promo_start = {
    'ru': "👩🏽‍💻 <b>Введи</b> /promo-код для @{0}-бота:\n\n👩🏽‍💻 <i>Текущий /promo-код</i>:\n{1}\n👩🏽‍💻 <i>Удалить /promo-код</i>:\n<code>/promo 0</code>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Enter</b> /promo code for @{0}-bot:\n\n👩🏽‍💻 <i>Current /promo code</i>:\n{1}\n👩🏽‍💻 <i>Delete /promo code</i>:\n<code>/promo 0</code>\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Ingrese</b> /código promocional para @{0}-bot:\n\n👩🏽‍💻 <i>Código promocional/actual</i>:\n{1}\n👩🏽‍💻 <i>Eliminar /código promocional</i>:\n<code>/promo 0</code>\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Entrez</b> le code promotionnel pour @{0}-bot :\n\n👩🏽‍💻 <i>Code promotionnel actuel</i> :\n{1}\n👩🏽‍💻 <i>Supprimer /code promo</i> :\n<code>/promo 0</code>\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>输入</b> @{0}-bot 的/促销代码：\n\n👩🏽‍💻 <i>当前/促销代码</i>：\n{1}\n👩🏽‍💻 <i>删除/促销代码</i>：\n<code>/promo 0</code>\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>أدخل</b> /الرمز الترويجي لـ @{0}-bot:\n\n👩🏽‍💻 <i>الرمز الترويجي /الحالي</i>:\n{1}\n👩🏽‍💻 <i>حذف /الرمز الترويجي</i>:\n<code>/promo 0</code>\n\n⚙️ <b>الأوامر</b> /cmd",
}
# endregion


# region cadmin_
l_cadmin_text2 = {
    'ru': "👮🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>доступ добавленных администраторов к функционалу <b>[💬 Оповещения]</b></i>\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/admin - добавить/удалить администратора\n/parse - вывести всех пользователей</blockquote>",
    'en': "👮🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>access of added administrators to the <b>[💬 Notifications] functionality</b></i>\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/admin-add/remove administrator\n/parse-display all users",
    'es': "👮🏽 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> <i>acceso de administradores agregados a la funcionalidad <b>[💬 Notificaciones]</b></i>\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/admin-agregar/eliminar administrador\n/parse-mostrar todos los usuarios",
    'fr': "👮🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> <i>l'accès des administrateurs ajoutés à la fonctionnalité <b>[💬 Notifications]</b></i>\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/admin-ajouter/supprimer un administrateur\n/parse-afficher tous les utilisateurs",
    'zh': "👮🏽 <b>按</b> ✅/☑️ <b>开启/关闭</b> <i>添加的管理员对<b>[💬通知]功能的访问</b></i>\n\n👩🏽‍💻 <b>命令</b>:\n/cmd-所有命令\n/admin-添加/删除管理员\n/parse-显示所有用户",
    'ar': "👮🏽 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>وصول المسؤولين المضافين إلى وظيفة <b>[💬 الإشعارات]</b></i>\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-كافة الأوامر\n/admin-إضافة/إزالة المسؤول\n/parse-عرض كافة المستخدمين",
}
l_cadmin_done = {
    'ru': "👮🏽 <b>Готово!</b> /admin-список @{0}-бота:\n\n{1}\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/admin - добавить/удалить администратора\n/parse - вывести всех пользователей\n\n👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{2}/10</u>",
    'en': "👮🏽 <b>Ready!</b> /admin-list @{0}-bot:\n\n{1}\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/admin-add/remove administrator\n/parse-display all users\n\n👩🏽‍💻 <b>Current</b> number of administrators: <u>{2}/10</u >",
    'es': "👮🏽 <b>¡Listo!</b> /admin-list @{0}-bot:\n\n{1}\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/admin-agregar/eliminar administrador\n/parse-mostrar todos los usuarios\n\n👩🏽‍💻 Número <b>actual</b> de administradores: <u>{2}/10</ tu >",
    'fr': "👮🏽 <b>Prêt !</b> /admin-list @{0}-bot :\n\n{1}\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/admin-ajouter/supprimer un administrateur\n/analyser-afficher tous les utilisateurs\n\n👩🏽‍💻 <b>Nombre actuel</b> d'administrateurs : <u>{2}/10</ toi >",
    'zh': "👮🏽 <b>准备好！</b> /admin-list @{0}-bot:\n\n{1}\n\n👩🏽‍💻 <b>命令</b>:\n/cmd-所有命令\n/admin-添加/删除管理员\n/parse-显示所有用户\n\n👩🏽‍💻 <b>当前</b>管理员数量：<u>{2}/10</你>",
    'ar': "👮🏽 <b>جاهز!</b> /admin-list @{0}-bot:\n\n{1}\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-جميع الأوامر\n/admin-إضافة/إزالة المسؤول\n/parse-عرض جميع المستخدمين\n\n👩🏽‍💻 العدد <b>الحالي</b> للمسؤولين: <u>{2}/10</ ش>",
}
l_cadmin_add = {
    'ru': "👮🏽 <b>Введи</b> до 10 id-пользователей через <i>пробелы/раздели</i> символы, чтобы добавить их в /admin-список\n\n👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{0}</u>",
    'en': "👮🏽 <b>Enter</b> up to 10 user IDs separated by <i>spaces/separate</i> characters to add them to the /admin list\n\n👩🏽‍💻 <b>Current</ b> number of administrators: <u>{0}</u>",
    'es': "👮🏽 <b>Ingrese</b> hasta 10 ID de usuario separados por <i>espacios/caracteres separados</i> para agregarlos a la lista /admin\n\n👩🏽‍💻 <b>Actual</ b> número de administradores: <u>{0}</u>",
    'fr': "👮🏽 <b>Entrez</b> jusqu'à 10 identifiants d'utilisateur séparés par des <i>espaces/caractères séparés</i> pour les ajouter à la liste /admin\n\n👩🏽‍💻 <b>Actuel</ b> nombre d'administrateurs : <u>{0}</u>",
    'zh': "👮🏽 <b>输入</b>最多 10 个用<i>空格/单独</i>字符分隔的用户 ID，将其添加到 /admin 列表\n\n👩🏽‍💻 <b>当前</ b> 管理员人数：<u>{0}</u>",
    'ar': "👮🏽 <b>أدخل</b> ما يصل إلى 10 معرفات مستخدمين مفصولة بأحرف <i>مسافات/منفصلة</i> لإضافتها إلى قائمة /admin\n\n👩🏽‍💻 <b>الحالية</ ب> عدد المسؤولين: <u>{0}</u>",
}
l_cadmin_remove = {
    'ru': "👮🏽 <b>Введи</b> id пользователей через <i>пробелы/раздели</i>, чтобы удалить их из /admin-список\n\n<blockquote>👩🏽‍💻 <b>Текущее</b> число администраторов: <u>{0}</u></blockquote>",
    'en': "👮🏽 <b>Enter</b> user ids separated by <i>spaces/separate</i> to remove them from the /admin list\n\n👩🏽‍💻 <b>Current</b> number of administrators : <u>{0}</u>",
    'es': "👮🏽 <b>Ingrese</b> ID de usuario separados por <i>espacios/separate</i> para eliminarlos de la lista /admin\n\n👩🏽‍💻 Número <b>actual</b> de administradores: <u>{0}</u>",
    'fr': "👮🏽 <b>Entrez</b> les identifiants des utilisateurs séparés par des <i>espaces/séparés</i> pour les supprimer de la liste /admin\n\n👩🏽‍💻 <b>Nombre actuel</b> de administrateurs : <u>{0}</u>",
    'zh': "👮🏽<b>输入</b>用户ID，用<i>空格/分隔</i>分隔，将其从/admin列表中删除\n\n👩🏽‍💻<b>当前</b>个数管理员：<u>{0}</u>",
    'ar': "👮🏽 <b>أدخل</b> معرفات المستخدمين مفصولة <i>مسافات/منفصلة</i> لإزالتهم من قائمة /admin\n\n👩🏽‍💻 <b>الرقم الحالي</b> من المسؤولون: <u>{0}</u>",
}
l_parse_text = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Парсинг пользователей (<u>{0}</u>) @{1}-бота\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse     <i>все пользователи бота</i>\n<code>/parse utm</code>   <i>utm-рефералы</i>\n<code>/parse ban</code>    <i>ban-пользователи</i>\n<code>/parse old</code>    <i>старые id-пользователи</i>\n<code>/parse admin</code>    <i>admin-пользователи</i>\n<code>/parse promo</code>    <i>promo-пользователи</i>\n<code>/parse premium</code>    <i>premium-пользователи</i>\n<code>/parse 1</code>    <i>кто лайкнул пост #1</i></blockquote>",
    'en': "👩🏽‍💻 <b>Done!</b> Parsing users (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/parse <i>all bot users</i>\n<code>/parse utm</code> <i>utm referrals</i>\n<code>/parse ban</code> <i>ban-users</i>\n<code>/parse old</code> <i>old id-users</i>\n<code>/parse admin</code> <i>admin-users</i>\n<code>/parse promo</code> <i>promo-users</i>\n<code>/parse premium</code> <i>premium-users </i>\n<code>/parse 1</code> <i>who liked post #1</i>",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Analizando usuarios (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/parse <i>todos los usuarios del bot</i>\n<code>/parse utm</code> <i>referencias utm</i>\n<code>/parse ban </code> <i>prohibir usuarios</i>\n<code>/parse old</code> <i>antiguos usuarios de id</i>\n<code>/parse admin</code> < i>usuarios-admin</i>\n<code>/parse promo</code> <i>usuarios-promo</i>\n<code>/parse premium</code> <i>usuarios premium < /i>\n<code>/parse 1</code> <i>a quién le gustó la publicación n.° 1</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Analyse des utilisateurs (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/parse <i>tous les utilisateurs du bot</i>\n<code>/parse utm</code> <i>références utm</i>\n<code>/parse ban </code> <i>ban-users</i>\n<code>/analyser les anciens</code> <i>anciens identifiants d'utilisateurs</i>\n<code>/analyser l'administrateur</code> < i>utilisateurs-admin</i>\n<code>/parse promo</code> <i>utilisateurs-promo</i>\n<code>/parse premium</code> <i>utilisateurs premium < /i>\n<code>/parse 1</code> <i>qui a aimé le post n°1</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> 解析用户 (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>命令</b>：\n/cmd-所有命令\n/parse <i>所有机器人用户</i>\n<code>/parse utm</code> <i>utm 推荐</i>\n<code>/parse ban </code> <i>禁止用户</i>\n<code>/parse old</code> <i>旧id-users</i>\n<code>/parse admin</code> < i>admin-users</i>\n<code>/parse promo</code> <i>promo-users</i>\n<code>/parse premium</code> <i>premium-users < /i>\n<code>/parse 1</code> <i>谁喜欢帖子 #1</i>",
    'ar': "👩🏽‍💻 <b>تم!</b> تحليل المستخدمين (<u>{0}</u>) @{1}-bot\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-جميع الأوامر\n/parse <i>جميع مستخدمي الروبوت</i>\n<code>/parse utm</code> <i>إحالات utm</i>\n<code>/parseban </code> <i>حظر المستخدمين</i>\n<code>/parse old</code> <i>مستخدمو المعرفات القديمة</i>\n<code>/parse admin</code> <<i>المستخدمون الإداريون</i>\n<code>/parse promo</code> <i>المستخدمون الترويجيون</i>\n<code>/parse premium</code> <i>المستخدمون المميزون < /i>\n<code>/parse 1</code> <i>من أبدى إعجابه بالمشاركة رقم 1</i>",
}
# endregion
# endregion


# region client
l_telegraph_title = {
    'ru': "📰 Telegraph блог",
    'en': "📰 Telegraph blog",
    'es': "📰 Blog de telégrafos",
    'fr': "📰Blog télégraphique",
    'zh': "📰 电讯报博客",
    'ar': "📰 مدونة التلغراف",
}
l_telegraph_blog = {
    'ru': "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Landing блог</blockquote>👩🏽‍💻 <b>Бот:</b> {2}<br>[<b>id</b>={3}]<br><b>Био:</b> {4}<br><aside>Канал</aside><a href='https://t.me/{5}'>@{5}</a>",
    'en': "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Landing блог</blockquote>👩🏽‍💻 <b>Бот:</b> {2}<br>[<b>id</b>={3}]<br><b>Био:</b> {4}<br><aside>Канал</aside><a href='https://t.me/{5}'>@{5}</a>",
    'es': "<figure><img src='{0}'/><figcaption>Foto de perfil: @{1}</figcaption></figure><blockquote>Blog de aterrizaje</blockquote>👩🏽‍💻 <b>Бот: </b> {2}<br>[<b>id</b>={3}]<br><b>Bio:</b> {4}<br><aside>Canal</aside> <a href=' https://t.me/{5} '> @{5}</a>",
    'fr': "<figure><img src='{0}'/><figcaption>Profil : @{1}</figcaption></figure><blockquote>Blog d'atterrissage</blockquote>👩🏽‍💻 <b>Photo : </b> {2}<br>[<b>id</b>={3}]<br><b>Био :</b> {4}<br><aside>Канал</aside> <a href=' https://t.me/{5} '> @{5}</a>",
    'zh': "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>登陆 блог</blockquote>👩🏽‍💻 <b>Бот: </b> {2}<br>[<b>id</b>={3}]<br><b>Био：</b> {4}<br><aside>Канал</aside> <a href=' https://t.me/{5} '> @{5}</a>",
    'ar': "<figure><img src='{0}'/><figcaption>صورة شخصية: @{1}</figcaption></figure><blockquote>صفحة الهبوط</blockquote>👩🏽‍💻 <b>Бот: </b> {2}<br>[<b>id</b>={3}]<br><b>Био:</b> {4}<br><aside>Канал</aside> <a href=' https://t.me/{5} '> @{5}</a>",
}
l_no_permission_table = {
    'ru': "👩🏽‍💻 <b>Нет прав</b> для записи в данную таблицу: {0}\n\n👩🏽‍💻 <b>Необходимо</b> заново добавить корректную ссылку на таблицу в @{1}-боте",
    'en': "👩🏽‍💻 <b>No rights</b> to write to this table: {0}\n\n👩🏽‍💻 <b>It is necessary</b> to re-add the correct link to the table in @{1}-both",
    'es': "👩🏽‍💻 <b>No hay derechos</b> para escribir en esta tabla: {0}\n\n👩🏽‍💻 <b>Es necesario</b> volver a agregar el enlace correcto a la tabla en @{1}-ambos",
    'fr': "👩🏽‍💻 <b>Aucun droit</b> pour écrire dans ce tableau : {0}\n\n👩🏽‍💻 <b>Il est nécessaire</b> de rajouter le bon lien vers le tableau dans @{1}-les deux",
    'zh': "👩🏽‍💻<b>无权</b>写入此表：{0}\n\n👩🏽‍💻<b>有必要</b>重新添加正确的链接到表在 @{1}-两者中",
    'ar': "👩🏽‍💻 <b>لا توجد حقوق</b> للكتابة في هذا الجدول: {0}\n\n👩🏽‍💻 <b>من الضروري</b> إعادة إضافة الرابط الصحيح إلى الجدول في @{1}-كلاهما",
}
l_transfer_need_username = {
    'ru': "👩🏽‍💻 <b>Создай</b> @username своего аккаунта, чтобы получить права на @{0}-бота",
    'en': "👩🏽‍💻 <b>Create</b> @username of your account to get rights to @{0}-bot",
    'es': "👩🏽‍💻 <b>Crea</b> @username de tu cuenta para obtener derechos sobre @{0}-bot",
    'fr': "👩🏽‍💻 <b>Créez</b> @username de votre compte pour obtenir les droits sur @{0}-bot",
    'zh': "👩🏽‍💻<b>创建</b>您帐户的@username以获取@{0}-bot 的权限",
    'ar': "👩🏽‍💻 <b>أنشئ</b> @ @username لحسابك للحصول على حقوق @{0}-bot",
}

# endregion


# region extra bot
l_show_admin_panel_md = {
    'ru': "*👩🏽‍💻 Создание и редактирование блога*\n\n👩🏽‍💻 Вы зашли как *Администратор* и можете создавать и редактировать блоги, но не удалять их\n\n<blockquote>¹ Авторизация (в течение 10сек) по ссылке в браузере:\n`{0}`\n\n² Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    'en': "*👩🏽‍💻 Creating and editing a blog*\n\n👩🏽‍💻 You are logged in as *Administrator* and can create and edit blogs, but not delete them\n\n¹ Authorization (within 10 seconds) using the link in the browser:\n`{0}`\n\n² Follow (within 10 seconds) the required link to edit the publication (click to copy):\n\n",
    'es': "*👩🏽‍💻 Creando y editando un blog*\n\n👩🏽‍💻 Has iniciado sesión como *Administrador* y puedes crear y editar blogs, pero no eliminarlos\n\n¹ Autorización (dentro de 10 segundos) usando el enlace en el navegador:\n`{0}`\n\n² Siga (dentro de 10 segundos) el enlace requerido para editar la publicación (haga clic para copiar):\n\n",
    'fr': "*👩🏽‍💻 Création et modification d'un blog*\n\n👩🏽‍💻 Vous êtes connecté en tant qu'*Administrateur* et pouvez créer et modifier des blogs, mais pas les supprimer.\n\n¹ Autorisation (dans les 10 secondes) à l'aide du lien dans le navigateur :\n`{0}`\n\n² Suivez (dans les 10 secondes) le lien requis pour modifier la publication (cliquez pour copier) :\n\n",
    'zh': "*👩🏽‍💻 创建和编辑博客*\n\n👩🏽‍💻 您以*管理员* 身份登录，可以创建和编辑博客，但不能删除它们\n\n¹ 使用授权（10 秒内）浏览器中的链接：\n`{0}`\n\n² 按照（10 秒内）所需的链接编辑出版物（单击复制）：\n\n",
    'ar': "*👩🏽‍💻 إنشاء مدونة وتحريرها*\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول بصفتك *مسؤول* ويمكنك إنشاء مدونات وتحريرها، ولكن لا يمكنك حذفها\n\n¹ التفويض (خلال 10 ثوانٍ) باستخدام الرابط الموجود في المستعرض:\n`{0}`\n\n² اتبع (خلال 10 ثوانٍ) الارتباط المطلوب لتحرير المنشور (انقر للنسخ):\n\n",
}
l_show_admin_panel_html = {
    'ru': "<b>👩🏽‍💻 Создание и редактирование блога</b>\n\n👩🏽‍💻 Вы зашли как <b>Администратор</b> и можете создавать и редактировать блоги, но не удалять их\n\n<blockquote>1. Авторизация по ссылке в браузере:\n{0}\n\n2. Перейди (в течение 10сек) по нужной ссылке для редактирования публикации (жми, чтобы скопировать):</blockquote>\n\n",
    'en': "<b>👩🏽‍💻 Creating and editing a blog</b>\n\n👩🏽‍💻 You are logged in as an <b>Administrator</b> and can create and edit blogs, but not delete them\n\n1. Authorization using the link in the browser:\n{0}\n\n2. Follow (within 10 seconds) the required link to edit the publication (click to copy):\n\n",
    'es': "<b>👩🏽‍💻 Creando y editando un blog</b>\n\n👩🏽‍💻 Has iniciado sesión como <b>Administrador</b> y puedes crear y editar blogs, pero no eliminarlos\ n\n1. Autorización mediante el enlace en el navegador:\n{0}\n\n2. Siga (en 10 segundos) el enlace requerido para editar la publicación (haga clic para copiar):\n\n",
    'fr': "<b>👩🏽‍💻 Créer et modifier un blog</b>\n\n👩🏽‍💻 Vous êtes connecté en tant qu'<b>Administrateur</b> et pouvez créer et modifier des blogs, mais pas les supprimer\ n\n1. Autorisation via le lien dans le navigateur :\n{0}\n\n2. Suivez (dans les 10 secondes) le lien requis pour modifier la publication (cliquez pour copier) :\n\n",
    'zh': "<b>👩🏽‍💻 创建和编辑博客</b>\n\n👩🏽‍💻 您以<b>管理员</b>身份登录，可以创建和编辑博客，但不能删除它们\ n\n1.使用浏览器中的链接进行授权：\n{0}\n\n2.点击（10 秒内）所需的链接来编辑出版物（单击以复制）：\n\n",
    'ar': "<b>👩🏽‍💻 إنشاء مدونة وتحريرها</b>\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول كـ <b>مسؤول</b> ويمكنك إنشاء مدونات وتحريرها، ولكن لا يمكنك حذفها\ ن\n1. التفويض باستخدام الرابط الموجود في المتصفح:\n{0}\n\n2. اتبع (خلال 10 ثوانٍ) الارتباط المطلوب لتحرير المنشور (انقر للنسخ):\n\n",
}
l_show_admin_panel_create = {
    'ru': "🆕 Создать",
    'en': "🆕 Create",
    'es': "🆕 Crear",
    'fr': "🆕 Créer",
    'zh': "🆕 创造",
    'ar': "🆕 إنشاء",
}
l_show_admin_panel_auth = {
    'ru': "👩🏽‍💻 Авторизация",
    'en': "👩🏽‍💻 Authorization",
    'es': "👩🏽‍💻 Autorización",
    'fr': "👩🏽‍💻 Autorisation",
    'zh': "👩🏽‍💻授权",
    'ar': "👩🏽‍💻 تصريح",
}

l_triggers = {
    'ru': "Триггеры",
    'en': "Triggers",
    'es': "Desencadenantes",
    'fr': "Déclencheurs",
    'zh': "触发器",
    'ar': "محفزات",
}
l_actions2 = {
    'ru': "Действия",
    'en': "Actions",
    'es': "Comportamiento",
    'fr': "Actions",
    'zh': "行动",
    'ar': "أجراءات",
}
l_messages = {
    'ru': "Сообщения",
    'en': "Messages",
    'es': "Mensajes",
    'fr': "Messages",
    'zh': "留言",
    'ar': "رسائل",
}
l_languages = {
    'ru': "Языки",
    'en': "Languages",
    'es': "Idiomas",
    'fr': "Langues",
    'zh': "语言",
    'ar': "اللغات",
}
l_buttons = {
    'ru': "Кнопки",
    'en': "Buttons",
    'es': "Botones",
    'fr': "Boutons",
    'zh': "纽扣",
    'ar': "أزرار",
}
l_medias = {
    'ru': "Медиа",
    'en': "Media",
    'es': "Medios de comunicación",
    'fr': "Médias",
    'zh': "媒体",
    'ar': "وسائط",
}

l_users = {
    'ru': "Пользователи",
    'en': "Users",
    'es': "Usuarios",
    'fr': "Utilisateurs",
    'zh': "用户",
    'ar': "المستخدمين",
}
l_promos = {
    'ru': "Promo-пользователи",
    'en': "Promo users",
    'es': "Usuarios promocionales",
    'fr': "Utilisateurs promotionnels",
    'zh': "促销用户",
    'ar': "المستخدمين الترويجي",
}
l_utms = {
    'ru': "UTM-пользователи",
    'en': "UTM users",
    'es': "Usuarios UTM",
    'fr': "Utilisateurs UTM",
    'zh': "UTM用户",
    'ar': "مستخدمي UTM",
}
l_premiums = {
    'ru': "Premium-пользователи",
    'en': "Premium users",
    'es': "Usuarios premium",
    'fr': "Utilisateurs premium",
    'zh': "高级用户",
    'ar': "المستخدمين المتميزين",
}
l_bans = {
    'ru': "Бан-пользователи",
    'en': "Banned users",
    'es': "Usuarios prohibidos",
    'fr': "Utilisateurs bannis",
    'zh': "被禁止的用户",
    'ar': "المستخدمين المحظورين",
}
l_auto_translate = {
    'ru': "Авто-перевод",
    'en': "Auto-translation",
    'es': "Traducción automática",
    'fr': "Traduction automatique",
    'zh': "自动翻译",
    'ar': "الترجمة التلقائية",
}
l_auto_answer = {
    'ru': "Авто-ответ",
    'en': "Auto-reply",
    'es': "Respuesta automática",
    'fr': "Réponse automatique",
    'zh': "自动回复",
    'ar': "رد آلي",
}
l_auto_post = {
    'ru': "Авто-постинг",
    'en': "Auto-posting",
    'es': "Publicación automática",
    'fr': "Publication automatique",
    'zh': "自动发布",
    'ar': "النشر التلقائي",
}
# endregion


# region html
l_burger_save = {
    'ru': "Сохранить",
    'en': "Save",
    'es': "Ahorrar",
    'fr': "Sauvegarder",
    'zh': "节省",
    'ar': "يحفظ",
}
l_burger_ai = {
    'ru': "Нейро-бот ᴺᴱᵂ",
    'en': "Neuro-bot ᴺᴱᵂ",
    'es': "Neuro-bot ᴺᴱᵂ",
    'fr': "Neuro-bot ᴺᴱᵂ",
    'zh': "神经机器人ᴺᴱᵂ",
    'ar': "الروبوت العصبي ᴺᴱᵂ",
}
l_burger_template = {
    'ru': "Шаблон бота",
    'en': "Template bot",
    'es': "Robot de plantilla",
    'fr': "Bot modèle",
    'zh': "模板机器人",
    'ar': "بوت القالب",
}
l_burger_import = {
    'ru': "Импортировать .bot",
    'en': "Import .bot",
    'es': "Importar .bot",
    'fr': "Importer .bot",
    'zh': "导入.bot",
    'ar': "استيراد بوت",
}
l_burger_export = {
    'ru': "Экспортировать как >",
    'en': "Export as >",
    'es': "Exportar como >",
    'fr': "Exporter sous >",
    'zh': "导出为>",
    'ar': "تصدير كـ >",
}
l_burger_clear = {
    'ru': "Очистить",
    'en': "Clear",
    'es': "Claro",
    'fr': "Clair",
    'zh': "清除",
    'ar': "واضح",
}
l_burger_gen_alert = {
    'ru': "Создать нового бота?",
    'en': "Create a new bot?",
    'es': "¿Crear un nuevo robot?",
    'fr': "Créer un nouveau bot ?",
    'zh': "创建一个新的机器人？",
    'ar': "إنشاء بوت جديد؟",
}
l_burger_import_alert = {
    'ru': "Загрузка..",
    'en': "Loading..",
    'es': "Cargando..",
    'fr': "Chargement..",
    'zh': "加载中..",
    'ar': "تحميل..",
}
l_burger_clear_alert = {
    'ru': "Очистить сцену?",
    'en': "Clear the stage?",
    'es': "¿Despejar el escenario?",
    'fr': "Vider la scène ?",
    'zh': "清理舞台？",
    'ar': "مسح المسرح؟",
}

l_ent_close = {
    'ru': "Закрыть",
    'en': "Close",
    'es': "Cerca",
    'fr': "Fermer",
    'zh': "关闭",
    'ar': "يغلق",
}
l_ent_save = {
    'ru': "Сохранить",
    'en': "Save",
    'es': "Ahorrar",
    'fr': "Sauvegarder",
    'zh': "节省",
    'ar': "يحفظ",
}
l_ent_delete = {
    'ru': "Удалить",
    'en': "Delete",
    'es': "Borrar",
    'fr': "Supprimer",
    'zh': "删除",
    'ar': "يمسح",
}
l_copied = {
    'ru': "Скопировано",
    'en': "Copied",
    'es': "Copiado",
    'fr': "Copié",
    'zh': "已复制",
    'ar': "نسخ",
}

l_neuro_gen = {
    'ru': "Сгенерировать",
    'en': "Generate",
    'es': "Generar",
    'fr': "Générer",
    'zh': "产生",
    'ar': "يولد",
}
l_neuro_count = {
    'ru': "Количество Сообщений-блоков",
    'en': "Number of Message Blocks",
    'es': "Número de bloques de mensajes",
    'fr': "Nombre de blocs de messages",
    'zh': "消息块数量",
    'ar': "عدد كتل الرسائل",
}
l_neuro_continue = {
    'ru': "Продолжить цепочки блоков",
    'en': "Continue the block chain",
    'es': "Continuar la cadena de bloques",
    'fr': "Continuer la chaîne de blocs",
    'zh': "延续区块链",
    'ar': "مواصلة سلسلة الكتلة",
}
l_neuro_text = {
    'ru': ": текст",
    'en': ": text",
    'es': ": texto",
    'fr': ": texte",
    'zh': "： 文本",
    'ar': ": نص",
}
l_neuro_media = {
    'ru': ": медиа",
    'en': ": media",
    'es': ": medios de comunicación",
    'fr': ": médias",
    'zh': "： 媒体",
    'ar': ": وسائط",
}

l_web_gen_txt = {
    'ru': "Сгенерировать Текст",
    'en': "Generate Text",
    'es': "Generar texto",
    'fr': "Générer du texte",
    'zh': "生成文本",
    'ar': "إنشاء نص",
}
l_web_gen_img = {
    'ru': "Сгенерировать Образ",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_gif = {
    'ru': "Сгенерировать Гиф",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_video = {
    'ru': "Сгенерировать Видео",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_telescope = {
    'ru': "Сгенерировать Телескоп",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_audio = {
    'ru': "Сгенерировать Аудио",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_voice = {
    'ru': "Сгенерировать Голос",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_sticker = {
    'ru': "Сгенерировать Стикер",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_doc = {
    'ru': "Сгенерировать Док",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}
l_web_gen_web = {
    'ru': "Сгенерировать Веб",
    'en': "Generate Image",
    'es': "Generar imagen",
    'fr': "Générer une image",
    'zh': "生成图像",
    'ar': "توليد الصورة",
}

l_all_trg = {
    'ru': ": все триггеры",
    'en': ": all triggers",
    'es': ": todos los desencadenantes",
    'fr': " : tous les déclencheurs",
    'zh': "：所有触发器",
    'ar': ": جميع المشغلات",
}
l_one_trg = {
    'ru': ": 1 триггер",
    'en': ": 1 trigger",
    'es': ": 1 gatillo",
    'fr': ": 1 déclencheur",
    'zh': "：1个触发器",
    'ar': ": 1 الزناد",
}

l_order_act = {
    'ru': ": по порядку",
    'en': ": in order",
    'es': ": in order",
    'fr': ": in order",
    'zh': ": in order",
    'ar': ": in order",
}
l_rand_act = {
    'ru': ": вразброс",
    'en': ": randomly",
    'es': ": randomly",
    'fr': ": randomly",
    'zh': ": randomly",
    'ar': ": randomly",
}
l_trigger = {
    'ru': "Триггер",
    'en': "Trigger",
    'es': "Desencadenar",
    'fr': "Déclenchement",
    'zh': "扳机",
    'ar': "مشغل",
}
l_action = {
    'ru': "Действие",
    'en': "Action",
    'es': "Acción",
    'fr': "Action",
    'zh': "行动",
    'ar': "فعل",
}
l_message = {
    'ru': "Сообщение",
    'en': "Message",
    'es': "Mensaje",
    'fr': "Message",
    'zh': "信息",
    'ar': "رسالة",
}

l_trg_add = {
    'ru': "+ Добавить Триггер",
    'en': "+ Add Trigger",
    'es': "+ Agregar disparador",
    'fr': "+ Ajouter un déclencheur",
    'zh': "+ 添加触发器",
    'ar': "+ إضافة الزناد",
}
l_trg_cmd = {
    'ru': "+ команда",
    'en': "+ team",
    'es': "+ equipo",
    'fr': "+ équipe",
    'zh': "+ 团队",
    'ar': "+ فريق",
}
l_trg_txt = {
    'ru': "+ сообщение",
    'en': "+ message",
    'es': "+ texto",
    'fr': "+ texte",
    'zh': "+ 文字",
    'ar': "+ نص",
}
l_trg_bpm = {
    'ru': "+ бизнес лс",
    'en': "+ business pm",
    'es': "+ texto",
    'fr': "+ texte",
    'zh': "+ 文字",
    'ar': "+ نص",
}
l_trg_btn = {
    'ru': "+ кнопка",
    'en': "+ button",
    'es': "Botón +",
    'fr': "+ bouton",
    'zh': "+ 按钮",
    'ar': "+ زر",
}
l_trg_rct = {
    'ru': "+ реакция",
    'en': "+ button",
    'es': "Botón +",
    'fr': "+ bouton",
    'zh': "+ 按钮",
    'ar': "+ زر",
}
l_trg_var = {
    'ru': "+ переменная",
    'en': "+ variable",
    'es': "+ variable",
    'fr': "+ variable",
    'zh': "+ 变量",
    'ar': "+ متغير",
}
l_trg_lst = {
    'ru': "+ список",
    'en': "+ list",
    'es': "+ lista",
    'fr': "+ liste",
    'zh': "+ 列表",
    'ar': "+ قائمة",
}

l_act_add = {
    'ru': "+ Добавить Действие",
    'en': "+ Add Action",
    'es': "+ Agregar acción",
    'fr': "+ Ajouter une action",
    'zh': "+ 添加动作",
    'ar': "+ إضافة إجراء",
}
l_act_dly = {
    'ru': "+ задержка",
    'en': "+ delay",
    'es': "+ retraso",
    'fr': "+ retard",
    'zh': "+ 延迟",
    'ar': "+ تأخير",
}
l_act_wait = {
    'ru': "+ ожидание",
    'en': "+ waiting",
    'es': "+ esperando",
    'fr': "+ attendre",
    'zh': "+ 等待",
    'ar': "+ الانتظار",
}
l_act_wait_title = {
    'ru': "Ожидание",
    'en': "Expectation",
    'es': "Expectativa",
    'fr': "Attente",
    'zh': "期待",
    'ar': "توقع",
}
l_act_req = {
    'ru': "+ запрос",
    'en': "+ request",
    'es': "+ solicitud",
    'fr': "+ demande",
    'zh': "+ 请求",
    'ar': "+ طلب",
}
l_act_unpin = {
    'ru': "+ открепить все",
    'en': "+ request",
    'es': "+ solicitud",
    'fr': "+ demande",
    'zh': "+ 请求",
    'ar': "+ طلب",
}
l_act_unpin_title = {
    'ru': "Открепить все сообщения",
    'en': "Expectation",
    'es': "Expectativa",
    'fr': "Attente",
    'zh': "期待",
    'ar': "توقع",
}
l_act_delkb = {
    'ru': "+ удалить нижнюю клавиатуру",
    'en': "+ request",
    'es': "+ solicitud",
    'fr': "+ demande",
    'zh': "+ 请求",
    'ar': "+ طلب",
}
l_act_delkb_title = {
    'ru': "Удалить нижнюю клавиатуру↓",
    'en': "Expectation",
    'es': "Expectativa",
    'fr': "Attente",
    'zh': "期待",
    'ar': "توقع",
}

l_msg_text = {
    'ru': ": текст",
    'en': ": text",
    'es': ": texto",
    'fr': ": texte",
    'zh': "： 文本",
    'ar': ": نص",
}
l_msg_photo = {
    'ru': ": фото",
    'en': ": photo",
    'es': ": foto",
    'fr': ": photo",
    'zh': "： 照片",
    'ar': ": صورة",
}
l_msg_gif = {
    'ru': ": гиф",
    'en': ": gif",
    'es': ": gif",
    'fr': ": gif",
    'zh': "： 动图",
    'ar': ": جيف",
}
l_msg_video = {
    'ru': ": видео",
    'en': ": video",
    'es': ": video",
    'fr': ": vidéo",
    'zh': "： 视频",
    'ar': ": فيديو",
}
l_msg_video_note = {
    'ru': ": телескоп",
    'en': ": telescope",
    'es': ": telescopio",
    'fr': ": télescope",
    'zh': "：望远镜",
    'ar': ": تلسكوب",
}
l_msg_audio = {
    'ru': ": аудио",
    'en': ": audio",
    'es': ": sonido",
    'fr': ": l'audio",
    'zh': "： 声音的",
    'ar': ": صوتي",
}
l_msg_voice = {
    'ru': ": голосовое",
    'en': ": voice",
    'es': ": voz",
    'fr': ": voix",
    'zh': "： 嗓音",
    'ar': ": صوت",
}
l_msg_document = {
    'ru': ": документ",
    'en': ": document",
    'es': ": documento",
    'fr': ": document",
    'zh': "： 文档",
    'ar': ": وثيقة",
}
l_msg_sticker = {
    'ru': ": стикер",
    'en': ": sticker",
    'es': ": pegatina",
    'fr': ": autocollant",
    'zh': "： 贴纸",
    'ar': ": ملصق",
}
l_msg_quiz = {
    'ru': ": опрос",
    'en': ": survey",
    'es': ": encuesta",
    'fr': ": enquête",
    'zh': "： 民意调查",
    'ar': ": استطلاع",
}
l_msg_dice = {
    'ru': ": игра",
    'en': ": game",
    'es': ": juego",
    'fr': ": jeu",
    'zh': "： 游戏",
    'ar': ": لعبة",
}
l_msg_web = {
    'ru': ": веб",
    'en': ": web",
    'es': ": web",
    'fr': ": la toile",
    'zh': "：网络",
    'ar': ": الويب",
}

l_btn_button_in = {
    'ru': "✅ Кнопка ↑",
    'en': "✅ Button ↑",
    'es': "✅ Botón ↑",
    'fr': "✅ Bouton ↑",
    'zh': "✅ 按钮 ↑",
    'ar': "✅ الزر ↑",
}
l_btn_link = {
    'ru': "🔗 Ссылка",
    'en': "🔗 Link",
    'es': "🔗 Enlace",
    'fr': "🔗 Lien",
    'zh': "🔗 链接",
    'ar': "🔗 الرابط",
}
l_btn_pay = {
    'ru': "💳 Оплата",
    'en': "💳 Payment",
    'es': "💳 Pago",
    'fr': "💳 Paiement",
    'zh': "💳 付款",
    'ar': "💳 الدفع",
}
l_btn_search = {
    'ru': "🔎 Поиск",
    'en': "🔎Search",
    'es': "🔎Buscar",
    'fr': "🔎Recherche",
    'zh': "🔎搜索",
    'ar': "🔎بحث",
}
l_btn_like = {
    'ru': "❤️ Лайк",
    'en': "❤️ Like",
    'es': "❤️ Me gusta",
    'fr': "❤️ J'aime",
    'zh': "❤️ 喜欢",
    'ar': "❤️ اعجبني",
}
l_btn_web = {
    'ru': "🌐 Веб",
    'en': "🌐 Web",
    'es': "🌐 Web",
    'fr': "🌐Web",
    'zh': "🌐 网络",
    'ar': "🌐 الويب",
}
l_btn_button_kb = {
    'ru': "✅ Кнопка ↓",
    'en': "✅ Button ↓",
    'es': "✅ Botón ↓",
    'fr': "✅ Bouton ↓",
    'zh': "✅ 按钮 ↓",
    'ar': "✅ زر ↓",
}
l_btn_phone = {
    'ru': "📞 Сотовый",
    'en': "📞 Cellular",
    'es': "📞 Celular",
    'fr': "📞 Cellulaire",
    'zh': "📞 蜂窝网络",
    'ar': "📞 خلوي",
}
l_btn_geo = {
    'ru': "📍 Гео",
    'en': "📍 Geo",
    'es': "📍 Geo",
    'fr': "📍 Géo",
    'zh': "📍 地理",
    'ar': "📍جيو",
}
l_btn_blog = {
    'ru': "📰 Блог",
    'en': "📰 Blog",
    'es': "📰 Blog",
    'fr': "📰Blogue",
    'zh': "📰 博客",
    'ar': "📰 المدونة",
}
l_btn_name = {
    'ru': "Имя:",
    'en': "Name:",
    'es': "Nombre:",
    'fr': "Nom:",
    'zh': "姓名：",
    'ar': "اسم:",
}
l_btn_type = {
    'ru': "Тип:",
    'en': "Type:",
    'es': "Tipo:",
    'fr': "Taper:",
    'zh': "类型：",
    'ar': "يكتب:",
}

l_check_box_pin_message = {
    'ru': "Закреп сообщения",
    'en': "Pinned messages",
    'es': "Mensajes fijados",
    'fr': "Messages épinglés",
    'zh': "固定消息",
    'ar': "الرسائل المثبتة",
}
l_check_box_protect_message = {
    'ru': "Защита сообщения",
    'en': "Message protection",
    'es': "Protección de mensajes",
    'fr': "Protection des messages",
    'zh': "消息保护",
    'ar': "حماية الرسالة",
}
l_check_box_edit_message = {
    'ru': "Замена текущего сообщения",
    'en': "Replacing the current message",
    'es': "Reemplazo del mensaje actual",
    'fr': "Remplacer le message actuel",
    'zh': "替换当前消息",
    'ar': "استبدال الرسالة الحالية",
}
l_check_box_auto_format = {
    'ru': "Формат сообщения",
    'en': "Message Format",
    'es': "Formato de mensaje",
    'fr': "Format des messages",
    'zh': "消息格式",
    'ar': "تنسيق الرسالة",
}
l_check_box_auto_typing = {
    'ru': "Печатание сообщения ¹²⁸",
    'en': "Printing message ¹²⁸",
    'es': "Mensaje de impresión ¹²⁸",
    'fr': "Impression du message ¹²⁸",
    'zh': "打印消息 12⁸",
    'ar': "رسالة الطباعة ¹²⁸",
}
l_check_box_preview = {
    'ru': "Превью контент",
    'en': "Preview content",
    'es': "Vista previa del contenido",
    'fr': "Aperçu du contenu",
    'zh': "预览内容",
    'ar': "معاينة المحتوى",
}
l_check_box_spoiler = {
    'ru': "Гиф/фото/видео спойлер",
    'en': "GIF/photo/video spoiler",
    'es': "Spoiler de GIF/foto/vídeo",
    'fr': "Spoiler GIF/photo/vidéo",
    'zh': "GIF/照片/视频剧透",
    'ar': "GIF/صورة/فيديو المفسد",
}
l_check_box_silence = {
    'ru': "Тихое сообщение",
    'en': "Quiet message",
    'es': "Mensaje tranquilo",
    'fr': "Message silencieux",
    'zh': "安静的消息",
    'ar': "رسالة هادئة",
}
l_check_box_cryptopay = {
    'ru': "Подключить веб3ᵀᴼᴺ-донаты",
    'en': "Сonnect web3ᵀᴼᴺ-donations",
    'es': "Mensaje tranquilo",
    'fr': "Message silencieux",
    'zh': "安静的消息",
    'ar': "رسالة هادئة",
}
l_check_box_destruct = {
    'ru': "Самоуничтожение фото/видео/голосовое/телескоп",
    'en': "Self-destruct photo/video",
    'es': "Foto/video de autodestrucción",
    'fr': "Photo/vidéo d'autodestruction",
    'zh': "自毁照片/视频",
    'ar': "صورة/فيديو التدمير الذاتي",
}
l_check_box_shade = {
    'ru': "Оттенок цвета",
    'en': "Сonnect web3ᵀᴼᴺ-donations",
    'es': "Mensaje tranquilo",
    'fr': "Message silencieux",
    'zh': "安静的消息",
    'ar': "رسالة هادئة",
}
l_check_box_menu = {
    'ru': "Замена кнопки меню",
    'en': "Сonnect web3ᵀᴼᴺ-donations",
    'es': "Mensaje tranquilo",
    'fr': "Message silencieux",
    'zh': "安静的消息",
    'ar': "رسالة هادئة",
}
# endregion


# region json
l_all_json = {
    'ru': ": *",
    'en': ": *",
    'es': ": *",
    'fr': ": *",
    'zh': ": *",
    'ar': ": جميع المشغلات",
}
l_one_json = {
    'ru': ": 1",
    'en': ": 1",
    'es': ": 1",
    'fr': ": 1",
    'zh': ": 1",
    'ar': ": 1 الزناد",
}
l_add_trg_json = {
    'ru': "+ Триггер",
    'en': "+ Триггер",
    'es': ": 1",
    'fr': ": 1",
    'zh': ": 1",
    'ar': ": 1 الزناد",
}
l_add_act_json = {
    'ru': "+ Действие",
    'en': "+ Действие",
    'es': ": 1",
    'fr': ": 1",
    'zh': ": 1",
    'ar': ": 1 الزناد",
}
l_add_msg_json = {
    'ru': "+ Сообщение",
    'en': "+ Сообщение",
    'es': ": 1",
    'fr': ": 1",
    'zh': ": 1",
    'ar': ": 1 الزناد",
}
# endregion
# endregion


# region FereyUserBot
l_usr_btn1 = {
    'ru': "👩🏽‍💻 Аккаунты",
    'en': "👩🏽‍💻 Accounts",
    'es': "👩🏽‍💻 Cuentas",
    'fr': "👩🏽‍💻 Comptes",
    'zh': "👩🏽‍💻 账户",
    'ar': "👩🏽‍💻 الحسابات",
}
l_usr_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_usr_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в #нейро-автоматизацию <b>Telegram</b>-аккаунтов:\n\n<blockquote>▪️<b>авто</b>-перевод/транскрибация\n▪️<b>#нейро-генерация</b> бота\n▪️<b>мониторинг</b> гео/слов\n▪️<b>авто-формат/подкасты</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> neuro-automation of <b>Telegram</b> accounts:\n\n▪️<b>auto</ b>-translation/transcription\n▪️<b>neuro-generation</b>bot\n▪️<b>monitoring</b> geo/words\n▪️<b>auto-format/podcasts</b>\ n▪️<b>web app/neuro</b>-posting\n\n❗️<b>Regular</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>landing bot</i> neuroautomatización de cuentas de <b>Telegram</b>:\n\n▪️<b>auto</ b >-traducción/transcripción\n▪️<b>bot de neurogeneración</b>\n▪️<b>monitoreo</b> geo/palabras\n▪️<b>autoformato/podcasts</b>\ n ▪️<b>aplicación web/neuro</b>-publicación\n\n❗️<b>Contenido/actualizado regularmente</b>",
    'fr': "🌱 <b>{0}</b>, bienvenue dans le <i>bot d'atterrissage</i> neuro-automatisation des comptes <b>Telegram</b> :\n\nproducer<b>auto</ b >-traduction/transcription\nwithout ▪️<b>application web/neuro</b>-publication\n\n❗️<b>Régulier</b>-mis à jour/contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用 <b>Telegram</b> 帐户的<i>登陆机器人</i>神经自动化：\n\n▪️<b>auto</ b >-翻译/转录\n▪️<b>神经生成</b>机器人\n▪️<b>监控</b>地理/单词\n▪️<b>自动格式/播客</b>\ n ▪️<b>网络应用/神经</b>-发布\n\n❗️<b>常规</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> للأتمتة العصبية لحسابات <b>Telegram</b>:\n\n▪️<b>auto</ b >-الترجمة/النسخ\n▪️<b>الجيل العصبي</b>الروبوت\n▪️<b>المراقبة</b> الموقع الجغرافي/الكلمات\n▪️<b>التنسيق التلقائي/البودكاست</b>\n▪️<b>تطبيق ويب/عصبي</b>-النشر\n\n❗️<b>عادي</b>-محتوى/محدث",
}
l_usr_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyUserBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_user = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>добавление</b> нескольких аккаунтов\n▪️<b>#нейро-ответ/постинг</b>\n(<i>на основе контента блоков/постов</i>)\n▪️аудио/видео-<b>подкасты</b> более 5мин\n▪️<b>#нейро-генерация</b> блоков\n(<i>через текстовый запрос</i>)\n▪️<b>авто</b>-транскрибация входящих</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>adding</b> several accounts\n▪️<b>neural response/posting</b>\n(<i>based on the content of blocks/posts</i>)\n▪️audio/video-<b>podcasts</b> more than 5 min\n▪️<b>neuro-generation</b> blocks\n(<i>via text request</i>)\n▪️<b >auto</b>-transcription of incoming\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>agregar</b> varias cuentas\n▪️<b>respuesta neuronal/publicación</b>\n(<i>basado en el contenido de bloques/publicaciones</ i>)\n▪️audio/vídeo-<b>podcasts</b> de más de 5 minutos\n▪️<b>bloques de neurogeneración</b>\n(<i>mediante solicitud de texto</i>)\n▪️<b >auto</b>-transcripción de entrada\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>ajout</b> de plusieurs comptes\nnoyer️<b>réponse/publication neuronale</b>\n(<i>en fonction du contenu des blocs/publications</ i>)\n▪️audio/vidéo-<b>podcasts</b> de plus de 5 minutes\nnoyance<b>blocs de neuro-génération</b>\n(<i>via demande de texte</i>)\n▪️<b >auto</b>-transcription des entrants\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>添加</b>多个帐户\n▪️<b>神经响应/发帖</b>\n（<i>基于区块/帖子的内容</b> i>)\n▪️音频/视频-<b>播客</b>超过 5 分钟\n▪️<b>神经生成</b>块\n（<i>通过文本请求</i>）\n▪️<b >auto</b>-传入的转录\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إضافة</b> عدة حسابات\n▪️<b>استجابة/نشر عصبي</b>\n(<i>استنادًا إلى محتوى عمليات الحظر/المشاركات</<i>)\n▪️صوت/فيديو-<b>بودكاست</b> أكثر من 5 دقائق\n▪️<b>كتل توليد عصبية</b>\n(<i>عبر طلب نصي</i>)\n▪️<b >تلقائي</b>-نسخ الرسائل الواردة\n\n👩🏽‍💻 /التوازن",
}
l_cmd_txt_usr = {
    'ru': "👩🏽‍💻 <b>Жми</b> [➕ Добавить акк]",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add account]",
    'es': "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar cuenta]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un compte]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加帐户]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة حساب]",
}

l_add_userbot_text = {
    'ru': "👇🏽 <b>Жми</b> на [➕ Добавить акк], чтобы добавить дополнительный аккаунт для автоматизации в @{0}\n\n👮🏽‍♀️ Используй <b>код</b> подтверждения с верифицированного <i>Telegram</i>-аккаунта",
    'en': "👇🏽 <b>Click</b> on [➕ Add acc] to add an additional account for automation in @{0}\n\n👮🏽‍♀️ Use <b>code</b> confirmation from verified <i >Telegram</i>account",
    'es': "👇🏽 <b>Haga clic</b> en [➕ Agregar cuenta] para agregar una cuenta adicional para la automatización en @{0}\n\n👮🏽‍♀️ Utilice el <b>código</b> de confirmación del <i verificado >Cuenta de Telegram</i>",
    'fr': "👇🏽 <b>Cliquez</b> sur [➕ Ajouter un accès] pour ajouter un compte supplémentaire pour l'automatisation dans @{0}\n\n👮🏽‍♀️ Utiliser le <b>code</b> de confirmation du <i vérifié Compte >Télégramme</i>",
    'zh': "👇🏽<b>点击</b><➕添加帐户>在@{0}\n\n👮🏽‍♀️中添加一个额外的自动化帐户，使用来自已验证的<i的<b>代码</b>确认>电报帐户</i>",
    'ar': "👇🏽 <b>انقر</b> على [➕ إضافة حساب] لإضافة حساب إضافي للأتمتة في @{0}\n\n👮🏽‍♀️ استخدم تأكيد <b>الكود</b> من <i الذي تم التحقق منه >حساب التليجرام</i>",
}
l_add_userbot_button = {
    'ru': "➕ Добавить акк",
    'en': "➕ Add account",
    'es': "➕ Agregar cuenta",
    'fr': "➕ Ajouter un compte",
    'zh': "➕ 添加帐户",
    'ar': "➕ إضافة حساب",
}
l_rent_userbot_button = {
    'ru': "💳 Арендовать акк",
    'en': "💳 Rent an account",
    'es': "💳 Alquilar una cuenta",
    'fr': "💳 Louer un compte",
    'zh': "💳 租一个帐户",
    'ar': "💳 استئجار حساب",
}
l_rent = {
    'ru': "💳 Аренда аккаунта",
    'en': "💳 Account rental",
    'es': "💳 Alquiler de cuenta",
    'fr': "💳 Location de compte",
    'zh': "💳 账户租赁",
    'ar': "💳 تأجير الحساب",
}
l_csend = {
    'ru': "📨️ Рассылка",
    'en': "📨️ Newsletter",
    'es': "📨️ Boletín",
    'fr': "📨️Newsletter",
    'zh': "📨️时事通讯",
    'ar': "📨️ النشرة الإخبارية",
}
l_cinvite = {
    'ru': "🚶 Инвайт",
    'en': "🚶 Invite",
    'es': "🚶 Invitar",
    'fr': "🚶 Inviter",
    'zh': "🚶 邀请",
    'ar': "🚶 دعوة",
}
l_add_owner_to_contacts = {
    'ru': "📇 Контакт <b>{0}</b> успешно добавлен!",
    'en': "📇 Contact <b>{0}</b> successfully added!",
    'es': "📇 ¡Contacto <b>{0}</b> agregado exitosamente!",
    'fr': "📇 Contact <b>{0}</b> ajouté avec succès !",
    'zh': "📇 联系人 <b>{0}</b> 已成功添加！",
    'ar': "📇 تمت إضافة جهة الاتصال <b>{0}</b> بنجاح!",
}
l_untill = {
    'ru': "до",
    'en': "to",
    'es': "a",
    'fr': "à",
    'zh': "到",
    'ar': "ل",
}
l_static_bot_only = {
    'ru': "👩🏽‍💻 <b>Без</b> 💨Подписки @{0} работает в <b>статическом</b> режиме: <i>без откликов на нажатия кнопок</i>",
    'en': "👩🏽‍💻 <b>Without</b> 💨Subscriptions @{0} works in <b>static</b> mode: <i>without responding to button presses</i>",
    'es': "👩🏽‍💻 <b>Sin</b> 💨Suscripciones @{0} funciona en modo <b>estático</b>: <i>sin responder a las pulsaciones de botones</i>",
    'fr': "👩🏽‍💻 <b>Sans</b> 💨Les abonnements @{0} fonctionnent en mode <b>statique</b> : <i>sans répondre aux pressions sur les boutons</i>",
    'zh': "👩🏽‍💻<b>没有</b> 💨订阅@{0}在<b>静态</b>模式下工作：<i>不响应按钮按下</i>",
    'ar': "👩🏽‍💻 <b>بدون</b> 💨الاشتراكات @{0} تعمل في الوضع <b>الثابت</b>: <i>بدون الاستجابة للضغطات على الأزرار</i>",
}
l_hand_request = {
    'ru': "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 1мин</i>",
    'en': "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 1 min</i>",
    'es': "👩🏽‍💻 <i><b>Procesando</b> solicitud..\n#duración 1 min</i>",
    'fr': "👩🏽‍💻 <i><b>Traitement</b> demande..\n#durée 1 min</i>",
    'zh': "👩🏽‍💻<i><b>正在处理</b>请求..\n#duration 1 分钟</i>",
    'ar': "👩🏽‍💻 <i><b>جارٍ معالجة</b> الطلب..\n#المدة دقيقة واحدة</i>",
}

# region function
l_rent_userbot_handler = {
    'ru': "👩🏽‍💻 <b>Аренда</b> аккаунта включает в себя стандартную 💨Подписку и все платные возможности\n\n👉🏼 Жми [💳 Аренда], чтобы получить уже прогретый аккаунт",
    'en': "👩🏽‍💻 <b>Rent</b> account includes a standard 💨Subscription and all paid features\n\n👉🏼 Click [💳 Rent] to get an already warmed up account",
    'es': "👩🏽‍💻 La cuenta <b>Rent</b> incluye una 💨Suscripción estándar y todas las funciones pagas\n\n👉🏼 Haga clic en [💳 Rent] para obtener una cuenta ya preparada",
    'fr': "👩🏽‍💻 Le compte <b>Louer</b> comprend un 💨Abonnement standard et toutes les fonctionnalités payantes\n\n👉🏼 Cliquez sur [💳 Louer] pour obtenir un compte déjà réchauffé",
    'zh': "👩🏽‍💻<b>租用</b>帐户包含标准💨订阅和所有付费功能\n\n👉🏼点击[💳租用]即可获得已预热的帐户",
    'ar': "👩🏽‍💻 يتضمن حساب <b>إيجار</b> اشتراكًا قياسيًا 💨 وجميع الميزات المدفوعة\n\n👉🏼 انقر فوق [💳 إيجار] للحصول على حساب جاهز بالفعل",
}
l_new_userbot_start = {
    'ru': "👩🏽‍💻 <b>1/5. Создай</b> [<code>используй дополнительный</code>] <i>Telegram</i>-аккаунт через <b>мобильное</b> приложение и отправь его <u>номер</u> телефона℡\n\n👩🏽‍💻 Например, <code>+34663072680</code>\n\n<i>P.S. Будет очень трудно пройти все шаги до конца, но это стоит того</i>",
    'en': "👩🏽‍💻 <b>1/5. Create</b> [<code>use additional</code>] <i>Telegram</i>-account through the <b>mobile</b> application and send its <u>number</u> phone℡\ n\n👩🏽‍💻 For example, <code>+34663072680</code>\n\n<i>PS It will be very difficult to complete all the steps, but it's worth it</i>",
    'es': "👩🏽‍💻 <b>1/5. Cree</b> [<code>usar adicional</code>] <i>Telegram</i> una cuenta a través de la aplicación <b>móvil</b> y envíe su <u>número</u> de teléfono℡ \ n\n👩🏽‍💻 Por ejemplo, <code>+34663072680</code>\n\n<i>PD: Será muy difícil completar todos los pasos, pero vale la pena</i>",
    'fr': "👩🏽‍💻 <b>1/5. Créez</b> [<code>utilisez un compte supplémentaire</code>] <i>Telegram</i> via l'application <b>mobile</b> et envoyez son <u>numéro</u> de téléphone℡ \ n\n👩🏽‍💻 Par exemple, <code>+34663072680</code>\n\n<i>PS Il sera très difficile de terminer toutes les étapes, mais cela en vaut la peine</i>",
    'zh': "👩🏽‍💻<b>1/5。通过<b>移动</b>应用程序创建</b> [<code>使用额外</code>] <i>Telegram</i>-帐户并将其<u>号码</u>电话℡ \ n\n👩🏽‍💻 例如，<code>+34663072680</code>\n\n<i>PS 完成所有步骤会非常困难，但这是值得的</i>",
    'ar': "👩🏽‍💻<b>1/5. أنشئ</b> [<code>استخدم</code>] حسابًا <i>Telegram</i> إضافيًا من خلال تطبيق <b>الجوال</b> وأرسل <u>رقمه</u> هاتفه℡\n\n👩🏽‍💻 على سبيل المثال، <code>+34663072680</code>\n\n<i>ملاحظة: سيكون من الصعب جدًا إكمال جميع الخطوات، لكن الأمر يستحق ذلك</i>",
}
l_new_userbot_api = {
    'ru': "👩🏽‍💻 <b>2/5. Зарегистрируй</b> свой <u>дополнительный</u> аккаунт на официальном сайта <b>Telegram-приложений</b> (выключи VPN): https://my.telegram.org/auth. <i>Придумай</i> [App title] и [Short name (из 5 цифр)] и <u>отправь</u>: <code>App api_id и App api_hash</code>\n\n👩🏽‍💻 <b>Например:</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
    'en': "👩🏽‍💻 <b>2/5. Register</b> your <u>additional</u> account on the official website of <b>Telegram applications</b> (turn off VPN): https://my.telegram.org/auth . <i>Come up with</i> [App title] and [Short name (5 digits)] and <u>came</u>: <code>App api_id and App api_hash</code>\n\n👩🏽 ‍💻 <b>For example:</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
    'es': "👩🏽‍💻 <b>2/5. Registre</b> su cuenta <u>adicional</u> en el sitio web oficial de <b>aplicaciones de Telegram</b> (desactive VPN): https://my.telegram.org/auth . <i>Sube</i> [Título de la aplicación] y [Nombre corto (5 dígitos)] y <u>vino</u>: <code>App api_id y App api_hash</code>\n\n👩 🏽 ‍💻 <b>Por ejemplo:</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
    'fr': "👩🏽‍💻 <b>2/5. Enregistrez</b> votre compte <u>supplémentaire</u> sur le site officiel des <b>applications Telegram</b> (désactivez le VPN) : https://my.telegram.org/auth . <i>Proposez</i> [Titre de l'application] et [Nom court (5 chiffres)] et <u>est venu</u> : <code>App api_id et App api_hash</code>\n\n👩 🏽 ‍💻 <b>Par exemple :</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
    'zh': "👩🏽‍💻<b>2/5。在<b>Telegram应用程序</b>的官方网站上注册</b>您的<u>额外</u>帐户（关闭VPN）：https: //my.telegram.org/auth 。 <i>提出</i>[应用程序标题]和[简称（5位数字）]并<u>得出</u>：<code>应用程序api_id和应用程序api_hash</code>\n\n👩 🏽 ‍💻 <b>例如：</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
    'ar': "👩🏽‍💻<b>2/5. سجل</b> حسابك <u>الإضافي</u> على الموقع الرسمي <b>لتطبيقات Telegram</b> (أوقف تشغيل VPN): https://my.telegram.org/auth . <i>ابتكر</i> [عنوان التطبيق] و[الاسم المختصر (5 أرقام)] و<u>جاء</u>: <code>App api_id وApp api_hash</code>\n\n👩 🏽 ‍💻 <b>على سبيل المثال:</b>\n<code>1225257 2bb552cc55d5cc2eccd22dab2d</code>",
}
l_fsm_new_userbot = {
    'ru': "👩🏽‍💻 <b>Отправь</b> корректный номер телефона℡\n\n👩🏽‍💻 Например, <code>34663072680</code>",
    'en': "👩🏽‍💻 <b>Come</b> correct phone number℡\n\n👩🏽‍💻 For example, <code>34663072680</code>",
    'es': "👩🏽‍💻 <b>Ven</b> número de teléfono correcto℡\n\n👩🏽‍💻 Por ejemplo, <code>34663072680</code>",
    'fr': "👩🏽‍💻 <b>Venez</b> le numéro de téléphone correct℡\n\n👩🏽‍💻 Par exemple, <code>34663072680</code>",
    'zh': "👩🏽‍💻 <b>来</b>正确的电话号码℡\n\n👩🏽‍💻 例如，<code>34663072680</code>",
    'ar': "👩🏽‍💻 <b>تعال</b> رقم الهاتف الصحيح℡\n\n👩🏽‍💻 على سبيل المثال <code>34663072680</code>",
}
l_fsm_auth = {
    'ru': "👩🏽‍💻 <b>3/5. Введи</b> код-авторизации, присланный в <u>дополнительный</u> аккаунт от <i>верифицированного</i> <b>Telegram</b>-аккаунта\n\n👩🏽‍💻 Например, как на рисунке <code>YVTdd9r7brb</code>",
    'en': "👩🏽‍💻 <b>3/5. Enter</b> the authorization code sent to the <u>additional</u> account from the <i>verified</i> <b>Telegram</b>-account\n\n👩🏽‍💻 For example, how in the picture <code>YVTdd9r7brb</code>",
    'es': "👩🏽‍💻 <b>3/5. Ingrese</b> el código de autorización enviado a la cuenta <u>adicional</u> desde la cuenta <i>verificada</i> <b>Telegram</b>\n\n👩🏽‍💻 Por ejemplo , como en la imagen <code>YVTdd9r7brb</code>",
    'fr': "👩🏽‍💻 <b>3/5. Saisissez</b> le code d'autorisation envoyé au compte <u>supplémentaire</u> à partir du compte <i>vérifié</i> <b>Telegram</b>\n\n👩🏽‍💻 Par exemple , comment dans l'image <code>YVTdd9r7brb</code>",
    'zh': "👩🏽‍💻<b>3/5。输入</b>从<i>已验证</i> <b>Telegram</b>-帐户发送到<u>附加</u>帐户的授权码\n\n👩🏽‍💻 例如，图中如何<code>YVTdd9r7brb</code>",
    'ar': "👩🏽‍💻<b>3/5. أدخل</b> رمز التفويض المرسل إلى الحساب <u>الإضافي</u> من حساب <i>الذي تم التحقق منه</i> <b>Telegram</b>\n\n👩🏽‍💻 على سبيل المثال ، كيف في الصورة <code>YVTdd9r7brb</code>",
}
l_fsm_auth_fail = {
    'ru': "👩🏽‍💻 <b>Попытка</b> авторизации на https://my.telegram.org/auth не удалась! Попробуй еще раз позже!",
    'en': "👩🏽‍💻 <b>Attempt</b> to authorize on https://my.telegram.org/auth failed! Try again later!",
    'es': "👩🏽‍💻 ¡El <b>intento</b> de autorizar en https://my.telegram.org/auth falló! ¡Inténtalo de nuevo más tarde!",
    'fr': "👩🏽‍💻 <b>Tentative</b> d'autorisation sur https://my.telegram.org/auth a échoué ! Réessayez plus tard!",
    'zh': "👩🏽‍💻 <b>尝试</b>在https://my.telegram.org/auth上授权失败！稍后再试！",
    'ar': "👩🏽‍💻 <b>فشلت محاولة</b> التفويض على https://my.telegram.org/auth ! حاول مرة أخرى في وقت لاحق!",
}
l_fsm_auth_cloud = {
    'ru': "👩🏽‍💻 <b>4/5. Придумай</b> <i>облачный пароль</i> для защиты аккаунта или отправь <b>текущий</b>, чтобы начать <u>запуcк</u> аккаунта\n\n👩🏽‍💻 Например, <code>ferey2</code>\n(жми, чтобы скопировать)",
    'en': "👩🏽‍💻 <b>4/5. Create</b> a <i>cloud password</i> to protect your account or send a <b>current</b> to start <u>launch</u> your account\n\n👩🏽‍💻 For example, < code>ferey2</code>\n(click to copy)",
    'es': "👩🏽‍💻 <b>4/5. Cree</b> una <i>contraseña de nube</i> para proteger su cuenta o envíe una <b>actual</b> para comenzar a <u>iniciar</u> su cuenta\n\n👩🏽‍💻 Por ejemplo, < code>ferey2</code>\n(haga clic para copiar)",
    'fr': "👩🏽‍💻 <b>4/5. Créez</b> un <i>mot de passe cloud</i> pour protéger votre compte ou envoyez un <b>courant</b> pour démarrer le <u>lancement</u> de votre compte\n\n👩🏽‍💻 Par exemple, < code>ferey2</code>\n(cliquez pour copier)",
    'zh': "👩🏽‍💻<b>4/5。创建</b><i>云密码</i>来保护您的帐户，或发送<b>当前</b>来开始<u>启动</u>您的帐户\n\n👩🏽‍💻例如<code>ferey2</code>\n（点击复制）",
    'ar': "👩🏽‍💻<b>4/5. أنشئ</b> <i>كلمة مرور سحابية</i> لحماية حسابك أو أرسل <b>كلمة مرور</b> حالية لبدء <u>إطلاق</u> حسابك\n\n👩🏽‍💻 على سبيل المثال، <code>ferey2</code>\n(انقر للنسخ)",
}
l_selenium_time = {
    'ru': "👩🏽‍💻 <b>Время</b> ожидания прошло! Попробуй еще раз позже!",
    'en': "👩🏽‍💻 <b>The time</b> of waiting is over! Try again later!",
    'es': "👩🏽‍💻 ¡<b>El tiempo</b> de espera ha terminado! ¡Inténtalo de nuevo más tarde!",
    'fr': "👩🏽‍💻 <b>Le temps</b> d'attendre est révolu ! Réessayez plus tard!",
    'zh': "👩🏽‍💻<b>等待的时间</b>结束了！稍后再试！",
    'ar': "👩🏽‍💻 <b>وقت</b> انتهى! حاول مرة أخرى في وقت لاحق!",
}
l_fsm_auth_code = {
    'ru': "👩🏽‍💻 <b>5/5. Введи</b> код-подтверждения для <u>запуска</u> аккаунта, также присланный от <b>Telegram</b> (у тебя 10 секунд)\n\n👩🏽‍💻 Например, как на рисунке <code>20777</code>",
    'en': "👩🏽‍💻 <b>5/5. Enter</b> the confirmation code to <u>launch</u> your account, also sent from <b>Telegram</b> (you have 10 seconds)\n\n👩🏽‍💻 For example, as in the picture < code>20777</code>",
    'es': "👩🏽‍💻 <b>5/5. Introduce</b> el código de confirmación para <u>iniciar</u> tu cuenta, también enviado desde <b>Telegram</b> (tienes 10 segundos)\n\n👩🏽‍💻 Por ejemplo, como en la imagen <código>20777</código>",
    'fr': "👩🏽‍💻 <b>5/5. Saisissez</b> le code de confirmation pour <u>lancer</u> votre compte, également envoyé depuis <b>Telegram</b> (vous avez 10 secondes)\n\n👩🏽‍💻 Par exemple, comme dans la photo < code>20777</code>",
    'zh': "👩🏽‍💻<b>5/5。输入</b>确认码以<u>启动</u>您的帐户，该确认码也是从 <b>Telegram</b> 发送的（您有 10 秒的时间）\n\n👩🏽‍💻 例如，如下所示图片 <code>20777</code>",
    'ar': "👩🏽‍💻<b>5/5. أدخل</b> رمز التأكيد <u>لتشغيل</u> حسابك، والذي تم إرساله أيضًا من <b>Telegram</b> (لديك 10 ثوانٍ)\n\n👩🏽‍💻 على سبيل المثال، كما في الصورة <code>20777</code>",
}
l_fsm_cloud_current = {
    'ru': "👩🏽‍💻 <b>Укажи</b> текущий <i>облачный пароль</i>",
    'en': "👩🏽‍💻 <b>Specify</b> the current <i>cloud password</i>",
    'es': "👩🏽‍💻 <b>Especifique</b> la <i>contraseña de nube</i> actual",
    'fr': "👩🏽‍💻 <b>Spécifiez</b> le <i>mot de passe cloud</i> actuel",
    'zh': "👩🏽‍💻<b>指定</b>当前<i>云密码</i>",
    'ar': "👩🏽‍💻 <b>حدد</b> <i>كلمة مرور السحابة</i> الحالية",
}
l_fsm_auth_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> Telegram, попробуй еще раз! <b>Создай</b>/<code>используй дополнительный</code> <i>Telegram</i>-аккаунт через <b>мобильное</b> приложение, а затем отправь его <u>номер</u> телефона℡\n\n👩🏽‍💻 Например, <code>34663072680</code>",
    'en': "👩🏽‍💻 <b>Error</b> Telegram, try again! <b>Create</b>/<code>use an additional</code> <i>Telegram</i>-account through the <b>mobile</b> application, and then send its <u>number</u > phone℡\n\n👩🏽‍💻 For example, <code>34663072680</code>",
    'es': "👩🏽‍💻 <b>Error</b> Telegram, ¡inténtalo de nuevo! <b>Crea</b>/<code>usa una cuenta</code> <i>Telegram</i> adicional a través de la aplicación <b>móvil</b> y luego envía su <u>número< /u > teléfono℡\n\n👩🏽‍💻 Por ejemplo, <code>34663072680</code>",
    'fr': "👩🏽‍💻 <b>Erreur</b> Telegram, réessayez ! <b>Créez</b>/<code>utilisez un compte <i>Telegram</i> supplémentaire</code> via l'application <b>mobile</b>, puis envoyez son <u>numéro< /u > téléphone℡\n\n👩🏽‍💻 Par exemple, <code>34663072680</code>",
    'zh': "👩🏽‍💻<b>错误</b>电报，请重试！ <b>通过<b>移动</b>应用程序<b>创建</b>/<code>使用额外的</code><i>Telegram</i>帐户，然后发送其<u>号码< /u > 电话℡\n\n👩🏽‍💻 例如，<code>34663072680</code>",
    'ar': "👩🏽‍💻 <b>خطأ</b> تيليجرام، حاول مرة أخرى! <b>إنشاء</b>/<code>استخدام</code> <i>حساب Telegram</i> إضافي من خلال تطبيق <b>الجوال</b>، ثم إرسال <u>رقمه< /u > phone℡\n\n👩🏽‍💻 على سبيل المثال، <code>34663072680</code>",
}
l_fsm_code_error = {
    'ru': "👩🏽‍💻 <b>Отправь</b> корректный числовой код",
    'en': "👩🏽‍💻 <b>We've arrived</b> correct numeric code",
    'es': "👩🏽‍💻 <b>Hemos llegado</b> código numérico correcto",
    'fr': "👩🏽‍💻 <b>Nous sommes arrivés</b> code numérique correct",
    'zh': "👩🏽‍💻<b>我们已到达</b>正确的数字代码",
    'ar': "👩🏽‍💻 <b>لقد وصلنا</b> إلى الرمز الرقمي الصحيح",
}
l_fsm_code_ban = {
    'ru': "👩🏽‍💻 <b>Telegram</b> забанил аккаунт на отправку кода\n\n#длительность {0}",
    'en': "👩🏽‍💻 <b>Telegram</b> has banned the account from sending the code\n\n#duration {0}",
    'es': "👩🏽‍💻 <b>Telegram</b> ha prohibido que la cuenta envíe el código\n\n#duration {0}",
    'fr': "👩🏽‍💻 <b>Telegram</b> a interdit au compte d'envoyer le code\n\n#durée {0}",
    'zh': "👩🏽‍💻 <b>Telegram</b> 已禁止该帐户发送代码\n\n#duration {0}",
    'ar': "👩🏽‍💻 <b>Telegram</b> قام بحظر الحساب من إرسال الرمز\n\n#duration {0}",
}
l_fsm_auth_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> Аккаунт <b>{0}</b> \n[<b>id</b>=<code>{1}</code>, <code>+{2}</code>] успешно <i>прикреплен</i> к @{3}\n\n👩🏽‍💻 <b>Добавь</b> <b>{4}</b> ({5}) в свои контакты и отправь любое сообщение",
    'en': "👩🏽‍💻 <b>Done!</b> Account <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code> +{2}</code>] successfully <i>attached</i> to @{3}\n\n👩🏽‍💻 <b>Add</b> <b>{4}</b> ( {5}) to your contacts and send any message",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Cuenta <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code> +{2}</code>] <i>adjuntado</i> exitosamente a @{3}\n\n👩🏽‍💻 <b>Agregar</b> <b>{4}</b> ( {5}) a tus contactos y enviar cualquier mensaje",
    'fr': "👩🏽‍💻 <b>Terminé !</b> Compte <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code> +{2}</code>] <i>attaché</i> avec succès à @{3}\n\n👩🏽‍💻 <b>Ajouter</b> <b>{4}</b> ( {5}) à vos contacts et envoyez n'importe quel message",
    'zh': "👩🏽‍💻 <b>完成！</b> 帐户 <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code> +{2}</code>] 已成功<i>附加</i>到@{3}\n\n👩🏽‍💻 <b>添加</b> <b>{4}</b> ( {5}）到您的联系人并发送任何消息",
    'ar': "👩🏽‍💻 <b>تم!</b> الحساب <b>{0}</b>\n[<b>id</b>=<code>{1}</code>, <code> +{2}</code>] <i>تم إرفاقه</i> بنجاح بـ @{3}\n\n👩🏽‍💻 <b>إضافة</b> <b>{4}</b> ( {5}) إلى جهات الاتصال الخاصة بك وإرسال أي رسالة",
}

l_userbot_res_repair = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Очистка черновиков..\n ✅ Открепление сообщений..\n ✅ Просмотр упоминаний..\n ✅ Сброс уведомлений..\n ✅ Чтение истории..\n ✅ Отмена таймеров удаления..\n ✅ Удаление отложенной отправки..\n ✅ Обновление папок..\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Cleaning drafts..\n✅ Unpin messages..\n✅ View mentions..\n✅ Reset notifications..\n✅ Read history..\n✅ Cancel deletion timers..\n✅ Delete pending sends..\n✅ Updating folders..\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Limpieza borradores...\n✅ Desanclar mensajes...\n✅ Ver menciones...\n✅ Restablecer notificaciones...\n✅ Leer historial...\n✅ Cancelar temporizadores de eliminación...\n✅ Eliminar envíos pendientes...\n✅ Actualizando carpetas...\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Nettoyage brouillons..\n✅ Désépingler les messages..\n✅ Afficher les mentions..\n✅ Réinitialiser les notifications..\n✅ Lire l'historique..\n✅ Annuler les minuteurs de suppression..\n✅ Supprimer les envois en attente..\n✅ Mise à jour des dossiers..\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ 清洁草稿..\n✅ 取消固定消息..\n✅ 查看提及..\n✅ 重置通知..\n✅ 阅读历史记录..\n✅ 取消删除计时器..\n✅ 删除待处理的发送..\n✅正在更新文件夹..\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ التنظيف المسودات..\n✅ إلغاء تثبيت الرسائل..\n✅ عرض الإشارات..\n✅ إعادة تعيين الإشعارات..\n✅ قراءة السجل..\n✅ إلغاء مؤقتات الحذف..\n✅ حذف عمليات الإرسال المعلقة..\n✅ جارٍ تحديث المجلدات..\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_reset = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n ✅ Сброс настроек..\n ✅ Удаление контактов..\n ✅ Удаление Telegram-ботов..\n ✅ Удаление диалогов..\n ✅ Выход из групп и каналов..\n ✅ Удаление платежной информации..\n ✅ Удаление истории звонков..\n ✅ Удаление стикеров/эможди..\n ✅ Сброс настроек оповещения..\n ✅ Очистка галереи обоев..\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Reset settings..\n✅ Deleting contacts..\n✅ Deleting Telegram bots..\n✅ Deleting dialogs..\n✅ Exiting groups and channels..\n✅ Deleting payment information..\n✅ Deleting call history ..\n✅ Removing stickers/emoticons..\n✅ Resetting notification settings..\n✅ Clearing the wallpaper gallery..\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Restablecer configuración...\n✅ Eliminar contactos...\n✅ Eliminar bots de Telegram...\n✅ Eliminar cuadros de diálogo...\n✅ Salir de grupos y canales...\n✅ Eliminar información de pago...\n✅ Eliminar historial de llamadas...\n✅ Eliminando pegatinas/emoticones...\n✅ Restableciendo la configuración de notificaciones...\n✅ Borrando la galería de fondos de pantalla...\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Réinitialiser paramètres..\n✅ Supprimer des contacts..\n✅ Supprimer des robots Telegram..\n✅ Supprimer des boîtes de dialogue..\n✅ Quitter des groupes et des canaux..\n✅ Supprimer les informations de paiement..\n✅ Supprimer l'historique des appels ..\n✅ Suppression des autocollants/émoticônes..\n✅ Réinitialisation des paramètres de notification..\n✅ Effacement de la galerie de fonds d'écran..\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ 重置设置..\n✅ 删除联系人..\n✅ 删除 Telegram 机器人..\n✅ 删除对话框..\n✅ 退出群组和频道..\n✅ 删除付款信息..\n✅ 删除通话记录 ..\n✅ 删除贴纸/表情符号..\n✅ 重置通知设置..\n✅ 清除壁纸库..\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ إعادة تعيين الإعدادات..\n✅ حذف جهات الاتصال..\n✅ حذف روبوتات Telegram..\n✅ حذف مربعات الحوار..\n✅ الخروج من المجموعات والقنوات..\n✅ حذف معلومات الدفع..\n✅ حذف سجل المكالمات ..\n✅ إزالة الملصقات/الرموز التعبيرية..\n✅ إعادة ضبط إعدادات الإشعارات..\n✅ مسح معرض الخلفيات..\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_run = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Успешно запущен\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Success launched\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Éxito lanzado\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ Succès lancé\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ 成功启动\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n✅ نجاح تم إطلاق\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_spambot = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot: {3}\n\n👩🏽‍💻 <b>Карма:</b>\n{4}: локальная\n{5}: глобальная\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot : {3}\n\n👩🏽‍💻 <b>Karma:</b>\n{4}: local\n{5}: global\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot : {3}\n\n👩🏽‍💻 <b>Karma:</b>\n{4}: local\n{5}: global\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot : {3}\n\n👩🏽‍💻 <b>Karma :</b>\n{4} : local\n{5} : global\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot : {3}\n\n👩🏽‍💻 <b>Karma:</b>\n{4}: 本地\n{5}: 全局\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n@spambot : {3}\n\n👩🏽‍💻 <b>الكارما:</b>\n{4}: محلي\n{5}: عالمي\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_login = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽‍💻 <b>Telegram-code:</b>\n{0}\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Telegram-code:</b>\n{0}\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Código de Telegram:</b>\n{0}\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Code-télégramme :</b>\n{0}\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>电报代码：</b>\n{0}\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>رمز التليجرام:</b>\n{0}\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_post = {
    'ru': "👩🏽‍💻 <b>Публикация</b> сообщения успешно запущена\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Publishing</b> message started successfully\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 El mensaje de <b>publicación</b> se inició correctamente\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 Le message <b>Publication</b> a démarré avec succès\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>发布</b>消息已成功开始\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>النشر</b> بدأ بنجاح الرسالة\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_res_parse_csend_correct = {
    'ru': "📨 Вставь <b>корректную</b> ссылку на группу для парсинга @username",
    'en': "📨 Insert the <b>correct</b> link to the group for parsing @username",
    'es': "📨 Inserte el enlace <b>correcto</b> al grupo para analizar @username",
    'fr': "📨 Insérez le lien <b>correct</b> vers le groupe pour analyser @username",
    'zh': "📨 将<b>正确</b>链接插入到解析@username的组中",
    'ar': "📨 أدخل الرابط <b>الصحيح</b> في المجموعة لتحليل @username",
}
l_userbot_res_parse_csend_done = {
    'ru': "👩🏽‍💻 Готово! Парсинг <b>{0}</b> реальных @username: <u>{1}</u>",
    'en': "👩🏽‍💻 Done! Parsing <b>{0}</b> real @username : <u>{1}</u>",
    'es': "👩🏽‍💻¡Listo! Analizando <b>{0}</b> @username real: <u>{1}</u>",
    'fr': "👩🏽‍💻 C'est fait ! Analyse <b>{0}</b> réel @username : <u>{1}</u>",
    'zh': "👩🏽‍💻 完成！正在解析 <b>{0}</b> 真实@username ：<u>{1}</u>",
    'ar': "👩🏽‍💻 تم! تحليل <b>{0}</b> @username الحقيقي : <u>{1}</u>",
}
l_userbot_res_geo_csend_empty = {
    'ru': "📨 В данной <b>геопозиции</b> @username не найдено",
    'en': "📨 @username not found in this <b>geolocation</b>",
    'es': "📨 @username no encontrado en esta <b>geolocalización</b>",
    'fr': "📨 @username introuvable dans cette <b>géolocalisation</b>",
    'zh': "📨 在此<b>地理位置</b>中找不到@username",
    'ar': "📨 @username غير موجود في هذا <b>الموقع الجغرافي</b>",
}
l_userbot_res_geo_csend_done = {
    'ru': "👩🏽‍💻 Готово! По геопозиции <b>{0} {1}</b> найдено реальных @username: <u>{2}</u>",
    'en': "👩🏽‍💻 Done! By geoposition <b>{0} {1}</b> found real @username : <u>{2}</u>",
    'es': "👩🏽‍💻¡Listo! Por geoposición <b>{0} {1}</b> encontrado @username real: <u>{2}</u>",
    'fr': "👩🏽‍💻 C'est fait ! Par géoposition <b>{0} {1}</b> trouvé réel @username : <u>{2}</u>",
    'zh': "👩🏽‍💻 完成！按地理位置 <b>{0} {1}</b> 找到真实的@username ：<u>{2}</u>",
    'ar': "👩🏽‍💻 تم! حسب الموقع الجغرافي، تم العثور على <b>{0} {1}</b> @ @username حقيقي: <u>{2}</u>",
}
l_userbot_res_init = {
    'ru': "👩🏽‍💻 Созданы <b>служебные</b> telegram бот и канал:\n\n@{0}, @{1}\n\n👩🏽‍💻 Для корректной работы не изменяй их @username",
    'en': "👩🏽‍💻 <b>service</b> Telegram bot and channel have been created:\n\n@{0}, @{1}\n\n👩🏽‍💻 For correct operation, do not change them @username",
    'es': "👩🏽‍💻 <b>servicio</b> Se ha creado el bot y el canal de Telegram:\n\n@{0}, @{1}\n\n👩🏽‍💻 Para su correcto funcionamiento no los cambies @username",
    'fr': "👩🏽‍💻 <b>service</b> Le bot et la chaîne Telegram ont été créés :\n\n@{0}, @{1}\n\n👩🏽‍💻 Pour un fonctionnement correct, ne les modifiez pas @username",
    'zh': "👩🏽‍💻 <b>服务</b> Telegram 机器人和频道已创建：\n\n@{0}、@{1}\n\n👩🏽‍💻 为了正确操作，请勿更改它们@username",
    'ar': "👩🏽‍💻 <b>الخدمة</b> تم إنشاء بوت وقناة تيليجرام:\n\n@{0}, @{1}\n\n👩🏽‍💻 للتشغيل الصحيح، لا تغيرهما @username",
}
l_userbot_res_is_mutual = {
    'ru': "👩🏽‍💻 <b>Добавь</b> {0} [<code>{1}</code>] в свои контакты",
    'en': "👩🏽‍💻 <b>Add</b> {0} [<code>{1}</code>] to your contacts",
    'es': "👩🏽‍💻 <b>Agrega</b> {0} [<code>{1}</code>] a tus contactos",
    'fr': "👩🏽‍💻 <b>Ajoutez</b> {0} [<code>{1}</code>] à vos contacts",
    'zh': "👩🏽‍💻<b>添加</b> {0} [<code>{1}</code>]到您的联系人",
    'ar': "👩🏽‍💻 <b>أضف</b> {0} [<code>{1}</code>] إلى جهات الاتصال الخاصة بك",
}
l_userbot_res_scheduler_client = {
    'ru': "👩🏽‍💻 Сессия не найдена! Добавь аккаунт повторно",
    'en': "👩🏽‍💻 Session not found! Add your account again",
    'es': "👩🏽‍💻 ¡Sesión no encontrada! Agrega tu cuenta nuevamente",
    'fr': "👩🏽‍💻 Séance introuvable ! Ajoutez à nouveau votre compte",
    'zh': "👩🏽‍💻 找不到会话！再次添加您的帐户",
    'ar': "👩🏽‍💻 الجلسة غير موجودة! أضف حسابك مرة أخرى",
}
# endregion


# region user
l_usr_config = {
    ("cctor", "👩🏽‍💻", "☑"): {
        'ru': "Конструктор ᴺᴱᵂ",
        'en': "Constructor ᴺᴱᵂ",
        'es': "Constructor ᴺᴱᵂ",
        'fr': "Constructeur ᴺᴱᵂ",
        'zh': "构造函数ᴺᴱᵂ",
        'ar': "منشئ ᴺᴱᵂ",
    },
    ("cformat", "🪄", "☑"): {
        'ru': "Формат",
        'en': "Format",
        'es': "Formato",
        'fr': "Format",
        'zh': "格式",
        'ar': "شكل",
    },
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自动禁止",
        'ar': "الحظر التلقائي",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自动发布",
        'ar': "النشر التلقائي",
    },
    ("cneuro", "🦾", "☐"): {
        'ru': "Нейро-постинг",
        'en': "Neuro-posting",
        'es': "Neuropublicación",
        'fr': "Neuro-posting",
        'zh': "神经张贴",
        'ar': "النشر العصبي",
    },

    ("ctranslate", "文", "☐"): {
        'ru': "Авто-перевод",
        'en': "Auto-translation",
        'es': "Traducción automática",
        'fr': "Traduction automatique",
        'zh': "自动翻译",
        'ar': "الترجمة التلقائية",
    },
    ("cpodcast", "🎥", "☐"): {
        'ru': "Авто-подкаст",
        'en': "Auto-podcast",
        'es': "Podcast automático",
        'fr': "Podcast automatique",
        'zh': "自动播客",
        'ar': "البودكاست التلقائي",
    },
    ("creaction", "🫶🏽", "☑"): {
        'ru': "Авто-реакция",
        'en': "Auto reaction",
        'es': "Reacción automática",
        'fr': "Réaction automatique",
        'zh': "自动反应",
        'ar': "رد فعل تلقائي",
    },
    ("cservice", "👥", "☑"): {
        'ru': "Пользователи",
        'en': "Users",
        'es': "Usuarios",
        'fr': "Utilisateurs",
        'zh': "用户",
        'ar': "المستخدمين",
    },
    ("ctranscribe", "🗣", "☐"): {
        'ru': "Авто-транскрибация",
        'en': "Auto-transcription",
        'es': "Transcripción automática",
        'fr': "Transcription automatique",
        'zh': "自动转录",
        'ar': "النسخ التلقائي",
    },

    ("canswer", "💭", "☐"): {
        'ru': "Нейро-ответ",
        'en': "Neuro-response",
        'es': "Neuro-respuesta",
        'fr': "Neuro-réponse",
        'zh': "神经反应",
        'ar': "الاستجابة العصبية",
    },
    ("cgeo", "📍", "☐"): {
        'ru': "Мониторинг-гео",
        'en': "Monitoring-geo",
        'es': "Monitoreo-geo",
        'fr': "Surveillance-géo",
        'zh': "监控地理",
        'ar': "مراقبة جغرافية",
    },
    ("cword", "🚀", "☐"): {
        'ru': "Мониторинг-слов",
        'en': "Word monitoring",
        'es': "Monitoreo de palabras",
        'fr': "Surveillance des mots",
        'zh': "文字监控",
        'ar': "مراقبة الكلمات",
    },
}
l_to_delete = {
    'ru': "🚫Убрать акк",
    'en': "🚫Remove acc",
    'es': "🚫Eliminar cuenta",
    'fr': "🚫Supprimer l'acc",
    'zh': "🚫删除 acc",
    'ar': "🚫 قم بإزالة التنسيق",
}
l_show_userbots = {
    'ru': "👩🏽‍💻 <b>Добавленные аккаунты</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Added accounts</b>\n\n[commands/cmd]",
    'es': "👩🏽‍💻 <b>Cuentas agregadas</b>\n\n[commands/cmd]",
    'fr': "👩🏽‍💻 <b>Comptes ajoutés</b>\n\n[commands/cmd]",
    'zh': "👩🏽‍💻 <b>已添加帐户</b>\n\n[commands/cmd]",
    'ar': "👩🏽‍💻 <b>الحسابات المضافة</b>\n\n[commands/cmd]",
}
l_userbot_CCHECKBTNNAME = {
    'ru': "✔ Я человек",
    'en': "✔ I'm human",
    'es': "✔soy humano",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人类",
    'ar': "✔ أنا إنسان",
}
# endregion


# region commands
l_usr_commands_handler = {
    'ru': "⚙️ <b>Команды</b> /cmd для <b>{0}</b> [<code>{1}</code>] в @{2} работают также и в самом аккаунте\n\n<blockquote>/info информация об аккаунте\n/stat статистика\n/update обновление профиля\n/status статус\n/on включение\n<code>/off</code> выключение\n<code>/restart</code> перезагрузка\n<code>/repair</code> очистка: чтение истории\n<code>/reset</code> сброс: удаление диалогов\n\n/parse [ссылка/id на чат] [аргумент]\n/login вход в аккаунт\n/spambot карма аккаунта\n<code>/leave</code> покинуть все группы и каналы\n<code>/delete</code> удалить все диалоги</blockquote>\n\n👩🏽‍💻 <b>Только</b> от имени аккаунта\n<blockquote>/screen скриншот-уведомление\n<code>/type +сообщ</code> печатание\n/think обдумывание\n/emoji подвижный emoji\n<code>* отправка 📍гео возвращает @username-список</code></blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    'en': "⚙️ <b>Commands</b> /cmd for <b>{0}</b> in @{1} also work in the account itself\n\n/info <i>account information</i>\ n/stat <i>statistics</i>\n/update <i>profile update</i>\n/status <i>status</i>\n/on <i>enable</i>\n<code>/off</code> <i>shutdown</i>\n<code>/restart</code> <i>reboot</i>\n<code>/repair</code> <i> clear: read history</i>\n<code>/reset</code> <i>reset: delete dialogs</i>\n\n/parse <i>[chat link/id] [argument]< /i>\n/login <i>login to account</i>\n/spambot <i>account karma</i>\n<code>/leave</code> <i>leave all groups and channels< /i>\n<code>/delete</code> <i>delete all dialogs</i>\n\n👩🏽‍💻 <b>Only</b> on behalf of the account\n/screen <i> screenshot notification</i>\n/type +message <i>typing</i>\n/think <i>thinking</i>\n/emoji <i>moving emoji</i>\n<code >* sending 📍geo returns @username-list</code>\n\n💨 <b>Subscription</b>: <i>{2}</i>",
    'es': "⚙️ Los <b>comandos</b> /cmd para <b>{0}</b> en @{1} también funcionan en la cuenta misma\n\n/info <i>información de la cuenta</i>\ n /stat <i>estadísticas</i>\n/update <i>actualización de perfil</i>\n/status <i>status</i>\n/on <i>habilitar</i>\n< código>/apagado</code> <i>apagar</i>\n<code>/restart</code> <i>reboot</i>\n<code>/repair</code> <i> borrar : leer historial</i>\n<code>/reset</code> <i>restablecer: eliminar cuadros de diálogo</i>\n\n/parse <i>[enlace de chat/id] [argumento]< /i >\n/login <i>iniciar sesión en la cuenta</i>\n/spambot <i>cuenta karma</i>\n<code>/leave</code> <i>abandonar todos los grupos y canales</i >\n<code>/delete</code> <i>eliminar todos los cuadros de diálogo</i>\n\n👩🏽‍💻 <b>Solo</b> en nombre de la cuenta\n/screen <i> notificación de captura de pantalla</i>\n/type +mensaje <i>escribiendo</i>\n/think <i>pensando</i>\n/emoji <i>emoji en movimiento</i>\n<code > * enviando 📍geo devuelve @username-list</code>\n\n💨 <b>Suscripción</b>: <i>{2}</i>",
    'fr': "⚙️ Les <b>Commandes</b> /cmd pour <b>{0}</b> dans @{1} fonctionnent également dans le compte lui-même\n\n/info <i>informations sur le compte</i>\ n /stat <i>statistiques</i>\n/update <i>mise à jour du profil</i>\n/status <i>statut</i>\n/on <i>activer</i>\n< code>/off</code> <i>arrêt</i>\n<code>/restart</code> <i>reboot</i>\n<code>/réparation</code> <i> effacer : lire l'historique</i>\n<code>/reset</code> <i>reset : supprimer les boîtes de dialogue</i>\n\n/parse <i>[lien de discussion/id] [argument]< /i >\n/login <i>se connecter au compte</i>\n/spambot <i>karma du compte</i>\n<code>/quitter</code> <i>quitter tous les groupes et chaînes< /i >\n<code>/delete</code> <i>supprimer toutes les boîtes de dialogue</i>\n\n👩🏽‍💻 <b>Uniquement</b> au nom du compte\n/écran <i> notification de capture d'écran</i>\n/type + message <i>saisie</i>\n/penser <i>penser</i>\n/emoji <i>emoji en mouvement</i>\n<code > * l'envoi de 📍geo renvoie @username-list</code>\n\n💨 <b>Abonnement</b> : <i>{2}</i>",
    'zh': "⚙️ @{1} 中 <b>{0}</b> 的<b>命令</b> /cmd 也适用于帐户本身\n\n/info <i>帐户信息</i>\ n /stat <i>统计</i>\n/update <i>配置文件更新</i>\n/status <i>状态</i>\n/on <i>启用</i>\n< code>/off</code> <i>关机</i>\n<code>/restart</code> <i>重新启动</i>\n<code>/repair</code> <i>清除：读取历史记录</i>\n<code>/reset</code> <i>重置：删除对话框</i>\n\n/parse <i>[聊天链接/id] [参数]</i >\n/login <i>登录帐户</i>\n/spambot <i>帐户业力</i>\n<code>/leave</code> <i>离开所有群组和频道</i >\n<code>/delete</code> <i>删除所有对话框</i>\n\n👩🏽‍💻 <b>仅</b>代表帐户\n/screen <i>截图通知</i>\n/type +message <i>打字</i>\n/think <i>思考</i>\n/emoji <i>移动表情符号</i>\n<code > * 发送 📍geo 返回@username-list</code>\n\n💨 <b>订阅</b>：<i>{2}</i>",
    'ar': "⚙️ <b>الأوامر</b> /cmd لـ <b>{0}</b> في @{1} تعمل أيضًا في الحساب نفسه\n\n/info <i>معلومات الحساب</i>\n/stat <i>الإحصائيات</i>\n/update <i>تحديث الملف الشخصي</i>\n/status <i>status</i>\n/on <i>enable</i>\n< code>/off</code> <i>إيقاف التشغيل</i>\n<code>/restart</code> <i>إعادة التشغيل</i>\n<code>/repair</code> <i> واضح : قراءة السجل</i>\n<code>/reset</code> <i>إعادة الضبط: حذف مربعات الحوار</i>\n\n/parse <i>[رابط/معرف الدردشة] [وسيطة]< /i >\n/تسجيل الدخول <i>تسجيل الدخول إلى الحساب</i>\n/spambot <i>حساب الكارما</i>\n<code>/leave</code> <i>مغادرة كافة المجموعات والقنوات< /i >\n<code>/delete</code> <i>حذف كافة مربعات الحوار</i>\n\n👩🏽‍💻 <b>فقط</b> نيابة عن الحساب\n/الشاشة <i> إشعار لقطة الشاشة</i>\n/type +رسالة <i>كتابة</i>\n/think <i>أفكر</i>\n/emoji <i>رمز تعبيري متحرك</i>\n<code > * إرسال 📍إرجاع الموقع الجغرافي @username-list</code>\n\n💨 <b>الاشتراك</b>: <i>{2}</i>",
}
l_commands_handler_userbot = {
    'ru': "⚙️ <b>Команды</b> /cmd для @{0} работают также и в @{1}\n\n<code>/info</code>   <i>информация об аккаунте</i>\n<code>/stat</code>   <i>аналитика</i>\n<code>/update</code> <i>обновление профиля</i>\n<code>/status</code> <i>статус</i>\n<code>/off</code>  <i>выключение</i>\n<code>/repair</code> <i>очистка: чтение истории</i>\n<code>/reset</code>  <i>сброс: удаление диалогов</i>\n\n<code>/parse</code>      <i>[ссылка/id на чат] [аргумент]</i>\n<code>/spambot</code>    <i>карма аккаунта</i>\n<code>/leave</code>   <i>покинуть все группы и каналы</i>\n<code>/delete</code>  <i>удалить все диалоги</i>\n\n👩🏽‍💻 <b>Только</b> от имени аккаунта\n<code>/screen</code> <i>скриншот-уведомление</i>\n<code>/type +сообщ</code>   <i>печатание</i>\n<code>/think</code>   <i>обдумывание</i>\n<code>/emoji</code>  <i>подвижный emoji</i>\n<code>* отправка 📍гео возвращает @username-список</code>\n\n💨 <b>Подписка</b>: <i>{2}</i>",
    'en': "⚙️ <b>Commands</b> /cmd for @{0} also work in @{1}\n\n<code>/info</code> <i>account information</i>\n< code>/stat</code> <i>analytics</i>\n<code>/update</code> <i>profile update</i>\n<code>/status</code> <i> status</i>\n<code>/off</code> <i>shutdown</i>\n<code>/repair</code> <i>cleaning: reading history</i>\n<code >/reset</code> <i>reset: deleting dialogs</i>\n\n<code>/parse</code> <i>[chat link/id] [argument]</i>\n<code>/spambot</code> <i>account karma</i>\n<code>/leave</code> <i>leave all groups and channels</i>\n<code>/delete</ code> <i>delete all dialogs</i>\n\n👩🏽‍💻 <b>Only</b> on behalf of the account\n<code>/screen</code> <i>screenshot notification</ i>\n<code>/type +message</code> <i>typing</i>\n<code>/think</code> <i>thinking</i>\n<code>/emoji< /code> <i>moving emoji</i>\n<code>* sending 📍geo returns @username-list</code>\n\n💨 <b>Subscription</b>: <i>{2} </i>",
    'es': "⚙️ Los <b>comandos</b> /cmd para @{0} también funcionan en @{1}\n\n<code>/info</code> <i>información de cuenta</i>\n< code> /stat</code> <i>analítica</i>\n<code>/update</code> <i>actualización de perfil</i>\n<code>/status</code> <i> estado< /i>\n<code>/off</code> <i>apagado</i>\n<code>/repair</code> <i>limpieza: lectura del historial</i>\n<code >/ reset</code> <i>restablecer: eliminar cuadros de diálogo</i>\n\n<code>/parse</code> <i>[enlace de chat/id] [argumento]</i>\n<code> /spambot</code> <i>cuenta karma</i>\n<code>/leave</code> <i>dejar todos los grupos y canales</i>\n<code>/delete</ code> < i>eliminar todos los cuadros de diálogo</i>\n\n👩🏽‍💻 <b>Solo</b> en nombre de la cuenta\n<code>/screen</code> <i>notificación de captura de pantalla</ i>\n<code>/type +mensaje</code> <i>escribiendo</i>\n<code>/think</code> <i>pensando</i>\n<code>/emoji< /code > <i>emoji en movimiento</i>\n<code>* enviando 📍geo devuelve @username-list</code>\n\n💨 <b>Suscripción</b>: <i>{2} </ yo>",
    'fr': "⚙️ Les <b>Commandes</b> /cmd pour @{0} fonctionnent également dans @{1}\n\n<code>/info</code> <i>informations du compte</i>\n< code> /stat</code> <i>analyses</i>\n<code>/update</code> <i>mise à jour du profil</i>\n<code>/statut</code> <i> statut< /i>\n<code>/off</code> <i>arrêt</i>\n<code>/réparation</code> <i>nettoyage : lecture de l'historique</i>\n<code >/ reset</code> <i>reset : suppression des boîtes de dialogue</i>\n\n<code>/parse</code> <i>[lien/id de chat] [argument]</i>\n<code> /spambot</code> <i>karma du compte</i>\n<code>/quitter</code> <i>quitter tous les groupes et chaînes</i>\n<code>/delete</ code> < i>supprimer toutes les boîtes de dialogue</i>\n\n👩🏽‍💻 <b>Uniquement</b> au nom du compte\n<code>/écran</code> <i>notification de capture d'écran</ i>\n<code>/type +message</code> <i>saisir</i>\n<code>/penser</code> <i>réfléchir</i>\n<code>/emoji< /code > <i>emoji en mouvement</i>\n<code>* l'envoi de 📍geo renvoie @username-list</code>\n\n💨 <b>Abonnement</b> : <i>{2} </ je>",
    'zh': "⚙️ @{0} 的<b>命令</b> /cmd 也适用于 @{1}\n\n<code>/info</code> <i>帐户信息</i>\n< code> /stat</code> <i>分析</i>\n<code>/update</code> <i>配置文件更新</i>\n<code>/status</code> <i>状态< /i>\n<code>/off</code> <i>关机</i>\n<code>/repair</code> <i>清理：读取历史记录</i>\n<code>/重置</code> <i>重置：删除对话框</i>\n\n<code>/parse</code> <i>[聊天链接/id] [参数]</i>\n<code> /spambot</code> <i>帐户业力</i>\n<code>/leave</code> <i>离开所有群组和频道</i>\n<code>/delete</code> < i>删除所有对话框</i>\n\n👩🏽‍💻 <b>仅</b>代表帐户\n<code>/screen</code> <i>截图通知</ i>\n<code>/type +message</code> <i>打字</i>\n<code>/think</code> <i>思考</i>\n<code>/emoji</code > <i>移动表情符号</i>\n<code>* 发送📍geo 返回@username-list</code>\n\n💨 <b>订阅</b>：<i>{2} </我>",
    'ar': "⚙️ <b>الأوامر</b> /cmd لـ @{0} تعمل أيضًا في @{1}\n\n<code>/info</code> <i>معلومات الحساب</i>\n< code> /stat</code> <i>التحليلات</i>\n<code>/update</code> <i>تحديث الملف الشخصي</i>\n<code>/status</code> <i> الحالة< /i>\n<code>/off</code> <i>إيقاف التشغيل</i>\n<code>/repair</code> <i>التنظيف: قراءة السجل</i>\n<code >/ إعادة تعيين</code> <i>إعادة تعيين: حذف مربعات الحوار</i>\n\n<code>/parse</code> <i>[رابط/معرف الدردشة] [وسيطة]</i>\n<code> /spambot</code> <i>كارما الحساب</i>\n<code>/leave</code> <i>اترك جميع المجموعات والقنوات</i>\n<code>/delete</code> <<i>حذف جميع مربعات الحوار</i>\n\n👩🏽‍💻 <b>فقط</b> نيابةً عن الحساب\n<code>/screen</code> <i>إشعار لقطة الشاشة</<i>\n<code>/type +message</code> <i>typing</i>\n<code>/think</code> <i>thinking</i>\n<code>/emoji< /code > <i>رموز تعبيرية متحركة</i>\n<code>* إرسال 📍إرجاع جغرافي @username-list</code>\n\n💨 <b>الاشتراك</b>: <i>{2} </ أنا>",
}
l_update_fun = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Био:</b> {3}\n\n✅ <i>Профиль обновлен</i>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Bio :</b> {3}\n\n✅ <i>Profile updated</i>\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Biografía :</b> {3}\n\n✅ <i>Perfil actualizado</i>\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>Bio :</b> {3}\n\n✅ <i>Profil mis à jour</i>\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>个人简介:</b> {3}\n\n✅ <i>个人资料已更新</i>\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n<b>السيرة الذاتية :</b> {3}\n\n✅ <i>تم تحديث الملف الشخصي</i>\n\n⚙️ <b>الأوامر</b> /cmd",
}

l_status_handler = {
    'ru': "👩🏽‍💻 <b>Аккаунт</b>-статус: {0}",
    'en': "👩🏽‍💻 <b>Account</b>-status: {0}",
    'es': "👩🏽‍💻 <b>Cuenta</b>-estado: {0}",
    'fr': "👩🏽‍💻 <b>Statut du compte</b> : {0}",
    'zh': "👩🏽‍💻<b>帐户</b>-状态：{0}",
    'ar': "👩🏽‍💻 <b>الحساب</b>-الحالة: {0}",
}
l_on_handler = {
    'ru': "👩🏽‍💻 Начинаем запуск аккаунта..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Let's start launching the account..\n\n#duration 1 min",
    'es': "👩🏽‍💻 Comencemos a abrir la cuenta...\n\n#duración 1 min",
    'fr': "👩🏽‍💻 Commençons par lancer le compte..\n\n#durée 1 min",
    'zh': "👩🏽‍💻 让我们开始启动帐户..\n\n#duration 1 分钟",
    'ar': "👩🏽‍💻 لنبدأ بإطلاق الحساب..\n\n#المدة دقيقة واحدة",
}
l_on_handler_already = {
    'ru': "👩🏽‍💻 Аккаунт уже запущен",
    'en': "👩🏽‍💻 Account has already been launched",
    'es': "👩🏽‍💻 La cuenta ya ha sido lanzada",
    'fr': "👩🏽‍💻 Le compte a déjà été lancé",
    'zh': "👩🏽‍💻 账户已开通",
    'ar': "👩🏽‍💻 لقد تم إطلاق الحساب بالفعل",
}
l_off_handler = {
    'ru': "👩🏽‍💻 Завершаем сессию аккаунта {0}..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 We close the session of account {0}..\n\n#duration 1 min",
    'es': "👩🏽‍💻 Cerramos la sesión de la cuenta {0}..\n\n#duración 1 min",
    'fr': "👩🏽‍💻 Nous fermons la session du compte {0}..\n\n#durée 1 min",
    'zh': "👩🏽‍💻 我们关闭帐户 {0} 的会话..\n\n#duration 1 分钟",
    'ar': "👩🏽‍💻 نغلق جلسة الحساب {0}..\n\n#المدة دقيقة واحدة",
}
l_off_handler_already = {
    'ru': "👩🏽‍💻 Аккаунт уже выключен",
    'en': "👩🏽‍💻 Account is already disabled",
    'es': "👩🏽‍💻 La cuenta ya está deshabilitada",
    'fr': "👩🏽‍💻 Le compte est déjà désactivé",
    'zh': "👩🏽‍💻 帐户已被禁用",
    'ar': "👩🏽‍💻 الحساب معطل بالفعل",
}
l_off_handler_done = {
    'ru': "👩🏽‍💻 Аккаунт выключен",
    'en': "👩🏽‍💻 Account disabled",
    'es': "👩🏽‍💻 Cuenta inhabilitada",
    'fr': "👩🏽‍💻 Compte désactivé",
    'zh': "👩🏽‍💻 帐户已停用",
    'ar': "👩🏽‍💻 الحساب معطل",
}
l_restart_handler = {
    'ru': "👩🏽‍💻 Перезапуск сессии аккаунта {0}..\n\n#длительность 1мин",
    'en': "👩🏽‍💻 Restarting account session {0}..\n\n#duration 1 min",
    'es': "👩🏽‍💻 Reiniciando la sesión de la cuenta {0}..\n\n#duración 1 min",
    'fr': "👩🏽‍💻 Redémarrage de la session du compte {0}..\n\n#durée 1 min",
    'zh': "👩🏽‍💻 正在重新启动帐户会话 {0}..\n\n#duration 1 分钟",
    'ar': "👩🏽‍💻 إعادة تشغيل جلسة الحساب {0}..\n\n#المدة دقيقة واحدة",
}
l_leave_handler = {
    'ru': "👩🏽‍💻 <b>Выход</b> из групп/каналов выполнен",
    'en': "👩🏽‍💻 <b>Exit</b> from groups/channels completed",
    'es': "👩🏽‍💻 <b>Salida</b> de grupos/canales completada",
    'fr': "👩🏽‍💻 <b>Sortie</b> des groupes/chaînes terminée",
    'zh': "👩🏽‍💻 <b>退出</b>群组/频道已完成",
    'ar': "👩🏽‍💻 اكتمل <b>الخروج</b> من المجموعات/القنوات",
}
l_delete_handler = {
    'ru': "👩🏽‍💻 <b>Удаление</b> диалогов выполнено",
    'en': "👩🏽‍💻 <b>Deleting</b> dialogues completed",
    'es': "👩🏽‍💻 <b>Eliminación</b> de diálogos completados",
    'fr': "👩🏽‍💻 <b>Suppression</b> des dialogues terminée",
    'zh': "👩🏽‍💻<b>删除</b>对话已完成",
    'ar': "👩🏽‍💻 اكتمل <b>حذف</b> مربعات الحوار",
}
l_think_handler = {
    'ru': "💭 Думаю об этом.. {0}%",
    'en': "💭 Thinking about it.. {0}%",
    'es': "💭 Pensando en ello... {0}%",
    'fr': "💭 J'y pense.. {0}%",
    'zh': "💭 想想.. {0}%",
    'ar': "💭 أفكر في الأمر.. {0}%",
}
l_poll_handler = {
    'ru': "👩🏽‍💻 <b>Авто-голосование</b> в {0} [{1}, <code>{2}</code>] за <u>{3}</u>-вариант успешно проведено",
    'en': "👩🏽‍💻 <b>Auto-voting</b> in {0} [{1}, <code>{2}</code>] for <u>{3}</u>-option successfully completed",
    'es': "👩🏽‍💻 <b>Votación automática</b> en {0} [{1}, <code>{2}</code>] para la opción <u>{3}</u> completada con éxito",
    'fr': "👩🏽‍💻 <b>Vote automatique</b> dans {0} [{1}, <code>{2}</code>] pour l'option <u>{3}</u> terminée avec succès",
    'zh': "👩🏽‍💻 <b>自动投票</b>在 {0} [{1}, <code>{2}</code>] 中为 <u>{3}</u> 选项成功完成",
    'ar': "👩🏽‍💻 <b>التصويت التلقائي</b> في {0} [{1}، <code>{2}</code>] لـ <u>{3}</u>-تم إكمال الخيار بنجاح",
}

l_add_new_acc = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽‍💻 <b>Добавь</b> <i>новый</i> аккаунт на устройстве: введи <i>номер телефона</i>. <b>Код</b> подтверждения будет выслан в @{3}",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Add</b> a <i>new</i> account on your device: enter <i>phone number</i>. <b>Confirmation code</b> will be sent to @{3}",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Agregue</b> una cuenta <i>nueva</i> en su dispositivo: ingrese el <i>número de teléfono</i>. El <b>código de confirmación</b> se enviará a @{3}",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>Ajoutez</b> un <i>nouveau</i> compte sur votre appareil : saisissez le <i>numéro de téléphone</i>. Le <b>code de confirmation</b> sera envoyé à @{3}",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 在您的设备上<b>添加</b><i>新</i>帐户：输入<i>电话号码</i>。 <b>确认码</b>将发送至@{3}",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]\n\n👩🏽 ‍💻 <b>أضف</b> حساب <i>جديد</i> على جهازك: أدخل <i>رقم الهاتف</i>. سيتم إرسال <b>رمز التأكيد</b> إلى @{3}",
}
l_parse_text2 = {
    'ru': "👩🏽‍💻 <b>Формат парсинга</b>:\n/parse [ссылка или id] [<u>аргумент</u>]\n\n👩🏽‍💻 Возможные <u>аргументы</u>:\n<b>all</b> (всех участников по умолчанию)\n<b>old</b> (старых пользователей)\n<b>premium</b> (премиум-аккаунтов)\n<b>active</b> (активных в чате)\n<b>online</b> (сейчас в сети)\n<b>contacts</b> (telegram-контактов)\n<b>dialogs</b> (всех id-диалогов)\n<b>bots</b> (telegram-ботов)\n\n👩🏽‍💻 Например, парсинг:\n<code>/parse https://t.me/MoscowNames</code> (все)\n<code>/parse @moscownames online</code> (онлайн)\n<code>/parse -1001560037735</code> (по id диалога)\n<code>/parse</code> (внутри чата)",
    'en': "👩🏽‍💻 <b>Parsing format</b>:\n/parse [link or id] [<u>argument</u>]\n\n👩🏽‍💻 Possible <u>arguments</u> :\n<b>all</b> (all members by default)\n<b>old</b> (old users)\n<b>premium</b> (premium accounts)\n<b >active</b> (active in chat)\n<b>online</b> (currently online)\n<b>contacts</b> (telegram contacts)\n<b>dialogs</b > (all id-dialogs)\n<b>bots</b> (telegram bots)\n\n👩🏽‍💻 For example, parsing:\n<code>/parse https://t.me/MoscowNames </code> (all)\n<code>/parse @moscownames online</code> (online)\n<code>/parse-1001560037735</code> (by dialogue id)\n<code>/parse< /code> (inside chat)",
    'es': "👩🏽‍💻 <b>Formato de análisis</b>:\n/parse [enlace o id] [<u>argumento</u>]\n\n👩🏽‍💻 Posibles <u>argumentos</u> :\n<b>todos</b> (todos los miembros de forma predeterminada)\n<b>antiguos</b> (usuarios antiguos)\n<b>premium</b> (cuentas premium)\n<b > activo</b> (activo en el chat)\n<b>en línea</b> (actualmente en línea)\n<b>contactos</b> (contactos de Telegram)\n<b>diálogos</b > (todos id-dialogs)\n<b>bots</b> (bots de Telegram)\n\n👩🏽‍💻 Por ejemplo, parsing:\n<code>/parse https://t.me/MoscowNames </code > (todos)\n<code>/parse @moscownames online</code> (en línea)\n<code>/parse-1001560037735</code> (por ID de diálogo)\n<code>/parse< /code> (dentro del chat)",
    'fr': "👩🏽‍💻 <b>Format d'analyse</b> :\n/parse [lien ou identifiant] [<u>argument</u>]\n\n👩🏽‍💻 <u>arguments</u> possibles :\n<b>tous</b> (tous les membres par défaut)\n<b>old</b> (anciens utilisateurs)\n<b>premium</b> (comptes premium)\n<b > actif</b> (actif dans le chat)\n<b>en ligne</b> (actuellement en ligne)\n<b>contacts</b> (contacts télégrammes)\n<b>dialogues</b > (tous id-dialogs)\n<b>bots</b> (robots télégrammes)\n\n👩🏽‍💻 Par exemple, parsing :\n<code>/parse https://t.me/MoscowNames </code > (tous)\n<code>/parse @moscownames en ligne</code> (en ligne)\n<code>/parse-1001560037735</code> (par identifiant de dialogue)\n<code>/parse< /code> (dans le chat)",
    'zh': "👩🏽‍💻 <b>解析格式</b>：\n/parse [链接或id] [<u>参数</u>]\n\n👩🏽‍💻 可能的<u>参数</u> :\n<b>全部</b>（默认为所有成员）\n<b>旧</b>（老用户）\n<b>高级</b>（高级帐户）\n<b >活跃</b>（聊天中活跃）\n<b>在线</b>（当前在线）\n<b>联系人</b>（电报联系人）\n<b>对话框</b>（所有id-dialogs)\n<b>bots</b> (电报机器人)\n\n👩🏽‍💻 例如解析：\n<code>/parse https://t.me/MoscowNames </code > (全部)\n<code>/parse @moscownames online</code> (在线)\n<code>/parse-1001560037735</code> (通过对话 ID)\n<code>/parse</code> （聊天内）",
    'ar': "👩🏽‍💻 <b>تنسيق التحليل</b>:\n/parse [link or id] [<u>وسيطة</u>]\n\n👩🏽‍💻 <u>وسيطات</u> محتملة :\n<b>الجميع</b> (جميع الأعضاء بشكل افتراضي)\n<b>القدامى</b> (المستخدمون القدامى)\n<b>المتميزون</b> (الحسابات المميزة)\n<b > نشط</b> (نشط في الدردشة)\n<b>متصل</b> (متصل حاليًا)\n<b>جهات الاتصال</b> (جهات اتصال برقية)\n<b>مربعات الحوار</b > (الكل id-dialogs)\n<b>bots</b> (bots bots)\n\n👩🏽‍💻 على سبيل المثال، التحليل:\n<code>/parse https://t.me/MoscowNames </code > (الكل)\n<code>/parse @moscownames عبر الإنترنت</code> (عبر الإنترنت)\n<code>/parse-1001560037735</code> (حسب معرف الحوار)\n<code>/parse< /code> (داخل الدردشة)",
}
l_autodel_text = {
    'ru': "👩🏽‍💻 Введи число дней для <b>автоудаления</b> <u>private</u>-сообщений (текущее количество дней: <code>/autodel {0}</code>):\n\nот <u>1</u> до <u>365</u> (один год)\n<u>0</u> (отключение автоудаления)",
    'en': "👩🏽‍💻 Enter the number of days for <b>autodelete</b> <u>private</u> messages (current number of days: <code>/autodel {0}</code>):\n\nfrom < u>1</u> to <u>365</u> (one year)\n<u>0</u> (disable auto-delete)",
    'es': "👩🏽‍💻 Ingrese el número de días para <b>eliminación automática</b> mensajes <u>privados</u> (número de días actual: <code>/autodel {0}</code>):\n\ nde <u>1</u> a <u>365</u> (un año)\n<u>0</u> (deshabilitar la eliminación automática)",
    'fr': "👩🏽‍💻 Entrez le nombre de jours pour les messages <b>autodelete</b> <u>privés</u> (nombre de jours actuel : <code>/autodel {0}</code>) :\n\ nde < u>1</u> à <u>365</u> (un an)\n<u>0</u> (désactiver la suppression automatique)",
    'zh': "👩🏽‍💻 输入<b>自动删除</b><u>私人</u>消息的天数（当前天数：<code>/autodel {0}</code>）：\n\ n从 <u>1</u> 到 <u>365</u>（一年）\n<u>0</u>（禁用自动删除）",
    'ar': "👩🏽‍💻 أدخل عدد الأيام للرسائل <b>الحذف التلقائي</b> <u>الخاصة</u> (العدد الحالي للأيام: <code>/autodel {0}</code>):\n\nمن < u>1</u> إلى <u>365</u> (سنة واحدة)\n<u>0</u> (تعطيل الحذف التلقائي)",
}
l_autodel_on = {
    'ru': "👩🏽‍💻 Установлено <b>автоудаление</b> <u>private</u>-сообщений для новых пользователей: <u>{0}</u> days",
    'en': "👩🏽‍💻 <b>auto-delete</b> <u>private</u> messages for new users: <u>{0}</u> days",
    'es': "👩🏽‍💻 <b>eliminación automática</b> mensajes <u>privados</u> para nuevos usuarios: <u>{0}</u> días",
    'fr': "👩🏽‍💻 <b>suppression automatique</b> messages <u>privés</u> pour les nouveaux utilisateurs : <u>{0}</u> jours",
    'zh': "👩🏽‍💻 <b>自动删除</b> <u>私人</u>条新用户消息：<u>{0}</u> 天",
    'ar': "👩🏽‍💻 <b>الحذف التلقائي</b> للرسائل <u>الخاصة</u> للمستخدمين الجدد: <u>{0}</u> يوم",
}
l_autodel_off = {
    'ru': "👩🏽‍💻 <b>Автоудаление</b> <u>private</u>-сообщений отключено",
    'en': "👩🏽‍💻 <b>Auto-delete</b> <u>private</u>-messages disabled",
    'es': "👩🏽‍💻 <b>Eliminación automática</b> <u>privada</u>: mensajes deshabilitados",
    'fr': "👩🏽‍💻 <b>Suppression automatique</b> <u>messages privés</u> désactivés",
    'zh': "👩🏽‍💻 <b>自动删除</b> <u>私人</u>-消息已禁用",
    'ar': "👩🏽‍💻 <b>الحذف التلقائي</b> <u>الخاص</u>-الرسائل معطلة",
}
l_delay_text2 = {
    'ru': "👩🏽‍💻 Введи число секунд <b>задержки</b> перед автоответом (текущая задержка: <code>/delay {0}</code>):\n\nот <u>1</u> до <u>{1}</u> (один день)\n<u>0</u> (отключение задержки)",
    'en': "👩🏽‍💻 Enter the number of seconds <b>delay</b> before auto-answer (current delay: <code>/delay {0}</code>):\n\nfrom <u>1</u> to <u >{1}</u> (one day)\n<u>0</u> (disable delay)",
    'es': "👩🏽‍💻 Ingrese el número de segundos de <b>retraso</b> antes de la respuesta automática (retraso actual: <code>/retraso {0}</code>):\n\nde <u>1</u > a <u >{1}</u> (un día)\n<u>0</u> (deshabilitar retraso)",
    'fr': "👩🏽‍💻 Saisissez le nombre de secondes de <b>délai</b> avant la réponse automatique (délai actuel : <code>/delay {0}</code>) :\n\nà partir de <u>1</u > à <u >{1}</u> (un jour)\n<u>0</u> (désactiver le délai)",
    'zh': "👩🏽‍💻 输入自动应答前<b>延迟</b>的秒数（当前延迟：<code>/delay {0}</code>）：\n\n来自 <u>1</u > 到 <u >{1}</u>（一天）\n<u>0</u>（禁用延迟）",
    'ar': "👩🏽‍💻 أدخل عدد الثواني <b>التأخير</b> قبل الرد التلقائي (التأخير الحالي: <code>/التأخير {0}</code>):\n\nمن <u>1</u > إلى <u >{1}</u> (يوم واحد)\n<u>0</u> (تعطيل التأخير)",
}
l_delay2_on = {
    'ru': "👩🏽‍💻 Установлена <b>задержка</b> перед автоответом: <u>{0}</u> sec",
    'en': "👩🏽‍💻 Set <b>delay</b> before auto-answer: <u>{0}</u> sec",
    'es': "👩🏽‍💻 Establecer <b>retraso</b> antes de la respuesta automática: <u>{0}</u> seg",
    'fr': "👩🏽‍💻 Définir le <b>délai</b> avant la réponse automatique : <u>{0}</u> s",
    'zh': "👩🏽‍💻 设置自动应答前<b>延迟</b>：<u>{0}</u>秒",
    'ar': "👩🏽‍💻 اضبط <b>التأخير</b> قبل الرد التلقائي: <u>{0}</u> ثانية",
}
l_delay2_off = {
    'ru': "👩🏽‍💻 <b>Задержка</b> перед автоответом отключена",
    'en': "👩🏽‍💻 <b>Delay</b> before auto-answer is disabled",
    'es': "👩🏽‍💻 <b>Retraso</b> antes de que se desactive la respuesta automática",
    'fr': "👩🏽‍💻 <b>Délai</b> avant que la réponse automatique soit désactivée",
    'zh': "👩🏽‍💻 禁用自动应答之前<b>延迟</b>",
    'ar': "👩🏽‍💻 <b>التأخير</b> قبل تعطيل الرد التلقائي",
}
l_spoiler2_text = {
    'ru': "👩🏽‍💻 Введи <b>символ</b>, который будет <tg-spoiler>скрываться</tg-spoiler>{0}\n\n<code>/spoiler a</code> (сокрытие <code>w</code>-символа, если активирован режим [✅☑Вкл сокрытие текста])\n<code>/spoiler 0</code> (сокрытие конкретного символа отключено)",
    'en': "👩🏽‍💻 Enter a <b>symbol</b> that will <tg-spoiler>hide</tg-spoiler>{0}\n\n<code>/spoiler a</code> (hiding <code> w</code>-character, if the mode [✅☑On text hiding])\n<code>/spoiler 0</code> is activated (hiding a specific character is disabled)",
    'es': "👩🏽‍💻 Ingrese un <b>símbolo</b> que <tg-spoiler>ocultará</tg-spoiler>{0}\n\n<code>/spoiler a</code> (ocultando <code> w</code>-carácter, si el modo [✅☑On text hide])\n<code>/spoiler 0</code> está activado (ocultar un carácter específico está deshabilitado)",
    'fr': "👩🏽‍💻 Entrez un <b>symbole</b> qui <tg-spoiler>masquer</tg-spoiler>{0}\n\n<code>/spoiler a</code> (cachant <code> w</code>-caractère, si le mode [✅☑Sur le masquage du texte])\n<code>/spoiler 0</code> est activé (le masquage d'un caractère spécifique est désactivé)",
    'zh': "👩🏽‍💻 输入<b>符号</b>，该符号将<tg-spoiler>隐藏</tg-spoiler>{0}\n\n<code>/spoiler a</code>（隐藏<code> w</code>-字符，如果模式 [✅☑隐藏文本])\n<code>/spoiler 0</code> 被激活（隐藏特定字符被禁用）",
    'ar': "👩🏽‍💻 أدخل <b>رمز</b> الذي سيؤدي إلى <tg-spoiler>إخفاء</tg-spoiler>{0}\n\n<code>/spoiler a</code> (إخفاء <code> w</code>-character، إذا تم تفعيل الوضع [✅☑On textإخفاء])\n<code>/spoiler 0</code> (تم تعطيل إخفاء حرف معين)",
}
l_spoiler_current = {
    'ru': " (текущий символ: <code>/spoiler {0}</code>)",
    'en': "(current symbol: <code>/spoiler {0}</code>)",
    'es': "(símbolo actual: <code>/spoiler {0}</code>)",
    'fr': "(symbole actuel : <code>/spoiler {0}</code>)",
    'zh': "（当前符号：<code>/spoiler {0}</code>）",
    'ar': "(الرمز الحالي: <code>/spoiler {0}</code>)",
}
l_spoiler_on = {
    'ru': "👩🏽‍💻 <b>Установлен</b> <tg-spoiler>{0}</tg-spoiler>-символ, который будет скрываться, если активирована опция [{0}]",
    'en': "👩🏽‍💻 <b>Set</b> <tg-spoiler>{0}</tg-spoiler>-symbol that will be hidden if option [{0}] is activated",
    'es': "👩🏽‍💻 <b>Establecer</b> <tg-spoiler>{0}</tg-spoiler>-símbolo que se ocultará si se activa la opción [{0}]",
    'fr': "👩🏽‍💻 <b>Définir</b> <tg-spoiler>{0}</tg-spoiler>-symbole qui sera masqué si l'option [{0}] est activée",
    'zh': "👩🏽‍💻 <b>设置</b> <tg-spoiler>{0}</tg-spoiler>-如果选项 [{0}] 被激活，该符号将被隐藏",
    'ar': "👩🏽‍💻 <b>Set</b> <tg-spoiler>{0}</tg-spoiler>-الرمز الذي سيتم إخفاؤه في حالة تفعيل الخيار [{0}]",
}
l_spoiler_off = {
    'ru': "👩🏽‍💻 <b>Использование</b> символа для сокрытия отключено (включение: <code>/spoiler a</code>)",
    'en': "👩🏽‍💻 <b>Use</b> symbol for hiding is disabled (enable: <code>/spoiler a</code>)",
    'es': "👩🏽‍💻 <b>Usar</b> el símbolo para ocultar está deshabilitado (habilitar: <code>/spoiler a</code>)",
    'fr': "👩🏽‍💻 Le symbole <b>Utiliser</b> pour masquer est désactivé (activer : <code>/spoiler a</code>)",
    'zh': "👩🏽‍💻 <b>使用</b>符号隐藏已禁用（启用：<code>/spoiler a</code>）",
    'ar': "👩🏽‍💻 تم تعطيل رمز <b>استخدام</b> للإخفاء (تمكين: <code>/spoiler a</code>)",
}
l_vote_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> id-чата и id-ответа для авто-голосования (текущая настройка: <code>/vote {0}</code>)\n\n<b>/vote -1001894710086 0</b> (автоголосование за верхний вариант ответа)\n<b>/vote 0</b> (автоголосование отключено)",
    'en': "👩🏽‍💻 <b>Enter</b> chat ID and reply ID for auto-voting (current setting: <code>/vote {0}</code>)\n\n<b>/vote-1001894710086 0</b> (autovoting for the top answer)\n<b>/vote 0</b> (autovoting disabled)",
    'es': "👩🏽‍💻 <b>Ingrese</b> el ID de chat y el ID de respuesta para la votación automática (configuración actual: <code>/vote {0}</code>)\n\n<b>/vote-1001894710086 0 </b> (votación automática para la respuesta principal)\n<b>/voto 0</b> (votación automática deshabilitada)",
    'fr': "👩🏽‍💻 <b>Entrez</b> l'ID de chat et l'ID de réponse pour le vote automatique (paramètre actuel : <code>/vote {0}</code>)\n\n<b>/vote-1001894710086 0 </b> (vote automatique pour la première réponse)\n<b>/vote 0</b> (vote automatique désactivé)",
    'zh': "👩🏽‍💻 <b>输入</b>聊天 ID 和回复 ID 进行自动投票（当前设置：<code>/vote {0}</code>）\n\n<b>/vote-1001894710086 0 </b>（自动投票为最佳答案）\n<b>/vote 0</b>（自动投票已禁用）",
    'ar': "👩🏽‍💻 <b>أدخل</b> معرف الدردشة ومعرف الرد للتصويت التلقائي (الإعداد الحالي: <code>/التصويت {0}</code>)\n\n<b>/التصويت-1001894710086 0 </b> (التصويت التلقائي لأفضل إجابة)\n<b>/التصويت 0</b> (التصويت التلقائي معطل)",
}
l_vote_on = {
    'ru': "👩🏽‍💻 <b>Автоголосование</b> в <code>{0}</code>-чате на <u>{1}</u>-вариант установлено",
    'en': "👩🏽‍💻 <b>Auto-voting</b> in <code>{0}</code>-chat on <u>{1}</u>-option set",
    'es': "👩🏽‍💻 <b>Votación automática</b> en <code>{0}</code>-chatear en <u>{1}</u>-conjunto de opciones",
    'fr': "👩🏽‍💻 <b>Vote automatique</b> dans <code>{0}</code>-chat sur <u>{1}</u>-ensemble d'options",
    'zh': "👩🏽‍💻<code>{0}</code>中的<b>自动投票</b>-在<u>{1}</u>上聊天-选项集",
    'ar': "👩🏽‍💻 <b>التصويت التلقائي</b> في <code>{0}</code>-الدردشة على <u>{1}</u>-مجموعة الخيارات",
}
l_vote_off = {
    'ru': "👩🏽‍💻 <b>Автоголосование</b> отключено",
    'en': "👩🏽‍💻 <b>Auto-voting</b> disabled",
    'es': "👩🏽‍💻 <b>Voto automático</b> deshabilitado",
    'fr': "👩🏽‍💻 <b>Vote automatique</b> désactivé",
    'zh': "👩🏽‍💻 <b>自动投票</b>已禁用",
    'ar': "👩🏽‍💻 <b>التصويت التلقائي</b> معطل",
}
l_userbot_is_off = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> выключен\n\n/on - включить аккаунт",
    'en': "👩🏽‍💻 <b>Account:</b> disabled\n\n/on-enable account",
    'es': "👩🏽‍💻 <b>Cuenta:</b> deshabilitada\n\n/activada-habilitar cuenta",
    'fr': "👩🏽‍💻 <b>Compte :</b> désactivé\n\n/activé-activer le compte",
    'zh': "👩🏽‍💻<b>帐户：</b>已禁用\n\n/on-启用帐户",
    'ar': "👩🏽‍💻 <b>الحساب:</b> معطل\n\n/مفعّل-تمكين الحساب",
}
l_usr_cmd_ok = {
    'ru': "👩🏽‍💻 <b>Команда</b> /{0} выполнена\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Command</b> /{0} completed\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Comando</b> /{0} completado\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Commandes</b> /{0} terminées\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>命令</b> /{0}已完成\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>الأمر</b> /{0} مكتمل\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_usr_karma_ok = {
    'ru': "👩🏽‍💻 <b>Карма</b>:\n{0} - локальная\n{1} - глобальная\n<i>{2}</i>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Karma</b>:\n{0}-local\n{1}-global\n<i>{2}</i>\n\n⚙️ <b>Teams</ b>/cmd",
    'es': "👩🏽‍💻 <b>Karma</b>:\n{0}-local\n{1}-global\n<i>{2}</i>\n\n⚙️ <b>Equipos</ b>/cmd",
    'fr': "👩🏽‍💻 <b>Karma</b> :\n{0}-local\n{1}-global\n<i>{2}</i>\n\n⚙️ <b>Équipes</ b>/cmd",
    'zh': "👩🏽‍💻 <b>业力</b>：\n{0}-本地\n{1}-全球\n<i>{2}</i>\n\n⚙️ <b>团队</ b>/cmd",
    'ar': "👩🏽‍💻 <b>الكارما</b>:\n{0}-محلي\n{1}-عالمي\n<i>{2}</i>\n\n⚙️ <b>الفرق</ ب>/كمد",
}
# endregion


# region config


# region cformat_
l_cformat_text = {
    'ru': "🪄 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-генерацию <i><b>кнопок</b> для ссылок в тексте/стильных <b>@упоминаний</b>/<b>бот-ссылку</b> над именем/<b>сокрытие</b> <tg-spoiler>/spoiler a</tg-spoiler> текста/символа</i> для гарантированного просмотра сообщения",
    'en': "🪄 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-generation of <i><b>buttons</b> for links in the text/stylish @tager-<b> mentions</b>/<b>bot link</b> above the name/<b>hiding</b> <tg-spoiler>/spoiler a</tg-spoiler> text/symbol</i> for < code>guaranteed</code> message viewing",
    'es': "🪄 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> la generación automática de <i><b>botones</b> para enlaces en el texto/elegante @tager-< b> menciona</b>/<b>enlace del bot</b> encima del nombre/<b>oculta</b> <tg-spoiler>/spoiler a</tg-spoiler> texto/símbolo</i> para visualización de mensajes < code>garantizada</code>",
    'fr': "🪄 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> la génération automatique des <i><b>boutons</b> pour les liens dans le texte/style @tager-< b> mentionne</b>/<b>lien du robot</b> au-dessus du nom/<b>masquage</b> <tg-spoiler>/spoiler un</tg-spoiler> texte/symbole</i> pour un affichage < code>garanti</code> des messages",
    'zh': "🪄 <b>按</b> ✅/☑️ 可以<b>开/关</b>自动生成文本/时尚@tager中的链接的<i><b>按钮</b>-< b> 在名称上方提及</b>/<b>机器人链接</b>/<b>隐藏</b> <tg-spoiler>/spoiler a</tg-spoiler> 文本/符号</i>保证<code>消息查看</code>",
    'ar': "🪄 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الإنشاء التلقائي <i><b>للأزرار</b> للروابط الموجودة في النص/ @tager الأنيق-< b> الإشارات</b>/<b>رابط الروبوت</b> أعلى الاسم/<b>الإخفاء</b> <tg-spoiler>/spoiler a</tg-spoiler> text/symbol</i> لعرض الرسائل <code>المضمونة</code>",
}
l_cformat_urllink_on = {
    'ru': "✅☑Вкл кнопка-ссылка",
    'en': "✅☑On link button",
    'es': "✅☑En el botón de enlace",
    'fr': "✅☑Sur le bouton de lien",
    'zh': "✅☑链接按钮",
    'ar': "✅☑على زر الرابط",
}
l_cformat_urllink_off = {
    'ru': "☑️☐Выкл кнопка-ссылка",
    'en': "☑️☐Off link button",
    'es': "☑️☐Botón de enlace desactivado",
    'fr': "☑️☐ Bouton Hors lien",
    'zh': "☑️☐关闭链接按钮",
    'ar': "☑️☐ زر إيقاف الارتباط",
}
l_cformat_mentionlink_on = {
    'ru': "✅☑Вкл @tager-ссылка",
    'en': "✅☑On @tager-link",
    'es': "✅☑En @tager-enlace",
    'fr': "✅☑Sur @tager-lien",
    'zh': "✅☑在@tager-link",
    'ar': "✅☑على @tager-link",
}
l_cformat_mentionlink_off = {
    'ru': "☑️☐Выкл @tager-ссылка",
    'en': "☑️☐Off @tager-link",
    'es': "☑️☐Apagado @tager-link",
    'fr': "☑️☐Off @tager-link",
    'zh': "☑️️关闭@tager-link",
    'ar': "☑️☐Off @tager-link",
}
l_cformat_botlink_on = {
    'ru': "✅☑Вкл бот-ссылка",
    'en': "✅☑Include bot link",
    'es': "✅☑Incluir enlace de bot",
    'fr': "✅☑Inclure le lien du bot",
    'zh': "✅☑包含机器人链接",
    'ar': "✅☑ تضمين رابط الروبوت",
}
l_cformat_botlink_off = {
    'ru': "☑️☐Выкл бот-ссылка",
    'en': "☑️☐Disable bot link",
    'es': "☑️☐Desactivar enlace de bot",
    'fr': "☑️☐Désactiver le lien du bot",
    'zh': "☑️️禁用机器人链接",
    'ar': "☑️☐تعطيل رابط البوت",
}
l_cformat_txtprotect_on = {
    'ru': "✅☑Вкл защита контента",
    'en': "✅☑Content protection on",
    'es': "✅☑Protección de contenido activada",
    'fr': "✅☑Protection du contenu activée",
    'zh': "✅☑内容保护",
    'ar': "✅☑تشغيل حماية المحتوى",
}
l_cformat_txtprotect_off = {
    'ru': "☑️☐Выкл защита контента",
    'en': "☑️☐Turn off content protection",
    'es': "☑️☐Desactivar la protección de contenido",
    'fr': "☑️☐Désactivez la protection du contenu",
    'zh': "☑️️关闭内容保护",
    'ar': "☑️☐ قم بإيقاف تشغيل حماية المحتوى",
}
l_cformat_txthide_on = {
    'ru': "✅☑Вкл сокрытие текста",
    'en': "✅☑On hiding text",
    'es': "✅☑Sobre ocultar texto",
    'fr': "✅☑Sur le masquage du texte",
    'zh': "✅☑关于隐藏文本",
    'ar': "✅☑عند إخفاء النص",
}
l_cformat_txthide_off = {
    'ru': "☑️☐Выкл сокрытие текста",
    'en': "☑️☐Turn off hiding text",
    'es': "☑️☐Desactiva ocultar texto",
    'fr': "☑️☐Désactivez le masquage du texte",
    'zh': "☑️️关闭文本隐藏",
    'ar': "☑️☐ قم بإيقاف تشغيل إخفاء النص",
}
# endregion


# region cservice_
l_cservice_text = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i><b>пересылку</b> входящих себе/оповещение когда контакты <b>в сети</b>/авто-замена голосовых/телескопов на <b>audio/video</b></i>\n\n<blockquote>[✅☑Вкл audio/video замена] рекомендуется, если premium-пользователи установили запрет на <i>voice/telescope</i></blockquote>",
    'en': "👥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i><b>forward</b> incoming messages to yourself/notify when contacts are <b>online</b> /auto-replacement of voice/telescopes with <b>audio/video</b></i>\n\n[✅☑Enable audio/video replacement] is recommended if premium users have set a ban on <i>voice/telescope </i>",
    'es': "👥 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i><b>reenviar</b> mensajes entrantes a ti mismo/notificar cuando los contactos estén <b>en línea</ b> /auto-reemplazo de voz/telescopios con <b>audio/video</b></i>\n\n[✅☑Habilitar reemplazo de audio/video] se recomienda si los usuarios premium han establecido una prohibición en <i >voz/telescopio </i>",
    'fr': "👥 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> <i><b>transférer</b> les messages entrants vers vous-même/notifier lorsque les contacts sont <b>en ligne</ b> /le remplacement automatique de la voix/télescopes par <b>audio/vidéo</b></i>\n\n[✅☑Activer le remplacement audio/vidéo] est recommandé si les utilisateurs premium ont banni <i >voix/télescope </i>",
    'zh': "👥<b>按</b> ✅/☑️<b>开/关</b><i><b>转发</b>收到的消息给自己/在联系人<b>在线时通知</ b> /自动用<b>音频/视频替换语音/望远镜</b></i>\n\n[✅☑启用音频/视频替换]如果高级用户已设置禁止<i >声音/望远镜</i>",
    'ar': "👥 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i><b>إعادة توجيه</b> الرسائل الواردة إليك/إعلامك عندما تكون جهات الاتصال <b>متصلة</b> b> /الاستبدال التلقائي للصوت/التلسكوبات بـ <b>الصوت/الفيديو</b></i>\n\n[✅☑تمكين استبدال الصوت/الفيديو] يوصى به إذا قام المستخدمون المميزون بفرض حظر على <i >الصوت/التلسكوب </i>",
}
l_cservice_status_on = {
    'ru': "✅☑Вкл сервисные статусы",
    'en': "✅☑On service statuses",
    'es': "✅☑Sobre estados de servicio",
    'fr': "✅☑Sur les statuts de service",
    'zh': "✅☑关于服务状态",
    'ar': "✅☑في حالات الخدمة",
}
l_cservice_status_off = {
    'ru': "☑️☐Выкл сервисные статусы",
    'en': "☑️☐Off service statuses",
    'es': "☑️☐Estados fuera de servicio",
    'fr': "☑️☐Statuts hors service",
    'zh': "☑️️关闭服务状态",
    'ar': "☑️☐حالات خارج الخدمة",
}
l_cservice_forward_on = {
    'ru': "✅☑Вкл пересылка себе",
    'en': "✅☑On forwarding to yourself",
    'es': "✅☑Sobre reenviarse a usted mismo",
    'fr': "✅☑Sur la transmission à vous-même",
    'zh': "✅☑转发给自己",
    'ar': "✅☑عند إعادة التوجيه لنفسك",
}
l_cservice_forward_off = {
    'ru': "☑️☐Выкл пересылка себе",
    'en': "☑️☐Off forward to yourself",
    'es': "☑️☐Adelante hacia ti mismo",
    'fr': "☑️☐Envoyez-vous à vous-même",
    'zh': "☑️️向自己前进",
    'ar': "☑️☐انطلق إلى نفسك",
}
l_cservice_read_on = {
    'ru': "✅☑Вкл чтение сообщений",
    'en': "✅☑On reading messages",
    'es': "✅☑Sobre la lectura de mensajes",
    'fr': "✅☑Sur la lecture des messages",
    'zh': "✅☑阅读消息时",
    'ar': "✅☑عند قراءة الرسائل",
}
l_cservice_read_off = {
    'ru': "☑️☐Выкл чтение сообщений",
    'en': "☑️☐Turn off reading messages",
    'es': "☑️☐Desactiva la lectura de mensajes",
    'fr': "☑️☐Désactivez la lecture des messages",
    'zh': "☑️️关闭阅读消息",
    'ar': "☑️☐إيقاف قراءة الرسائل",
}
l_cservice_online_stat_on = {
    'ru': "✅☑Вкл пользователь в сети",
    'en': "✅☑Online user online",
    'es': "✅☑Usuario en línea en línea",
    'fr': "✅☑Utilisateur en ligne en ligne",
    'zh': "✅☑在线用户在线",
    'ar': "✅☑مستخدم عبر الإنترنت عبر الإنترنت",
}
l_cservice_online_stat_off = {
    'ru': "☑️☐Выкл пользователь в сети",
    'en': "☑️☐Off user online",
    'es': "☑️☐Usuario desconectado en línea",
    'fr': "☑️☐Hors utilisateur en ligne",
    'zh': "☑️️离线用户在线",
    'ar': "☑️☐ خارج المستخدم عبر الإنترنت",
}
l_cservice_restricted_on = {
    'ru': "✅☑Вкл audio/video замена",
    'en': "✅☑Includes audio/video replacement",
    'es': "✅☑Incluye reemplazo de audio/video",
    'fr': "✅☑Comprend le remplacement audio/vidéo",
    'zh': "✅☑包括音频/视频替换",
    'ar': "✅☑يتضمن استبدال الصوت/الفيديو",
}
l_cservice_restricted_off = {
    'ru': "☑️☐Выкл audio/video замена",
    'en': "☑️☐Off audio/video replacement",
    'es': "☑️☐Desactivado reemplazo de audio/vídeo",
    'fr': "☑️☐Hors remplacement audio/vidéo",
    'zh': "☑️☐关闭音频/视频替换",
    'ar': "☑️☐إيقاف تشغيل استبدال الصوت/الفيديو",
}
l_cservice_user_online = {
    'ru': "<b>👩🏽‍💻 Пользователь</b>: {0} в сети",
    'en': "<b>👩🏽‍💻 User</b>: {0} online",
    'es': "<b>👩🏽‍💻 Usuario</b>: {0} en línea",
    'fr': "<b>👩🏽‍💻 Utilisateur</b> : {0} en ligne",
    'zh': "<b>👩🏽‍💻用户</b>：{0}在线",
    'ar': "<b>👩🏽‍💻 المستخدم</b>: {0} متصل بالإنترنت",
}
# endregion


# region creaction_
l_creaction_text = {
    'ru': "🫶🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-реакцию на: <i><b>emoji</b> внутри сообщения/<b>медиа</b>-контент</i>/<b>ответную</b> реакцию",
    'en': "🫶🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-reaction to: <i><b>emoji</b> inside a message/<b>media</ b>-content</i>/<b>response</b>",
    'es': "🫶🏽 <b>Presiona</b> en ✅/☑️ para <b>activar/desactivar</b> la reacción automática a: <i><b>emoji</b> dentro de un mensaje/<b>medio< / b>-contenido</i>/<b>respuesta</b>",
    'fr': "🫶🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la réaction automatique à : <i><b>emoji</b> dans un message/<b>média< / b>-contenu</i>/<b>réponse</b>",
    'zh': "🫶🏽 <b>按</b> ✅/☑️ 可<b>开启/关闭</b>自动反应：消息/<b>媒体<内的<i><b>表情符号</b> / b>-内容</i>/<b>回复</b>",
    'ar': "🫶🏽 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الرد التلقائي على: <i><b>الرمز التعبيري</b> داخل الرسالة/<b>الوسائط< / b>-المحتوى</i>/<b>الاستجابة</b>",
}
l_creaction_reacemoji_on = {
    'ru': "✅☑Вкл реакция на emoji",
    'en': "✅☑Includes emoji reaction",
    'es': "✅☑Incluye reacción emoji",
    'fr': "✅☑Comprend une réaction emoji",
    'zh': "✅☑包括表情符号反应",
    'ar': "✅☑يتضمن تفاعل الرموز التعبيرية",
}
l_creaction_reacemoji_off = {
    'ru': "☑️☐Выкл реакция на emoji",
    'en': "☑️☐Emoji reaction off",
    'es': "☑️☐Reacción emoji desactivada",
    'fr': "☑️☐Réaction Emoji désactivée",
    'zh': "☑️️表情符号反应关闭",
    'ar': "☑️☐إيقاف تفاعل الرموز التعبيرية",
}
l_creaction_reacmedia_on = {
    'ru': "✅☑Вкл реакция на media",
    'en': "✅☑Including media reaction",
    'es': "✅☑Incluyendo reacción de los medios",
    'fr': "✅☑Y compris la réaction des médias",
    'zh': "✅☑包括媒体反应",
    'ar': "✅☑بما في ذلك رد فعل وسائل الإعلام",
}
l_creaction_reacmedia_off = {
    'ru': "☑️☐Выкл реакция на media",
    'en': "☑️☐Disable media response",
    'es': "☑️☐Desactivar respuesta de los medios",
    'fr': "☑️☐Désactiver la réponse des médias",
    'zh': "☑️️禁止媒体回应",
    'ar': "☑️☐تعطيل استجابة الوسائط",
}
l_creaction_reacreac_on = {
    'ru': "✅☑Вкл ответная реакция",
    'en': "✅☑On response",
    'es': "✅☑Al responder",
    'fr': "✅☑Sur réponse",
    'zh': "✅☑回复中",
    'ar': "✅☑عند الرد",
}
l_creaction_reacreac_off = {
    'ru': "☑️☐Выкл ответная реакция",
    'en': "☑️☐Off feedback",
    'es': "☑️☐Fuera de comentarios",
    'fr': "☑️☐Off commentaires",
    'zh': "☑️️关闭反馈",
    'ar': "☑️☐ خارج ردود الفعل",
}
# endregion


# region ctranslate_
l_ctranslate2_text = {
    'ru': "文 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-перевод для <i>цепочки</i> сообщений на <b>язык пользователя</b> при нажатии любой кнопки {0}-бота\n(<i>в том числе текста кнопок</i>)",
    'en': "文 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-translate for <i>chain</i> messages into <b>user language</b> when pressing any {0}-bot buttons\n(<i>including button text</i>)",
    'es': "文 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> la traducción automática de mensajes <i>en cadena</i> al <b>idioma del usuario</b> al presionar cualquier {0}-bot botones\n(<i>incluido el texto del botón</i>)",
    'fr': "文 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la traduction automatique des messages <i>en chaîne</i> dans la <b>langue utilisateur</b> lorsque vous appuyez sur n'importe quelle touche. {0}-boutons du robot\n(<i>y compris le texte du bouton</i>)",
    'zh': "文<b>按</b> ✅/☑️ 可以<b>开/关</b>在按任意键时将<i>链</i>消息自动翻译成<b>用户语言</b> {0}-机器人按钮\n（<i>包括按钮文本</i>）",
    'ar': "文 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الترجمة التلقائية لرسائل <i>سلسلة</i> إلى <b>لغة المستخدم</b> عند الضغط على أي {0}-أزرار الروبوت\n(<i>بما في ذلك نص الزر</i>)",
}
l_ctranslate2_in_on = {
    'ru': "✅☑Вкл перевод входящих",
    'en': "✅☑On inbox translation",
    'es': "✅☑En la traducción de la bandeja de entrada",
    'fr': "✅☑Sur la traduction de la boîte de réception",
    'zh': "✅☑关于收件箱翻译",
    'ar': "✅☑في ترجمة البريد الوارد",
}
l_ctranslate2_in_off = {
    'ru': "☑️☐Выкл перевод входящих",
    'en': "☑️☐Disable inbox transfer",
    'es': "☑️☐Desactivar transferencia de bandeja de entrada",
    'fr': "☑️☐Désactiver le transfert de la boîte de réception",
    'zh': "☑️️禁用收件箱传输",
    'ar': "☑️☐تعطيل نقل البريد الوارد",
}
l_ctranslate2_out_on = {
    'ru': "✅☑Вкл перевод исходящих",
    'en': "✅☑On outgoing transfer",
    'es': "✅☑En transferencia saliente",
    'fr': "✅☑Sur virement sortant",
    'zh': "✅☑关于汇出转账",
    'ar': "✅☑عند التحويل الصادر",
}
l_ctranslate2_out_off = {
    'ru': "☑️☐Выкл перевод исходящих",
    'en': "☑️☐Disable outgoing transfer",
    'es': "☑️☐Desactivar transferencia saliente",
    'fr': "☑️☐Désactiver le transfert sortant",
    'zh': "☑️️禁用传出转账",
    'ar': "☑️☐تعطيل النقل الصادر",
}
# endregion


# region ctranscribe_
l_ctranscribe_text = {
    'ru': "🗣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-транскрибацию в приватных диалогах (перевод голосовых/телескопов в текст) для <i><b>входящих</b>/<b>исходящих</b> сообщений (сохранение в <b>Избранное</b>)</i>",
    'en': "🗣 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-transcription in private dialogues (translation of voice/telescopes into text) for <i><b>incoming</b> /<b>outgoing</b> messages (saving to <b>Favorites</b>)</i>",
    'es': "🗣 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> la transcripción automática en diálogos privados (traducción de voz/telescopios a texto) para <i><b>entrantes</b > /<b>mensajes salientes</b> (guardar en <b>Favoritos</b>)</i>",
    'fr': "🗣 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> la transcription automatique dans les dialogues privés (traduction de la voix/télescopes en texte) pour les <i><b>entrants</b > /<b>Messages sortants</b> (enregistrement dans les <b>Favoris</b>)</i>",
    'zh': "🗣 <b>按</b> ✅/☑️ 可以<b>打开/关闭</b>私人对话中的自动转录（将语音/望远镜翻译成文本）<i><b>传入</b > /<b>传出</b>消息（保存到<b>收藏夹</b>）</i>",
    'ar': "🗣 <b>اضغط</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> النسخ التلقائي في الحوارات الخاصة (ترجمة الصوت/التلسكوبات إلى نص) <i><b>الوارد</b > /<b>الصادرة</b> الرسائل (الحفظ في <b>المفضلة</b>)</i>",
}
l_ctranscribe_in_on = {
    'ru': "✅☑Вкл транскриб входящих",
    'en': "✅☑Transcribe incoming messages on",
    'es': "✅☑Transcribe los mensajes entrantes en",
    'fr': "✅☑Transcrivez les messages entrants sur",
    'zh': "✅☑转录收到的消息",
    'ar': "✅☑نسخ الرسائل الواردة على",
}
l_ctranscribe_in_off = {
    'ru': "☑️☐Выкл транскриб входящих",
    'en': "☑️☐Turn off incoming transcript",
    'es': "☑️☐Desactivar transcripción entrante",
    'fr': "☑️☐Désactivez la transcription entrante",
    'zh': "☑️️关闭传入的文字记录",
    'ar': "☑️☐ قم بإيقاف تشغيل النسخة الواردة",
}
l_ctranscribe_out_on = {
    'ru': "✅☑Вкл транскриб исходящих",
    'en': "✅☑On outgoing transcript",
    'es': "✅☑En transcripción saliente",
    'fr': "✅☑Sur relevé de notes sortant",
    'zh': "✅☑在传出成绩单上",
    'ar': "✅☑في النسخة الصادرة",
}
l_ctranscribe_out_off = {
    'ru': "☑️☐Выкл транскриб исходящих",
    'en': "☑️☐Turn off outgoing transcript",
    'es': "☑️☐Desactivar transcripción saliente",
    'fr': "☑️☐Désactivez la transcription sortante",
    'zh': "☑️️关闭传出成绩单",
    'ar': "☑️☐ قم بإيقاف تشغيل النسخة الصادرة",
}
l_ctranscribe_res = {
    'ru': "👩🏽‍💻 <b>Транскрибация</b> <i>{0}</i> для {1}",
    'en': "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> for {1}",
    'es': "👩🏽‍💻 <b>Transcripción</b> <i>{0}</i> para {1}",
    'fr': "👩🏽‍💻 <b>Transcription</b> <i>{0}</i> pour {1}",
    'zh': "👩🏽‍💻 <b>转录</b> <i>{0}</i> {1}",
    'ar': "👩🏽‍💻 <b>النسخ</b> <i>{0}</i> لـ {1}",
}
# endregion


# region cpodcast_
l_cpodcast_text = {
    'ru': "🎥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-трансляцию подкастов в канал/группу, где аккаунт: [✅ Администратор] c режимом [✅ Управление трансляциями]\n\n<blockquote>👩🏽‍💻 <b>Настройки</b> авто-подкаста\n[<code>посты</code>]/[<code>канал|группа</code>]:\n[<code>{0}</code>]/[<code>{1}</code>]</blockquote>",
    'en': "🎥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> automatic broadcasting of podcasts to a channel/group where the account is: [✅ Administrator] with the [✅ Broadcast Management] mode\n\ n👩🏽‍💻 <b>Settings</b> auto-podcast\n[<code>posts</code>]/[<code>channel|group</code>]:\n[<code>{0 }</code>]/[<code>{1}</code>]",
    'es': "🎥 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la transmisión automática de podcasts a un canal/grupo donde la cuenta sea: [✅ Administrador] con el modo [✅ Gestión de transmisión]\n\ n👩🏽‍💻 <b>Configuración</b> podcast automático\n[<code>publicaciones</code>]/[<code>canal|grupo</code>]:\n[<code >{0 }</code>]/[<code>{1}</code>]",
    'fr': "🎥 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> la diffusion automatique des podcasts vers une chaîne/un groupe dont le compte est : [✅Administrateur] avec le mode [✅Gestion de la diffusion]\n\ n👩🏽‍💻 <b>Paramètres</b> podcast automatique\n[<code>posts</code>]/[<code>canal|groupe</code>] :\n[<code >{0 }</code>]/[<code>{1}</code>]",
    'zh': "🎥 <b>按</b> ✅/☑️ 可以<b>开启/关闭</b>自动将播客广播到帐户所在的频道/群组：[✅ 管理员]，使用 [✅ 广播管理] 模式\n\ n👩🏽‍💻<b>设置</b>自动播客\n[<code>帖子</code>]/[<code>频道|群组</code>]:\n[<code >{0}</code>]/[<code>{1}</code>]",
    'ar': "🎥 <b>اضغط</b> على تشغيل ✅/☑️ من أجل <b>تشغيل/إيقاف</b> البث التلقائي للبودكاست إلى قناة/مجموعة حيث يكون الحساب: [✅ مسؤول] مع وضع [✅ إدارة البث]\n\n👩🏽‍💻 <b>الإعدادات</b> البودكاست التلقائي\n[<code>المشاركات</code>]/[<code>القناة|المجموعة</code>]:\n[<code >{0 }</code>]/[<code>{1}</code>]",
}
l_cpodcast_alert = {
    'ru': "🎥 Нужно ⚙️Настроить хотя бы один подкаст",
    'en': "🎥 You need to ⚙️Set up at least one podcast",
    'es': "🎥 Necesitas ⚙️Configurar al menos un podcast",
    'fr': "🎥 Vous devez ⚙️Configurer au moins un podcast",
    'zh': "🎥 您需要⚙️设置至少一个播客",
    'ar': "🎥 أنت بحاجة إلى ⚙️إعداد بودكاست واحد على الأقل",
}
l_cpodcast_loop_on = {
    'ru': "✅☑Вкл зацикливание",
    'en': "✅☑Looping on",
    'es': "✅☑ Bucle",
    'fr': "✅☑En boucle",
    'zh': "✅☑循环播放",
    'ar': "✅☑التكرار",
}
l_cpodcast_loop_off = {
    'ru': "☑️☐Выкл зацикливание",
    'en': "☑️☐Turn off cycling",
    'es': "☑️☐Apaga el ciclismo",
    'fr': "☑️☐Désactivez le vélo",
    'zh': "☑️️停止骑自行车",
    'ar': "☑️☐ قم بإيقاف تشغيل ركوب الدراجات",
}
l_cpodcast_order_on = {
    'ru': "✅☑Вкл по порядку",
    'en': "✅☑In order",
    'es': "✅☑En orden",
    'fr': "✅☑Dans l'ordre",
    'zh': "✅☑按顺序",
    'ar': "✅☑بالترتيب",
}
l_cpodcast_order_off = {
    'ru': "☑️☐Выкл по порядку",
    'en': "☑️☐Off in order",
    'es': "☑️☐Apagado en orden",
    'fr': "☑️☐Désactivé dans l'ordre",
    'zh': "☑️️按顺序关闭",
    'ar': "☑️☐إيقاف بالترتيب",
}
l_cpodcast_posts = {
    'ru': "🎥 <b>Перечисли</b> номера постов из [🔔 Авто-постинга] с <i>аудио/видео</i> контентом для подкаста (<code>{0}</code>)",
    'en': "🎥 <b>List</b> the numbers of posts from [🔔 Auto-posting] with <i>audio/video</i> content for the podcast (<code>{0}</code>)",
    'es': "🎥 <b>Enumere</b> el número de publicaciones de [🔔 Publicación automática] con contenido de <i>audio/vídeo</i> para el podcast (<code>{0}</code>)",
    'fr': "🎥 <b>Liste</b> le nombre de publications de [🔔 Publication automatique] avec du contenu <i>audio/vidéo</i> pour le podcast (<code>{0}</code>)",
    'zh': "🎥 <b>列出</b>来自[🔔自动发布]的帖子数量，其中包含播客的<i>音频/视频</i>内容 (<code>{0}</code>)",
    'ar': "🎥 <b>إدراج</b> أعداد المشاركات من [🔔 النشر التلقائي] مع محتوى <i>الصوت/الفيديو</i> للبودكاست (<code>{0}</code>)",
}
l_cpodcast_ids = {
    'ru': "🎥 <b>Введи</b> id-канала/группы, где аккаунт [✅ Администратор] c режимом [✅ Управление трансляциями]\n\n<blockquote>👩🏽‍💻 <b>Выбранные</b> audio/video-посты: {0}</blockquote>",
    'en': "🎥 <b>Enter</b> the channel/group id, where the account is [✅ Administrator] with the [✅ Broadcast Management] mode\n\n👩🏽‍💻 <b>Selected</b> audio/video posts: {0}",
    'es': "🎥 <b>Ingrese</b> el ID del canal/grupo, donde la cuenta es [✅ Administrador] con el modo [✅ Gestión de transmisión]\n\n👩🏽‍💻 Audio/vídeo <b>Seleccionado</b> publicaciones: {0}",
    'fr': "🎥 <b>Entrez</b> l'identifiant de la chaîne/du groupe, où le compte est [✅ Administrateur] avec le mode [✅ Gestion de la diffusion]\n\n👩🏽‍💻 <b>Sélectionné</b> audio/vidéo messages : {0}",
    'zh': "🎥<b>输入</b>频道/群组ID，其中帐户是[✅管理员]，具有[✅广播管理]模式\n\n👩🏽‍💻<b>已选择</b>音频/视频帖子：{0}",
    'ar': "🎥 <b>أدخل</b> معرف القناة/المجموعة، حيث يكون الحساب [✅ المسؤول] مع وضع [✅ إدارة البث]\n\n👩🏽‍💻 <b>محدد</b> الصوت/الفيديو المشاركات: {0}",
}
# endregion


# region canswer_
l_canswer_alert = {
    'ru': "👋🏽 Нужно ⚙️Настроить хотя бы один триггер",
    'en': "👋🏽 You need to ⚙️Configure at least one trigger",
    'es': "👋🏽 Necesitas ⚙️Configurar al menos un disparador",
    'fr': "👋🏽 Vous devez ⚙️Configurer au moins un déclencheur",
    'zh': "👋🏽 你需要⚙️配置至少一个触发器",
    'ar': "👋🏽 أنت بحاجة إلى ⚙️تكوين مشغل واحد على الأقل",
}
l_canswer2_text = {
    'ru': "👋🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим авто-ответа на триггеры\n\n<blockquote>👩🏽‍💻 <b>Общее</b> количество триггеров: <u>{0}</u></blockquote>",
    'en': "👋🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-reply mode to triggers\n\n👉🏼 Total number of triggers: <u>{0}</u >",
    'es': "👋🏽 <b>Presione</b> en ✅/☑️ para <b>activar/desactivar</b> el modo de respuesta automática a los activadores\n\n👉🏼 Número total de activadores: <u>{0}</ tu >",
    'fr': "👋🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le mode de réponse automatique aux déclencheurs\n\n👉🏼 Nombre total de déclencheurs : <u>{0}</ toi >",
    'zh': "👋🏽 <b>按</b> ✅/☑️ 即可<b>开启/关闭</b>自动回复模式来触发\n\n👉🏼 触发总数：<u>{0}</你>",
    'ar': "👋🏽 <b>اضغط</b> على ✅/☑️ للدخول إلى وضع <b>تشغيل/إيقاف</b> الرد التلقائي على المشغلات\n\n👉🏼 إجمالي عدد المشغلات: <u>{0}</ ش>",
}
l_canswerconfigtext = {
    'ru': "👋🏽 Выбери пост, который будет использован для авто-ответа и жми [{0}] под выбранным постом\n\n👉🏼 Общее количество триггеров: <u>{1}</u>",
    'en': "👋🏽 Select the post that will be used for auto-reply and click [{0}] under the selected post\n\n👉🏼 Total number of triggers: <u>{1}</u>",
    'es': "👋🏽 Seleccione la publicación que se utilizará para la respuesta automática y haga clic en [{0}] debajo de la publicación seleccionada\n\n👉🏼 Número total de activadores: <u>{1}</u>",
    'fr': "👋🏽 Sélectionnez le message qui sera utilisé pour la réponse automatique et cliquez sur [{0}] sous le message sélectionné\n\n👉🏼 Nombre total de déclencheurs : <u>{1}</u>",
    'zh': "👋🏽 选择要用于自动回复的帖子，然后点击所选帖子下的[{0}]\n\n👉🏼 触发总数：<u>{1}</u>",
    'ar': "👋🏽 حدد المشاركة التي سيتم استخدامها للرد التلقائي وانقر على [{0}] أسفل المشاركة المحددة\n\n👉🏼 إجمالي عدد المشغلات: <u>{1}</u>",
}
l_canswerconfig_use = {
    'ru': "👋🏽 Использовать",
    'en': "👋🏽 Use",
    'es': "👋🏽 Uso",
    'fr': "👋🏽 Utilisation",
    'zh': "👋🏽 使用",
    'ar': "👋🏽 استخدم",
}
l_cansweroperationcaption = {
    'ru': "👋🏽 <b>Текущее</b> количество <i>триггеров</i> для поста #{0} в <code>{1}</code>-файле: <u>{2}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> триггер",
    'en': "👋🏽 <b>Current</b> number of <i>triggers</i> for post #{0} in <code>{1}</code>-file: <u>{2}</u>\ n\n👩🏽‍💻 <b>Press</b> on ✅/🚫 to <b>Add/Remove</b> trigger",
    'es': "👋🏽 Número <b>actual</b> de <i>activadores</i> para la publicación #{0} en el archivo <code>{1}</code>: <u>{2}</u> \ n\n👩🏽‍💻 <b>Presione</b> en ✅/🚫 para <b>Agregar o quitar</b> activador",
    'fr': "👋🏽 <b>Nombre actuel</b> de <i>déclencheurs</i> pour la publication n°{0} dans le fichier <code>{1}</code> : <u>{2}</u> \ n\n👩🏽‍💻 <b>Appuyez</b> sur ✅/🚫 pour <b>Ajouter/Supprimer</b> le déclencheur",
    'zh': "👋🏽<code>{1}</code>-文件中帖子#{0}的<b>当前</b><i>触发器</i>数量：<u>{2}</u> \ n\n👩🏽‍💻 <b>按</b> ✅/🚫 来<b>添加/删除</b>触发器",
    'ar': "👋🏽 <b>العدد <b>الحالي</b> من <i>المشغلات</i> للمنشور رقم {0} في <code>{1}</code>-الملف: <u>{2}</u>\n\n👩🏽‍💻 <b>اضغط</b> على ✅/🚫 من أجل <b>إضافة/إزالة</b> المشغل",
}
l_cansweroperationtext = {
    'ru': "👋🏽 <b>Текущее</b> количество <i>триггеров</i> для поста #{0}: <u>{1}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> триггер",
    'en': "👋🏽 <b>Current</b> number of <i>triggers</i> for post #{0}: <u>{1}</u>\n\n👩🏽‍💻 <b>Click</ b> to ✅/🚫 to <b>Add/Remove</b> trigger",
    'es': "👋🏽 Número <b>actual</b> de <i>activadores</i> para la publicación #{0}: <u>{1}</u>\n\n👩🏽‍💻 <b>Clic< / b> a ✅/🚫 para <b>Agregar o quitar</b> disparador",
    'fr': "👋🏽 <b>Nombre actuel</b> de <i>déclencheurs</i> pour le message n°{0} : <u>{1}</u>\n\n👩🏽‍💻 <b>Cliquez< / b> à ✅/🚫 au déclencheur <b>Ajouter/Supprimer</b>",
    'zh': "👋🏽 帖子 #{0} 的<b>当前</b><i>触发器</i>数量：<u>{1}</u>\n\n👩🏽‍💻 <b>点击< / b> 到 ✅/🚫 到<b>添加/删除</b>触发器",
    'ar': "👋🏽 <b>العدد الحالي</b> من <i>المشغلات</i> للمنشور رقم {0}: <u>{1}</u>\n\n👩🏽‍💻 <b>انقر< / b> إلى ✅/🚫 إلى مشغل <b>إضافة/إزالة</b>",
}
l_cansweroperation_add = {
    'ru': "\n\n▪️регистр не важен\n▪️* в конце слова учитывает вхождение",
    'en': "\n\n▪️case is not important\n▪️* at the end of a word takes into account the occurrence",
    'es': "\n\n▪️el caso no es importante\n▪️* al final de una palabra tiene en cuenta la aparición",
    'fr': "\n\nnounced️la casse n'a pas d'importance\nnoyer* à la fin d'un mot prend en compte l'occurrence",
    'zh': "\n\n▪️大小写并不重要\n▪️* 考虑到单词末尾的出现情况",
    'ar': "\n\n▪️حالة الأحرف ليست مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار حدوثها",
}
l_cansweroperation_words = {
    'ru': "👋🏽 Введи <u>триггер-слова</u> <b>через</b> пробелы или разделители, в ответ на которые будет приходить пост #<u>{0}</u>{1}",
    'en': "👋🏽 Enter <u>trigger words</u> <b>separated</b> by spaces or separators, in response to which you will receive a post #<u>{0}</u>{1}",
    'es': "👋🏽 Ingrese <u>palabras desencadenantes</u> <b>separadas</b> por espacios o separadores, en respuesta a las cuales recibirá una publicación #<u>{0}</u>{1}",
    'fr': "👋🏽 Saisissez les <u>mots déclencheurs</u> <b>séparés</b> par des espaces ou des séparateurs, en réponse auxquels vous recevrez un message #<u>{0}</u>{1}",
    'zh': "👋🏽 输入<u>触发词</u> <b>以空格或分隔符分隔</b>，您将收到一条帖子 #<u>{0}</u>{1}",
    'ar': "👋🏽 أدخل <u>كلمات التحفيز</u> <b>مفصولة</b> بمسافات أو فواصل، وستتلقى ردًا عليها مشاركة #<u>{0}</u>{1}",
}
l_cansweroperationnoanswer = {
    'ru': "🚫 Выбери <b>триггер</b> для отключения <i>авто-ответа</i>:",
    'en': "🚫 Select a <b>trigger</b> to disable <i>auto-reply</i>:",
    'es': "🚫 Seleccione un <b>activador</b> para desactivar la <i>respuesta automática</i>:",
    'fr': "🚫 Sélectionnez un <b>déclencheur</b> pour désactiver la <i>réponse automatique</i> :",
    'zh': "🚫 选择一个<b>触发器</b>来禁用<i>自动回复</i>：",
    'ar': "🚫 حدد <b>مشغلًا</b> لتعطيل <i>الرد التلقائي</i>:",
}
l_fsmAnswer_add_caption = {
    'ru': "👋🏽 Готово! <b>Текущее</b> количество триггеров для поста #{0} в <code>{1}</code>-файле: <u>{2}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> триггер",
    'en': "👋🏽 Done! <b>Current</b> number of triggers for post #{0} in <code>{1}</code>-file: <u>{2}</u>\n\n👩🏽‍💻 <b >Press</b>on ✅/🚫 to <b>Add/Remove</b> trigger",
    'es': "👋🏽 ¡Listo! Número <b>actual</b> de activadores para la publicación #{0} en el archivo <code>{1}</code>: <u>{2}</u>\n\n👩🏽‍💻 < b >Presione</b>en ✅/🚫 para <b>Agregar/Quitar</b> activador",
    'fr': "👋🏽 C'est fait ! <b>Nombre actuel</b> de déclencheurs pour la publication n° {0} dans le fichier <code>{1}</code> : <u>{2}</u>\n\n👩🏽‍💻 < b >Appuyez</b>sur ✅/🚫 pour <b>Ajouter/Supprimer</b> le déclencheur",
    'zh': "👋🏽完成！ <b>当前</b> <code>{1}</code>-文件中帖子 #{0} 的触发器数量：<u>{2}</u>\n\n👩🏽‍💻 < b>按</b>✅/🚫<b>添加/删除</b>触发器",
    'ar': "👋🏽 تم! <b>العدد الحالي</b> من المشغلات للنشر رقم {0} في <code>{1}</code>-الملف: <u>{2}</u>\n\n👩🏽‍💻 < b >اضغط</b>على ✅/🚫 لتفعيل مشغل <b>إضافة/إزالة</b>",
}

l_canswer_handler_btn = {
    'ru': "🔣 Нажатие на кнопку",
    'en': "🔣 Pressing a button",
    'es': "🔣 Presionando un botón",
    'fr': "🔣 Appuyer sur un bouton",
    'zh': "🔣 按下按钮",
    'ar': "🔣 الضغط على زر",
}
l_canswer_handler_txt = {
    'ru': "🔡 Текст содержится",
    'en': "🔡 Text contained",
    'es': "🔡 Texto contenido",
    'fr': "🔡 Texte contenu",
    'zh': "🔡 包含文字",
    'ar': "🔡النص موجود",
}
l_canswer_no_triggers = {
    'ru': "👋🏽 Для поста #{0} триггеры отсутствуют",
    'en': "👋🏽 There are no triggers for post #{0}",
    'es': "👋🏽 No hay activadores para la publicación #{0}",
    'fr': "👋🏽 Il n'y a aucun déclencheur pour la publication n° {0}",
    'zh': "👋🏽 帖子 #{0} 没有触发器",
    'ar': "👋🏽 لا توجد مشغلات للمشاركة رقم {0}",
}
l_canswer_push_triggers = {
    'ru': "👋🏽 <b>Жми</b> на ❌, чтобы удалить триггер для поста #<u>{0}</u>",
    'en': "👋🏽 <b>Click</b> on ❌ to remove the trigger for post #<u>{0}</u>",
    'es': "👋🏽 <b>Haga clic</b> en ❌ para eliminar el activador de la publicación n.°<u>{0}</u>",
    'fr': "👋🏽 <b>Cliquez</b> sur ❌ pour supprimer le déclencheur de la publication n°<u>{0}</u>",
    'zh': "👋🏽 <b>点击</b> ❌ 可删除帖子 #<u>{0}</u> 的触发器",
    'ar': "👋🏽 <b>انقر</b> على ❌ لإزالة عامل المشاركة رقم<u>{0}</u>",
}
l_canswer_choose_btn = {
    'ru': "👩🏽‍💻 Выбери одну из <b>кнопок</b>, нажав на которую, пользователю придет пост #<u>{0}</u>",
    'en': "👩🏽‍💻 Select one of the <b>buttons</b>, by clicking on which the user will receive a post #<u>{0}</u>",
    'es': "👩🏽‍💻 Seleccione uno de los <b>botones</b>, al hacer clic en el cual el usuario recibirá una publicación #<u>{0}</u>",
    'fr': "👩🏽‍💻 Sélectionnez l'un des <b>boutons</b>, en cliquant sur lequel l'utilisateur recevra un message #<u>{0}</u>",
    'zh': "👩🏽‍💻 选择<b>按钮</b>之一，点击该按钮用户将收到帖子#<u>{0}</u>",
    'ar': "👩🏽‍💻 حدد أحد <b>الأزرار</b>، والتي من خلال النقر عليها سيتلقى المستخدم مشاركة #<u>{0}</u>",
}
l_canswer_add_trigger = {
    'ru': "👋🏽 Готово! Триггер ({0}): <b>{1}</b> добавлен для поста #{2}\n\n👩🏽‍💻 <b>Текущее</b> количество триггеров для поста #{2}: <u>{3}</u>",
    'en': "👋🏽 Done! Trigger ({0}): <b>{1}</b> added for post #{2}\n\n👩🏽‍💻 <b>Current</b> number of triggers for post #{2}: < u>{3}</u>",
    'es': "👋🏽 ¡Listo! Activador ({0}): <b>{1}</b> agregado para la publicación #{2}\n\n👩🏽‍💻 Número <b>actual</b> de activadores para la publicación #{2}: <u>{3}</u>",
    'fr': "👋🏽 C'est fait ! Déclencheur ({0}) : <b>{1}</b> ajouté pour la publication n°{2}\n\n👩🏽‍💻 Nombre <b>actuel</b> de déclencheurs pour la publication n°{2} : <u>{3}</u>",
    'zh': "👋🏽完成！触发器 ({0})：为帖子#{2}添加了<b>{1}</b>\n\n👩🏽‍💻帖子#{2}的<b>当前</b>触发器数量： <u>{3}</u>",
    'ar': "👋🏽 تم! المشغل ({0}): تمت إضافة <b>{1}</b> للنشر رقم {2}\n\n👩🏽‍💻 <b>العدد الحالي</b> من المشغلات للنشر رقم {2}: < ش>{3}</u>",
}
l_canswer_trigger_choose = {
    'ru': "👋🏽 Выбери <b>триггер</b>, в ответ на который будет присылаться пост #<u>{0}</u>",
    'en': "👋🏽 Select a <b>trigger</b>, in response to which the post #<u>{0}</u> will be sent",
    'es': "👋🏽 Seleccione un <b>activador</b>, en respuesta al cual se enviará la publicación #<u>{0}</u>",
    'fr': "👋🏽 Sélectionnez un <b>déclencheur</b>, en réponse auquel le message #<u>{0}</u> sera envoyé",
    'zh': "👋🏽 选择<b>触发器</b>，作为响应，将发送帖子 #<u>{0}</u>",
    'ar': "👋🏽 حدد <b>مشغل</b>، والذي سيتم إرسال المشاركة #<u>{0}</u> ردًا عليه",
}
l_canswer_trigger_without_url_buttons = {
    'ru': "👩🏽‍💻 Создай хотя бы один пост с кнопками без url-ссылок",
    'en': "👩🏽‍💻 Create at least one post with buttons without URL links",
    'es': "👩🏽‍💻 Crea al menos una publicación con botones sin enlaces URL",
    'fr': "👩🏽‍💻 Créez au moins une publication avec des boutons sans liens URL",
    'zh': "👩🏽‍💻 创建至少一篇带有不带 URL 链接的按钮的帖子",
    'ar': "👩🏽‍💻 أنشئ مشاركة واحدة على الأقل تحتوي على أزرار بدون روابط URL",
}
# endregion


# region cgeo_
l_cgeo_text = {
    'ru': "📍 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> мониторинг ближайших гео-контактов/встреч\n\n<blockquote>👩🏽‍💻 <b>Начни</b> [📍Трансляция геопозиции] от имени @{0} в любом приватном диалоге [<b>выбери</b> 15мин/1ч/8ч]. В разделе <i>Избранное</i> будут появляться отфильтрованные пользователи в текущей геопозиции</blockquote>",
    'en': "📍 <b>Press</b> on ✅/☑️ to <b>On/Off</b> monitoring of nearby geo-contacts/meetings\n\n👩🏽‍💻 <b>Start</b> [📍Broadcast geolocation] on behalf of @{0} in any private dialogue [<b>select</b> 15min/1h/8h]. Filtered users in the current geolocation will appear in the <i>Favorites</i> section",
    'es': "📍 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el monitoreo de contactos/reuniones geográficas cercanas\n\n👩🏽‍💻 <b>Iniciar</b> [📍 Transmitir geolocalización] en nombre de @{0} en cualquier diálogo privado [<b>seleccione</b> 15min/1h/8h]. Los usuarios filtrados en la geolocalización actual aparecerán en la sección <i>Favoritos</i>",
    'fr': "📍 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la surveillance des géo-contacts/réunions à proximité\n\n👩🏽‍💻 <b>Démarrer</b> [📍 Diffusez la géolocalisation] au nom de @{0} dans n'importe quel dialogue privé [<b>sélectionnez</b> 15 min/1h/8h]. Les utilisateurs filtrés dans la géolocalisation actuelle apparaîtront dans la section <i>Favoris</i>.",
    'zh': "📍<b>按</b> ✅/☑️<b>开启/关闭</b>监控附近的地理联系人/会议\n\n👩🏽‍💻<b>开始</b> [📍在任何私人对话中代表 @{0} 广播地理位置] [<b>选择</b> 15 分钟/1 小时/8 小时]。当前地理位置中过滤的用户将显示在<i>收藏夹</i>部分",
    'ar': "📍 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> مراقبة جهات الاتصال الجغرافية/الاجتماعات القريبة\n\n👩🏽‍💻 <b>البدء</b> [📍 بث الموقع الجغرافي] نيابة عن @{0} في أي حوار خاص [<b>اختر</b> 15 دقيقة/1 ساعة/8 ساعات]. سيظهر المستخدمون الذين تمت تصفيتهم في الموقع الجغرافي الحالي في قسم <i>المفضلة</i>",
}
l_cgeo_config = {
    'ru': "📍 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> фильтр гео-мониторинга пользователей по <i>наличию @username/аватара/телефон/<b>премиум</b>-аккаунта</i>",
    'en': "📍 <b>Press</b> on ✅/☑️ to <b>On/Off</b> filter for geo-monitoring of users by <i>presence of @username /avatar/phone/<b>premium</b>-account</i>",
    'es': "📍 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el filtro de monitoreo geográfico de usuarios por <i>presencia de @username /avatar/teléfono/<b>premium</ b>-cuenta</i>",
    'fr': "📍 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> filtrer la géo-surveillance des utilisateurs par <i>présence de @username /avatar/phone/<b>premium</ b>-compte</i>",
    'zh': "📍 <b>按</b> ✅/☑️ <b>开/关</b>过滤器，通过<i> @username /avatar/phone/<b>premium 的存在来对用户进行地理监控</ b>-帐户</i>",
    'ar': "📍 <b>اضغط</b> على ✅/☑️ لتشغيل مرشح <b>تشغيل/إيقاف</b> للمراقبة الجغرافية للمستخدمين من خلال <i>وجود @username /avatar/phone/<b>premium</ ب>-الحساب</i>",
}
l_cgeo_username_on = {
    'ru': "✅☑Вкл @username",
    'en': "✅☑Incl @username",
    'es': "✅☑Incluye @username",
    'fr': "✅☑Inclut @username",
    'zh': "✅☑包含@username",
    'ar': "✅☑Incl @username",
}
l_cgeo_username_off = {
    'ru': "☑️☐Выкл @username",
    'en': "☑️☐Выкл @username",
    'es': "☑️☐Выкл @username",
    'fr': "☑️☐Выкл @username",
    'zh': "☑️ Выкл @username",
    'ar': "☑️☐Выкл @username",
}
l_cgeo_avatar_on = {
    'ru': "✅☑Вкл аватар",
    'en': "✅☑Avatar on",
    'es': "✅☑Avatar en",
    'fr': "✅☑Avatar activé",
    'zh': "✅☑头像已开启",
    'ar': "✅☑الصورة الرمزية قيد التشغيل",
}
l_cgeo_avatar_off = {
    'ru': "☑️☐Выкл аватар",
    'en': "☑️☐Off avatar",
    'es': "☑️☐Avatar fuera",
    'fr': "☑️☐Hors avatar",
    'zh': "☑️️关闭头像",
    'ar': "☑️☐ خارج الصورة الرمزية",
}
l_cgeo_bio_on = {
    'ru': "✅☑Вкл телефон",
    'en': "✅☑Phone included",
    'es': "✅☑Teléfono incluido",
    'fr': "✅☑Téléphone inclus",
    'zh': "✅☑包括电话",
    'ar': "✅☑الهاتف متضمن",
}
l_cgeo_bio_off = {
    'ru': "☑️☐Выкл телефон",
    'en': "☑️☐Turn off the phone",
    'es': "☑️☐Apaga el teléfono",
    'fr': "☑️☐Éteignez le téléphone",
    'zh': "☑️️关掉手机",
    'ar': "☑️☐أغلق الهاتف",
}
l_cgeo_premium_on = {
    'ru': "✅☑Вкл премиум",
    'en': "✅☑Including premium",
    'es': "✅☑Incluye prima",
    'fr': "✅☑Y compris la prime",
    'zh': "✅☑包括保费",
    'ar': "✅☑بما في ذلك قسط",
}
l_cgeo_premium_off = {
    'ru': "☑️☐Выкл премиум",
    'en': "☑️☐Premium turned off",
    'es': "☑️☐Premium desactivado",
    'fr': "☑️☐Premium désactivé",
    'zh': "☑️️高级版已关闭",
    'ar': "☑️☐ تم إيقاف الاشتراك المميز",
}
l_geo_caption = {
    'ru': "👩🏽‍💻 <b>{0}</b>{1}\n<i>фото</i>: {2}\n<i>премиум</i>: {3}\n<i>телефон</i>: {4}\n\n<a href='https://maps.google.com/?q={5},{6}'>{7}</a>",
    'en': "👩🏽‍💻 <b>{0}</b>{1}\n<i>фото</i>: {2}\n<i>премиум</i>: {3}\n<i>телефон</i>: {4}\n\n<a href='https://maps.google.com/?q={5},{6}'>{7}</a>",
    'es': "👩🏽‍💻 <b>{0}</b>{1}\n<i>foto</i>: {2}\n<i>премиум</i>: {3}\n<i> teléfono</i>: {4}\n\n<a href=' https://maps.google.com/?q={5},{6} '> {7}</a>",
    'fr': "👩🏽‍💻 <b>{0}</b>{1}\n<i>photo</i> : {2}\n<i>премиум</i> : {3}\n<i> Téléphone</i> : {4}\n\n<a href=' https://maps.google.com/?q={5},{6} '> {7}</a>",
    'zh': "👩🏽‍💻 <b>{0}</b>{1}\n<i>фото</i>：{2}\n<i>премиум</i>：{3}\n<i>地址：{4}\n\n<a href=' https://maps.google.com/?q={5},{6} '> {7}</a>",
    'ar': "👩🏽‍💻 <b>{0}</b>{1}\n<i>фото</i>: {2}\n<i>премиум</i>: {3}\n<i> телефон</i>: {4}\n\n<a href=' https://maps.google.com/?q={5},{6} '> {7}</a>",
}
l_geo_wait = {
    'ru': "👩🏽‍💻 <b>Обработка</b> геолокации..\n\n#длительность 2мин",
    'en': "👩🏽‍💻 <b>Processing</b> geolocation..\n\n#duration 1 min",
    'es': "👩🏽‍💻 <b>Procesando</b> geolocalización..\n\n#duración 1 min",
    'fr': "👩🏽‍💻 <b>Traitement</b> géolocalisation..\n\n#durée 1 min",
    'zh': "👩🏽‍💻<b>正在处理</b>地理位置..\n\n#duration 1 分钟",
    'ar': "👩🏽‍💻 <b>معالجة</b> الموقع الجغرافي..\n\n#المدة دقيقة واحدة",
}
# endregion


# region cword_
l_cword_text = {
    'ru': "🚀 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> мониторинг-слов групп/каналов\n\n<blockquote>👩🏽‍💻 <b>Мониторинг</b> слов: <code>{0}</code>\n👩🏽‍💻 <b>Мониторинг</b> групп/каналов: <code>{1}</code></blockquote>",
    'en': "🚀 <b>Press</b> on ✅/☑️ to <b>On/Off</b> monitoring words of groups/channels\n\n👩🏽‍💻 <b>Monitoring</b> words: <code >{0}</code>\n👩🏽‍💻 <b>Monitoring</b> groups/channels: <code>{1}</code>",
    'es': "🚀 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> palabras de monitoreo de grupos/canales\n\n👩🏽‍💻 Palabras de <b>Monitoreo</b>: <código >{0}</code>\n👩🏽‍💻 <b>Monitoreo</b> de grupos/canales: <code>{1}</code>",
    'fr': "🚀 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la surveillance des mots des groupes/canaux\n\n👩🏽‍💻 <b>Surveillance</b> des mots : <code >{0}</code>\n👩🏽‍💻 <b>Surveillance</b> des groupes/canaux : <code>{1}</code>",
    'zh': "🚀 <b>按</b> ✅/☑️ <b>开启/关闭</b>监控群组/频道的词语\n\n👩🏽‍💻<b>监控</b>词语：<code >{0}</code>\n👩🏽‍💻 <b>监控</b>组/频道：<code>{1}</code>",
    'ar': "🚀 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> مراقبة كلمات المجموعات/القنوات\n\n👩🏽‍💻 <b>مراقبة</b> الكلمات: <code >{0}</code>\n👩🏽‍💻 مجموعات/قنوات <b>المراقبة</b>: <code>{1}</code>",
}
l_cword_call = {
    'ru': "🚀 Нет слов/групп/каналов для мониторинга\nЖми ⚙️Настроить",
    'en': "🚀 There are no words/groups/channels for monitoring\nClick ⚙️Customize",
    'es': "🚀 No hay palabras/grupos/canales para monitorear\nHaga clic en ⚙️Personalizar",
    'fr': "🚀 Il n'y a pas de mots/groupes/canaux à surveiller\nCliquez sur ⚙️Personnaliser",
    'zh': "🚀 没有可监控的词/组/频道\n点击⚙️自定义",
    'ar': "🚀 لا توجد كلمات/مجموعات/قنوات للمراقبة\nانقر على ⚙️تخصيص",
}
l_cword_wrd = {
    'ru': "🚀 1/2. <b>Введи</b> слова для мониторинга (более <u>4</u> символов) через <i>пробелы/раздели</i> (без 💨Подписки: до <u>5</u> слов): укажи символ * (в конце слова) чтобы учитывать вхождение\n\n<blockquote>👩🏽‍💻 <b>Мониторинг</b> слов: <code>{0}</code>\n👩🏽‍💻 <b>Мониторинг</b> групп/каналов: <code>{1}</code></blockquote>",
    'en': "🚀 1/2. <b>Enter</b> words for monitoring (more than <u>4</u> characters) separated by <i>spaces/separate</i> (without 💨Subscription: up to <u>5</u> words) : specify the symbol * (at the end of the word) to take into account the occurrence of\n\n👩🏽‍💻 <b>Monitoring</b> words: <code>{0}</code>\n👩🏽‍💻 <b>Monitoring </b> groups/channels: <code>{1}</code>",
    'es': "🚀 1/2. <b>Ingrese</b> palabras para monitorear (más de <u>4</u> caracteres) separadas por <i>espacios/separados</i> (sin 💨Suscripción: hasta <u>5</u > palabras): especifique el símbolo * (al final de la palabra) para tener en cuenta la aparición de\n\n👩🏽‍💻 <b>Palabras de seguimiento</b>: <code>{0}</code >\n👩🏽‍💻 <b>Supervisión de </b> grupos/canales: <code>{1}</code>",
    'fr': "🚀1/2. <b>Saisissez</b> les mots à surveiller (plus de <u>4</u> caractères) séparés par <i>espaces/séparés</i> (sans 💨Abonnement : jusqu'à <u>5</u > mots) : précisez le symbole * (à la fin du mot) pour prendre en compte l'occurrence des mots\n\n👩🏽‍💻 <b>Suivi</b> : <code>{0}</code >\n👩🏽‍💻 <b>Surveillance </b> groupes/canaux : <code>{1}</code>",
    'zh': "🚀 1/2。 <b>输入</b>个用于监控的单词（超过<u>4</u>个字符），以<i>空格/单独</i>分隔（无💨订阅：最多<u>5</u> > Words) : 指定符号 *（在单词末尾）以考虑\n\n👩🏽‍💻 <b>监控</b>单词的出现：<code>{0}</code >\n👩🏽‍💻<b>监控</b>组/频道：<code>{1}</code>",
    'ar': "🚀 1/2. <b>أدخل</b> كلمات للمراقبة (أكثر من <u>4</u> أحرف) مفصولة بـ <i>مسافات/منفصلة</i> (بدون 💨الاشتراك: حتى <u>5</u > الكلمات) : حدد الرمز * (في نهاية الكلمة) لمراعاة حدوث\n\n👩🏽‍💻 كلمات <b>المراقبة</b>: <code>{0}</code >\n👩🏽‍💻 <b>مراقبة </b> المجموعات/القنوات: <code>{1}</code>",
}
l_cword_src = {
    'ru': "🚀 2/2. <b>Введи</b> @username/id групп/каналов (через <i>пробелы/разделители</i>), в которых {0}-аккаунт участник, например: {1} (без 💨Подписки: до <u>10</u> групп/каналов)\n\n<blockquote>👩🏽‍💻 <b>Мониторинг</b> слов: <code>{2}</code>\n👩🏽‍💻 <b>Мониторинг</b> групп/каналов: <code>{3}</code></blockquote>",
    'en': "🚀 2/2. <b>Enter</b> @username /id of groups/channels (separated by <i>spaces/separators</i>) in which {0}-account is a member, for example: {1} (without 💨Subscription: up to < u>10</u> groups/channels)\n\n👩🏽‍💻 <b>Monitoring</b> words: <code>{2}</code>\n👩🏽‍💻 <b>Monitoring< /b> groups/channels: <code>{3}</code>",
    'es': "🚀 2/2. <b>Ingrese</b> @username /id de grupos/canales (separados por <i>espacios/separadores</i>) del cual {0}-cuenta es miembro, por ejemplo: {1} (sin 💨 Suscripción: hasta < u>10</u> grupos/canales)\n\n👩🏽‍💻 Palabras de <b>Monitoreo</b>: <code>{2}</code>\n👩🏽‍💻 <b>Supervisión</b> de grupos/canales: <code>{3}</code>",
    'fr': "🚀2/2. <b>Entrez</b> @username /id des groupes/canaux (séparés par des <i>espaces/séparateurs</i>) dont le compte {0} est membre, par exemple : {1} (sans 💨 Abonnement : jusqu'à < u>10</u> groupes/canaux)\n\n👩🏽‍💻 <b>Surveillance</b> mots : <code>{2}</code>\n👩🏽‍💻 <b>Surveillance</b> des groupes/canaux : <code>{3}</code>",
    'zh': "🚀 2/2。 <b>输入</b>组/频道的@username /id（用<i>空格/分隔符</i>分隔），其中 {0}-account 是其中的成员，例如：{1}（不带 💨订阅：最多< u>10</u>个群组/频道）\n\n👩🏽‍💻 <b>监控</b>个字：<code>{2}</code>\n👩🏽‍💻 <b>监控</b>组/频道：<code>{3}</code>",
    'ar': "🚀 2/2. <b>أدخل</b> @username /id للمجموعات/القنوات (مفصولة <i>بمسافات/فواصل</i>) التي يكون {0}-account عضوًا فيها، على سبيل المثال: {1} (بدون 💨 الاشتراك: ما يصل إلى < u>10</u> مجموعات/قنوات)\n\n👩🏽‍💻 <b>مراقبة</b> الكلمات: <code>{2}</code>\n👩🏽‍💻 <b>مجموعات/قنوات المراقبة< /b>: <code>{3}</code>",
}
l_cword_find = {
    'ru': "👩🏽‍💻 <b>Мониторинг слов</b>: <code>{0}</code> [{1}]",
    'en': "👩🏽‍💻 <b>Word monitoring</b>: <code>{0}</code> [{1}]",
    'es': "👩🏽‍💻 <b>Monitoreo de palabras</b>: <code>{0}</code> [{1}]",
    'fr': "👩🏽‍💻 <b>Surveillance des mots</b> : <code>{0}</code> [{1}]",
    'zh': "👩🏽‍💻 <b>单词监控</b>：<code>{0}</code> [{1}]",
    'ar': "👩🏽‍💻 <b>مراقبة الكلمات</b>: <code>{0}</code> [{1}]",
}
# endregion


# region csend_
l_csend_alert = {
    'ru': "📨️ Нужно ⚙️Настроить пост и источник пользователей для рассылки",
    'en': "📨️ You need to ⚙️Set up a post and user source for mailing",
    'es': "📨️ Debes ⚙️Configurar una publicación y una fuente de usuario para el envío por correo",
    'fr': "📨️ Vous devez ⚙️Configurer une publication et une source d'utilisateurs pour le mailing",
    'zh': "📨️您需要⚙️设置用于邮寄的帖子和用户来源",
    'ar': "📨️ تحتاج إلى ⚙️ إعداد منشور ومصدر مستخدم للمراسلة",
}
l_csend_text = {
    'ru': "📨️ <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-рассылку нескольким пользователям выбранного поста\n\n👩🏽‍💻 <b>Текущие</b> настройки авто-рассылки: {0}",
    'en': "📨️ <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-mailing to several users of the selected post\n\n👩🏽‍💻 <b>Current</b> auto-settings mailings: {0}",
    'es': "📨️ <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> el envío automático a varios usuarios de la publicación seleccionada\n\n👩🏽‍💻 <b>Actual</b> correos con configuración automática: {0}",
    'fr': "📨️ <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> la distribution automatique à plusieurs utilisateurs de la publication sélectionnée\n\n👩🏽‍💻 <b>Actuel</b> mailings de paramètres automatiques : {0}",
    'zh': "📨️<b>按</b> ✅/☑️<b>开启/关闭</b>自动分发给所选帖子的多个用户\n\n👩🏽‍💻<b>当前</b>自动设置邮件：{0}",
    'ar': "📨️ <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> التوزيع التلقائي للمنشور المحدد على العديد من المستخدمين\n\n👩🏽‍💻 <b>الحالي</b> رسائل الإعدادات التلقائية: {0}",
}
l_csend_current = {
    'ru': "📨️ <b>Текущие</b> настройки авто-рассылки:\n\n<u>{0}</u> сообщ/сутки\n<u>{1}</u> пост\n<u>{2}</u> источник",
    'en': "📨️ <b>Current</b> auto-mail settings:\n\n<u>{0}</u> messages/day\n<u>{1}</u> post\n<u>{ 2}</u>source",
    'es': "📨️ Configuración de correo automático <b>actual</b>:\n\n<u>{0}</u> mensajes/día\n<u>{1}</u> publicación\n<u>{ 2}</u>fuente",
    'fr': "📨️ Paramètres de messagerie automatique <b>actuels</b> :\n\n<u>{0}</u> messages/jour\n<u>{1}</u> publication\n<u>{ 2</u>source",
    'zh': "📨️ <b>当前</b>自动邮件设置：\n\n<u>{0}</u> 条消息/天\n<u>{1}</u> 条帖子\n<u>{ 2}</u>来源",
    'ar': "📨️ <b>إعدادات البريد التلقائي</b> الحالية:\n\n<u>{0}</u> الرسائل/اليوم\n<u>{1}</u> منشور\n<u>{ 2}</u>المصدر",
}

l_csend_cnt = {
    'ru': "{0} сообщ/сутки",
    'en': "{0} messages/day",
    'es': "{0} mensajes/día",
    'fr': "{0} messages/jour",
    'zh': "{0} 条消息/天",
    'ar': "{0} رسالة/يوم",
}
l_csend_post = {
    'ru': "{0} пост",
    'en': "{0} post",
    'es': "{0} publicación",
    'fr': "{0} message",
    'zh': "{0} 条帖子",
    'ar': "مشاركة {0}.",
}
l_csend_src = {
    'ru': "{0} источник",
    'en': "{0} source",
    'es': "{0} fuente",
    'fr': "{0} source",
    'zh': "{0}来源",
    'ar': "{0} المصدر",
}
l_csendconfig_use = {
    'ru': "📨️ Использовать",
    'en': "📨️ Use",
    'es': "📨️ Uso",
    'fr': "📨️ Utiliser",
    'zh': "📨️使用",
    'ar': "📨️ الاستخدام",
}
l_csend_choose = {
    'ru': "Выбрать",
    'en': "Choose",
    'es': "Elegir",
    'fr': "Choisir",
    'zh': "选择",
    'ar': "يختار",
}

l_csend_group = {
    'ru': "📨️ Группа",
    'en': "📨️ Group",
    'es': "📨️ Grupo",
    'fr': "📨️ Groupe",
    'zh': "📨️组",
    'ar': "📨️ المجموعة",
}
l_csend_file = {
    'ru': "📨️ Файл",
    'en': "📨️ File",
    'es': "📨️ Archivo",
    'fr': "📨️ Fichier",
    'zh': "📨️ 文件",
    'ar': "📨️ ملف",
}
l_csend_geo = {
    'ru': "📨️ Гео",
    'en': "📨️ Geo",
    'es': "📨️ Geo",
    'fr': "📨️ Géo",
    'zh': "📨️ 地理",
    'ar': "📨️جيو",
}

l_csend_choose_src = {
    'ru': "📨️ Выбери <b>источник</b>, откуда будем брать @username для авто-рассылки",
    'en': "📨️ Select a <b>source</b> from where we will take @username for auto-mailing",
    'es': "📨️ Seleccione una <b>fuente</b> desde donde tomaremos @username para el envío automático",
    'fr': "📨️ Sélectionnez une <b>source</b> à partir de laquelle nous prendrons @username pour l'envoi automatique",
    'zh': "📨️ 选择一个<b>来源</b>，我们将从中获取@username进行自动邮寄",
    'ar': "📨️ حدد <b>مصدرًا</b> حيث سنأخذ @username لإرسال البريد تلقائيًا",
}
l_csend_choose_cnt = {
    'ru': "📨️ Введи <b>количество</b> сообщений для авто-рассылки, которое будет отправляться ежедневно (без 💨Подписки: до 1 сообщ)",
    'en': "📨️ Enter the <b>number</b> of messages for auto-mailing, which will be sent daily (without 💨Subscription: up to 1 message)",
    'es': "📨️ Ingrese el <b>número</b> de mensajes para envío automático, que se enviarán diariamente (sin 💨Suscripción: hasta 1 mensaje)",
    'fr': "📨️ Saisissez le <b>nombre</b> de messages à envoyer automatiquement, qui seront envoyés quotidiennement (sans 💨Abonnement : jusqu'à 1 message)",
    'zh': "📨️ 输入自动邮件的<b>数量</b>条消息，该消息将每天发送（无💨订阅：最多 1 条消息）",
    'ar': "📨️ أدخل <b>عدد</b> الرسائل التي سيتم إرسالها تلقائيًا يوميًا (بدون 💨اشتراك: حتى رسالة واحدة)",
}
l_csend_choose_post = {
    'ru': "📨️ Выбери <b>пост</b>, который будет использован для авто-рассылки и жми [{0}] под выбранным постом",
    'en': "📨️ Select the <b>post</b> that will be used for auto-mailing and click [{0}] under the selected post",
    'es': "📨️ Seleccione la <b>publicación</b> que se utilizará para el envío automático y haga clic en [{0}] debajo de la publicación seleccionada.",
    'fr': "📨️ Sélectionnez la <b>post</b> qui sera utilisée pour l'envoi automatique et cliquez sur [{0}] sous la publication sélectionnée",
    'zh': "📨️ 选择将用于自动邮寄的<b>帖子</b>，然后点击所选帖子下方的 [{0}]",
    'ar': "📨️ حدد <b>المنشور</b> الذي سيتم استخدامه لإرسال البريد التلقائي وانقر على [{0}] أسفل المنشور المحدد",
}

l_csendsrc_group = {
    'ru': "📨️ Отправь <b>ссылку</b> на группу, чтобы сделать авто-рассылку по ее @username",
    'en': "📨️ Send a <b>link</b> to the group to make an automatic newsletter to its @username",
    'es': "📨️ Envía un <b>enlace</b> al grupo para realizar un newsletter automático a su @username",
    'fr': "📨️ Envoyez un <b>lien</b> au groupe pour faire une newsletter automatique à son @username",
    'zh': "📨️ 向群组发送<b>链接</b>，以向其@username发送自动新闻通讯",
    'ar': "📨️ أرسل <b>رابطًا</b> إلى المجموعة لإنشاء رسالة إخبارية تلقائية إلى @username الخاص بها",
}
l_csendsrc_file = {
    'ru': "📨️ Прикрепи текстовый <b>файл</b> со списком @username, чтобы сделать по ним авто-рассылку",
    'en': "📨️ Attach a text <b>file</b> with a list of @username to make an automatic newsletter for them",
    'es': "📨️ Adjunte un <b>archivo</b> de texto con una lista de @username para crear un boletín automático para ellos",
    'fr': "📨️ Joindre un <b>fichier</b> texte avec une liste de @username pour créer une newsletter automatique pour eux",
    'zh': "📨️ 附加一个带有@username列表的文本<b>文件</b>，为他们制作自动新闻通讯",
    'ar': "📨️ أرفق <b>ملفًا</b> نصيًا يتضمن قائمة @username لإنشاء رسالة إخبارية تلقائية له",
}
l_csendsrc_geo = {
    'ru': "📨️ Отправь <b>геопозицию</b>, чтобы получить @usernames в этой гео-локации для авто-рассылки",
    'en': "📨️ Send <b>geolocation</b> to receive @usernames in this geo-location for auto-mailing",
    'es': "📨️ Envíe <b>geolocalización</b> para recibir @usernames en esta ubicación geográfica para envío automático por correo",
    'fr': "📨️ Envoyez la <b>géolocalisation</b> pour recevoir @usernames dans cette géolocalisation pour un envoi automatique",
    'zh': "📨️ 发送<b>地理位置</b>以接收此地理位置中的@usernames以进行自动邮寄",
    'ar': "📨️ أرسل <b>الموقع الجغرافي</b> لتلقي @usernames في هذا الموقع الجغرافي لإرسالها بالبريد التلقائي",
}

l_csend_fsm_cnt = {
    'ru': "📨️ Введи корректное число пользователей для рассылки",
    'en': "📨️ Enter the correct number of users for mailing",
    'es': "📨️ Ingrese el número correcto de usuarios para enviar correo",
    'fr': "📨️ Entrez le nombre correct d'utilisateurs pour le mailing",
    'zh': "📨️输入正确的邮寄用户数",
    'ar': "📨️ أدخل العدد الصحيح للمستخدمين للمراسلة",
}
l_csend_fsm_geo = {
    'ru': "📨 Начинаем гео-парсинг @username по координатам <b>{0} {1}</b>\n\n#длительность 1min",
    'en': "📨 We begin geo-parsing @username at coordinates <b>{0} {1}</b>\n\n#duration 1min",
    'es': "📨 Comenzamos a analizar @username en las coordenadas <b>{0} {1}</b>\n\n#duration 1min",
    'fr': "📨 Nous commençons la géo-analyse @username aux coordonnées <b>{0} {1}</b>\n\n#durée 1min",
    'zh': "📨 我们在坐标 <b>{0} {1}</b>\n\n#duration 1min 处开始对@username进行地理解析",
    'ar': "📨 نبدأ التحليل الجغرافي @username عند الإحداثيات <b>{0} {1}</b>\n\n#duration 1min",
}
l_csend_fsm_parse_start = {
    'ru': "📨 Начинаем парсинг @username из <b>{0}</b>\n\n#длительность 1min",
    'en': "📨 We begin parsing @username from <b>{0}</b>\n\n#duration 1min",
    'es': "📨 Comenzamos a analizar @username desde <b>{0}</b>\n\n#duración 1 min.",
    'fr': "📨 Nous commençons l'analyse @username à partir de <b>{0}</b>\n\n#durée 1 min",
    'zh': "📨 我们开始从 <b>{0}</b>\n\n#duration 1min 解析@username",
    'ar': "📨 نبدأ في تحليل @username من <b>{0}</b>\n\n#duration 1min",
}
# endregion
# endregion


# region client
l_userbot_cmd_acc = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Био:</b> {2}",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio:</b> {2}",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Biografía:</b> {2}",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>Bio :</b> {2}",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>个人简介：</b> {2}",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>]\n<b>السيرة الذاتية:</b> {2}",
}
l_userbot_cmd_acc2 = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}]",
}
l_set_ban = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> <b>{0}</b> [id=<code>{1}</code>] был заблокирован по причине: {2}",
    'en': "👩🏽‍💻 <b>User</b> <b>{0}</b> [id=<code>{1}</code>] was blocked for reason: {2}",
    'es': "👩🏽‍💻 <b>Usuario</b> <b>{0}</b> [id=<code>{1}</code>] fue bloqueado por el motivo: {2}",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> <b>{0}</b> [id=<code>{1}</code>] a été bloqué pour la raison : {2}",
    'zh': "👩🏽‍💻 <b>用户</b> <b>{0}</b> [id=<code>{1}</code>] 被阻止，原因为：{2}",
    'ar': "👩🏽‍💻 تم حظر <b>المستخدم</b> <b>{0}</b> [id=<code>{1}</code>] للسبب: {2}",
}
l_direct_message = {
    'ru': "👩🏽‍💻 <b>Пересылка</b> от {0}:",
    'en': "👩🏽‍💻 <b>Forwarding</b> from {0}:",
    'es': "👩🏽‍💻 <b>Reenvío</b> desde {0}:",
    'fr': "👩🏽‍💻 <b>Transfert</b> depuis {0} :",
    'zh': "👩🏽‍💻 <b>转发</b>，来自 {0}：",
    'ar': "👩🏽‍💻 <b>إعادة التوجيه</b> من {0}:",
}
l_translated_in = {
    'ru': "👩🏽‍💻 <b>Переведено</b> в [{0}]-язык для {1} [<code>{2}</code>]",
    'en': "👩🏽‍💻 <b>Translated</b> into [{0}]-language for {1} [<code>{2}</code>]",
    'es': "👩🏽‍💻 <b>Traducido</b> al idioma [{0}] para {1} [<code>{2}</code>]",
    'fr': "👩🏽‍💻 <b>Traduit</b> en langue [{0}] pour {1} [<code>{2}</code>]",
    'zh': "👩🏽‍💻 <b>已翻译</b>为 {1} [<code>{2}</code>] 的 [{0}] 语言",
    'ar': "👩🏽‍💻 <b>مترجمة</b> إلى [{0}]-لغة {1} [<code>{2}</code>]",
}
l_send_by_offer_id = {
    'ru': "👩🏽‍💻 Пост #<u>{0}</u> отправлен @{1} (id={2})",
    'en': "👩🏽‍💻 Post #<u>{0}</u> sent by @{1} (id={2})",
    'es': "👩🏽‍💻 Publicación #<u>{0}</u> enviada por @{1} (id={2})",
    'fr': "👩🏽‍💻 Message n°<u>{0}</u> envoyé par @{1} (id={2})",
    'zh': "👩🏽‍💻 @{1} (id={2}) 发送的帖子 #<u>{0}</u>",
    'ar': "👩🏽‍💻 المشاركة #<u>{0}</u> مرسلة بواسطة @{1} (المعرف={2})",
}
l_userbot_cmd_info_fun = {
    'ru': "👩🏽‍💻 <b>Аккаунт:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, цвет: {3}, тема: {4}, dc: {5}]\n<b>Био:</b> {6}",
    'en': "👩🏽‍💻 <b>Account:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, topic: {4}, dc: {5}]\n<b>Bio:</b> {6}",
    'es': "👩🏽‍💻 <b>Cuenta:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, color: {3}, Tema: {4}, dc: {5}]\n<b>Biografía:</b> {6}",
    'fr': "👩🏽‍💻 <b>Compte :</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}, couleur : {3}, sujet : {4}, cc : {5}]\n<b>Bio :</b> {6}",
    'zh': "👩🏽‍💻 <b>帐户：</b> {0}\n[<b>id</b>=<code>{1}</code>，+{2}，颜色：{3}，主题：{4}，直流：{5}]\​​n<b>简介：</b> {6}",
    'ar': "👩🏽‍💻 <b>الحساب:</b> {0}\n[<b>id</b>=<code>{1}</code>, +{2}، اللون: {3}، الموضوع: {4}، العاصمة: {5}]\n<b>السيرة الذاتية:</b> {6}",
}
l_userbot_cmd_info_confident = {
    'ru': "\n\n<b>Конфиденциальность:</b>\n{0}",
    'en': "\n\n<b>Privacy:</b>\n{0}",
    'es': "\n\n<b>Privacidad:</b>\n{0}",
    'fr': "\n\n<b>Confidentialité :</b>\n{0}",
    'zh': "\n\n<b>隐私：</b>\n{0}",
    'ar': "\n\n<b>الخصوصية:</b>\n{0}",
}
l_userbot_cmd_info_status = {
    'ru': "{0}-<i>эмоджи-статус</i>",
    'en': "{0}-<i>emoji status</i>",
    'es': "{0}-<i>estado de emoji</i>",
    'fr': "{0}-<i>statut emoji</i>",
    'zh': "{0}-<i>表情符号状态</i>",
    'ar': "{0}-<i>حالة الرموز التعبيرية</i>",
}
l_userbot_cmd_info_premium = {
    'ru': "\n<b>Премиум:</b> {0}",
    'en': "\n<b>Premium:</b> {0}",
    'es': "\n<b>Premium:</b> {0}",
    'fr': "\n<b>Premium :</b> {0}",
    'zh': "\n<b>高级：</b> {0}",
    'ar': "\n<b>الإصدار المميز:</b> {0}",
}
l_userbot_cmd_info_fake = {
    'ru': "\n<b>Фейк:</b> да",
    'en': "\n<b>Fake:</b> yes",
    'es': "\n<b>Falso:</b> sí",
    'fr': "\n<b>Faux :</b> oui",
    'zh': "\n<b>假：</b>是的",
    'ar': "\n<b>زائف:</b> نعم",
}
l_userbot_cmd_info_scam = {
    'ru': "\n<b>Скам:</b> да",
    'en': "\n<b>Scam:</b> yes",
    'es': "\n<b>Estafa:</b> sí",
    'fr': "\n<b>Arnaque :</b> oui",
    'zh': "\n<b>诈骗：</b>是的",
    'ar': "\n<b>عملية احتيال:</b> نعم",
}
l_userbot_cmd_info_restricted = {
    'ru': "\n<b>Ограничен:</b> да",
    'en': "\n<b>Limited:</b> yes",
    'es': "\n<b>Limitado:</b> sí",
    'fr': "\n<b>Limité :</b> oui",
    'zh': "\n<b>限制：</b> 是",
    'ar': "\n<b>محدودة:</b> نعم",
}
l_userbot_cmd_info_extra = {
    'ru': "\n<b>Цвет:</b> да",
    'en': "\n<b>Color:</b> yes",
    'es': "\n<b>Color:</b> sí",
    'fr': "\n<b>Couleur :</b> oui",
    'zh': "\n<b>颜色：</b> 是",
    'ar': "\n<b>اللون:</b> نعم",
}

l_userbot_cmd_nsfw = {
    'ru': "<b>NSFW (/sensitive контент):</b> ",
    'en': "<b>NSFW (/sensitive content):</b>",
    'es': "<b>NSFW (/contenido sensible):</b>",
    'fr': "<b>NSFW (/contenu sensible) :</b>",
    'zh': "<b>NSFW（/敏感内容）：</b>",
    'ar': "<b>NSFW (/محتوى حساس):</b>",
}
l_userbot_cmd_auto_archive = {
    'ru': "<b>Авто-архив spam-пользователей:</b> ",
    'en': "<b>Auto-archive of spam users:</b>",
    'es': "<b>Archivado automático de usuarios de spam:</b>",
    'fr': "<b>Archive automatique des utilisateurs indésirables :</b>",
    'zh': "<b>垃圾邮件用户的自动存档：</b>",
    'ar': "<b>الأرشفة التلقائية لمستخدمي البريد العشوائي:</b>",
}
l_userbot_cmd_cloud_pswd = {
    'ru': "<b>Облачный пароль</b>: <code>{0}</code>",
    'en': "<b>Cloud password</b>: <code>{0}</code>",
    'es': "<b>Contraseña de la nube</b>: <code>{0}</code>",
    'fr': "<b>Mot de passe cloud</b> : <code>{0}</code>",
    'zh': "<b>云密码</b>：<code>{0}</code>",
    'ar': "<b>كلمة مرور السحابة</b>: <code>{0}</code>",
}
l_userbot_cmd_profile_photo = {
    'ru': "\n<b>Фото профиля</b>: {0}",
    'en': "\n<b>Profile photo</b>: {0}",
    'es': "\n<b>Foto de perfil</b>: {0}",
    'fr': "\n<b>Photo de profil</b> : {0}",
    'zh': "\n<b>个人资料照片</b>：{0}",
    'ar': "\n<b>صورة الملف الشخصي</b>: {0}",
}
l_userbot_cmd_common_chats = {
    'ru': "\n<b>Общие чаты:</b> {0}",
    'en': "\n<b>General chats:</b> {0}",
    'es': "\n<b>Chats generales:</b> {0}",
    'fr': "\n<b>Chats généraux :</b> {0}",
    'zh': "\n<b>一般聊天：</b> {0}",
    'ar': "\n<b>الدردشات العامة:</b> {0}",
}
l_userbot_cmd_lang = {
    'ru': "\n<b>Язык</b>: <code>{0}</code>",
    'en': "\n<b>Language</b>: <code>{0}</code>",
    'es': "\n<b>Idioma</b>: <código>{0}</código>",
    'fr': "\n<b>Langue</b> : <code>{0}</code>",
    'zh': "\n<b>语言</b>：<code>{0}</code>",
    'ar': "\n<b>اللغة</b>: <code>{0}</code>",
}
l_userbot_cmd_react = {
    'ru': "\n<b>Стандарт-реакции:</b> <code>{0}</code>",
    'en': "\n<b>Standard reaction:</b> <code>{0}</code>",
    'es': "\n<b>Reacción estándar:</b> <code>{0}</code>",
    'fr': "\n<b>Réaction standard :</b> <code>{0}</code>",
    'zh': "\n<b>标准反应：</b> <code>{0}</code>",
    'ar': "\n<b>التفاعل القياسي:</b> <code>{0}</code>",
}
l_userbot_cmd_gif_mask = {
    'ru': "\n<b>Сохраненные гиф/маски:</b> <code>{0}/{1}</code>",
    'en': "\n<b>Saved gifs/masks:</b> <code>{0}/{1}</code>",
    'es': "\n<b>Gifs/máscaras guardadas:</b> <code>{0}/{1}</code>",
    'fr': "\n<b>Gifs/masques enregistrés :</b> <code>{0}/{1}</code>",
    'zh': "\n<b>已保存的 gif/蒙版：</b> <code>{0}/{1}</code>",
    'ar': "\n<b>صور متحركة/أقنعة محفوظة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_theme_wall = {
    'ru': "\n<b>Темы/Обои:</b> <code>{0}/{1}</code> {2}",
    'en': "\n<b>Themes/Wallpapers:</b> <code>{0}/{1}</code> {2}",
    'es': "\n<b>Temas/Fondos de pantalla:</b> <code>{0}/{1}</code> {2}",
    'fr': "\n<b>Thèmes/Fonds d'écran :</b> <code>{0}/{1}</code> {2}",
    'zh': "\n<b>主题/壁纸：</b> <code>{0}/{1}</code> {2}",
    'ar': "\n<b>المظاهر/الخلفيات:</b> <code>{0}/{1}</code> {2}",
}
l_userbot_cmd_sick_emoj = {
    'ru': "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    'en': "\n<b>Stickers/Emoji</b>: <code>{0}/{1}</code>{2}",
    'es': "\n<b>Pegatinas/Emoji</b>: <código>{0}/{1}</código>{2}",
    'fr': "\n<b>Autocollants/Emoji</b> : <code>{0}/{1}</code>{2}",
    'zh': "\n<b>贴纸/表情符号</b>：<code>{0}/{1}</code>{2}",
    'ar': "\n<b>الملصقات/الرموز التعبيرية</b>: <code>{0}/{1}</code>{2}",
}
l_userbot_cmd_bot = {
    'ru': "\n\n<b>Бот:</b> @{0} ({1})",
    'en': "\n\n<b>Bot:</b> @{0} ({1})",
    'es': "\n\n<b>Bot:</b> @{0} ({1})",
    'fr': "\n\n<b>Bot :</b> @{0} ({1})",
    'zh': "\n\n<b>机器人：</b> @{0} ({1})",
    'ar': "\n\n<b>الروبوت:</b> @{0} ({1})",
}
l_userbot_cmd_chn = {
    'ru': "\n<b>Канал:</b> @{0} ({1})",
    'en': "\n<b>Channel:</b> @{0} ({1})",
    'es': "\n<b>Canal:</b> @{0} ({1})",
    'fr': "\n<b>Canal :</b> @{0} ({1})",
    'zh': "\n<b>频道：</b> @{0} ({1})",
    'ar': "\n<b>القناة:</b> @{0} ({1})",
}
l_userbot_cmd_bot_chn = {
    'ru': "\n<i>[бот и публичный канал необходимы для работы со сложными постами]</i>",
    'en': "\n<i>[bot and public channel are required to work with complex posts]</i>",
    'es': "\n<i>[se requiere un bot y un canal público para trabajar con publicaciones complejas]</i>",
    'fr': "\n<i>[le robot et le canal public sont requis pour travailler avec des publications complexes]</i>",
    'zh': "\n<i>[机器人和公共渠道需要处理复杂的帖子]</i>",
    'ar': "\n<i>[مطلوب روبوت وقناة عامة للعمل مع المنشورات المعقدة]</i>",
}
l_userbot_cmd_cmds = {
    'ru': "\n\n⚙️ <b>Команды</b> /cmd",
    'en': "\n\n⚙️ <b>Commands</b> /cmd",
    'es': "\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "\n\n⚙️ <b>命令</b> /cmd",
    'ar': "\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_userbot_cmd_top_send = {
    'ru': "\n@{0} написал(а): {1} сообщ",
    'en': "\n@{0} wrote: {1} message",
    'es': "\n@{0} escribió: {1} mensaje",
    'fr': "\n@{0} a écrit : {1} message",
    'zh': "\n@{0} 写了：{1} 条消息",
    'ar': "\n@{0} كتب: {1} رسالة",
}
l_userbot_cmd_top_users = {
    'ru': "<b>\n\n👩🏽‍💻 Топ пользователей (на 1000 сообщ)</b>: {0}\n",
    'en': "<b>\n\n👩🏽‍💻 Top users (per 1000 posts)</b>: {0}\n",
    'es': "<b>\n\n👩🏽‍💻 Usuarios principales (por cada 1000 publicaciones)</b>: {0}\n",
    'fr': "<b>\n\n👩🏽‍💻 Principaux utilisateurs (pour 1 000 posts)</b> : {0}\n",
    'zh': "<b>\n\n👩🏽‍💻 热门用户（每 1000 个帖子）</b>：{0}\n",
    'ar': "<b>\n\n👩🏽‍💻 أهم المستخدمين (لكل 1000 مشاركة)</b>: {0}\n",
}
l_userbot_cmd_top_words = {
    'ru': "\n{0}. <i>{1}</i>..: встретилось {2} раз",
    'en': "\n{0}. <i>{1}</i>..: occurred {2} times",
    'es': "\n{0}. <i>{1}</i>..: ocurrió {2} veces",
    'fr': "\n{0}. <i>{1}</i>.. : s'est produit {2} fois",
    'zh': "\n{0}。 <i>{1}</i>..：发生了 {2} 次",
    'ar': "\n{0}. <i>{1}</i>..: حدث {2} مرة",
}
l_userbot_cmd_top_msgs = {
    'ru': "<b>\n👩🏽‍💻 Топ сообщ (из 1000)</b>: {0}\n",
    'en': "<b>\n👩🏽‍💻 Top messages (out of 1000)</b>: {0}\n",
    'es': "<b>\n👩🏽‍💻 Mensajes principales (de 1000)</b>: {0}\n",
    'fr': "<b>\n👩🏽‍💻 Messages principaux (sur 1 000)</b> : {0}\n",
    'zh': "<b>\n👩🏽‍💻 热门消息（共 1000 条）</b>：{0}\n",
    'ar': "<b>\n👩🏽‍💻 أهم الرسائل (من أصل 1000)</b>: {0}\n",
}
l_userbot_cmd_fld_fave = {
    'ru': "избранное",
    'en': "favorites",
    'es': "favoritos",
    'fr': "favoris",
    'zh': "收藏夹",
    'ar': "المفضلة",
}
l_userbot_cmd_fld_users = {
    'ru': "пользователи",
    'en': "users",
    'es': "usuarios",
    'fr': "utilisateurs",
    'zh': "用户",
    'ar': "المستخدمين",
}
l_userbot_cmd_fld_chns = {
    'ru': "каналы",
    'en': "channels",
    'es': "canales",
    'fr': "chaînes",
    'zh': "渠道",
    'ar': "القنوات",
}
l_userbot_cmd_fld_grps = {
    'ru': "группы",
    'en': "groups",
    'es': "grupos",
    'fr': "groupes",
    'zh': "团体",
    'ar': "مجموعات",
}
l_userbot_cmd_fld_bots = {
    'ru': "боты",
    'en': "boots",
    'es': "botas",
    'fr': "bottes",
    'zh': "靴子",
    'ar': "أحذية",
}
l_userbot_cmd_life_time = {
    'ru': "\n\n<b>Время жизни аккаунта:</b> ~{0} дней",
    'en': "\n\n<b>Account lifetime:</b> ~{0} days",
    'es': "\n\n<b>Vida útil de la cuenta:</b> ~{0} días",
    'fr': "\n\n<b>Durée de vie du compte :</b> ~{0} jours",
    'zh': "\n\n<b>帐户生命周期：</b> ~{0} 天",
    'ar': "\n\n<b>عمر الحساب:</b> ~{0} يوم",
}
l_userbot_cmd_first_dlg = {
    'ru': "\n<b>Дата первого диалога:</b> ~{0}",
    'en': "\n<b>Date of first conversation:</b> ~{0}",
    'es': "\n<b>Fecha de la primera conversación:</b> ~{0}",
    'fr': "\n<b>Date de la première conversation :</b> ~{0}",
    'zh': "\n<b>第一次对话的日期：</b> ~{0}",
    'ar': "\n<b>تاريخ المحادثة الأولى:</b> ~{0}",
}
l_userbot_cmd_first_karma = {
    'ru': "\n<b>Карма:</b> <code>{0}</code> /spambot",
    'en': "\n<b>Karma:</b> <code>{0}</code> /spambot",
    'es': "\n<b>Karma:</b> <code>{0}</code> /spambot",
    'fr': "\n<b>Karma :</b> <code>{0}</code> /spambot",
    'zh': "\n<b>业力：</b> <code>{0}</code> /spambot",
    'ar': "\n<b>الكارما:</b> <code>{0}</code> /spambot",
}
l_userbot_cmd_authorizations = {
    'ru': "\n<b>Авторизации:</b> <code>{0}</code>\n{1}",
    'en': "\n<b>Authorizations:</b> <code>{0}</code>\n{1}",
    'es': "\n<b>Autorizaciones:</b> <code>{0}</code>\n{1}",
    'fr': "\n<b>Autorisations :</b> <code>{0}</code>\n{1}",
    'zh': "\n<b>授权：</b> <code>{0}</code>\n{1}",
    'ar': "\n<b>التفويضات:</b> <code>{0}</code>\n{1}",
}
l_current_auth = {
    'ru': "текущая",
    'en': "current",
    'es': "actual",
    'fr': "actuel",
    'zh': "当前的",
    'ar': "حاضِر",
}
l_userbot_cmd_flds = {
    'ru': "\n<b>Папки</b>: <code>{0}</code>\n{1}",
    'en': "\n<b>Folders</b>: <code>{0}</code>\n{1}",
    'es': "\n<b>Carpetas</b>: <code>{0}</code>\n{1}",
    'fr': "\n<b>Dossiers</b> : <code>{0}</code>\n{1}",
    'zh': "\n<b>文件夹</b>：<code>{0}</code>\n{1}",
    'ar': "\n<b>المجلدات</b>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_ring = {
    'ru': "\n<b>Рингтоны:</b> <code>{0}</code>",
    'en': "\n<b>Ringtone:</b> <code>{0}</code>",
    'es': "\n<b>Tono de llamada:</b> <código>{0}</código>",
    'fr': "\n<b>Sonnerie :</b> <code>{0}</code>",
    'zh': "\n<b>铃声：</b> <code>{0}</code>",
    'ar': "\n<b>نغمة الرنين:</b> <code>{0}</code>",
}
l_userbot_cmd_black = {
    'ru': "\n<b>Черный список</b>: <code>{0}</code>",
    'en': "\n<b>Blacklist</b>: <code>{0}</code>",
    'es': "\n<b>Lista negra</b>: <código>{0}</código>",
    'fr': "\n<b>Liste noire</b> : <code>{0}</code>",
    'zh': "\n<b>黑名单</b>：<code>{0}</code>",
    'ar': "\n<b>القائمة السوداء</b>: <code>{0}</code>",
}
l_userbot_cmd_notify = {
    'ru': "\n<b>Особые уведомления:</b> {0}",
    'en': "\n<b>Special notices:</b> {0}",
    'es': "\n<b>Avisos especiales:</b> {0}",
    'fr': "\n<b>Avis spéciaux :</b> {0}",
    'zh': "\n<b>特别通知：</b> {0}",
    'ar': "\n<b>إشعارات خاصة:</b> {0}",
}
l_userbot_cmd_drafts = {
    'ru': "\n<b>Черновики/помеченные:</b> <code>{0}/{1}</code>",
    'en': "\n<b>Drafts/marked:</b> <code>{0}/{1}</code>",
    'es': "\n<b>Borradores/marcados:</b> <code>{0}/{1}</code>",
    'fr': "\n<b>Brouillons/marqués :</b> <code>{0}/{1}</code>",
    'zh': "\n<b>草稿/标记：</b> <code>{0}/{1}</code>",
    'ar': "\n<b>المسودات/التي تم وضع علامة عليها:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_sched = {
    'ru': "\n<b>Отложенные/посты/офферы</b>: {0}",
    'en': "\n<b>Pending/posts/offers</b>: {0}",
    'es': "\n<b>Pendientes/publicaciones/ofertas</b>: {0}",
    'fr': "\n<b>En attente/messages/offres</b> : {0}",
    'zh': "\n<b>待处理/帖子/优惠</b>：{0}",
    'ar': "\n<b>معلق/منشورات/عروض</b>: {0}",
}
l_userbot_cmd_dlgs = {
    'ru': "\n<b>Диалоги</b> <u>архив/закреп/все</u>: {0}",
    'en': "\n<b>Dialogs</b> <u>archive/pinned/all</u>: {0}",
    'es': "\n<b>Diálogos</b> <u>archivar/fijar/todos</u>: {0}",
    'fr': "\n<b>Dialogues</b> <u>archive/épinglé/tout</u> : {0}",
    'zh': "\n<b>对话框</b> <u>存档/固定/全部</u>：{0}",
    'ar': "\n<b>مربعات الحوار</b> <u>الأرشفة/المثبتة/الكل</u>: {0}",
}
l_userbot_cmd_last_react = {
    'ru': "\n<b>Последние реакции:</b> {0}",
    'en': "\n<b>Latest reactions:</b> {0}",
    'es': "\n<b>Últimas reacciones:</b> {0}",
    'fr': "\n<b>Dernières réactions :</b> {0}",
    'zh': "\n<b>最新反应：</b> {0}",
    'ar': "\n<b>أحدث التفاعلات:</b> {0}",
}
l_userbot_cmd_unread_react = {
    'ru': "\n<b>Непрочитанные @тэги/реакции:</b> <code>{0}/{1}</code>",
    'en': "\n<b>Unread @tags/reactions:</b> <code>{0}/{1}</code>",
    'es': "\n<b>@etiquetas/reacciones no leídas:</b> <código>{0}/{1}</código>",
    'fr': "\n<b>@tags/réactions non lus :</b> <code>{0}/{1}</code>",
    'zh': "\n<b>未读@tags/reactions：</b> <code>{0}/{1}</code>",
    'ar': "\n<b>العلامات/التفاعلات غير المقروءة:</b> <code>{0}/{1}</code>",
}
l_userbot_cmd_unread_msgs = {
    'ru': "\n<b>Непрочитанные сообщ (и архив):</b> <code>{0}</code>",
    'en': "\n<b>Unread messages (and archive):</b> <code>{0}</code>",
    'es': "\n<b>Mensajes no leídos (y archivados):</b> <code>{0}</code>",
    'fr': "\n<b>Messages non lus (et archives) :</b> <code>{0}</code>",
    'zh': "\n<b>未读消息（和存档）：</b> <code>{0}</code>",
    'ar': "\n<b>الرسائل غير المقروءة (والأرشفة):</b> <code>{0}</code>",
}
l_userbot_cmd_contacts = {
    'ru': "\n<b>Контакты</b> <u>взаимные/недавние/все</u>: {0}",
    'en': "\n<b>Contacts</b> <u>mutual/recent/all</u>: {0}",
    'es': "\n<b>Contactos</b> <u>mutuos/recientes/todos</u>: {0}",
    'fr': "\n<b>Contacts</b> <u>mutuels/récents/tous</u> : {0}",
    'zh': "\n<b>联系人</b> <u>共同/最近/全部</u>：{0}",
    'ar': "\n<b>جهات الاتصال</b> <u>المتبادلة/الحديثة/الكل</u>: {0}",
}
l_userbot_cmd_all = {
    'ru': "\n<b>Пользователи/боты/группы/каналы</b>: {0}",
    'en': "\n<b>Users/bots/groups/channels</b>: {0}",
    'es': "\n<b>Usuarios/bots/grupos/canales</b>: {0}",
    'fr': "\n<b>Utilisateurs/bots/groupes/canaux</b> : {0}",
    'zh': "\n<b>用户/机器人/组/频道</b>：{0}",
    'ar': "\n<b>المستخدمون/الروبوتات/المجموعات/القنوات</b>: {0}",
}
l_userbot_cmd_owner = {
    'ru': "\n\n<b>Владелец</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    'en': "\n\n<b>Owner</b> <u>groups/channels</u>: <code>{0}</code>\n{1}",
    'es': "\n\n<b>Propietario</b> <u>grupos/canales</u>: <code>{0}</code>\n{1}",
    'fr': "\n\n<b>Propriétaire</b> <u>groupes/canaux</u> : <code>{0}</code>\n{1}",
    'zh': "\n\n<b>所有者</b> <u>群组/频道</u>：<code>{0}</code>\n{1}",
    'ar': "\n\n<b>المالك</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_admin = {
    'ru': "\n\n<b>Админ</b> <u>групп/каналов</u>: <code>{0}</code>\n{1}",
    'en': "\n\n<b>Admin</b> <u>groups/channels</u>: <code>{0}</code>\n{1}",
    'es': "\n\n<b>Administrador</b> <u>grupos/canales</u>: <code>{0}</code>\n{1}",
    'fr': "\n\n<b>Administrateur</b> <u>groupes/canaux</u> : <code>{0}</code>\n{1}",
    'zh': "\n\n<b>管理员</b> <u>群组/频道</u>：<code>{0}</code>\n{1}",
    'ar': "\n\n<b>المسؤول</b> <u>المجموعات/القنوات</u>: <code>{0}</code>\n{1}",
}
l_userbot_cmd_bot_father = {
    'ru': "\n\n<b>Боты {0}</b>: <code>{1}/20</code>\n{2}",
    'en': "\n\n<b>Bots {0}</b>: <code>{1}/20</code>\n{2}",
    'es': "\n\n<b>Bots {0}</b>: <code>{1}/20</code>\n{2}",
    'fr': "\n\n<b>Bots {0}</b> : <code>{1}/20</code>\n{2}",
    'zh': "\n\n<b>机器人 {0}</b>：<code>{1}/20</code>\n{2}",
    'ar': "\n\n<b>الروبوتات {0}</b>: <code>{1}/20</code>\n{2}",
}
l_userbot_cmd_top_affects = {
    'ru': "\n\n<b>Топ взаимодействий</b>:\n{0}",
    'en': "\n\n<b>Top interactions</b>:\n{0}",
    'es': "\n\n<b>Interacciones principales</b>:\n{0}",
    'fr': "\n\n<b>Principales interactions</b> :\n{0}",
    'zh': "\n\n<b>热门互动</b>：\n{0}",
    'ar': "\n\n<b>أهم التفاعلات</b>:\n{0}",
}
l_userbot_cmd_last_msgs = {
    'ru': "\n\n<b>Последние сообщения</b>:\n{0}",
    'en': "\n\n<b>Latest messages</b>:\n{0}",
    'es': "\n\n<b>Últimos mensajes</b>:\n{0}",
    'fr': "\n\n<b>Derniers messages</b> :\n{0}",
    'zh': "\n\n<b>最新消息</b>：\n{0}",
    'ar': "\n\n<b>أحدث الرسائل</b>:\n{0}",
}
l_userbot_cmd_parse_fun = {
    'ru': "👩🏽‍💻 Готово! Для <b>{0}</b> собрано реальных <b>{1}</b>-участников: <u>{2}</u>{3}",
    'en': "👩🏽‍💻 Done! For <b>{0}</b> real <b>{1}</b> participants were collected: <u>{2}</u>{3}",
    'es': "👩🏽‍💻¡Listo! Para los <b>{0}</b> participantes reales <b>{1}</b> se recopilaron: <u>{2}</u>{3}",
    'fr': "👩🏽‍💻 C'est fait ! Pour <b>{0}</b> de vrais <b>{1}</b> participants ont été collectés : <u>{2}</u>{3}",
    'zh': "👩🏽‍💻 完成！对于<b>{0}</b>，收集了真实的<b>{1}</b>参与者：<u>{2}</u>{3}",
    'ar': "👩🏽‍💻 تم! بالنسبة إلى <b>{0}</b> تم جمع <b>{1}</b> من المشاركين الحقيقيين: <u>{2}</u>{3}",
}
l_parse_handler_err = {
    'ru': "👩🏽‍💻 Вставь корректную ссылку, повтори операцию или попробуй вступить вручную",
    'en': "👩🏽‍💻 Insert the correct link, repeat the operation or try to enter manually",
    'es': "👩🏽‍💻 Inserta el enlace correcto, repite la operación o intenta ingresar manualmente",
    'fr': "👩🏽‍💻 Insérez le bon lien, répétez l'opération ou essayez de saisir manuellement",
    'zh': "👩🏽‍💻插入正确的链接，重复操作或尝试手动输入",
    'ar': "👩🏽‍💻 أدخل الرابط الصحيح، كرر العملية أو حاول الدخول يدويا",
}

l_nsfw_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> <code>/sensitive 1</code> или <code>/sensitive 0</code>, чтобы <i>вкл/выкл</i> <b>NSFW</b> (небезопасный контент). <b>Используй</b> /info, чтобы проверить статус",
    'en': "👩🏽‍💻 <b>Enter</b> <code>/sensitive 1</code> or <code>/sensitive 0</code> to <i>on/off</i> <b>NSFW< /b> (unsafe content). <b>Use</b> /info to check status",
    'es': "👩🏽‍💻 <b>Ingrese</b> <code>/SENSITIVE 1</code> o <code>/SENSITIVE 0</code> para <i>activar/desactivar</i> <b>NSFW< / b> (contenido inseguro). <b>Utilice</b> /info para comprobar el estado",
    'fr': "👩🏽‍💻 <b>Entrez</b> <code>/sensitive 1</code> ou <code>/sensitive 0</code> pour <i>on/off</i> <b>NSFW< / b> (contenu dangereux). <b>Utilisez</b> /info pour vérifier l'état",
    'zh': "👩🏽‍💻 <b>输入</b> <code>/sensitive 1</code> 或 <code>/sensitive 0</code> 来<i>开/关</i> <b>NSFW</code> b>（不安全内容）。 <b>使用</b> /info 检查状态",
    'ar': "👩🏽‍💻 <b>أدخل</b> <code>/sensitive 1</code> أو <code>/sensitive 0</code> إلى <i>on/off</i> <b>NSFW< / ب> (محتوى غير آمن). <b>استخدم</b> /info للتحقق من الحالة",
}
l_nsfw_off = {
    'ru': "👩🏽‍💻 <b>NSFW</b>-контент выключен",
    'en': "👩🏽‍💻 <b>NSFW</b> content is disabled",
    'es': "👩🏽‍💻 El contenido <b>NSFW</b> está deshabilitado",
    'fr': "👩🏽‍💻 Le contenu <b>NSFW</b> est désactivé",
    'zh': "👩🏽‍💻 <b>NSFW</b> 内容已被禁用",
    'ar': "👩🏽‍💻 محتوى <b>NSFW</b> معطل",
}
l_nsfw_on = {
    'ru': "👩🏽‍💻 <b>NSFW</b>-контент включен",
    'en': "👩🏽‍💻 <b>NSFW</b>-content included",
    'es': "👩🏽‍💻 Contenido <b>NSFW</b> incluido",
    'fr': "👩🏽‍💻 <b>NSFW</b>-contenu inclus",
    'zh': "👩🏽‍💻<b>NSFW</b>-包含内容",
    'ar': "👩🏽‍💻 <b>NSFW</b>-المحتوى متضمن",
}

l_userbot_cmd_update_err = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> обновления профиля",
    'en': "👩🏽‍💻 <b>Error</b> profile update",
    'es': "👩🏽‍💻 <b>Error</b> actualización de perfil",
    'fr': "👩🏽‍💻 <b>Erreur</b> mise à jour du profil",
    'zh': "👩🏽‍💻<b>错误</b>个人资料更新",
    'ar': "👩🏽‍💻 <b>خطأ</b> في تحديث الملف الشخصي",
}
l_userbot_cmd_update_info = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> получения профиля",
    'en': "👩🏽‍💻 <b>Error</b> receiving profile",
    'es': "👩🏽‍💻 <b>Error</b> al recibir el perfil",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de la réception du profil",
    'zh': "👩🏽‍💻 <b>接收个人资料时出错</b>",
    'ar': "👩🏽‍💻 <b>خطأ</b> في استلام الملف الشخصي",
}
l_userbot_cmd_update_stat = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> получения статистики",
    'en': "👩🏽‍💻 <b>Error</b> getting statistics",
    'es': "👩🏽‍💻 <b>Error</b> al obtener estadísticas",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de l'obtention des statistiques",
    'zh': "👩🏽‍💻 <b>获取统计信息时出错</b>",
    'ar': "👩🏽‍💻 <b>خطأ</b> في الحصول على الإحصائيات",
}
l_userbot_cmd_geo_fun = {
    'ru': "👩🏽‍💻 <b>Готово</b>! По <a href='{0}'>геопозиции</a> собрано <code>@usernames</code>: <u>{1}</u>",
    'en': "👩🏽‍💻 <b>Done</b>! After <a href='{0}'>geopositions</a> collected <code> @usernames </code>: <u>{1}</u>",
    'es': "👩🏽‍💻 <b>Listo</b>! Después de <a href='{0}'>geoposiciones</a> recopiladas <code> @usernames </code>: <u>{1}</u>",
    'fr': "👩🏽‍💻 <b>Terminé</b> ! Après la collecte des <a href='{0}'>géopositions</a> <code> @usernames </code> : <u>{1}</u>",
    'zh': "👩🏽‍💻<b>完成</b>！收集<a href='{0}'>地理位置</a>后<code> @usernames </code>：<u>{1}</u>",
    'ar': "👩🏽‍💻 <b>تم</b>! بعد أن قامت <a href='{0}'>المواقع الجغرافية</a> بجمع <code> @usernames </code>: <u>{1}</u>",
}

l_idea = {
    'ru': "💡 <b>Идея!</b>",
    'en': "💡 <b>Idea!</b>",
    'es': "💡 <b>¡Idea!</b>",
    'fr': "💡 <b>Idée !</b>",
    'zh': "💡<b>想法！</b>",
    'ar': "💡 <b>فكرة!</b>",
}
l_have_read = {
    'ru': "👩🏽‍💻 {0} прочитал сообщение",
    'en': "👩🏽‍💻 {0} read the message",
    'es': "👩🏽‍💻 {0} lee el mensaje",
    'fr': "👩🏽‍💻 {0} lire le message",
    'zh': "👩🏽‍💻 {0} 已阅读该消息",
    'ar': "👩🏽‍💻 {0}اقرأ الرسالة",
}
l_telegraph2_title = {
    'ru': "📰 Telegraph блог",
    'en': "📰 Telegraph blog",
    'es': "📰 Blog de telégrafos",
    'fr': "📰Blog télégraphique",
    'zh': "📰 电讯报博客",
    'ar': "📰 مدونة التلغراف",
}
l_telegraph2_blog = {
    'ru': "<figure><img src='{0}'/><figcaption>Фото профиля: @{1}</figcaption></figure><blockquote>Лэндинг-блог для продвижения в <i>Telegram</i></blockquote>👩🏽‍💻 <b>Аккаунт:</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Био:</b> {4}<br><aside>Telegram-канал экспертности</aside><aside><a href='https://t.me/{5}'>Подписаться</a></aside>",
    'en': "<figure><img src='{0}'/><figcaption>Profile photo: @{1}</figcaption></figure><blockquote>Landing blog for promotion in <i>Telegram</i>< /blockquote>👩🏽‍💻 <b>Account:</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Bio :</b> {4}<br><aside>Telegram channel of expertise</aside><aside> <a href=' https://t.me/{5} '> Subscribe</a></ aside>",
    'es': "<figure><img src='{0}'/><figcaption>Foto de perfil: @{1}</figcaption></figure><blockquote>Blog de aterrizaje para promoción en <i>Telegram</i>< / blockquote>👩🏽‍💻 <b>Cuenta:</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Biografía: </b> {4}<br><aside>Canal especializado de Telegram</aside><aside> <a href=' https://t.me/{5} '> Suscríbete</a></ aside >",
    'fr': "<figure><img src='{0}'/><figcaption>Photo de profil : @{1}</figcaption></figure><blockquote>Blog de destination pour la promotion dans <i>Telegram</i>< / blockquote>👩🏽‍💻 <b>Compte :</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>Bio : </b> {4}<br><aside>Chaîne d'expertise Telegram</aside><aside> <a href=' https://t.me/{5} '> Abonnez-vous</a></ aparté >",
    'zh': "<figure><img src='{0}'/><figcaption>个人资料照片：@{1}</figcaption></figure><blockquote>登陆博客在<i>Telegram</i>进行推广</i></ blockquote>👩🏽‍💻 <b>帐户：</b> {2}<br>[<b>id</b>=<code>{3}</code>]<br><b>简介： </b> {4}<br><aside>Telegram 专业频道</aside><aside> <a href=' https://t.me/{5} '>订阅</a></aside >",
    'ar': "<figure><img src='{0}'/><figcaption>صورة الملف الشخصي: @{1}</figcaption></figure><blockquote>المدونة المقصودة للترويج في <i>Telegram</i>< / blockquote>👩🏽‍💻 <b>الحساب:</b> {2}<br>[<b>المعرف</b>=<code>{3}</code>]<br><b>السيرة الذاتية : </b> {4}<br><aside>قناة الخبرة على التليجرام</aside><aside> <a href=' https://t.me/{5} '> اشترك</a></ جانبًا >",
}
# endregion


# region extra bot
l_markup_check_list = {
    'ru': "📕 Чек-лист",
    'en': "📕 Checklist",
    'es': "📕 Lista de verificación",
    'fr': "📕 Liste de contrôle",
    'zh': "📕 清单",
    'ar': "📕 قائمة المراجعة",
}
l_markup_check_contact = {
    'ru': "☎️ Контакт",
    'en': "☎️ Contact",
    'es': "☎️ Contacto",
    'fr': "☎️ Contacter",
    'zh': "☎️联系方式",
    'ar': "☎️ الاتصال",
}
l_markup_check_gift = {
    'ru': "🎁 Подарок",
    'en': "🎁 Gift",
    'es': "🎁 Regalo",
    'fr': "🎁 Cadeau",
    'zh': "🎁 礼物",
    'ar': "🎁 هدية",
}
l_markup_check_blog = {
    'ru': "📰 Блог",
    'en': "📰 Blog",
    'es': "📰 Blog",
    'fr': "📰Blogue",
    'zh': "📰 博客",
    'ar': "📰 المدونة",
}

l_extra_bot_block = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} заблокировал @{1}-бота",
    'en': "👩🏽‍💻 <b>User</b> {0} blocked @{1}-bot",
    'es': "👩🏽‍💻 <b>Usuario</b> {0} bloqueó @{1}-bot",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} bloqué @{1}-bot",
    'zh': "👩🏽‍💻 <b>用户</b> {0} 屏蔽了 @{1}-bot",
    'ar': "👩🏽‍💻 <b>مستخدم</b> {0} تم حظره @{1}-bot",
}
l_extra_bot_unblock = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} разблокировал @{1}-бота",
    'en': "👩🏽‍💻 <b>User</b> {0} unblocked @{1}-bot",
    'es': "👩🏽‍💻 <b>Usuario</b> {0} @{1}-bot desbloqueado",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} débloqué @{1}-bot",
    'zh': "👩🏽‍💻 <b>用户</b> {0} 已解锁@{1}-bot",
    'ar': "👩🏽‍💻 <b>مستخدم</b> {0} تم رفع الحظر عنه @{1}-bot",
}
l_extra_bot_answer = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} (<code>{1}</code>) ответил в @{2}-боте:",
    'en': "👩🏽‍💻 <b>User</b> {0} (<code>{1}</code>) responded to @{2}-bot:",
    'es': "👩🏽‍💻 El <b>Usuario</b> {0} (<code>{1}</code>) respondió a @{2}-bot:",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} (<code>{1}</code>) a répondu à @{2}-bot :",
    'zh': "👩🏽‍💻 <b>用户</b> {0} (<code>{1}</code>) 回复了 @{2}-bot：",
    'ar': "👩🏽‍💻 <b>المستخدم</b> {0} (<code>{1}</code>) رد على @{2}-bot:",
}
l_extra_bot_gift_handler = {
    'ru': "🎁 <b>Разломи</b> одну из печенек, чтобы открыть свой бонус",
    'en': "🎁 <b>Break</b> one of the cookies to unlock your bonus",
    'es': "🎁 <b>Rompe</b> una de las cookies para desbloquear tu bono",
    'fr': "🎁 <b>Casse</b> un des cookies pour débloquer votre bonus",
    'zh': "🎁<b>打破</b>其中一个 cookie 即可解锁您的奖金",
    'ar': "🎁 <b>كسر</b> أحد ملفات تعريف الارتباط لفتح مكافأتك",
}
l_extra_bot_my_blog = {
    'ru': "📑 Мой Блог",
    'en': "📑 My Blog",
    'es': "📑 Mi blog",
    'fr': "📑 Mon blog",
    'zh': "📑 我的博客",
    'ar': "📑 مدونتي",
}
l_extra_bot_start = {
    'ru': "👩🏽‍💻 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> @{1}:\n\n▪️сбор ЦА и <b>рассылка</b> оффера\n▪️<b>публикация</b> постов через бота\n▪️ведение <b>telegraph</b>-блога\n▪️проведение <b>опросов</b> и квизов\n\n👩🏽‍💻 Больше возможностей в <a href='https://t.me/{2}'>demo</a>-боте",
    'en': "👩🏽‍💻 <b>{0}</b>, welcome to <i>landing bot</i> @{1}:\n\n▪️collection of target audience and <b>mailing</b> offer\n▪️<b>publishing</b> posts through a bot\n▪️maintaining a <b>telegraph</b> blog\n▪️conducting <b>surveys</b> and quizzes\n\n👩🏽‍💻 More features in <a href=' https://t.me/{2} '> demo</a>-bot",
    'es': "👩🏽‍💻 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> @{1}:\n\n▪️recopilación de público objetivo y oferta de <b>correo</b>\n▪️<b>publicar</b> publicaciones a través de un bot\n▪️mantener un blog de <b>telegraph</b>\n▪️realizar <b>encuestas</b> y cuestionarios\n\n👩🏽‍ 💻 Más funciones en <a href=' https://t.me/{2} '> demo</a>-bot",
    'fr': "👩🏽‍💻 <b>{0}</b>, bienvenue sur le <i>landing bot</i> @{1} :\n\nnoyercollecte du public cible et <b>offre de mailing</b>\n▪️<b>publier</b> des articles via un robot\n▪️maintenir un blog <b>télégraphique</b>\n▪️mener des <b>enquêtes</b> et des quiz\n\n👩🏽‍ 💻 Plus de fonctionnalités dans la <a href=' https://t.me/{2} '> démo</a>-bot",
    'zh': "👩🏽‍💻<b>{0}</b>，欢迎使用<i>登陆机器人</i>@{1}：\n\n▪️目标受众集合和<b>邮寄</b>优惠\n▪️通过机器人<b>发布</b>帖子\n▪️维护<b>电报</b>博客\n▪️进行<b>调查</b>和测验\n\n👩🏽‍ 💻 <a href=' https://t.me/{2} '>演示</a>-bot 中的更多功能",
    'ar': "👩🏽‍💻 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> @{1}:\n\n▪️مجموعة من الجمهور المستهدف وعرض <b>البريد</b>\n▪️<b>نشر</b> المشاركات من خلال برنامج التتبُّع\n▪️الاحتفاظ بمدونة <b>تلغراف</b>\n▪️إجراء <b>الاستطلاعات</b> والاختبارات\n\n👩🏽‍ 💻 المزيد من الميزات في <a href=' https://t.me/{2} '> التجريبي</a>-bot",
}
l_extra_bot_option = {
    'ru': "👇🏼 <b>Выбери</b> опцию ниже",
    'en': "👇🏼 <b>Select</b> the option below",
    'es': "👇🏼 <b>Seleccione</b> la opción a continuación",
    'fr': "👇🏼 <b>Sélectionnez</b> l'option ci-dessous",
    'zh': "👇🏼<b>选择</b>下面的选项",
    'ar': "👇🏼 <b>حدد</b> الخيار أدناه",
}
l_extra_bot_gift1 = {
    'ru': "3️⃣ Активирован <b>промокод</b> на <b>3%-скидку</b>",
    'en': "3️⃣ Activated <b>promo code</b> for <b>3% discount</b>",
    'es': "3️⃣ <b>código promocional</b> activado para <b>3% de descuento</b>",
    'fr': "3️⃣ <b>code promotionnel</b> activé pour <b>3 % de réduction</b>",
    'zh': "3️⃣ 激活<b>促销代码</b>以获得<b>3％折扣</b>",
    'ar': "3️⃣ تم تفعيل <b>الرمز الترويجي</b> للحصول على <b>خصم 3%</b>",
}
l_extra_bot_gift2 = {
    'ru': "7️⃣ Активирован <b>промокод</b> на <b>7%-скидку</b>",
    'en': "7️⃣ Activated <b>promo code</b> for <b>7% discount</b>",
    'es': "7️⃣ <b>código promocional</b> activado para <b>7% de descuento</b>",
    'fr': "7️⃣ <b>code promotionnel</b> activé pour <b>7 % de réduction</b>",
    'zh': "7️⃣ 激活<b>促销代码</b>以获得<b>7％折扣</b>",
    'ar': "7️⃣ تم تفعيل <b>الرمز الترويجي</b> للحصول على <b>خصم 7%</b>",
}
l_extra_bot_gift3 = {
    'ru': "🎁 Запись на безоплатную <b>консультацию</b>",
    'en': "🎁 Sign up for a free <b>consultation</b>",
    'es': "🎁 Regístrese para una <b>consulta</b> gratuita",
    'fr': "🎁 Inscrivez-vous pour une <b>consultation</b> gratuite",
    'zh': "🎁 注册免费<b>咨询</b>",
    'ar': "🎁 قم بالتسجيل للحصول على <b>استشارة</b> مجانية",
}
l_extra_bot_gift_no = {
    'ru': "😔 <b>Здесь</b> пусто",
    'en': "😔 <b>Here</b> is empty",
    'es': "😔 <b>Aquí</b> está vacío",
    'fr': "😔 <b>Ici</b> est vide",
    'zh': "😔 <b>这里</b>是空的",
    'ar': "😔 <b>هنا</b> فارغ",
}
l_extra_bot_gift_choose = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} (<code>{1}</code>) выбрал [{2}] в @{3}-боте",
    'en': "👩🏽‍💻 <b>User</b> {0} (<code>{1}</code>) selected [{2}] in @{3}-bot",
    'es': "👩🏽‍💻 <b>Usuario</b> {0} (<code>{1}</code>) seleccionó [{2}] en @{3}-bot",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} (<code>{1}</code>) sélectionné [{2}] dans @{3}-bot",
    'zh': "👩🏽‍💻 <b>用户</b> {0} (<code>{1}</code>) 在 @{3}-bot 中选择了 [{2}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b> {0} (<code>{1}</code>) تم تحديد [{2}] في @{3}-bot",
}
l_extra_bot_notify = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> ({0}) {1} (<code>{2}</code>) запустил @{3}-бота <b>{4}</b>",
    'en': "👩🏽‍💻 <b>User</b> ({0}) {1} (<code>{2}</code>) launched @{3}-bot <b>{4}</b>",
    'es': "👩🏽‍💻 <b>Usuario</b> ({0}) {1} (<code>{2}</code>) lanzó @{3}-bot <b>{4}</b>",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> ({0}) {1} (<code>{2}</code>) a lancé @{3}-bot <b>{4}</b>",
    'zh': "👩🏽‍💻 <b>用户</b> ({0}) {1} (<code>{2}</code>) 启动了 @{3}-bot <b>{4}</b>",
    'ar': "👩🏽‍💻 <b>مستخدم</b> ({0}) {1} (<code>{2}</code>) تم إطلاقه @{3}-bot <b>{4}</b>",
}

l_show_admin_panel = {
    'ru': "<b>👩🏽‍💻 Создание и редактирование публикаций</b>\n\n👩🏽‍💻 Вы зашли как <b>Администратор</b> - вы можете создавать и редактировать блоги, но не удалять их\n\n - <b>Жми</b> на кнопку [👩🏽‍💻 Авторизация] (у нее короткое время жизни)\n2 - Затем: на нужную ссылку (она скопируется), чтобы открыть ее в браузере для редактирования:\n\n",
    'en': "<b>👩🏽‍💻 Creating and editing publications</b>\n\n👩🏽‍💻 You are logged in as an <b>Administrator</b>-you can create and edit blogs, but not delete them\n\n-<b>Click</b> on the [👩🏽‍💻 Authorization] button (it has a short lifetime)\n2-Then: on the desired link (it will be copied) to open it in the browser for editing:\n\n",
    'es': "<b>👩🏽‍💻 Creación y edición de publicaciones</b>\n\n👩🏽‍💻 Has iniciado sesión como <b>Administrador</b>: puedes crear y editar blogs, pero no eliminarlos\ n\n-<b>Haga clic</b> en el botón [👩🏽‍💻 Autorización] (tiene una duración corta)\n2-Luego: en el enlace deseado (se copiará) para abrirlo en el navegador para editar:\n\n",
    'fr': "<b>👩🏽‍💻 Création et modification de publications</b>\n\n👩🏽‍💻 Vous êtes connecté en tant qu'<b>Administrateur</b>-vous pouvez créer et modifier des blogs, mais pas les supprimer\ n\n-<b>Cliquez</b> sur le bouton [👩🏽‍💻 Autorisation] (il a une durée de vie courte)\n2-Puis : sur le lien souhaité (il sera copié) pour l'ouvrir dans le navigateur pour l'édition :\n\n",
    'zh': "<b>👩🏽‍💻 创建和编辑出版物</b>\n\n👩🏽‍💻 您以<b>管理员</b>身份登录-您可以创建和编辑博客，但不能删除它们\ n\n-<b>点击</b> [👩🏽‍💻 授权] 按钮（它的生命周期很短）\n2-然后：点击所需的链接（它将被复制）以在浏览器中打开它用于编辑:\n\n",
    'ar': "<b>👩🏽‍💻 إنشاء المنشورات وتحريرها</b>\n\n👩🏽‍💻 لقد قمت بتسجيل الدخول كـ <b>مسؤول</b>-يمكنك إنشاء مدونات وتحريرها، ولكن لا يمكنك حذفها\n\n-<b>انقر</b> على زر [👩🏽‍💻 التفويض] (له عمر قصير)\n2-ثم: على الرابط المطلوب (سيتم نسخه) لفتحه في المتصفح للتحرير:\n\n",
}
l_broadcast_send = {
    'ru': "🏁 <b>Рассылка</b> завершена\n\n📨️ Количество пользователей, получивших сообщение: <u>{0}</u>",
    'en': "🏁 <b>Mail mailing</b> completed\n\n📨️ Number of users who received the message: <u>{0}</u>",
    'es': "🏁 <b>Envío de correo</b> completado\n\n📨️ Número de usuarios que recibieron el mensaje: <u>{0}</u>",
    'fr': "🏁 <b>Envoi du courrier</b> terminé\n\n📨️ Nombre d'utilisateurs ayant reçu le message : <u>{0}</u>",
    'zh': "🏁 <b>邮件发送</b>已完成\n\n📨️ 收到消息的用户数量：<u>{0}</u>",
    'ar': "🏁 <b>اكتمل إرسال البريد</b>\n\n📨️ عدد المستخدمين الذين تلقوا الرسالة: <u>{0}</u>",
}
l_get_default_link = {
    'ru': "🤳🏽 Связаться",
    'en': "🤳🏽 Contact",
    'es': "🤳🏽 Contacto",
    'fr': "🤳🏽Contacter",
    'zh': "🤳🏽联系方式",
    'ar': "🤳🏽 الاتصال",
}
l_get_default_share = {
    'ru': "🔗 Поделиться",
    'en': "🔗 Share",
    'es': "🔗 Compartir",
    'fr': "🔗 Partager",
    'zh': "🔗 分享",
    'ar': "🔗 شارك",
}
l_get_default_channel = {
    'ru': "🎥 Канал",
    'en': "🎥 Channel",
    'es': "🎥 Canal",
    'fr': "🎥 Chaîne",
    'zh': "🎥 频道",
    'ar': "🎥 قناة",
}
l_get_default_blog = {
    'ru': "📰 Блог",
    'en': "📰 Blog",
    'es': "📰 Blog",
    'fr': "📰Blogue",
    'zh': "📰 博客",
    'ar': "📰 المدونة",
}
l_contact_handler = {
    'ru': "☎️ Получен <b>контакт</b>: {0}",
    'en': "☎️ Received <b>contact</b>: {0}",
    'es': "☎️ <b>contacto</b> recibido: {0}",
    'fr': "☎️ <b>contact</b> reçu : {0}",
    'zh': "☎️ 收到<b>联系人</b>：{0}",
    'ar': "☎️ تم تلقي <b>جهة اتصال</b>: {0}",
}
l_handler_3127 = {
    'ru': "👩🏽‍💻 Активирован <b>промокод</b> на 5%-скидку",
    'en': "👩🏽‍💻 <b>promotional code</b> for a 5% discount has been activated",
    'es': "👩🏽‍💻 Se ha activado el <b>código promocional</b> para un 5% de descuento",
    'fr': "👩🏽‍💻 Le <b>code promotionnel</b> pour une réduction de 5 % a été activé",
    'zh': "👩🏽‍💻 5% 折扣的<b>促销代码</b>已激活",
    'ar': "👩🏽‍💻 تم تفعيل <b>الرمز الترويجي</b> للحصول على خصم 5%",
}
l_handler_3127_admin = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} (<code>{1}</code>) активировал <b>промокод</b> на 5% в @{2}-боте",
    'en': "👩🏽‍💻 <b>User</b> {0} (<code>{1}</code>) activated a <b>promo code</b> for 5% in @{2}-bot",
    'es': "👩🏽‍💻 El <b>Usuario</b> {0} (<code>{1}</code>) activó un <b>código promocional</b> del 5 % en @{2}-bot",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} (<code>{1}</code>) a activé un <b>code promotionnel</b> de 5 % dans @{2}-bot",
    'zh': "👩🏽‍💻 <b>用户</b> {0} (<code>{1}</code>) 在 @{2}-bot 中激活了 5% 的<b>促销代码</b>",
    'ar': "👩🏽‍💻 <b>المستخدم</b> {0} (<code>{1}</code>) قام بتنشيط <b>الرمز الترويجي</b> مقابل 5% في @{2}-bot",
}
l_poll_explanation = {
    'ru': "ℹ️ Следует держать руку на пульсе!",
    'en': "ℹ️ You should keep your finger on the pulse!",
    'es': "ℹ️ ¡Debes mantener el dedo en el pulso!",
    'fr': "ℹ️ Vous devriez garder le doigt sur le pouls !",
    'zh': "ℹ️ 你应该时刻关注脉搏！",
    'ar': "ℹ️ يجب أن تبقي إصبعك على النبض!",
}
l_poll_question = {
    'ru': "💣 Лучшие инструменты продвижения в Telegram?\n\n*прими решение за 30 секунд",
    'en': "💣 The best promotion tools on Telegram?\n\n*make a decision in 30 seconds",
    'es': "💣 ¿Las mejores herramientas de promoción en Telegram?\n\n*toma una decisión en 30 segundos",
    'fr': "💣 Les meilleurs outils de promotion sur Telegram ?\n\n*prenez une décision en 30 secondes",
    'zh': "💣 Telegram 上最好的推广工具？\n\n*30 秒内做出决定",
    'ar': "💣 ما هي أفضل أدوات الترويج على Telegram؟\n\n*اتخذ القرار خلال 30 ثانية",
}
l_poll_option1 = {
    'ru': "🇺🇸 Трансляция экспертности в блог/канал/группу",
    'en': "🇺🇸 Broadcasting expertise to a blog/channel/group",
    'es': "🇺🇸 Transmitir experiencia a un blog/canal/grupo",
    'fr': "🇺🇸 Expertise de diffusion sur un blog/chaîne/groupe",
    'zh': "🇺🇸 向博客/频道/群组传播专业知识",
    'ar': "🇺🇸 خبرة في البث لمدونة/قناة/مجموعة",
}
l_poll_option2 = {
    'ru': "🇺🎥 Использование ботов/веб-ботов/юзер-ботов",
    'en': "🇺🎥 Using bots/web bots/user bots",
    'es': "🇺🎥 Uso de bots/bots web/bots de usuario",
    'fr': "🇺🎥 Utilisation de bots/bots web/bots utilisateurs",
    'zh': "🇺🎥 使用机器人/网络机器人/用户机器人",
    'ar': "🇺🎥 استخدام الروبوتات/روبوتات الويب/روبوتات المستخدم",
}
l_poll_option3 = {
    'ru': "🇺📄 Все вышеперечисленное в одной экосистеме",
    'en': "🇺📄 All of the above in one ecosystem",
    'es': "🇺📄 Todo lo anterior en un solo ecosistema",
    'fr': "🇺📄 Tout ce qui précède dans un seul écosystème",
    'zh': "🇺📄 以上所有内容都在一个生态系统中",
    'ar': "🇺📄 كل ما سبق في نظام بيئي واحد",
}
# endregion


l_emoji_text = {
    'ru': "{0} <b>Текущая</b> эмоджи-реакция на пост: {1}",
    'en': "{0} <b>Current</b> emoji reaction to post: {1}",
    'es': "{0} Reacción emoji <b>actual</b> a la publicación: {1}",
    'fr': "{0} Réaction <b>actuelle</b> de l'emoji à la publication : {1}",
    'zh': "{0}<b>当前</b>表情符号对帖子的反应：{1}",
    'ar': "{0} تفاعل الرموز التعبيرية <b>الحالي</b> للنشر: {1}",
}
l_timer_text = {
    'ru': "{0} <b>Таймер</b> авто-удаления (в днях) для поста: {1}",
    'en': "{0} <b>Timer</b> auto-deletion (in days) for post: {1}",
    'es': "{0} Eliminación automática del <b>temporizador</b> (en días) para la publicación: {1}",
    'fr': "{0} Suppression automatique <b>minuterie</b> (en jours) pour la publication : {1}",
    'zh': "{0}帖子<b>计时器</b>自动删除（以天为单位）：{1}",
    'ar': "{0} <b>المؤقت</b> الحذف التلقائي (بالأيام) للمشاركة: {1}",
}
l_theme_text = {
    'ru': "{0} <b>Текущая</b> тема приватного диалога для поста: {1}\n\n<blockquote>👩🏽‍💻 <b>Текущее</b> фоновое фото: {2}\n👩🏽‍💻 <b>Прикрепи</b> фоновое фото диалога</blockquote>",
    'en': "{0} <b>Current</b> private dialogue topic for post: {1}\n\n👩🏽‍💻 <b>Current</b> background photo: {2}\n\n👩🏽‍💻 <b>Attach</b> a background photo of the dialogue",
    'es': "{0} Tema de diálogo privado <b>actual</b> para la publicación: {1}\n\n👩🏽‍💻 Foto de fondo <b>actual</b>: {2}\n\n👩🏽‍💻 <b>Adjunte</b> una foto de fondo del diálogo.",
    'fr': "{0} Sujet de dialogue privé <b>actuel</b> pour le message : {1}\n\n👩🏽‍💻 <b>Photo d'arrière-plan actuelle</b> : {2}\n\n👩🏽‍💻 <b>Joindre</b> une photo d'arrière-plan du dialogue",
    'zh': "{0} <b>当前</b>帖子的私人对话主题：{1}\n\n👩🏽‍💻 <b>当前</b>背景照片：{2}\n\n👩🏽‍💻 <b>附上</b>对话的背景照片",
    'ar': "{0} موضوع الحوار الخاص <b>الحالي</b> للمشاركة: {1}\n\n👩🏽‍💻 صورة الخلفية <b>الحالية</b>: {2}\n\n👩🏽‍💻 <b>أرفق</b> صورة خلفية للحوار",
}
l_wp_text = {
    'ru': "👩🏽‍💻 <b>Фоновое</b> фото успешно загружено",
    'en': "👩🏽‍💻 <b>Background</b> photo uploaded successfully",
    'es': "👩🏽‍💻 La foto de <b>fondo</b> se cargó correctamente",
    'fr': "👩🏽‍💻 <b>Photo d'arrière-plan</b> téléchargée avec succès",
    'zh': "👩🏽‍💻<b>背景</b>照片上传成功",
    'ar': "👩🏽‍💻 <b>الخلفية</b> تم تحميل الصورة بنجاح",
}
# endregion


# region FereyChannelBot
l_chn_btn1 = {
    'ru': "👩🏽‍💻 Каналы",
    'en': "👩🏽‍💻 Channels",
    'es': "👩🏽‍💻 Canales",
    'fr': "👩🏽‍💻 Chaînes",
    'zh': "👩🏽‍💻频道",
    'ar': "👩🏽‍💻 القنوات",
}
l_chn_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_chn_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> администрирования <b>Telegram</b>-каналов:\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️<b>авто-декор/подкасты</b> поста\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> administration of <b>Telegram</b> channels:\n\n▪️<b>collection/ban/analytics </b> subscribers\n▪️<b>auto-decor/podcasts</b> posts\n▪️button <b>counter</b>\n▪️<b>web app/neuro</b>-posting\n\n❗️<b>Regular</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido a la administración del <i>bot de aterrizaje</i> de los canales de <b>Telegram</b>:\n\n▪️<b>collection/ban/analytics < /b> suscriptores\n▪️<b>publicaciones de autodecoración/podcasts</b>\n▪️botón <b>contador</b>\n▪️<b>aplicación web/neuro</b>-publicación\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue dans l'administration du <i>landing bot</i> des chaînes <b>Telegram</b> :\n\nlessly<b>collection/ban/analytics < /b> abonnés\nnoyer<b>auto-decor/podcasts</b> posts\nnoyer️bouton <b>compteur</b>\n▪️<b>web app/neuro</b>-posting\n\n❗️<b>Régulier</b>-mis à jour /contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用 <b>Telegram</b> 频道的<i>登陆机器人</i>管理：\n\n▪️<b>collection/ban/analytics < /b> 订阅者\n▪️<b>自动装饰/播客</b> 帖子\n▪️按钮 <b>计数器</b>\n▪️<b>网络应用/神经</b>-发布\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في إدارة <i>الروبوت المقصود</i> لقنوات <b>Telegram</b>:\n\n▪️<b>collection/ban/analytics < /b> المشتركون\n▪️<b>الديكور التلقائي/البودكاست</b> المشاركات\n▪️زر <b>العداد</b>\n▪️<b>تطبيق الويب/العصبية</b>-النشر\n\n❗️<b>عادي</b>-محتوى/محدث",
}
l_chn_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyChannelBot-10-21',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_channel = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную <i>подписку</i>:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>добавление</b> нескольких каналов\n▪️более 5 <b>emoji</b> на пост\n▪️<b>нейро</b>-постинг\n▪️аудио/видео-<b>подкасты</b> более 1мин\n▪️<b>/parse</b> подписчиков/кликов</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly <i>subscription</i>:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0}-bot]:\n▪️<b>adding</b> several channels\n▪️more than 5 <b>emoji</b> per post\n▪️<b>neuro</b >-posting\n▪️audio/video-<b>podcasts</b> more than 1 min\n▪️<b>/parse</b> subscribers/clicks\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una <i>suscripción</i> mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u> %)]\n² [@{0}-bot]:\n▪️<b>agregando</b> varios canales\n▪️más de 5 <b>emoji</b> por publicación\n▪️<b>neuro </b >-publicación\n▪️audio/video-<b>podcasts</b> más de 1 min\n▪️<b>/parse</b> suscriptores/clics\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>Abonnez-vous</b> à un <i>abonnement</i> mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u> %)]\n² [@{0}-bot] :\nproduced</b> plusieurs chaînes\nwithout </b >-publication\nnouncedaudio/vidéo-<b>podcasts</b> plus d'1 min\nnoyance<b>/analyser</b> les abonnés/clics\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>每月<i>订阅</i>：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u> %)]\n² [@{0}-bot]:\n▪️<b>添加</b>多个频道\n▪️每个帖子超过 5 个<b>表情符号</b>\n▪️<b>neuro </b >-发布\n▪️音频/视频-<b>播客</b>超过 1 分钟\n▪️<b>/parse</b> 订阅者/点击次数\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في <i>اشتراك</i> شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u> %)]\n² [@{0}-bot]:\n▪️<b>إضافة</b> عدة قنوات\n▪️أكثر من 5 <b>إيموجي</b> لكل مشاركة\n▪️<b>neuro </b >-النشر\n▪️صوت/فيديو-<b>ملفات بودكاست</b> أكثر من دقيقة واحدة\n▪️<b>/تحليل</b> المشتركين/النقرات\n\n👩🏽‍💻 /التوازن",
}
l_cmd_txt_chn = {
    'ru': "👩🏽‍💻 <b>Жми</b> [➕ Добавить канал]",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add channel]",
    'es': "👩🏽‍💻 <b>Haz clic</b> [➕ Agregar canal]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter une chaîne]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加频道]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة قناة]",
}

l_add_chn_text = {
    'ru': "👮🏽‍♀️ <b>Добавь</b> @{0}-бота как <b>Administrator</b> через настройки своего канала:\n\n<blockquote>[👤 Добавить администратора]</blockquote>",
    'en': "👮🏽‍♀️ <b>Add</b> @{0}-bot as <b>Administrator</b> through your channel settings: [👤Add Admin]\n\n👮🏽‍♀️ <b>Option< /b> [✅ Assigning administrators] will allow you to scrape old subscribers, even if the channel has more than 200 subscribers",
    'es': "👮🏽‍♀️ <b>Agrega</b> @{0}-bot como <b>Administrador</b> a través de la configuración de tu canal: [👤Agregar administrador]\n\n👮🏽‍♀️ <b>Opción< /b> [✅ Asignar administradores] te permitirá eliminar suscriptores antiguos, incluso si el canal tiene más de 200 suscriptores.",
    'fr': "👮🏽‍♀️ <b>Ajouter</b> @{0}-bot en tant qu'<b>Administrateur</b> via les paramètres de votre chaîne : [👤Ajouter un administrateur]\n\n👮🏽‍♀️ <b>Option< /b> [✅ Affectation d'administrateurs] vous permettra de supprimer les anciens abonnés, même si la chaîne compte plus de 200 abonnés",
    'zh': "👮🏽‍♀️ 通过您的频道设置<b>添加</b> @{0}-bot 作为<b>管理员</b>： [👤添加管理员]\n\n👮🏽‍♀️ <b>选项< /b> [✅ 分配管理员] 将允许您抓取旧订阅者，即使该频道有超过 200 名订阅者",
    'ar': "👮🏽‍♀️ <b>أضف</b> @{0}-bot بصفته <b>مسؤولًا</b> من خلال إعدادات قناتك: [👤إضافة مسؤول]\n\n👮🏽‍♀️ <b>Option< /b> [✅ تعيين مسؤولين] سيسمح لك بحذف المشتركين القدامى، حتى لو كانت القناة تضم أكثر من 200 مشترك",
}
l_add_chn_txt_call = {
    'ru': "👮🏽‍♀️ Добавь @{0}-бота как Administrator через настройки своего канала: [👤Add Admin]",
    'en': "👮🏽‍♀️ Add @{0}-bot as Administrator through your channel settings: [👤Add Admin]",
    'es': "👮🏽‍♀️ Agrega @{0}-bot como administrador a través de la configuración de tu canal: [👤Agregar administrador]",
    'fr': "👮🏽‍♀️ Ajoutez @{0}-bot en tant qu'administrateur via les paramètres de votre chaîne : [👤Ajouter un administrateur]",
    'zh': "👮🏽‍♀️ 通过您的频道设置将@{0}-bot 添加为管理员：<👤添加管理员>>",
    'ar': "👮🏽‍♀️ أضف @{0}-bot كمسؤول من خلال إعدادات قناتك: [👤Add Admin]",
}
l_add_chn_button = {
    'ru': "➕ Добавить канал",
    'en': "➕ Add channel",
    'es': "➕ Agregar canal",
    'fr': "➕ Ajouter une chaîne",
    'zh': "➕ 添加频道",
    'ar': "➕ إضافة قناة",
}
l_bot_removed = {
    'ru': "🚫 @{0}-бот удален из <b>{1}</b> [id=<code>{2}</code>]",
    'en': "🚫 @{0}-bot removed from <b>{1}</b> [id=<code>{2}</code>]",
    'es': "🚫 @{0}-bot eliminado de <b>{1}</b> [id=<code>{2}</code>]",
    'fr': "🚫 @{0}-bot supprimé de <b>{1}</b> [id=<code>{2}</code>]",
    'zh': "🚫 @{0}-bot 已从 <b>{1}</b> [id=<code>{2}</code>] 中删除",
    'ar': "🚫 @{0}-تمت إزالة الروبوت من <b>{1}</b> [id=<code>{2}</code>]",
}

l_chn_config = {
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自动禁止",
        'ar': "الحظر التلقائي",
    },
    ("cdecor", "🪄", "☐"): {
        'ru': "Авто-декор",
        'en': "Auto-decor",
        'es': "Autodecoración",
        'fr': "Décoration automatique",
        'zh': "自动装饰",
        'ar': "ديكور تلقائي",
    },
    ("csystem", "👣", "☐"): {
        'ru': "Сообщ системные",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系统消息",
        'ar': "رسائل النظام",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自动发布",
        'ar': "النشر التلقائي",
    },
    ("cneuro", "🦾", "☐"): {
        'ru': "Нейро-постинг",
        'en': "Neuro-posting",
        'es': "Neuropublicación",
        'fr': "Neuro-posting",
        'zh': "神经张贴",
        'ar': "النشر العصبي",
    },

    ("cmember", "👥", "☐"): {
        'ru': "Подписчики",
        'en': "Subscribers",
        'es': "Suscriptores",
        'fr': "Les abonnés",
        'zh': "订阅者",
        'ar': "مشتركين",
    },
    ("ccheck", "👮🏽", "☐"): {
        'ru': "Запрос на вступление",
        'en': "Request to join",
        'es': "Solicitud de ingreso",
        'fr': "Demande d'adhésion",
        'zh': "请求加入",
        'ar': "طلب الانضمام",
    },
}
l_to_default = {
    'ru': "✖️Сброс",
    'en': "✖️Reset",
    'es': "✖️Restablecer",
    'fr': "✖️Réinitialiser",
    'zh': "✖️重置",
    'ar': "✖️إعادة تعيين",
}
l_remove_channel = {
    'ru': "🚫Убрать канал",
    'en': "🚫Remove channel",
    'es': "🚫Eliminar canal",
    'fr': "🚫Supprimer la chaîne",
    'zh': "🚫删除频道",
    'ar': "🚫إزالة القناة",
}
l_show_channels = {
    'ru': "👩🏽‍💻 <b>Добавленные каналы</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Added channels</b>\n\n[commands/cmd]",
    'es': "👩🏽‍💻 <b>Canales agregados</b>\n\n[commands/cmd]",
    'fr': "👩🏽‍💻 <b>Canaux ajoutés</b>\n\n[commands/cmd]",
    'zh': "👩🏽‍💻 <b>添加频道</b>\n\n[commands/cmd]",
    'ar': "👩🏽‍💻 <b>القنوات المضافة</b>\n\n[commands/cmd]",
}
l_show_settings = {
    'ru': "⚙️ <b>Выбери</b> опцию для /cmd <i>настройки</i> [<b>{0}</b>] {1}",
    'en': "⚙️ <b>Select</b> option for /cmd <i>settings</i> [<b>{0}</b>] {1}",
    'es': "⚙️ <b>Seleccione</b> la opción para /cmd <i>configuración</i> [<b>{0}</b>] {1}",
    'fr': "⚙️ <b>Sélectionnez</b> l'option pour /cmd <i>paramètres</i> [<b>{0}</b>] {1}",
    'zh': "⚙️ <b>选择</b> /cmd <i>设置</i>选项 [<b>{0}</b>] {1}",
    'ar': "⚙️ <b>حدد</b> خيار /cmd <i>الإعدادات</i> [<b>{0}</b>] {1}",
}
l_chat_join_request_handler = {
    'ru': "👮🏽 {0}, ты отправил(а) заявку на вступление в <b>{1}</b>\n\n👩🏽‍💻 <b>Выбери</b> <i>правильный вариант</i> в соответствии с заданием на картинке, чтобы твоя <i>заявка</i> на вступление была <b>одобрена</b>",
    'en': "👮🏽 {0}, you have sent an application to join <b>{1}</b>\n\n👩🏽‍💻 <b>Choose</b> <i>the correct option</i> in accordance with the task in the picture, so that your <i>application</i> for membership is <b>approved</b>",
    'es': "👮🏽 {0}, has enviado una solicitud para unirte a <b>{1}</b>\n\n👩🏽‍💻 <b>Elige</b> <i>la opción correcta</i> en de acuerdo con la tarea en la imagen, para que su <i>solicitud</i> de membresía sea <b>aprobada</b>",
    'fr': "👮🏽 {0}, vous avez envoyé une candidature pour rejoindre <b>{1}</b>\n\n👩🏽‍💻 <b>Choisissez</b> <i>la bonne option</i> dans conformément à la tâche illustrée, afin que votre <i>demande</i> d'adhésion soit <b>approuvée</b>",
    'zh': "👮🏽 {0}，您已发送加入<b>{1}</b>\n\n👩🏽‍💻<b>选择</b><i>正确选项</i>的申请按照图中的任务，您的<i>会员申请</i>就会<b>获得批准</b>",
    'ar': "👮🏽 {0}، لقد أرسلت طلبًا للانضمام إلى <b>{1}</b>\n\n👩🏽‍💻 <b>اختر</b> <i>الخيار الصحيح</i> في وفقًا للمهمة الموجودة في الصورة، بحيث يتم <b>الموافقة</b> على <i>طلبك</i> للحصول على العضوية.",
}
l_content_types_sub_button = {
    'ru': "👮🏽 Я подписался",
    'en': "👮🏽 I subscribed",
    'es': "👮🏽 Me suscribí",
    'fr': "👮🏽 Je me suis abonné",
    'zh': "👮🏽我订阅了",
    'ar': "👮🏽 لقد اشتركت",
}
l_content_types_subscribe = {
    'ru': "👮🏽 {0}, подпишись на {1}, чтобы твоя заявка на вступление была одобрена",
    'en': "👮🏽 {0}, subscribe to {1} so that your application to join will be approved",
    'es': "👮🏽 {0}, suscríbete a {1} para que se apruebe tu solicitud para unirte",
    'fr': "👮🏽 {0}, abonnez-vous à {1} pour que votre demande d'adhésion soit approuvée",
    'zh': "👮🏽 {0}，订阅{1}，以便您的加入申请获得批准",
    'ar': "👮🏽 {0}، اشترك في {1} حتى تتم الموافقة على طلبك للانضمام",
}
l_wait_1_min = {
    'ru': "🕐 Подожди 1мин",
    'en': "🕐 Wait 1 min",
    'es': "🕐 Espere 1 minuto",
    'fr': "🕐 Attendez 1 min",
    'zh': "🕐等待1分钟",
    'ar': "🕐 انتظر دقيقة واحدة",
}

l_creturn_answer = {
    'ru': "✖️ <b>Настройки</b> для [<b>{0}</b>] успешно сброшены!",
    'en': "✖️ <b>Settings</b> for [<b>{0}</b>] successfully reset!",
    'es': "✖️ ¡La <b>Configuración</b> para [<b>{0}</b>] se restableció correctamente!",
    'fr': "✖️ Les <b>Paramètres</b> de [<b>{0}</b>] ont été réinitialisés avec succès !",
    'zh': "✖️ [<b>{0}</b>] 的<b>设置</b>已成功重置！",
    'ar': "✖️ تمت إعادة تعيين <b>الإعدادات</b> لـ [<b>{0}</b>] بنجاح!",
}
l_cdelete_text = {
    'ru': "🚫 <b>Убрать</b> привязку бота к [<b>{0}</b>]?",
    'en': "🚫 <b>Remove</b> bot binding to [<b>{0}</b>]?",
    'es': "🚫 ¿<b>Eliminar</b> el enlace del bot a [<b>{0}</b>]?",
    'fr': "🚫 <b>Supprimer</b> la liaison du bot à [<b>{0}</b>] ?",
    'zh': "🚫 <b>删除</b>机器人与 [<b>{0}</b>] 的绑定？",
    'ar': "🚫 <b>إزالة</b> ربط الروبوت بـ [<b>{0}</b>]؟",
}
l_cdelete_answer = {
    'ru': "🚫 <b>Бот</b> успешно отсоединен от [<b>{0}</b>] и не числится его в участниках!",
    'en': "🚫 <b>Bot</b> has been successfully unlinked from [<b>{0}</b>] and is not listed as a participant!",
    'es': "🚫 <b>Bot</b> se ha desvinculado correctamente de [<b>{0}</b>] y no figura como participante.",
    'fr': "🚫 Le <b>Bot</b> a été dissocié avec succès de [<b>{0}</b>] et n'est pas répertorié comme participant !",
    'zh': "🚫 <b>机器人</b> 已成功取消与 [<b>{0}</b>] 的链接，并且未列为参与者！",
    'ar': "🚫 تم إلغاء ربط <b>الروبوت</b> بنجاح بـ [<b>{0}</b>] ولم يتم إدراجه كمشارك!",
}

l_ccheck_btn_name = {
    'ru': "✔ Я человек",
    'en': "✔ I'm human",
    'es': "✔soy humano",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人类",
    'ar': "✔ أنا إنسان",
}
l_ccheck_hello_txt = {
    'ru': "🌱 {name}, добро пожаловать в нашу <b>канал</b> {title}!",
    'en': "🌱 {name}, welcome to our <b>channel</b> {title}!",
    'es': "🌱 {name}, ¡bienvenido a nuestro <b>canal</b> {title}!",
    'fr': "🌱 {name}, bienvenue sur notre <b>chaîne</b> {title} !",
    'zh': "🌱 {name}，欢迎来到我们的<b>频道</b> {title}！",
    'ar': "🌱 {name}، مرحبًا بك في <b>قناتنا</b> {title}!",
}
l_ccheck_add_channel = {
    'ru': "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}
l_chn_already_taken = {
    'ru': "👮🏽 <b>Канал</b> [<b>{0}</b>] уже <i>администрируется</i> в @{1}-боте",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}
l_chn_subscribe_call = {
    'ru': "👩🏽‍💻 Необходима подписка на канал",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}


# region commands
l_chn_commands_handler = {
    'ru': "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<blockquote>/info информация о канале\n/stat статистика\n\n/parse [1] база подписчиков/лайков поста #1\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/channel NAME канал проверки подписки\n/transfer передача ADMIN-прав</blockquote>\n\n💨 <b>Подписка</b>: <i>{3}</i>",
    'en': "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1}\n\n/info <i>channel information</i>\n/stat <i> statistics</i>\n\n/parse [1] <i>subscriber/click base</i>\n/podcast 1 1 <i>video podcast announcement</i>\n<code>/clean< /code> <i>clearing deleted/scam accounts and [🕵🏽 Auto-ban] rules</i>\n/delete <code>FROM TO</code> <i>delete for a period</i>\ n/channel NAME <i>subscription verification channel</i>\n/transfer <i>transfer of admin rights</i>\n\n💨 <b>Subscription</b>: <i>{2}< /i>",
    'es': "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1}\n\n/info <i>información del canal</i>\n/stat <i> estadísticas </i>\n\n/parse [1] <i>base de suscriptores/clics</i>\n/podcast 1 1 <i>anuncio de podcast en vídeo</i>\n<code>/clean< /code > <i>borrar cuentas eliminadas/estafas y reglas de [🕵🏽 Prohibición automática]</i>\n/eliminar <code>DE HASTA</code> <i>eliminar por un período</i>\ n/canal NOMBRE <i>canal de verificación de suscripción</i>\n/transfer <i>transferencia de derechos de administrador</i>\n\n💨 <b>Suscripción</b>: <i>{2}< /i>",
    'fr': "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1}\n\n/info <i>informations sur la chaîne</i>\n/stat <i> statistiques </i>\n\n/parse [1] <i>abonné/clic de base</i>\n/podcast 1 1 <i>annonce de podcast vidéo</i>\n<code>/clean< /code > <i>effacer les comptes supprimés/arnaqueurs et les règles de [🕵🏽 Auto-ban]</i>\n/supprimer <code>FROM TO</code> <i>supprimer pendant une période</i>\ n/canal NOM <i>canal de vérification d'abonnement</i>\n/transfert <i>transfert des droits d'administrateur</i>\n\n💨 <b>Abonnement</b> : <i>{2}< /i>",
    'zh': "⚙️ <b>命令</b> /cmd 用于 [<b>{0}</b>] {1}\n\n/info <i>频道信息</i>\n/stat <i> 统计信息</i>\n\n/parse [1] <i>订阅者/点击量</i>\n/podcast 1 1 <i>视频播客公告</i>\n<code>/clean</code > <i>清除已删除/诈骗帐户和[🕵🏽自动禁止]规则</i>\n/delete <code>FROM TO</code> <i>删除一段时间</i>\n/channel NAME <i>订阅验证通道</i>\n/transfer <i>管理权限转让</i>\n\n💨 <b>订阅</b>：<i>{2}</i>",
    'ar': "⚙️ <b>الأوامر</b> /cmd لإحصائيات [<b>{0}</b>] {1}\n\n/info <i>معلومات القناة</i>\n/stat <i> </i>\n\n/parse [1] <i>قاعدة المشترك/النقر</i>\n/podcast 1 1 <i>إعلان بودكاست فيديو</i>\n<code>/clean< /code > <i>مسح الحسابات المحذوفة/المحتالة وقواعد [🕵🏽 الحظر التلقائي]</i>\n/حذف <code>من إلى</code> <i>حذف لفترة</i>\n/channel الاسم <i>قناة التحقق من الاشتراك</i>\n/transfer <i>نقل حقوق المسؤول</i>\n\n💨 <b>الاشتراك</b>: <i>{2}< /i>",
}
l_update_text = {
    'ru': "👩🏽‍💻 <b>Данные</b> о канале успешно обновлены:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</i>\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>Channel data</b> successfully updated:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}< /i>\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Datos del canal</b> actualizados correctamente:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}< / i>\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Données de la chaîne</b> mises à jour avec succès :\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}< / i>\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻 <b>频道数据</b>已成功更新：\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}</b> i>\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 تم تحديث <b>بيانات القناة</b> بنجاح:\n\n<b>{0}</b> [{1}]\n{2}\n<i>{3}< /<i>\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_info_restrict = {
    'ru': "запрещено\n",
    'en': "prohibited\n",
    'es': "prohibido\n",
    'fr': "interdit\n",
    'zh': "禁止\n",
    'ar': "محظور\n",
}
l_info_allow = {
    'ru': "разрешено\n",
    'en': "allowed\n",
    'es': "permitido\n",
    'fr': "autorisé\n",
    'zh': "允许\n",
    'ar': "مسموح\n",
}
l_info_protect = {
    'ru': "<b>Сохранение контента</b>: ",
    'en': "<b>Saving content</b>:",
    'es': "<b>Guardar contenido</b>:",
    'fr': "<b>Enregistrement du contenu</b> :",
    'zh': "<b>保存内容</b>：",
    'ar': "<b>حفظ المحتوى</b>:",
}
l_info_request = {
    'ru': "<b>Вступление после одобрения</b>: ",
    'en': "<b>Joining after approval</b>:",
    'es': "<b>Unirse después de la aprobación</b>:",
    'fr': "<b>Rejoindre après approbation</b> :",
    'zh': "<b>批准后加入</b>：",
    'ar': "<b>الانضمام بعد الموافقة</b>:",
}
l_info_send = {
    'ru': "<b>Возможность писать после вступления</b>: ",
    'en': "<b>Possibility to write after the introduction</b>:",
    'es': "<b>Posibilidad de escribir después de la introducción</b>:",
    'fr': "<b>Possibilité d'écrire après l'introduction</b> :",
    'zh': "<b>可以在介绍后写</b>：",
    'ar': "<b>إمكانية الكتابة بعد المقدمة</b>:",
}
l_info_subscribe = {
    'ru': "<b>Проверка 💨Подписки при вступлении в канал</b>: ",
    'en': "<b>Checking 💨Subscriptions when joining a channel</b>:",
    'es': "<b>Comprobación de 💨Suscripciones al unirse a un canal</b>:",
    'fr': "<b>Vérification des 💨Abonnements lorsque vous rejoignez une chaîne</b> :",
    'zh': "<b>加入频道时检查💨订阅</b>：",
    'ar': "<b>التحقق من 💨الاشتراكات عند الانضمام إلى قناة</b>:",
}
l_info_cmd = {
    'ru': "⚙️ <b>Команды</b> /cmd",
    'en': "⚙️ <b>Commands</b> /cmd",
    'es': "⚙️ <b>Comandos</b> /cmd",
    'fr': "⚙️ <b>Commandes</b> /cmd",
    'zh': "⚙️ <b>命令</b> /cmd",
    'ar': "⚙️ <b>الأوامر</b> /cmd",
}

l_change_chn_info = {
    'ru': "Изменение профиля канала",
    'en': "Changing a Channel Profile",
    'es': "Cambiar el perfil de un canal",
    'fr': "Modification d'un profil de chaîne",
    'zh': "更改频道配置文件",
    'ar': "تغيير ملف تعريف القناة",
}
l_send_messages = {
    'ru': "Отправка сообщений",
    'en': "Sending messages",
    'es': "Enviando mensajes",
    'fr': "Envoi de messages",
    'zh': "发送消息",
    'ar': "إرسال الرسائل",
}
l_info_reactions = {
    'ru': "Допуск emoji-реакций",
    'en': "Allowing emoji reactions",
    'es': "Permitir reacciones emoji",
    'fr': "Autoriser les réactions emoji",
    'zh': "允许表情符号反应",
    'ar': "السماح بتفاعلات الرموز التعبيرية",
}
l_admins = {
    'ru': "Администраторы",
    'en': "Administrators",
    'es': "Administradores",
    'fr': "Administrateurs",
    'zh': "管理员",
    'ar': "المسؤولين",
}

l_info_invite_admins = {
    'ru': "Назначение администраторов",
    'en': "Inviting other admins to",
    'es': "Invitar a otros administradores a",
    'fr': "Inviter d'autres administrateurs à",
    'zh': "邀请其他管理员",
    'ar': "دعوة المشرفين الآخرين إلى",
}
l_chn_info_start1 = {
    'ru': "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "👩🏽‍💻 <b>Information</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'es': "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participante]{5}{6}{7}",
    'fr': "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'zh': "👩🏽‍💻<b>信息</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3 }</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    'ar': "👩🏽‍💻 <b>المعلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>، <u>{4}</u> مشارك]{5}{6}{7}",
}
l_chn_stat_start1 = {
    'ru': "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'es': "👩🏽‍💻 <b>Análisis</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participante]{5}{6}{7}",
    'fr': "👩🏽‍💻 <b>Analytics</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'zh': "👩🏽‍💻<b>分析</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3 }</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    'ar': "👩🏽‍💻 <b>التحليلات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>، <u>{4}</u> مشارك]{5}{6}{7}",
}
l_chn_stat_start2 = {
    'ru': "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанная группа</b>: <code>{2}</code>\n",
    'en': "\n<b>Link</b>: {0}\n<b>Description</b>: {1}\n<b>Linked group</b>: <code>{2}</code>\n",
    'es': "\n<b>Enlace</b>: {0}\n<b>Descripción</b>: {1}\n<b>Grupo vinculado</b>: <code>{2}</code>\norte",
    'fr': "\n<b>Lien</b> : {0}\n<b>Description</b> : {1}\n<b>Groupe lié</b> : <code>{2}</code>\n",
    'zh': "\n<b>链接</b>：{0}\n<b>说明</b>：{1}\n<b>链接的群组</b>：<code>{2}</code>\n",
    'ar': "\n<b>الرابط</b>: {0}\n<b>الوصف</b>: {1}\n<b>المجموعة المرتبطة</b>: <code>{2}</code> \ن",
}
l_chn_stat_start3 = {
    'ru': "\n<b>ID последнего поста</b>: {0}\n<b>Посты</b>: {1}\n<b>Реакции</b>: {2}\n<b>Просмотры</b>: {3}\n<b>кѻмментарии</b>: {4}\n<b>$кэштеги</b>: {5}\n<b>#hashtag</b>: {6}\n",
    'en': "\n<b>Last post ID</b>: {0}\n<b>Posts</b>: {1}\n<b>Reactions</b>: {2}\n<b>Views </b>: {3}\n<b>Comments</b>: {4}\n<b>$cashtags</b>: {5}\n<b> #hashtags </b>: { 6}\n",
    'es': "\n<b>ID de la última publicación</b>: {0}\n<b>Publicaciones</b>: {1}\n<b>Reacciones</b>: {2}\n<b>Vistas </b>: {3}\n<b>Comentarios</b>: {4}\n<b>$cashtags</b>: {5}\n<b> #hashtags </b>: { 6}\n",
    'fr': "\n<b>ID du dernier message</b> : {0}\n<b>Messages</b> : {1}\n<b>Réactions</b> : {2}\n<b>Vues </b> : {3}\n<b>Commentaires</b> : {4}\n<b>$cashtags</b> : {5}\n<b> #hashtags </b> : { 6}\n",
    'zh': "\n<b>最后帖子 ID</b>：{0}\n<b>帖子</b>：{1}\n<b>反应</b>：{2}\n<b>观看次数</b>：{3}\n<b>评论</b>：{4}\n<b>$cashtags</b>：{5}\n<b> #hashtags </b>：{ 6}\n",
    'ar': "\n<b>معرف آخر مشاركة</b>: {0}\n<b>المشاركات</b>: {1}\n<b>التفاعلات</b>: {2}\n<b>المشاهدات </b>: {3}\n<b>التعليقات</b>: {4}\n<b>$cashtags</b>: {5}\n<b> #hashtags </b>: { 6}\ن",
}
l_top_hashtags = {
    'ru': "\n<b>Топ #hashtags</b>:\n{0}\n",
    'en': "\n<b>Top #hashtags </b>:\n{0}\n",
    'es': "\n<b> #hashtags principales </b>:\n{0}\n",
    'fr': "\n<b>Meilleurs #hashtags </b> :\n{0}\n",
    'zh': "\n<b>热门#hashtags </b>：\n{0}\n",
    'ar': "\n<b>أهم #hashtags </b>:\n{0}\n",
}

l_transfer_start = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} должен /start-запустить @{1}",
    'en': "👩🏽‍💻 <b>User</b> {0} must /start-run @{1}",
    'es': "👩🏽‍💻 El <b>Usuario</b> {0} debe /iniciar-ejecutar @{1}",
    'fr': "👩🏽‍💻 <b>L'utilisateur</b> {0} doit /start-run @{1}",
    'zh': "👩🏽‍💻 <b>用户</b> {0} 必须 /start-run @{1}",
    'ar': "👩🏽‍💻 <b>المستخدم</b> {0} يجب /بدء التشغيل @{1}",
}
l_transfer_admin = {
    'ru': "👩🏽‍💻 <b>Пользователь</b> {0} должен быть <b>администратором</b> в <b>{1}</b>",
    'en': "👩🏽‍💻 <b>User</b> {0} must be an <b>administrator</b> in <b>{1}</b>",
    'es': "👩🏽‍💻 El <b>Usuario</b> {0} debe ser un <b>administrador</b> en <b>{1}</b>",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> {0} doit être un <b>administrateur</b> dans <b>{1}</b>",
    'zh': "👩🏽‍💻 <b>用户</b> {0} 必须是 <b>{1}</b> 中的<b>管理员</b>",
    'ar': "👩🏽‍💻 <b>المستخدم</b> {0} يجب أن يكون <b>مسؤولًا</b> في <b>{1}</b>",
}
l_transfer_transfer = {
    'ru': "👩🏽‍💻 <b>Передать</b> <b>admin</b>-права на <b>{0}</b> пользователю {1} в @{2}-боте?",
    'en': "👩🏽‍💻 <b>Transfer</b> <b>admin</b>-rights to <b>{0}</b> to user {1} in @{2}-bot?",
    'es': "👩🏽‍💻 ¿<b>Transferir</b> derechos de <b>admin</b> a <b>{0}</b> al usuario {1} en @{2}-bot?",
    'fr': "👩🏽‍💻 <b>Transférer</b> les droits <b>admin</b> à <b>{0}</b> à l'utilisateur {1} dans @{2}-bot ?",
    'zh': "👩🏽‍💻 <b>将 <b>{0}</b> 的权限转让给 @{2}-bot 中的用户 {1}？",
    'ar': "👩🏽‍💻 <b>نقل</b> <b>المشرف</b>-الحقوق إلى <b>{0}</b> إلى المستخدم {1} في @{2}-bot؟",
}
l_transfer_text = {
    'ru': "👩🏽‍💻 <b>Для</b> передачи admin-прав канала в @{0}-боте используй команду:\n/transfer ID-ПОЛЬЗОВАТЕЛЯ, где пользователь: администратор канала и участник @{0}-бота (/id)\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👩🏽‍💻 <b>To</b> transfer channel admin rights to @{0}-bot, use the command:\n/transfer USER-ID, where user: channel administrator and @{0}-bot member (/ id)\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👩🏽‍💻 <b>Para</b> transferir derechos de administrador del canal a @{0}-bot, use el comando:\n/transfer USER-ID, donde usuario: administrador del canal y miembro de @{0}-bot ( / id)\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "👩🏽‍💻 <b>Pour</b> transférer les droits d'administrateur de chaîne vers @{0}-bot, utilisez la commande :\n/transfer USER-ID, où utilisateur : administrateur de chaîne et membre de @{0}-bot ( / id)\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "👩🏽‍💻<b>要将频道管理员权限转移给@{0}-bot，请使用命令：\n/transfer USER-ID，其中用户：频道管理员和@{0}-bot成员（ / id)\n\n⚙️ <b>命令</b> /cmd",
    'ar': "👩🏽‍💻 <b>ل</b> نقل حقوق مسؤول القناة إلى @{0}-bot، استخدم الأمر:\n/transfer USER-ID، حيث المستخدم: مسؤول القناة و@{0}-bot member ( /id)\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_transfer_done_to = {
    'ru': "👩🏽‍💻 <b>Admin</b>-права на [<b>{0}</b>] успешно переданы {1}",
    'en': "👩🏽‍💻 <b>Admin</b>-rights to [<b>{0}</b>] successfully transferred to {1}",
    'es': "👩🏽‍💻 Los derechos de <b>Administrador</b> de [<b>{0}</b>] se transfirieron correctamente a {1}",
    'fr': "👩🏽‍💻 <b>Droits d'administrateur</b> sur [<b>{0}</b>] transférés avec succès à {1}",
    'zh': "👩🏽‍💻 <b>管理员</b>-[<b>{0}</b>] 的权限已成功转移至 {1}",
    'ar': "👩🏽‍💻 <b>المشرف</b>-تم نقل حقوق [<b>{0}</b>] بنجاح إلى {1}",
}
l_transfer_done_from = {
    'ru': "👩🏽‍💻 <b>Admin</b>-права на [<b>{0}</b>] успешно получены от {1}",
    'en': "👩🏽‍💻 <b>Admin</b>-rights to [<b>{0}</b>] successfully obtained from {1}",
    'es': "👩🏽‍💻 Derechos de <b>Administrador</b> para [<b>{0}</b>] obtenidos exitosamente de {1}",
    'fr': "👩🏽‍💻 <b>Droits d'administrateur</b> sur [<b>{0}</b>] obtenus avec succès auprès de {1}",
    'zh': "👩🏽‍💻<b>管理员</b>-已从 {1} 成功获得 [<b>{0}</b>] 的权限",
    'ar': "👩🏽‍💻 <b>المشرف</b>-تم الحصول على حقوق [<b>{0}</b>] بنجاح من {1}",
}
l_chn_check = {
    'ru': "👩🏽‍💻 <b>Добавь</b> @{0}-бота в канал для проверки подписки на него. Отправь мне корректную ссылку на канал:",
    'en': "👩🏽‍💻 <b>Add</b> @{0}-bot to the channel to check your subscription to it. Send me the correct link to the channel:",
    'es': "👩🏽‍💻 <b>Agrega</b> @{0}-bot al canal para verificar tu suscripción. Envíame el enlace correcto al canal:",
    'fr': "👩🏽‍💻 <b>Ajoutez</b> @{0}-bot à la chaîne pour vérifier votre abonnement. Envoyez-moi le bon lien vers la chaîne :",
    'zh': "👩🏽‍💻 <b>添加</b> @{0}-bot 到频道以检查您对该频道的订阅。向我发送正确的频道链接：",
    'ar': "👩🏽‍💻 <b>أضف</b> @{0}-bot إلى القناة للتحقق من اشتراكك فيها. أرسل لي الرابط الصحيح للقناة:",
}
l_podcast_rights = {
    'ru': "🎥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n[✅ Управление трансляциями]\n\n🕚Подожди 1min",
    'en': "🎥 <b>In settings</b> [Administrators] enable the option for @{0}-bot:\n[✅ Assigning administrators]\n[✅ Managing broadcasts]\n\n🕚Wait 1min",
    'es': "🎥 <b>En configuración</b> [Administradores] habilita la opción para @{0}-bot:\n[✅ Asignar administradores]\n[✅ Administrar transmisiones]\n\n🕚Espera 1 minuto",
    'fr': "🎥 <b>Dans les paramètres</b> [Administrateurs] activez l'option pour @{0}-bot :\n[✅ Attribuer des administrateurs]\n[✅ Gérer les diffusions]\n\n🕚Attendez 1 min",
    'zh': "🎥 <b>在设置中</b> [管理员]启用@{0}-bot的选项：\n[✅分配管理员]\n[✅管理广播]\n\n🕚等待1分钟",
    'ar': "🎥 <b>في الإعدادات</b> [المسؤولون] قم بتمكين خيار @{0}-bot:\n[✅ تعيين المسؤولين]\n[✅ إدارة عمليات البث]\n\n🕚انتظر دقيقة واحدة",
}
l_podcast_handler = {
    'ru': "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> [/podcast d h] каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /podcast {0}\n\n<code>/podcast 1 1</code>  ежедневный видео-анонс длительностью 1 час\n<code>/podcast 0</code>    отключение опции\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 <b>Auto-announcement</b> <i>video podcast</i> [/podcast d h] every <u>d</u>-day (1-31) on <u>h</u >-hours (1-168). Current value: /podcast {0}\n\n<code>/podcast 1 1</code> daily video announcement lasting 1 hour\n<code>/podcast 0</code> disable option\n\n⚙️ < b>Commands</b> /cmd",
    'es': "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i> [/podcast d h] cada <u>d</u> día (1-31) el <u>h</u>-horas (1-168). Valor actual: /podcast {0}\n\n<code>/podcast 1 1</code> anuncio de vídeo diario que dura 1 hora\n<code>/podcast 0</code> opción de desactivar\n\n⚙️ < b >Comandos</b> /cmd",
    'fr': "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> [/podcast d h] tous les <u>jours</u> (1-31) le <u>h</u >-heures (1-168). Valeur actuelle : /podcast {0}\n\n<code>/podcast 1 1</code> annonce vidéo quotidienne d'une durée d'une heure\n<code>/podcast 0</code> option de désactivation\n\n⚙️ < b >Commandes</b> /cmd",
    'zh': "🎥 <b>自动公告</b> <i>视频播客</i> [/podcast d h] 每 <u>d</u> 天 (1-31) <u>h</u >-小时 (1-168)。当前值：/podcast {0}\n\n<code>/podcast 1 1</code> 每日视频公告，持续 1 小时\n<code>/podcast 0</code> 禁用选项\n\n⚙️ < b >命令</b> /cmd",
    'ar': "🎥 <b>إعلان تلقائي</b> <i>فيديو بودكاست</i> [/podcast d h] كل <u>d</u>-يوم (1-31) في <u>h</u >-الساعات (1-168). القيمة الحالية: /podcast {0}\n\n<code>/podcast 1 1</code> إعلان فيديو يومي يستمر لمدة ساعة واحدة\n<code>/podcast 0</code> خيار التعطيل\n\n⚙️ < b >الأوامر</b> /cmd",
}
l_podcast_on = {
    'ru': "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i>: каждый <u>{0}</u> день на <u>{1}</u> часов\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 <b>Auto-announcement</b> <i>video podcast</i>: every <u>{0}</u> day for <u>{1}</u> hours\n\n⚙️ <b>Commands</b> /cmd",
    'es': "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i>: cada <u>{0}</u> día durante <u>{1}</u> horas\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> : tous les <u>{0}</u> jours pendant <u>{1}</u> heures\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "🎥 <b>自动公告</b> <i>视频播客</i>：每天 <u>{0}</u> 一次，持续 <u>{1}</u> 小时\n\n⚙️ <b>命令</b> /cmd",
    'ar': "🎥 <b>إعلان تلقائي</b> <i>فيديو بودكاست</i>: كل <u>{0}</u> يوم لمدة <u>{1}</u> ساعة\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_podcast_off = {
    'ru': "🎥 <b>Авто-анонс</b> <i>видео-подкаста</i> отключен\n\n⚙️ <b>Команды</b> /cmd",
    'en': "🎥 <b>Auto-announcement</b> <i>video podcast</i> disabled\n\n⚙️ <b>Commands</b> /cmd",
    'es': "🎥 <b>Anuncio automático</b> <i>podcast de vídeo</i> deshabilitado\n\n⚙️ <b>Comandos</b> /cmd",
    'fr': "🎥 <b>Annonce automatique</b> <i>podcast vidéo</i> désactivé\n\n⚙️ <b>Commandes</b> /cmd",
    'zh': "🎥 <b>自动播报</b> <i>视频播客</i>已禁用\n\n⚙️ <b>命令</b> /cmd",
    'ar': "🎥 <b>الإعلان التلقائي</b> <i>فيديو بودكاست</i> معطل\n\n⚙️ <b>الأوامر</b> /cmd",
}
l_podcast_start = {
    'ru': "👩🏽‍💻 Подкаст",
    'en': "👩🏽‍💻 Podcast",
    'es': "👩🏽‍💻 Pódcast",
    'fr': "👩🏽‍💻Podcast",
    'zh': "👩🏽‍💻播客",
    'ar': "👩🏽‍💻 بودكاست",
}

l_ban_users_start = {
    'ru': "👩🏽‍💻 <b>Очистка</b> запущена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u>",
    'en': "👩🏽‍💻 <b>Cleaning</b> has started. <b>Current</b> number of users in the database: <u>{0}</u>",
    'es': "👩🏽‍💻 La <b>limpieza</b> ha comenzado. Número <b>actual</b> de usuarios en la base de datos: <u>{0}</u>",
    'fr': "👩🏽‍💻 Le <b>nettoyage</b> a commencé. <b>Nombre actuel</b> d'utilisateurs dans la base de données : <u>{0}</u>",
    'zh': "👩🏽‍💻<b>清洁</b>已经开始。数据库中<b>当前</b>用户数：<u>{0}</u>",
    'ar': "👩🏽‍💻 بدأ <b>التنظيف</b>. <b>العدد الحالي</b> للمستخدمين في قاعدة البيانات: <u>{0}</u>",
}
l_ban_users_stop = {
    'ru': "👩🏽‍💻 <b>Очистка</b> завершена. <b>Текущее</b> количество пользователей в базе: <u>{0}</u> (-{1})",
    'en': "👩🏽‍💻 <b>Cleaning</b> is complete. <b>Current</b> number of users in the database: <u>{0}</u> (-{1})",
    'es': "👩🏽‍💻 La <b>limpieza</b> está completa. Número <b>actual</b> de usuarios en la base de datos: <u>{0}</u> (-{1})",
    'fr': "👩🏽‍💻 <b>Le nettoyage</b> est terminé. <b>Nombre actuel</b> d'utilisateurs dans la base de données : <u>{0}</u> (-{1})",
    'zh': "👩🏽‍💻<b>清洁</b>完成。数据库中<b>当前</b>用户数：<u>{0}</u> (-{1})",
    'ar': "👩🏽‍💻 اكتمل <b>التنظيف</b>. <b>العدد الحالي</b> للمستخدمين في قاعدة البيانات: <u>{0}</u> (-{1})",
}
l_chn_ccheck_handler = {
    'ru': "👮🏽 <b>Жми</b> на ✅/🔘, чтобы <b>переключить</b> тип <i>проверки</i> пользователя при <u>вступлении</u> по сгенерированной ссылке: {0} (только для ЧАСТНЫХ каналов)\n\n<blockquote>👩🏽‍💻 Для <b>проверки подписки</b> на другой канал <i>добавь</i> @{1}-бота в канал и выполни команду: <code>/channel {2}</code>\n\n👩🏽‍💻 Для <i>защиты от атаки</i> на канал включи режим <b>анти-рейд</b> (блокировка <u>всех</u> вступающих)</blockquote>",
    'en': "👮🏽 <b>Press</b> on ✅/🔘 to <b>switch</b> the type of <i>verification</i> of the user when <u>entering</u> via the generated link: {0} (only for PRIVATE channels)\n\n👩🏽‍💻 To <b>check subscription</b> to another channel <i>add</i> @{1}-bot to the channel and run the command: /channel { 2}\n\n👩🏽‍💻 To <i>protect against attacks</i> on the channel, turn on the <b>anti-raid</b> mode (blocking <u>everyone</u> entering)",
    'es': "👮🏽 <b>Presiona</b> ✅/🔘 para <b>cambiar</b> el tipo de <i>verificación</i> del usuario al <u>ingresar</u> a través del enlace generado : {0} (solo para canales PRIVADOS)\n\n👩🏽‍💻 Para <b>verificar suscripción</b> a otro canal <i>agregar</i> @{1}-bot al canal y ejecutar el comando: /canal { 2}\n\n👩🏽‍💻 Para <i>proteger contra ataques</i> en el canal, active el modo <b>anti-raid</b> (bloqueando <u> todos</u> entrando)",
    'fr': "👮🏽 <b>Appuyez</b> sur ✅/🔘 pour <b>changer</b> le type de <i>vérification</i> de l'utilisateur lors de la <u>entrée</u> via le lien généré : {0} (uniquement pour les chaînes PRIVÉES)\n\n👩🏽‍💻 Pour <b>vérifier l'abonnement</b> à une autre chaîne, <i>ajoutez</i> @{1}-bot à la chaîne et exécutez la commande : /channel { 2}\n\n👩🏽‍💻 Pour <i>vous protéger contre les attaques</i> sur la chaîne, activez le mode <b>anti-raid</b> (bloquant <u> tout le monde</u> entrant)",
    'zh': "👮🏽通过生成的链接<u>进入</u>时<b>按</b>✅/🔘<b>切换</b>用户的<i>验证</i>类型：{0}（仅适用于私人频道）\n\n👩🏽‍💻 要<b>检查订阅</b>另一个频道<i>添加</i>@{1}-bot到频道并运行命令：/channel { 2}\n\n👩🏽‍💻 要<i>防止频道上的攻击</i>，请开启<b>反袭击</b>模式（阻止<u>每个人</u>进入）",
    'ar': "👮🏽 <b>اضغط</b> على ✅/🔘 <b>لتبديل</b> نوع <i>التحقق</i> للمستخدم عند <u>الدخول</u> عبر الرابط الذي تم إنشاؤه : {0} (للقنوات الخاصة فقط)\n\n👩🏽‍💻 <b>للتحقق من الاشتراك</b> في قناة أخرى <i>أضف</i> @{1}-bot إلى القناة وقم بتشغيله الأمر: /channel { 2}\n\n👩🏽‍💻 <i>للحماية من الهجمات</i> على القناة، قم بتشغيل وضع <b>مكافحة الغارة</b> (حظر <u> الجميع</u> يدخلون)",
}
l_ccheck_call = {
    'ru': "👮🏽 Для проверки подписки необходимо добавить @{0}-бота в дополнительный канал и выполнить команду:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 To check the subscription, you need to add @{0}-bot to an additional channel and run the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para verificar la suscripción, debe agregar @{0}-bot a un canal adicional y ejecutar el comando:\n\n/channel ENLACE AL CANAL",
    'fr': "👮🏽 Pour vérifier l'abonnement, vous devez ajouter @{0}-bot à une chaîne supplémentaire et exécuter la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要检查订阅情况，您需要将 @{0}-bot 添加到其他频道并运行命令：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 للتحقق من الاشتراك، يلزمك إضافة @{0}-bot إلى قناة إضافية وتشغيل الأمر:\n\n/channel LINK TO CHANNEL",
}
l_ccheck_call2 = {
    'ru': "👮🏽 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Удаление сообщ]\n[✅ Блокировка польз]\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the [Administrators] settings, enable the option for @{0}-bot:\n[✅ Deleting messages]\n[✅ Blocking users]\n[✅ Adding a member]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Administradores], habilite la opción para @{0}-bot:\n[✅ Eliminar mensajes]\n[✅ Bloquear usuarios]\n[✅ Agregar un miembro]\n\n🕚Espera 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Administrateurs], activez l'option pour @{0}-bot :\n[✅ Supprimer des messages]\n[✅ Bloquer des utilisateurs]\n[✅ Ajouter un membre]\n\n🕚Attendez 1 min",
    'zh': "👮🏽 在[管理员]设置中，启用@{0}-bot选项：\n[✅删除消息]\n[✅阻止用户]\n[✅添加成员]\n\n🕚等待1分钟",
    'ar': "👮🏽 في إعدادات [المسؤولين]، قم بتمكين خيار @{0}-bot:\n[✅ حذف الرسائل]\n[✅ حظر المستخدمين]\n[✅ إضافة عضو]\n\n🕚انتظر دقيقة واحدة",
}
l_ccheck_chn_finish = {
    'ru': "👮🏽 <b>{0}</b>, <b>добро пожаловать</b>:\n\n{1}",
    'en': "👮🏽 <b>{0}</b>, <b>welcome</b>:\n\n{1}",
    'es': "👮🏽 <b>{0}</b>, <b>bienvenido</b>:\n\n{1}",
    'fr': "👮🏽 <b>{0}</b>, <b>bienvenue</b> :\n\n{1}",
    'zh': "👮🏽 <b>{0}</b>，<b>欢迎</b>：\n\n{1}",
    'ar': "👮🏽 <b>{0}</b>، <b>مرحبًا</b>:\n\n{1}",
}
l_ccheck_free_on = {
    'ru': "✅☑Вкл свободный вход",
    'en': "✅☑Free entry included",
    'es': "✅☑Entrada gratuita incluida",
    'fr': "✅☑Entrée gratuite incluse",
    'zh': "✅☑免费入场",
    'ar': "✅☑الدخول مجاني",
}
l_ccheck_free_off = {
    'ru': "🔘️☐Выкл свободный вход",
    'en': "🔘️☐Off free entry",
    'es': "🔘️☐Entrada gratuita",
    'fr': "🔘️☐Off entrée gratuite",
    'zh': "🔘️️免费入场",
    'ar': "🔘️☐الدخول مجاني",
}
l_ccheck_button_on = {
    'ru': "✅☑Вкл нажатие на кнопку",
    'en': "✅☑On by pressing a button",
    'es': "✅☑Encendido presionando un botón",
    'fr': "✅☑Activé en appuyant sur un bouton",
    'zh': "✅☑按下按钮即可开启",
    'ar': "✅☑يتم التشغيل بالضغط على زر",
}
l_ccheck_button_off = {
    'ru': "🔘️☐Выкл нажатие на кнопку",
    'en': "🔘️☐Turn off by pressing the button",
    'es': "🔘️☐Apaga presionando el botón",
    'fr': "🔘️☐Éteignez en appuyant sur le bouton",
    'zh': "🔘️️按按钮关闭",
    'ar': "🔘️☐إيقاف التشغيل بالضغط على الزر",
}
l_ccheck_subscribe_on = {
    'ru': "✅☑Вкл подписку",
    'en': "✅☑Include subscription",
    'es': "✅☑Incluye suscripción",
    'fr': "✅☑Inclure l'abonnement",
    'zh': "✅☑包括订阅",
    'ar': "✅☑ تضمين الاشتراك",
}
l_ccheck_subscribe_off = {
    'ru': "🔘☐Выкл подписку",
    'en': "🔘☐Turn off subscription",
    'es': "🔘☐Desactivar suscripción",
    'fr': "🔘☐Désactiver l'abonnement",
    'zh': "🔘☐关闭订阅",
    'ar': "🔘☐ قم بإيقاف الاشتراك",
}
l_ccheck_eq_on = {
    'ru': "✅☑Вкл решение уравнения",
    'en': "✅☑Includes solving equations",
    'es': "✅☑Incluye resolución de ecuaciones",
    'fr': "✅☑Comprend la résolution d'équations",
    'zh': "✅☑包括解方程",
    'ar': "✅☑ يشمل حل المعادلات",
}
l_ccheck_eq_off = {
    'ru': "🔘️☐Выкл решение уравнения",
    'en': "🔘️☐Off equation solution",
    'es': "🔘️☐Solución fuera de ecuación",
    'fr': "🔘️☐Solution hors équation",
    'zh': "🔘️️Off 方程解",
    'ar': "🔘️☐حل المعادلة خارج",
}
l_ccheck_captcha_on = {
    'ru': "✅☑Вкл решение капчи",
    'en': "✅☑Includes captcha solution",
    'es': "✅☑Incluye solución captcha",
    'fr': "✅☑Comprend une solution captcha",
    'zh': "✅☑包括验证码解决方案",
    'ar': "✅☑يتضمن حل كلمة التحقق",
}
l_ccheck_captcha_off = {
    'ru': "🔘️☐Выкл решение капчи",
    'en': "🔘️☐Turn off captcha solution",
    'es': "🔘️☐Desactivar la solución captcha",
    'fr': "🔘️☐Désactivez la solution captcha",
    'zh': "🔘️☐关闭验证码解决方案",
    'ar': "🔘️☐ قم بإيقاف تشغيل حل captcha",
}
l_ccheck_request_on = {
    'ru': "✅☑Вкл подачу заявки",
    'en': "✅☑Includes application submission",
    'es': "✅☑Incluye envío de solicitud",
    'fr': "✅☑Comprend la soumission de la candidature",
    'zh': "✅☑包括提交申请",
    'ar': "✅☑يتضمن تقديم الطلب",
}
l_ccheck_request_off = {
    'ru': "🔘️☐Выкл подачу заявки",
    'en': "🔘️☐Turn off application submission",
    'es': "🔘️☐Desactivar envío de solicitudes",
    'fr': "🔘️☐Désactivez la soumission des candidatures",
    'zh': "🔘️☐关闭申请提交",
    'ar': "🔘️☐إيقاف تقديم الطلب",
}
l_ccheck_antiraid_on = {
    'ru': "✅☑Вкл анти-рейд",
    'en': "✅☑Anti-raid on",
    'es': "✅☑Anti-raid en",
    'fr': "✅☑Anti-raid activé",
    'zh': "✅☑防袭",
    'ar': "✅☑مضاد للغارات",
}
l_ccheck_antiraid_off = {
    'ru': "🔘️☐Выкл анти-рейд",
    'en': "🔘️☐Disable anti-raid",
    'es': "🔘️☐Desactivar anti-raid",
    'fr': "🔘️☐Désactiver l'anti-raid",
    'zh': "🔘️☐禁用防袭击",
    'ar': "🔘️☐تعطيل مكافحة الغارة",
}

l_chn_graph_yes = {
    'ru': "👩🏽‍💻 <b>Экстра</b>-статистика канала за неделю [{0}]\n\n▪️ Подписчики: {1} ({2}{3})\n▪️ Просмотры: {4} ({5}{6})\n▪️ Поделиться: {7} ({8}{9})\n▪️ Уведомления у {10}% подписчиков\n",
    'en': "👩🏽‍💻 <b>Extra</b>-channel statistics for the week [{0}]\n\n▪️ Subscribers: {1} ({2}{3})\n▪️ Views: {4} ({ 5}{6})\n▪️ Share: {7} ({8}{9})\n▪️ Notifications for {10}% of subscribers\n",
    'es': "👩🏽‍💻 Estadísticas del canal <b>extra</b> para la semana [{0}]\n\n▪️ Suscriptores: {1} ({2}{3})\n▪️ Vistas: {4} ( { 5}{6})\n▪️ Compartir: {7} ({8}{9})\n▪️ Notificaciones para el {10}% de los suscriptores\n",
    'fr': "👩🏽‍💻 Statistiques <b>extra</b> des chaînes pour la semaine [{0}]\n\nwithout { 5}{6})\nnoyer Partage : {7} ({8}{9})\nnoyaux Notifications pour {10} % des abonnés\n",
    'zh': "👩🏽‍💻 <b>额外</b>-本周 [{0}]\n\n▪️ 订阅者：{1} ({2}{3})\n▪️ 观看次数：{4} ( { 5}{6})\n▪️ 分享：{7} ({8}{9})\n▪️ 针对 {10}% 订阅者的通知\n",
    'ar': "👩🏽‍💻 <b>إضافية</b>-إحصائيات القناة لهذا الأسبوع [{0}]\n\n▪️ المشتركون: {1} ({2}{3})\n▪️ المشاهدات: {4} ( { 5}{6})\n▪️ مشاركة: {7} ({8}{9})\n▪️ إشعارات لـ {10}% من المشتركين\n",
}
l_chn_graph_no = {
    'ru': "👩🏽‍💻 <b>Вкл</b> [✅ Назначение администраторов] для @{0}, чтобы вывести <b>экстра</b>-графику канала за неделю",
    'en': "👩🏽‍💻 <b>On</b> [✅ Assigning administrators] for @{0} to display <b>extra</b> channel graphics for the week",
    'es': "👩🏽‍💻 <b>Activado</b> [✅ Asignar administradores] para que @{0} muestre gráficos de canal <b>adicionales</b> para la semana",
    'fr': "👩🏽‍💻 <b>Activé</b> [✅ Attribution d'administrateurs] pour que @{0} affiche des graphiques de chaîne <b>supplémentaires</b> pour la semaine.",
    'zh': "👩🏽‍💻 <b>开启</b> [✅ 分配管理员] @{0} 显示本周<b>额外</b>个频道图形",
    'ar': "👩🏽‍💻 <b>تشغيل</b> [✅ تعيين مسؤولين] لـ @{0} لعرض <b>رسومات</b> إضافية للقناة لهذا الأسبوع",
}
l_chn_delete_parse = {
    'ru': "👩🏽‍💻 <b>Введи</b> дату начала/конца для удаления подписчиков из /parse-базы:\n<code>/delete {0} {1}</code>",
    'en': "👩🏽‍💻 <b>Enter</b> the start/end date to delete subscribers from the /parse database:\n<code>/delete {0} {1}</code>",
    'es': "👩🏽‍💻 <b>Ingrese</b> la fecha de inicio/finalización para eliminar suscriptores de la base de datos /parse:\n<code>/delete {0} {1}</code>",
    'fr': "👩🏽‍💻 <b>Entrez</b> la date de début/fin pour supprimer les abonnés de la base de données /parse :\n<code>/delete {0} {1}</code>",
    'zh': "👩🏽‍💻 <b>输入</b>开始/结束日期以从 /parse 数据库中删除订阅者：\n<code>/delete {0} {1}</code>",
    'ar': "👩🏽‍💻 <b>أدخل</b> تاريخ البدء/الانتهاء لحذف المشتركين من قاعدة البيانات /parse:\n<code>/delete {0} {1}</code>",
}
l_chn_delete_start = {
    'ru': "👩🏽‍💻 <b>Начинаем</b> удаление за период:\n<code>{0}</code>\n<code>{1}</code>",
    'en': "👩🏽‍💻 <b>We begin</b> deletion for the period:\n<code>{0}</code>\n<code>{1}</code>",
    'es': "👩🏽‍💻 <b>Comenzamos</b> eliminación para el período:\n<code>{0}</code>\n<code>{1}</code>",
    'fr': "👩🏽‍💻 <b>Nous commençons</b> la suppression pour la période :\n<code>{0}</code>\n<code>{1}</code>",
    'zh': "👩🏽‍💻 <b>我们开始</b>删除以下时间段：\n<code>{0}</code>\n<code>{1}</code>",
    'ar': "👩🏽‍💻 <b>نبدأ</b> بحذف الفترة:\n<code>{0}</code>\n<code>{1}</code>",
}
l_chn_delete_finish = {
    'ru': "👩🏽‍💻 <b>Удаление</b> пользователей завершено:\n<u>{0}</u> [-{1}]",
    'en': "👩🏽‍💻 <b>Deleting</b> users completed:\n<u>{0}</u> [-{1}]",
    'es': "👩🏽‍💻 <b>Eliminación</b> de usuarios completada:\n<u>{0}</u> [-{1}]",
    'fr': "👩🏽‍💻 <b>Suppression</b> des utilisateurs terminée :\n<u>{0}</u> [-{1}]",
    'zh': "👩🏽‍💻 <b>删除</b>个用户已完成：\n<u>{0}</u> [-{1}]",
    'ar': "👩🏽‍💻 اكتمل <b>حذف</b> المستخدمين:\n<u>{0}</u> [-{1}]",
}
# endregion


# region cban_
l_cban_add = {
    'ru': "🕵🏽 <b>Введи</b> id или @username пользователей через <i>пробелы/раздели</i>, чтобы добавить их в /ban-список (*даже тех, кто еще не запускал бота)\n\n<blockquote>👩🏽‍💻 <code>/ban 0</code> - очистить /ban-список</blockquote>",
    'en': "🕵🏽 <b>Enter</b> the id or @username of users separated by <i>spaces/separate</i> to add them to the /ban list (*even those who have not yet launched the bot)\n\n👩🏽‍💻 <code>/ban 0</code>-clear /ban list",
    'es': "🕵🏽 <b>Ingrese</b> el ID o @username de usuario de los usuarios separados por <i>espacios/separado</i> para agregarlos a la lista /ban (*incluso aquellos que aún no han iniciado el bot)\ n\n👩🏽‍💻 <code>/ban 0</code>-borrar lista /ban",
    'fr': "🕵🏽 <b>Entrez</b> l'identifiant ou @username des utilisateurs séparés par des <i>espaces/separate</i> pour les ajouter à la liste /ban (*même ceux qui n'ont pas encore lancé le bot)\ n\n👩🏽‍💻 <code>/ban 0</code>-effacer la liste /ban",
    'zh': "🕵🏽<b>输入</b>用户的ID或@username ，以<i>空格/单独</i>分隔，将其添加到/禁止列表中（*即使是那些尚未启动机器人的用户）\ n\n👩🏽‍💻 <code>/ban 0</code>-清除/禁止列表",
    'ar': "🕵🏽 <b>أدخل</b> المعرف أو @username للمستخدمين المفصولين <i>مسافات/منفصلة</i> لإضافتهم إلى قائمة /الحظر (*حتى أولئك الذين لم يطلقوا البوت بعد)\n\n👩🏽‍💻 <code>/ban 0</code>-مسح/قائمة الحظر",
}
l_cban_remove = {
    'ru': "🕵🏽 <b>Введи</b> id или @username пользователей через <i>пробелы/раздели</i>, чтобы удалить их из /ban-списка\n\n<blockquote>👩🏽‍💻 <code>/ban 0</code> - очистить /ban-список</blockquote>",
    'en': "🕵🏽 <b>Enter</b> user id or @username separated by <i>spaces/separate</i> to remove them from the /ban list\n\n👩🏽‍💻 <code>/ban 0< /code>-clear /ban list",
    'es': "🕵🏽 <b>Ingrese</b> ID de usuario o @username usuario separados por <i>espacios/separate</i> para eliminarlos de la lista /ban\n\n👩🏽‍💻 <code>/ban 0< /código>-borrar lista /prohibida",
    'fr': "🕵🏽 <b>Entrez</b> l'identifiant de l'utilisateur ou @username séparé par <i>espaces/separate</i> pour les supprimer de la liste /ban\n\n👩🏽‍💻 <code>/ban 0< /code>-effacer la liste /ban",
    'zh': "🕵🏽 <b>输入</b>用户 ID 或@username ，并用<i>空格/分隔</i>分隔，将其从 /ban 列表中删除\n\n👩🏽‍💻 <code>/ban 0< /code>-清除/禁止列表",
    'ar': "🕵🏽 <b>أدخل</b> معرف المستخدم أو @username مفصولاً <i>مسافات/منفصلة</i> لإزالتهما من قائمة /الحظر\n\n👩🏽‍💻 <code>/ban 0< /code>-مسح قائمة /الحظر",
}
l_cban_added = {
    'ru': "🕵🏽 <b>Пользователь</b> {0} добавлен в /ban-список (причина: <i>{1}</i>)",
    'en': "🕵🏽 <b>User</b> {0} added to the /ban list (reason: <i>{1}</i>)",
    'es': "🕵🏽 <b>Usuario</b> {0} agregado a la lista /ban (motivo: <i>{1}</i>)",
    'fr': "🕵🏽 <b>Utilisateur</b> {0} ajouté à la liste /ban (raison : <i>{1}</i>)",
    'zh': "🕵🏽 <b>用户</b> {0} 已添加到/禁止列表（原因：<i>{1}</i>）",
    'ar': "🕵🏽 تمت إضافة <b>المستخدم</b> {0} إلى قائمة /الحظر (السبب: <i>{1}</i>)",
}
l_cban_text = {
    'ru': "🕵🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> бан <u>пользователей</u> бота: <i>с недавно зарегистрированными new-id/аккаунтов без @username/cas-аккаунтов из <a href='https://cas.chat'>Anti-Spam Системы</a>/аккаунтов с 文-глиф, ب-араб/ <a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n<blockquote>👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/ban [id|@username] - блок пользователя\n/unban [id|@username] - разблок\n/parse - вывести всех пользователей</blockquote>",
    'en': "🕵🏽 <b>Click</b> on ✅/☑️ to <b>On/Off</b> ban <u>users</u> bot: <i>with recently registered new-id/accounts without @username /accounts from <a href=' https://cas.chat '> Anti-Spam System</a>/accounts with 文-glyph, ب-Arab/ <a href=' https://www.zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/ban [id| @username]-user block\n/unban [id| @username]-unblock\n/parse-display all users",
    'es': "🕵🏽 <b>Haga clic</b> en ✅/☑️ para <b>activar/desactivar</b> prohibir el bot de <u>usuarios</u>: <i>con nueva identificación recientemente registrada/cuentas sin @username /cuentas de <a href=' https://cas.chat '> Sistema Anti-Spam</a>/cuentas con 文-glifo, ب-Arab/ <a href=' https://www.zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/ban [id| @username]-bloqueo de usuario\n/unban [id| @username]-desbloquear\n/parse-mostrar todos los usuarios",
    'fr': "🕵🏽 <b>Cliquez</b> sur ✅/☑️ pour <b>On/Off</b> bannir les <u>utilisateurs</u> du bot : <i>avec un nouvel identifiant/compte récemment enregistré sans @username /comptes du <a href=' https://cas.chat '> Système anti-spam</a>/comptes avec 文-glyphe, ب-Arab/ <a href=' https://www.zalgo.org '>symboles zalgo</a></i>\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/ban [id| @username]-blocage de l'utilisateur\n/annuler le bannissement [id| @username]-débloquer\n/parse-afficher tous les utilisateurs",
    'zh': "🕵🏽<b>点击</b>✅/☑️<b>开/关</b>禁止<u>用户</u>机器人：<i>最近注册的新ID/帐户没有@username /accounts 来自<a href=' https://cas.chat '>反垃圾邮件系统</a>/accounts with wen-glyph, б-Arab/ <a href=' https://www.zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 <b>命令</b>：\n/cmd-所有命令\n/ban [id| @username]-用户阻止\n/解禁 [id| @username]-解锁\n/parse-显示所有用户",
    'ar': "🕵🏽 <b>انقر</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> حظر <u>المستخدمين</u> الروبوت: <i>بالمعرفات/الحسابات الجديدة المسجلة مؤخرًا بدون @username /حسابات من <a href=' https://cas.chat '> نظام مكافحة البريد العشوائي</a>/حسابات مع 文-glyph, ب-Arab/ <a href=' https://www.zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-جميع الأوامر\n/ban [id| @username]-حظر المستخدم\n/unban [id| @username]-إلغاء الحظر\n/parse-عرض كافة المستخدمين",
}
l_cban_done = {
    'ru': "🕵🏽 <b>Готово!</b> /ban-список нежелательных пользователей @{0}-бота\n\n👩🏽‍💻 <b>Команды</b>:\n/cmd - все команды\n/parse - вывести всех пользователей\n/ban [id|@username] - блок пользователя\n/unban [id|@username] - разблок\n<code>/ban 0</code> - очистить /ban-список\n\n👩🏽‍💻 <b>Текущее</b> число пользователей /ban-списка: <u>{1}</u>",
    'en': "🕵🏽 <b>Done!</b> /ban-list of unwanted users @{0}-bot\n\n👩🏽‍💻 <b>Commands</b>:\n/cmd-all commands\n/ parse-display all users\n/ban [id| @username]-user block\n/unban [id| @username]-unblock\n<code>/ban 0</code>-clear /ban list\n\n👩🏽‍💻 <b>Current</b> number of users /ban list: <u>{ 1}</u>",
    'es': "🕵🏽 <b>¡Listo!</b> /ban-list de usuarios no deseados @{0}-bot\n\n👩🏽‍💻 <b>Comandos</b>:\n/cmd-todos los comandos\n/ parse-muestra todos los usuarios\n/ban [id| @username]-bloqueo de usuario\n/unban [id| @username]-desbloquear\n<code>/ban 0</code>-borrar /lista de baneos\n\n👩🏽‍💻 <b>Número actual</b> de usuarios /lista de baneos: <u>{ 1 }</u>",
    'fr': "🕵🏽 <b>Terminé !</b> /ban-list des utilisateurs indésirables @{0}-bot\n\n👩🏽‍💻 <b>Commandes</b> :\n/cmd-toutes les commandes\n/ parse-afficher tous les utilisateurs\n/ban [id| @username]-blocage de l'utilisateur\n/annuler le bannissement [id| @username]-débloquer\n<code>/ban 0</code>-effacer /ban list\n\n👩🏽‍💻 <b>Nombre actuel</b> d'utilisateurs /ban list : <u>{ 1 </u>",
    'zh': "🕵🏽 <b>完成！</b> /ban-不需要的用户列表@{0}-bot\n\n👩🏽‍💻 <b>命令</b>：\n/cmd-所有命令\n/ parse-显示所有用户\n/ban [id| @username]-用户阻止\n/解禁 [id| @username]-解锁\n<code>/ban 0</code>-清除/ban列表\n\n👩🏽‍💻 <b>当前</b>用户/ban列表数量：<u>{ 1 }</u>",
    'ar': "🕵🏽 <b>تم!</b> /ban-list المستخدمين غير المرغوب فيهم @{0}-bot\n\n👩🏽‍💻 <b>الأوامر</b>:\n/cmd-جميع الأوامر\n/ تحليل-عرض كافة المستخدمين\n/ban [id| @username]-حظر المستخدم\n/unban [id| @username]-إلغاء الحظر\n<code>/ban 0</code>-مسح قائمة /الحظر\n\n👩🏽‍💻 <b>العدد الحالي</b> للمستخدمين /قائمة الحظر: <u>{ 1 </u>",
}
l_cban_correct = {
    'ru': "🕵🏽 <b>Введи</b> корректный id или @username пользователя или выведи всех пользователей в бана: /ban",
    'en': "🕵🏽 <b>Enter</b> the correct user id or @username or ban all users: /ban",
    'es': "🕵🏽 <b>Ingrese</b> la identificación de usuario correcta o @username o prohíba a todos los usuarios: /ban",
    'fr': "🕵🏽 <b>Entrez</b> le bon identifiant d'utilisateur ou @username ou bannissez tous les utilisateurs : /ban",
    'zh': "🕵🏽<b>输入</b>正确的用户ID或@username或禁止所有用户：/ban",
    'ar': "🕵🏽 <b>أدخل</b> معرف المستخدم الصحيح أو @username أو قم بحظر جميع المستخدمين: /ban",
}

l_cban_handler = {
    'ru': "🕵🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <u>авто</u>-бан <i>аккаунтов с недавно зарегистрированными new-id/без @username/cas-аккаунтов из <a href='https://cas.chat'>Anti-Spam Системы</a>/аккаунтов с 文-глиф, ب-араб/ <a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n<blockquote>[✅<b>new-id</b>] /ban аккаунтов со <i>свежим</i> <u>id</u></blockquote>",
    'en': "🕵🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <u>auto</u>-ban <i>accounts with recently registered new-id/without @username /accounts from <a href=' https://cas.chat '> Anti-Spam System</a>/accounts with 文-glyph, ب-Arab/ <a href=' https://www.zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 For example, the <b>new-id</b> option blocks accounts with <i>fresh</i> <u>id< /u>",
    'es': "🕵🏽 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <u>auto</u>-prohibir <i>cuentas con nuevo ID registrado recientemente/sin @username / cuentas de <a href=' https://cas.chat '> Sistema Anti-Spam</a>/cuentas con 文-glifo, ب-Arab/ <a href=' https://www.zalgo.org ' >zalgo-symbols</a></i>\n\n👩🏽‍💻 Por ejemplo, la opción <b>new-id</b> bloquea cuentas con <i>fresh</i> <u>id < /u>",
    'fr': "🕵🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> <u>auto</u>-ban <i>les comptes avec un nouvel identifiant récemment enregistré/sans @username / comptes du <a href=' https://cas.chat '> Système anti-spam</a>/comptes avec 文-glyph, ب-Arab/ <a href=' https://www.zalgo.org ' >zalgo-symbols</a></i>\n\n👩🏽‍💻 Par exemple, l'option <b>new-id</b> bloque les comptes avec <i>fresh</i> <u>id < /u>",
    'zh': "🕵🏽<b>按</b>✅/☑️<b>开/关</b><u>自动</u>-禁止<i>最近注册的新ID/不带@username帐户/来自<a href=' https://cas.chat '>反垃圾邮件系统</a>的帐户/带有 文-glyph、a-Arab/ 的帐户 <a href=' https://www.zalgo.org ' >zalgo-symbols</a></i>\n\n👩🏽‍💻 例如，<b>new-id</b> 选项会阻止具有 <i>fresh</i> <u>id 的帐户</u>",
    'ar': "🕵🏽 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <u>تلقائي</u>-ban <i>الحسابات ذات المعرف الجديد المسجل مؤخرًا/بدون @username / حسابات من <a href=' https://cas.chat '> نظام مكافحة البريد العشوائي</a>/حسابات مع 文-glyph, ب-Arab/ <a href=' https://www.zalgo.org ' >zalgo-symbols</a></i>\n\n👩🏽‍💻 على سبيل المثال، يقوم خيار <b>المعرف الجديد</b> بحظر الحسابات ذات المعرف <i>الجديد</i> <u> < /ش>",
}
l_cban_new_on = {
    'ru': "✅☑Вкл new-id-бан",
    'en': "✅☑Includes new-id-ban",
    'es': "✅☑Incluye prohibición de nueva identificación",
    'fr': "✅☑Comprend le nouvel interdiction d'identification",
    'zh': "✅☑包括新 ID 禁令",
    'ar': "✅☑يتضمن حظر الهوية الجديد",
}
l_cban_new_off = {
    'ru': "☑️☐Выкл new-id-бан",
    'en': "☑️☐Vykl new-id-ban",
    'es': "☑️☐Vykl nueva-id-ban",
    'fr': "☑️☐Vykl new-id-ban",
    'zh': "☑️☐Vykl 新 ID 禁令",
    'ar': "☑️☐Vykl حظر الهوية الجديد",
}
l_cban_nousername_on = {
    'ru': "✅☑Вкл без @username-бан",
    'en': "✅☑Vkl without @username-ban",
    'es': "✅☑Vkl sin @username-ban",
    'fr': "✅☑Vkl sans @username-ban",
    'zh': "✅☑没有@username的Vkl-ban",
    'ar': "✅☑Vkl بدون @username-ban",
}
l_cban_nousername_off = {
    'ru': "☑️☐Выкл без @username-бан",
    'en': "☑️☐Vykl without @username-ban",
    'es': "☑️☐Vykl sin @username-ban",
    'fr': "☑️☐Vykl sans @username-ban",
    'zh': "☑️☐Vykl 没有@username-ban",
    'ar': "☑️☐Vykl بدون @username-ban",
}
l_cban_cas_on = {
    'ru': "✅☑Вкл CAS-бан",
    'en': "✅☑Includes CAS-ban",
    'es': "✅☑Incluye prohibición CAS",
    'fr': "✅☑Comprend l'interdiction CAS",
    'zh': "✅☑包括 CAS 禁令",
    'ar': "✅☑يتضمن حظر CAS",
}
l_cban_cas_off = {
    'ru': "☑️☐Выкл CAS-бан",
    'en': "☑️☐Disable CAS ban",
    'es': "☑️☐Desactivar la prohibición de CAS",
    'fr': "☑️☐Désactiver l'interdiction CAS",
    'zh': "☑️️禁用 CAS 禁令",
    'ar': "☑️☐تعطيل حظر CAS",
}
l_cban_symbols_on = {
    'ru': "✅☑Вкл 文ب-бан",
    'en': "✅☑Incl. 文ب-ban",
    'es': "✅☑Incluye prohibición de 文ب",
    'fr': "✅☑Y compris l'interdiction de 文ب",
    'zh': "✅☑包括文巴禁令",
    'ar': "✅☑Incl.文ب-ban",
}
l_cban_symbols_off = {
    'ru': "☑️☐Выкл 文ب-бан",
    'en': "☑️☐Выкл 文ب-رан",
    'es': "☑️☐Выкл 文ب-رан",
    'fr': "☑️☐Выкл 文ب-رан",
    'zh': "☑️☐Выкл 文ب-бан",
    'ar': "☑️☐Выкл 文ب-بان",
}
l_cban_zalgo_on = {
    'ru': "✅☑Вкл zalgo-бан",
    'en': "✅☑Incl. pledge-ban",
    'es': "✅☑Incl. prohibición de compromiso",
    'fr': "✅☑Y compris l'interdiction de promesse de don",
    'zh': "✅☑包括质押禁令",
    'ar': "✅☑بما في ذلك حظر التعهد",
}
l_cban_zalgo_off = {
    'ru': "☑️☐Выкл zalgo-бан",
    'en': "☑️☐Vykl pledge-ban",
    'es': "☑️☐Prohibición de compromiso de Vykl",
    'fr': "☑️☐Vykl engagement-interdiction",
    'zh': "☑️☐Vykl 承诺禁令",
    'ar': "☑️☐فيكل تعهد بالحظر",
}
# endregion


# region cpost_
l_cpost_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы один пост",
    'en': "🔔 You need to ⚙️Customize at least one post",
    'es': "🔔 Necesitas ⚙️Personalizar al menos una publicación",
    'fr': "🔔 Vous devez ⚙️Personnaliser au moins une publication",
    'zh': "🔔 您需要⚙️自定义至少一篇帖子",
    'ar': "🔔 تحتاج إلى ⚙️ تخصيص منشور واحد على الأقل",
}
l_cpost_text = {
    'ru': "🔔 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <b>авто</b>-постинг по дате\n\n<blockquote>👩🏽‍💻 <b>Текущее</b> количество постов: <u>{0}</u></blockquote>",
    'en': "🔔 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <b>auto</b>-posting by date\n\n👩🏽‍💻 <b>Current< /b> number of posts <u>{0}</u>",
    'es': "🔔 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <b>publicación automática</b> por fecha\n\n👩🏽‍💻 <b>Actual< / b> número de publicaciones <u>{0}</u>",
    'fr': "🔔 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <b>auto</b>-publication par date\n\n👩🏽‍💻 <b>Actuel</b> b> nombre de messages <u>{0}</u>",
    'zh': "🔔 <b>按</b> ✅/☑️ <b>开/关</b> <b>自动</b>-按日期发布\n\n👩🏽‍💻 <b>当前</b> b> 帖子数量 <u>{0}</u>",
    'ar': "🔔 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <b>تلقائي</b>-النشر حسب التاريخ\n\n👩🏽‍💻 <b>الحالي< / ب> عدد المشاركات <u>{0}</u>",
}
l_fsm_post_call = {
    'ru': "🔔 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Отправка сообщений]\n[✅ Редактирование постов]\n\n🕚Подожди 1min",
    'en': "🔔 In the [Administrators] settings, enable the option for @{0}-bot:\n[✅ Sending messages]\n[✅ Editing posts]\n\n🕚Wait 1min",
    'es': "🔔 En la configuración de [Administradores], habilita la opción para @{0}-bot:\n[✅ Enviar mensajes]\n[✅ Editar publicaciones]\n\n🕚Espera 1 minuto",
    'fr': "🔔 Dans les paramètres [Administrateurs], activez l'option pour @{0}-bot :\n[✅ Envoi de messages]\n[✅ Modification des messages]\n\n🕚Attendez 1 min",
    'zh': "🔔 在[管理员]设置中，启用@{0}-bot的选项：\n[✅发送消息]\n[✅编辑帖子]\n\n🕚等待1分钟",
    'ar': "🔔 في إعدادات [المسؤولين]، قم بتمكين خيار @{0}-bot:\n[✅ إرسال الرسائل]\n[✅ تحرير المشاركات]\n\n🕚انتظر دقيقة واحدة",
}
l_fsm_post_pin_call = {
    'ru': "🔔 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Закрепление сообщений]\n\n🕚Подожди 1min",
    'en': "🔔 In the [Administrators] settings, enable the option for @{0}-bot:\n[✅ Pinning messages]\n\n🕚Wait 1min",
    'es': "🔔 En la configuración de [Administradores], habilite la opción para @{0}-bot:\n[✅ Fijar mensajes]\n\n🕚Espera 1 minuto",
    'fr': "🔔 Dans les paramètres [Administrateurs], activez l'option pour @{0}-bot :\n[✅ Épingler les messages]\n\n🕚Attendez 1 min",
    'zh': "🔔 在【管理员】设置中，启用 @{0}-bot 选项：\n[✅ 固定消息]\n\n🕚等待 1 分钟",
    'ar': "🔔 في إعدادات [المسؤولين]، قم بتمكين خيار @{0}-bot:\n[✅ تثبيت الرسائل]\n\n🕚انتظر دقيقة واحدة",
}
# endregion


# region creact_
l_creact_text = {
    'ru': "🫶🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> креативные авто-эмоджи на последний пост канала\n\n👩🏽‍💻 Используй команду <code>/emoji {0}</code>, чтобы задать количество авто-emoji на пост (без 💨Подписки: до <u>{1}</u>)\n\n👍🏽 <b>Tекущее</b> количество: <u>{0}</u>",
    'en': "🫶🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> creative auto-emoji for the last post of the channel\n\n👩🏽‍💻 Use the command <code>/emoji { 0}</code> to set the number of auto-emoji per post (without 💨Subscription: up to <u>{1}</u>)\n\n👍🏽 <b>Current</b> quantity: <u >{0}</u>",
    'es': "🫶🏽 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> emoji automático creativo para la última publicación del canal\n\n👩🏽‍💻 Usa el comando <código> /emoji { 0}</code> para establecer el número de emojis automáticos por publicación (sin 💨Suscripción: hasta <u>{1}</u>)\n\n👍🏽 <b>Actual</b > cantidad: <u >{0}</u>",
    'fr': "🫶🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> l'auto-emoji créatif pour le dernier post de la chaîne\n\n👩🏽‍💻 Utilisez la commande <code> /emoji { 0}</code> pour définir le nombre d'émojis automatiques par publication (sans 💨Abonnement : jusqu'à <u>{1}</u>)\n\n👍🏽 <b>Actuel</b > quantité : <u >{0}</u>",
    'zh': "🫶🏽 <b>按</b> ✅/☑️ 可以<b>打开/关闭</b>频道最后一篇帖子的创意自动表情符号\n\n👩🏽‍💻 使用命令 <code> /emoji { 0}</code> 设置每个帖子的自动表情符号数量（不含 💨订阅：最多 <u>{1}</u>）\n\n👍🏽 <b>当前</b > 数量：<u >{0}</u>",
    'ar': "🫶🏽 <b>اضغط على</b> على ✅/☑️ لـ <b>تشغيل/إيقاف</b> رمز تعبيري تلقائي إبداعي لآخر مشاركة في القناة\n\n👩🏽‍💻 استخدم الأمر <code> /emoji { 0}</code> لتعيين عدد الرموز التعبيرية التلقائية لكل مشاركة (بدون 💨الاشتراك: حتى <u>{1}</u>)\n\n👍🏽 <b>الحالي</b > الكمية: <u >{0}</u>",
}
l_creact_call = {
    'ru': "🫶🏽 В настройках [Администраторы] для @{0} вкл:\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "🫶🏽 In the [Administrators] settings for @{0} on:\n[✅ Adding a member]\n\n🕚Wait 1min",
    'es': "🫶🏽 En la configuración de [Administradores] para @{0} en:\n[✅ Agregar un miembro]\n\n🕚Espera 1 minuto",
    'fr': "🫶🏽 Dans les paramètres [Administrateurs] pour @{0} sur :\n[✅ Ajout d'un membre]\n\n🕚Attendez 1 min",
    'zh': "🫶🏽 在 @{0} 的 [管理员] 设置中：\n[✅ 添加成员]\n\n🕚等待 1 分钟",
    'ar': "🫶🏽 في إعدادات [المسؤولين] لـ @{0} على:\n[✅ إضافة عضو]\n\n🕚انتظر دقيقة واحدة",
}
l_creact_correct = {
    'ru': "🫶🏽 <b>Введи</b> корректное <b>число</b> креативных авто-эмоджи на последний пост канала\n\n👩🏽‍💻 Используй команду <code>/react {0}</code>, чтобы задать количество авто-эмоджи (без 💨Подписки: до <u>{1}</u>)",
    'en': "🫶🏽 <b>Enter</b> the correct <b>number</b> of creative auto-emojis for the last post of the channel\n\n👩🏽‍💻 Use the command <code>/react {0}</code>, to set the number of auto-emojis (without 💨Subscription: up to <u>{1}</u>)",
    'es': "🫶🏽 <b>Ingresa</b> el <b>número</b> correcto de emojis automáticos creativos para la última publicación del canal\n\n👩🏽‍💻 Usa el comando <code>/react {0 }</code>, para establecer el número de emojis automáticos (sin 💨Suscripción: hasta <u>{1}</u>)",
    'fr': "🫶🏽 <b>Entrez</b> le <b>numéro</b> correct d'émojis automatiques créatifs pour le dernier message de la chaîne\n\n👩🏽‍💻 Utilisez la commande <code>/react {0 }</code>, pour définir le nombre d'auto-emojis (sans 💨Abonnement : jusqu'à <u>{1}</u>)",
    'zh': "🫶🏽 <b>输入</b>该频道最后一篇帖子的正确<b>数量</b>创意自动表情符号\n\n👩🏽‍💻 使用命令 <code>/react {0 }</code>，设置自动表情符号的数量（不含💨订阅：最多 <u>{1}</u>）",
    'ar': "🫶🏽 <b>أدخل</b> <b>الرقم</b> الصحيح من الرموز التعبيرية التلقائية الإبداعية لآخر مشاركة في القناة\n\n👩🏽‍💻 استخدم الأمر <code>/react {0 }</code>، لتعيين عدد الرموز التعبيرية التلقائية (بدون 💨الاشتراك: حتى <u>{1}</u>)",
}
l_creact_on = {
    'ru': "🫶🏽 <b>Готово!</b> Текущее количество <b>авто-эмоджи</b> на пост канала установлено в значение <u>{0}</u> (без 💨Подписки: до <u>{1}</u>)",
    'en': "🫶🏽 <b>Done!</b> The current number of <b>auto-emoji</b> per channel post is set to <u>{0}</u> (without 💨Subscription: up to <u>{1 }</u>)",
    'es': "🫶🏽 <b>¡Listo!</b> El número actual de <b>auto-emoji</b> por publicación del canal está establecido en <u>{0}</u> (sin 💨Suscripción: hasta <u >{1 }</u>)",
    'fr': "🫶🏽 <b>Terminé !</b> Le nombre actuel d'<b>émoticônes automatiques</b> par publication de chaîne est défini sur <u>{0}</u> (sans 💨Abonnement : jusqu'à <u >{1 }</u>)",
    'zh': "🫶🏽<b>完成！</b>当前每个频道帖子的<b>自动表情符号</b>数量设置为<u>{0}</u>（没有💨订阅：最多<u >{1}</u>)",
    'ar': "🫶🏽 <b>تم!</b> تم تعيين العدد الحالي من <b>الرموز التعبيرية التلقائية</b> لكل مشاركة في القناة على <u>{0}</u> (بدون 💨الاشتراك: ما يصل إلى <u) >{1 }</u>)",
}
l_creact_off = {
    'ru': "🫶🏽 <b>Режим</b> /react-авто-эмоджи отключен",
    'en': "🫶🏽 <b>Mode</b> /react-auto-emoji disabled",
    'es': "🫶🏽 <b>Modo</b> /react-auto-emoji deshabilitado",
    'fr': "🫶🏽 <b>Mode</b> /react-auto-emoji désactivé",
    'zh': "🫶🏽 <b>模式</b> /react-auto-emoji 已禁用",
    'ar': "🫶🏽 <b>الوضع</b> /react-auto-emoji معطل",
}
# endregion


# region cview_
l_cview_text = {
    'ru': "👁️‍🗨️ <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-просмотры поста канала\n\n👩🏽‍💻 Используй команду <code>/view {0}</code>, чтобы задать количество авто-просмотров (без 💨Подписки: до <u>{1}</u>)\n\n👁️‍🗨️ <b>Tекущее</b> количество: <u>{0}</u>",
    'en': "👁️‍🗨️ <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-views of channel post\n\n👩🏽‍💻 Use the command <code>/view {0} </code> to set the number of auto-views (without 💨Subscription: up to <u>{1}</u>)\n\n👁️‍🗨️ <b>Current</b> quantity: <u>{0 }</u>",
    'es': "👁️‍🗨️ <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> las vistas automáticas de las publicaciones del canal\n\n👩🏽‍💻 Usa el comando <código>/ver {0 } </code> para establecer el número de vistas automáticas (sin 💨Suscripción: hasta <u>{1}</u>)\n\n👁️‍🗨️ Cantidad <b>actual</b>: <u >{0 }</u>",
    'fr': "👁️‍🗨️ <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> les vues automatiques des publications de la chaîne\n\n👩🏽‍💻 Utilisez la commande <code>/view {0 } </code> pour définir le nombre de vues automatiques (sans 💨Abonnement : jusqu'à <u>{1}</u>)\n\n👁️‍🗨️ Quantité <b>Actuelle</b> : <u >{0 }</u>",
    'zh': "👁️‍🗨️ <b>按</b> ✅/☑️ 可<b>开启/关闭</b>自动查看频道帖子\n\n👩🏽‍💻 使用命令 <code>/view {0 } </code> 设置自动观看次数（不含💨订阅：最多 <u>{1}</u>）\n\n👁️‍🗨️ <b>当前</b>数量：<u >{0}</u>",
    'ar': "👁️‍🗨️ <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> المشاهدات التلقائية لمنشور القناة\n\n👩🏽‍💻 استخدم الأمر <code>/view {0 } </code> لتعيين عدد مرات المشاهدة التلقائية (بدون 💨الاشتراك: حتى <u>{1}</u>)\n\n👁️‍🗨️ <b>الكمية</b> الحالية: <u >{0 }</u>",
}
l_cview_call = {
    'ru': "👁️‍🗨️ В настройках [Администраторы] для @{0} вкл:\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👁️‍🗨️ In the [Administrators] settings for @{0} on:\n[✅ Adding a member]\n\n🕚Wait 1min",
    'es': "👁️‍🗨️ En la configuración de [Administradores] para @{0} en:\n[✅ Agregar un miembro]\n\n🕚Espera 1 minuto",
    'fr': "👁️‍🗨️ Dans les paramètres [Administrateurs] pour @{0} sur :\n[✅ Ajout d'un membre]\n\n🕚Attendez 1 min",
    'zh': "👁️‍🗨️ 在 @{0} 的 [管理员] 设置中：\n[✅ 添加成员]\n\n🕚等待 1 分钟",
    'ar': "👁️‍🗨️ في إعدادات [المسؤولين] لـ @{0} على:\n[✅ إضافة عضو]\n\n🕚انتظر دقيقة واحدة",
}
l_cview_correct = {
    'ru': "👁️‍🗨️ <b>Введи</b> корректное <b>число</b> авто-просмотров последнего поста канала\n\n👩🏽‍💻 Используй команду <code>/view {0}</code>, чтобы задать количество авто-просмотров (без 💨Подписки: до <u>{1}</u>)",
    'en': "👁️‍🗨️ <b>Enter</b> the correct <b>number</b> of auto-views of the last channel post\n\n👩🏽‍💻 Use the command <code>/view {0}</code> to set the number of auto-views (without 💨Subscription: up to <u>{1}</u>)",
    'es': "👁️‍🗨️ <b>Ingrese</b> el <b>número</b> correcto de vistas automáticas de la última publicación del canal\n\n👩🏽‍💻 Utilice el comando <código>/vista {0}< /code> para establecer el número de vistas automáticas (sin 💨Suscripción: hasta <u>{1}</u>)",
    'fr': "👁️‍🗨️ <b>Entrez</b> le <b>nombre</b> correct de vues automatiques de la dernière publication de la chaîne\n\n👩🏽‍💻 Utilisez la commande <code>/view {0}< /code> pour définir le nombre de vues automatiques (sans 💨Abonnement : jusqu'à <u>{1}</u>)",
    'zh': "👁️‍🗨️ <b>输入</b>上一个频道帖子的正确<b>自动观看次数</b>\n\n👩🏽‍💻 使用命令<code>/view {0}< /code> 设置自动观看次数（不含💨订阅：最多 <u>{1}</u>）",
    'ar': "👁️‍🗨️ <b>أدخل</b> <b>العدد</b> الصحيح للمشاهدات التلقائية لمنشور القناة الأخير\n\n👩🏽‍💻 استخدم الأمر <code>/view {0}< /code> لتعيين عدد مرات المشاهدة التلقائية (بدون 💨الاشتراك: حتى <u>{1}</u>)",
}
l_cview_on = {
    'ru': "👁️‍🗨️ <b>Готово!</b> Текущее количество <b>авто-просмотров</b> на последний пост канала установлено в значение <u>{0}</u> (без 💨Подписки: до <u>{1}</u>)",
    'en': "👁️‍🗨️ <b>Done!</b> The current number of <b>auto-views</b> for the last channel post is set to <u>{0}</u> (without 💨Subscription: up to <u> {1}</u>)",
    'es': "👁️‍🗨️ <b>¡Listo!</b> El número actual de <b>vistas automáticas</b> para la última publicación del canal está establecido en <u>{0}</u> (sin 💨Suscripción: arriba a <u> {1}</u>)",
    'fr': "👁️‍🗨️ <b>Terminé !</b> Le nombre actuel de <b>vues automatiques</b> pour la dernière publication de la chaîne est défini sur <u>{0}</u> (sans 💨Abonnement : en haut à <u> {1}</u>)",
    'zh': "👁️‍🗨️ <b>完成！</b> 最后一个频道帖子的当前<b>自动观看</b>数量设置为 <u>{0}</u>（没有 💨订阅：向上至<u>{1}</u>）",
    'ar': "👁️‍🗨️ <b>تم!</b> تم تعيين العدد الحالي <b>للمشاهدات التلقائية</b> لآخر مشاركة في القناة على <u>{0}</u> (بدون 💨الاشتراك: أعلى إلى <u> {1}</u>)",
}
l_cview_off = {
    'ru': "👁️‍🗨️ <b>Режим</b> /view-авто-просмотров отключен",
    'en': "👁️‍🗨️ <b>Mode</b> /view-auto-views disabled",
    'es': "👁️‍🗨️ <b>Modo</b> /view-auto-views deshabilitado",
    'fr': "👁️‍🗨️ <b>Mode</b> /view-auto-views désactivé",
    'zh': "👁️‍🗨️ <b>模式</b> /view-auto-views 已禁用",
    'ar': "👁️‍🗨️ <b>الوضع</b> /العرض التلقائي معطل",
}
# endregion


# region cdecor_
l_cdecor_text = {
    'ru': "🪄 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-декор публикуемого поста: <i><b>пагинация</b> (порядковый номер поста)/креативный <b>формат</b> (<b>жирный</b>/<i>курсив</i>/<u>подчеркнутый</u>/<code>моно</code>/<tg-spoiler>спойлер</tg-spoiler>/#hashtag/цитата”/<a href='{0}'>ссылка</a>)/<b>футер</b> (текстовое окончание поста)</i>\n\n<blockquote>[✅ <b>Вкл формат</b>] креативное изменение поста с использованием 8 стилей\n[✅ <b>Вкл пагинация</b>] добавление порядкового номера поста</blockquote>",
    'en': "🪄 <b>Click</b> on ✅/☑️ to <b>On/Off</b> auto-decoration of the published post: <i><b>pagination</b> (post serial number)/creative < b>format</b> (<b>bold</b>/<i>italic</i>/<u>underlined</u>/<code>mono</code>/<tg-spoiler>spoiler </tg-spoiler>/ #hashtag /$cashtag/<a href='{0}'>link</a>)/<b>footer</b> (text end of post)</i>\n\ n👩🏽‍💻 Click <b>[✅☑On format]</b> to enable creative modification of the post using 8 styles",
    'es': "🪄 <b>Haz clic</b> en ✅/☑️ para <b>activar/desactivar</b> la decoración automática de la publicación publicada: <i><b>paginación</b> (número de serie de la publicación)/creatividad. < b>formato</b> (<b>negrita</b>/<i>cursiva</i>/<u>subrayado</u>/<code>mono</code>/<tg-spoiler> spoiler </tg-spoiler>/ #hashtag /$cashtag/<a href='{0}'>link</a>)/<b>pie de página</b> (texto al final de la publicación)</i>\ n\ n👩🏽‍💻 Haga clic en <b>[✅☑En formato]</b> para habilitar la modificación creativa de la publicación usando 8 estilos.",
    'fr': "🪄 <b>Cliquez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la décoration automatique du post publié : <i><b>pagination</b> (numéro de série du post)/création < b>format</b> (<b>gras</b>/<i>italique</i>/<u>souligné</u>/<code>mono</code>/<tg-spoiler> spoiler </tg-spoiler>/ #hashtag /$cashtag/<a href='{0}'>link</a>)/<b>pied de page</b> (texte de fin du message)</i>\ n\ n👩🏽‍💻 Cliquez sur <b>[✅☑Sur le format]</b> pour activer la modification créative de la publication en utilisant 8 styles",
    'zh': "🪄 <b>点击</b> ✅/☑️ 可以<b>开启/关闭</b>已发布帖子的自动装饰：<i><b>分页</b>（帖子序列号）/创意<b>格式</b>（<b>粗体</b>/<i>斜体</i>/<u>下划线</u>/<code>单色</code>/<tg-spoiler>剧透 </tg-spoiler>/ #hashtag /$cashtag/<a href='{0}'>link</a>)/<b>页脚</b>（帖子文本结尾）</i>\ n\ n👩🏽‍💻 点击<b>[✅☑格式]</b>即可使用8种样式对帖子进行创意修改",
    'ar': "🪄 <b>انقر</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الزخرفة التلقائية للمنشور المنشور: <i><b>ترقيم الصفحات</b> (الرقم التسلسلي للمنشور)/الإبداع < b>التنسيق</b> (<b>غامق</b>/<i>مائل</i>/<u>مسطر</u>/<code>أحادي</code>/<tg-spoiler> المفسد </tg-spoiler>/ #hashtag /$cashtag/<a href='{0}'>link</a>)/<b>footer</b> (نهاية نص التدوينة)</i>\n\n👩🏽‍💻 انقر على <b>[✅☑على التنسيق]</b> لتمكين التعديل الإبداعي للمنشور باستخدام 8 أنماط",
}
l_cdecor_footer_call = {
    'ru': "🪄 Футер пустой, необходимо его ⚙️Настроить",
    'en': "🪄 Footer is empty, you need to ⚙️Customize it",
    'es': "🪄 El pie de página está vacío, debes ⚙️Personalizarlo",
    'fr': "🪄 Le pied de page est vide, vous devez le ⚙️Personnaliser",
    'zh': "🪄 页脚为空，需要⚙️自定义",
    'ar': "🪄 التذييل فارغ، تحتاج إلى ⚙️ تخصيصه",
}
l_cdecor_footer_call2 = {
    'ru': "🪄 В настройках [Администраторы] вкл опцию для @{0}-бота:\n[✅ Редактирование постов]\n\n🕚Подожди 1min",
    'en': "🪄 In the [Administrators] settings, enable the option for @{0}-bot:\n[✅ Editing posts]\n\n🕚Wait 1min",
    'es': "🪄 En la configuración de [Administradores], habilita la opción para @{0}-bot:\n[✅ Editar publicaciones]\n\n🕚Espera 1 minuto",
    'fr': "🪄 Dans les paramètres [Administrateurs], activez l'option pour @{0}-bot :\n[✅ Modification des messages]\n\n🕚Attendez 1 min",
    'zh': "🪄 在【管理员】设置中，启用@{0}-bot的选项：\n[✅ 编辑帖子]\n\n🕚等待1分钟",
    'ar': "🪄 في إعدادات [المسؤولين]، قم بتمكين خيار @{0}-bot:\n[✅ تحرير المشاركات]\n\n🕚انتظر دقيقة واحدة",
}
l_cdecor_footer_config = {
    'ru': "🪄 <b>Введи</b> краткий <b>текст</b>, который будет добавляться в окончание к постам канала (например, часто используемые #hashtags)",
    'en': "🪄 <b>Enter</b> a short <b>text</b> that will be added to the end of channel posts (for example, frequently used #hashtags )",
    'es': "🪄 <b>Ingrese</b> un <b>texto</b> breve que se agregará al final de las publicaciones del canal (por ejemplo, #hashtags de uso frecuente)",
    'fr': "🪄 <b>Saisissez</b> un court <b>texte</b> qui sera ajouté à la fin des publications de la chaîne (par exemple, #hashtags fréquemment utilisés)",
    'zh': "🪄 <b>输入</b>一个简短的<b>文本</b>，该文本将添加到频道帖子的末尾（例如，常用的#hashtags ）",
    'ar': "🪄 <b>أدخل</b> <b>نصًا</b> قصيرًا سيتم إضافته إلى نهاية منشورات القناة (على سبيل المثال، #hashtags المستخدمة بشكل متكرر )",
}
l_cdecor_footer_done = {
    'ru': "🪄 <b>Готово!</b> <b>Футер</b> из <u>{0}</u>-символов будет использоваться как окончание поста в канале\n\n👩🏽‍💻 Опцию можно выключить, установив <b>[☑️☐Выкл футер]</b>",
    'en': "🪄 <b>Done!</b> <b>Footer</b> of <u>{0}</u>-characters will be used as the end of a post in the channel\n\n👩🏽‍💻 The option can be turned off, by setting <b>[☑️☐Off footer]</b>",
    'es': "🪄 <b>¡Listo!</b> <b>Pie de página</b> de <u>{0}</u>caracteres se utilizará como final de una publicación en el canal\n\n👩🏽‍ 💻 La opción se puede desactivar configurando <b>[☑️☐Off footer]</b>",
    'fr': "🪄 <b>Terminé !</b> <b>Pied de page</b> de <u>{0}</u>caractères sera utilisé comme fin d'une publication dans la chaîne\n\n👩🏽‍ 💻 L'option peut être désactivée en définissant <b>[☑️☐Off footer]</b>",
    'zh': "🪄 <b>完成！</b> <b>页脚</b>（共 <u>{0}</u> 个字符）将用作频道中帖子的结尾\n\n👩🏽‍ 💻 可以通过设置<b>[☑️buryOff footer]</b>来关闭该选项",
    'ar': "🪄 <b>تم!</b> <b>التذييل</b> المكون من <u>{0}</u>-الأحرف سيتم استخدامه كنهاية لمنشور في القناة\n\n👩🏽‍ 💻 يمكن إيقاف الخيار من خلال ضبط <b>[☑️☐Off footer]</b>",
}
l_cdecor_page_on = {
    'ru': "✅☑Вкл пагинация",
    'en': "✅☑Including pagination",
    'es': "✅☑Incluye paginación",
    'fr': "✅☑Y compris la pagination",
    'zh': "✅☑包括分页",
    'ar': "✅☑بما في ذلك ترقيم الصفحات",
}
l_cdecor_page_off = {
    'ru': "☑️☐Выкл пагинация",
    'en': "☑️☐Off pagination",
    'es': "☑️☐Fuera de paginación",
    'fr': "☑️☐Hors pagination",
    'zh': "☑️️关闭分页",
    'ar': "☑️☐ خارج ترقيم الصفحات",
}
l_cdecor_footer_on = {
    'ru': "✅☑Вкл футер",
    'en': "✅☑Footer included",
    'es': "✅☑Pie de página incluido",
    'fr': "✅☑Pied de page inclus",
    'zh': "✅☑包含页脚",
    'ar': "✅☑تذييل متضمن",
}
l_cdecor_footer_off = {
    'ru': "☑️☐Выкл футер",
    'en': "☑️☐Off footer",
    'es': "☑️☐Fuera del pie de página",
    'fr': "☑️☐Hors pied de page",
    'zh': "☑️️页脚外",
    'ar': "☑️☐ خارج التذييل",
}
l_cdecor_format_on = {
    'ru': "✅☑Вкл формат",
    'en': "✅☑Including format",
    'es': "✅☑Incluyendo formato",
    'fr': "✅☑Format inclus",
    'zh': "✅☑包括格式",
    'ar': "✅☑بما في ذلك التنسيق",
}
l_cdecor_format_off = {
    'ru': "☑️☐Выкл формат",
    'en': "☑️☐Format Off",
    'es': "☑️☐Formatear desactivado",
    'fr': "☑️☐Format désactivé",
    'zh': "☑️️格式化关闭",
    'ar': "☑️☐التنسيق معطل",
}
l_cdecor_footer = {
    'ru': "👩🏽‍💻 <b>Футер</b>: {0}",
    'en': "👩🏽‍💻 <b>Footer</b>: {0}",
    'es': "👩🏽‍💻 <b>Pie de página</b>: {0}",
    'fr': "👩🏽‍💻 <b>Pied de page</b> : {0}",
    'zh': "👩🏽‍💻 <b>页脚</b>：{0}",
    'ar': "👩🏽‍💻 <b>التذييل</b>: {0}",
}
# endregion


# region cmember_
l_cmember_text = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> сбор подписчиков канала\n\n<blockquote>👩🏽‍💻 Для выгрузки подписчиков канала выполни команду /parse</blockquote>",
    'en': "👥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> collecting channel subscribers\n\n👩🏽‍💻 To download channel subscribers, run the /parse command",
    'es': "👥 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> recopilar suscriptores del canal\n\n👩🏽‍💻 Para descargar suscriptores del canal, ejecuta el comando /parse",
    'fr': "👥 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la collecte des abonnés à la chaîne\n\n👩🏽‍💻 Pour télécharger les abonnés à la chaîne, exécutez la commande /parse",
    'zh': "👥 <b>按</b> ✅/☑️ <b>开/关</b>收集频道订阅者\n\n👩🏽‍💻 要下载频道订阅者，请运行 /parse 命令",
    'ar': "👥 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> تجميع مشتركي القناة\n\n👩🏽‍💻 لتنزيل مشتركي القناة، قم بتشغيل الأمر /parse",
}
l_cmember_on = {
    'ru': "👁️‍🗨️ <b>Готово!</b> Текущее количество <b>авто-просмотров</b> на последний пост канала установлено в значение <u>{0}</u>",
    'en': "👁️‍🗨️ <b>Done!</b> The current number of <b>auto-views</b> for the last channel post is set to <u>{0}</u>",
    'es': "👁️‍🗨️ <b>¡Listo!</b> El número actual de <b>vistas automáticas</b> para la última publicación del canal está establecido en <u>{0}</u>",
    'fr': "👁️‍🗨️ <b>Terminé !</b> Le nombre actuel de <b>vues automatiques</b> pour la dernière publication de la chaîne est défini sur <u>{0}</u>",
    'zh': "👁️‍🗨️ <b>完成！</b> 最后一个频道帖子的当前<b>自动观看</b>数量设置为<u>{0}</u>",
    'ar': "👁️‍🗨️ <b>تم!</b> تم تعيين العدد الحالي من <b>المشاهدات التلقائية</b> لآخر مشاركة في القناة على <u>{0}</u>",
}
l_cmember_off = {
    'ru': "👁️‍🗨️ <b>Режим</b> /view-авто-просмотров отключен",
    'en': "👁️‍🗨️ <b>Mode</b> /view-auto-views disabled",
    'es': "👁️‍🗨️ <b>Modo</b> /view-auto-views deshabilitado",
    'fr': "👁️‍🗨️ <b>Mode</b> /view-auto-views désactivé",
    'zh': "👁️‍🗨️ <b>模式</b> /view-auto-views 已禁用",
    'ar': "👁️‍🗨️ <b>الوضع</b> /العرض التلقائي معطل",
}
l_cmember_parse = {
    'ru': "👥 <b>Cписок</b> подписчиков: <u>{0}</u>\n\n[✅ <i>Назначение администраторов</i>] - включение опции позволяет получить подписчиков до добавления @{1}-бота\n\n👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей",
    'en': "👥 <b>List</b> of subscribers: <u>{0}</u>\n\n[✅ <i>Assigning administrators</i>]-enabling this option allows you to get subscribers before adding @{1}-bot\n\n👩🏽‍💻 <b>Subscribe</b> <a href='{2}'>💨Subscribe</a> to receive usernames",
    'es': "👥 <b>Lista</b> de suscriptores: <u>{0}</u>\n\n[✅ <i>Asignar administradores</i>]-habilitar esta opción le permite obtener suscriptores antes de agregar @ {1}-bot\n\n👩🏽‍💻 <b>Suscríbete</b> <a href='{2}'>💨Suscríbete</a> para recibir nombres de usuario",
    'fr': "👥 <b>Liste</b> des abonnés : <u>{0}</u>\n\n[✅ <i>Attribution des administrateurs</i>]-l'activation de cette option vous permet d'obtenir des abonnés avant d'ajouter @ {1}-bot\n\n👩🏽‍💻 <b>Abonnez-vous</b> <a href='{2}'>💨Abonnez-vous</a> pour recevoir des noms d'utilisateur",
    'zh': "👥 订阅者<b>列表</b>：<u>{0}</u>\n\n[✅ <i>分配管理员</i>]-启用此选项可让您在添加 @ 之前获取订阅者{1}-机器人\n\n👩🏽‍💻 <b>订阅</b> <a href='{2}'>💨订阅</a>以接收用户名",
    'ar': "👥 <b>قائمة</b> المشتركين: <u>{0}</u>\n\n[✅ <i>تعيين المسؤولين</i>]-يتيح لك تمكين هذا الخيار الحصول على مشتركين قبل إضافة @ {1}-bot\n\n👩🏽‍💻 <b>اشتراك</b> <a href='{2}'>💨اشتراك</a> لتلقي أسماء المستخدمين",
}
l_parse_rights = {
    'ru': "👥 <b>В настройках</b> [Администраторы] вкл опцию для @{0}-бота:\n[✅ Назначение администраторов]\n🕚Подожди 1min\n👩🏽‍💻 Выполни команду /parse\n\n⚙️ <b>Команды</b> /cmd",
    'en': "👥 <b>In settings</b> [Administrators] enable the option for @{0}-bot:\n[✅ Assigning administrators]\n🕚Wait 1min\n👩🏽‍💻 Run the command /parse\n\n⚙️ <b>Commands</b> /cmd",
    'es': "👥 <b>En configuración</b> [Administradores] habilita la opción para @{0}-bot:\n[✅ Asignando administradores]\n🕚Espera 1 minuto\n👩🏽‍💻 Ejecuta el comando /parse\n\ n⚙️ <b>Comandos</b> /cmd",
    'fr': "👥 <b>Dans les paramètres</b> [Administrateurs] activez l'option pour @{0}-bot :\n[✅ Attribution des administrateurs]\n🕚Attendez 1 min\n👩🏽‍💻 Exécutez la commande /parse\n\ n⚙️ <b>Commandes</b> /cmd",
    'zh': "👥 <b>在设置中</b> [管理员]启用 @{0}-bot 的选项：\n[✅ 分配管理员]\n🕚等待 1 分钟\n👩🏽‍💻 运行命令 /parse\n\ n⚙️ <b>命令</b> /cmd",
    'ar': "👥 <b>في الإعدادات</b> [المسؤولون] قم بتمكين خيار @{0}-bot:\n[✅ تعيين المسؤولين]\n🕚انتظر دقيقة واحدة\n👩🏽‍💻 قم بتشغيل الأمر /parse\n\n⚙️ <b>الأوامر</b> /cmd",
}
# endregion
# endregion


# region FereyGroupBot
l_grp_btn1 = {
    'ru': "👩🏽‍💻 Группы",
    'en': "👩🏽‍💻 Groups",
    'es': "👩🏽‍💻 Grupos",
    'fr': "👩🏽‍💻 Groupes",
    'zh': "👩🏽‍💻 团体",
    'ar': "👩🏽‍💻 المجموعات",
}
l_grp_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_grp_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> модерации <b>Telegram</b>-групп:\n\n<blockquote>▪️<b>защита</b> группы от шпионов\n▪️ограничение прав до <b>подписки</b>\n▪️<b>организация</b> бана/анти-флуда\n▪️аналитика и <b>вовлеченность</b>\n▪️<b>авто-ответы</b> и стоп-слова\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to <i>landing bot</i> moderation of <b>Telegram</b> groups:\n\n▪️<b>protection</b> groups from spies\n▪️restriction of rights to <b>subscription</b>\n▪️<b>organization</b> ban/anti-flood\n▪️analytics and <b>engagement</b>\n▪️< b>auto-responses</b> and stop words\n▪️button <b>counter</b>\n▪️<b>web app/neuro</b>-posting\n\n❗️<b> Regularly</b>updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido a la moderación del <i>bot de aterrizaje</i> de grupos de <b>Telegram</b>:\n\n▪️<b>grupos de protección</b> de espías\n▪️restricción de derechos de <b>suscripción</b>\n▪️<b>organización</b> prohibición/anti-inundación\n▪️análisis y <b>compromiso</b>\n▪️< b >respuestas automáticas</b> y palabras vacías\n▪️botón <b>contador</b>\n▪️<b>aplicación web/neuro</b>-publicación\n\n❗️<b> regularmente</ b>actualizado/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue dans la modération <i>landing bot</i> des groupes <b>Telegram</b> :\n\nproducer<b>groupes de protection</b> de espions\nְ️restriction des droits d'<b>abonnement</b>\n▪️<b>organisation</b> interdiction/anti-inondation\n▪️analyses et <b>engagement</b>\nnoyance</b>< b >réponses automatiques</b> et mots vides\nƒ️bouton <b>compteur</b>\nƒ️<b>application web/neuro</b>-publication\n\n❗️<b> Régulièrement</ b>mis à jour/contenu",
    'zh': "🌱 <b>{0}</b>，欢迎<i>登陆机器人</i>管理 <b>Telegram</b> 群组：\n\n▪️<b>保护</b>群组间谍\n▪️限制<b>订阅</b>\n▪️<b>组织</b>禁令/反洪水\n▪️分析和<b>参与</b>\n▪️< b >自动回复</b>和停用词\n▪️按钮<b>计数器</b>\n▪️<b>网络应用/神经</b>-发布\n\n❗️<b>定期</ b>更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في الإشراف على <i>الروبوت المقصود</i> لمجموعات <b>Telegram</b>:\n\n▪️<b>الحماية</b> من المجموعات من الجواسيس\n▪️تقييد حقوق <b>الاشتراك</b>\n▪️<b>المنظمة</b> الحظر/مكافحة الفيضانات\n▪️التحليلات و<b>المشاركة</b>\n▪️< b >الردود التلقائية</b> وكلمات التوقف\n▪️زر <b>العداد</b>\n▪️<b>تطبيق الويب/العصبي</b>-النشر\n\n❗️<b> بانتظام</ ب> محدث/المحتوى",
}
l_grp_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyGroupBot-11-13',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_group = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>добавление</b> нескольких групп\n▪️более 10 <b>стоп-слов</b>\n▪️более 1 <b>старт-слова</b>\n▪️<b>нейро</b>-постинг\n▪️аудио/видео-<b>подкасты</b> более 1мин\n▪️<b>/parse</b> подписчиков/кликов</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>adding</b> several groups\n▪️more than 10 <b>stop words</b>\n▪️more than 1 <b>start word</b>\n▪️<b>neuro</b>-posting\n▪️audio/video-<b>podcasts</b> more than 1 min\n▪️<b>/parse</b> subscribers/clicks\n\n👩🏽‍ 💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>añadiendo</b> varios grupos\n▪️más de 10 <b>palabras finales</b>\n▪️más de 1 <b>palabra inicial</b>\n▪️<b>neuro</b>-posting\n▪️audio/video-<b>podcasts</b> más de 1 min\n▪️<b>/parse</b> suscriptores/clics\n\ n👩🏽‍ 💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnounced<b>ajout</b> de plusieurs groupes\nnoyerplus de 10 <b>mots vides</b>\nnoyer️plus d'un <b>mot de départ</b>\n▪️<b>neuro</b>-posting\n▪️audio/vidéo-<b>podcasts</b> plus d'1 minute\nnoyance<b>/analyser</b> abonnés/clics\n\ n👩🏽‍ 💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>添加</b>多个组\n▪️超过 10 个<b>停用词</b>\n▪️超过 1 个<b>起始词</b>\n▪️<b>neuro</b>-发布\n▪️音频/视频-<b>播客</b>超过 1 分钟\n▪️<b>/parse</b> 订阅者/点击\n\ n👩🏽‍💻/余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إضافة</b> عدة مجموعات\n▪️أكثر من 10 <b>كلمات توقف</b>\n▪️أكثر من <b>كلمة بداية</b>\n▪️<b>neuro</b>-النشر\n▪️audio/video-<b>podcasts</b> أكثر من دقيقة واحدة\n▪️<b>/parse</b> المشتركون/النقرات\n\n👩🏽‍ 💻 /balance",
}
l_cmd_txt_grp = {
    'ru': "👩🏽‍💻 <b>Жми</b> [➕ Добавить группу]",
    'en': "👩🏽‍💻 <b>Click</b> [➕ Add group]",
    'es': "👩🏽‍💻 <b>Haga clic</b> [➕ Agregar grupo]",
    'fr': "👩🏽‍💻 <b>Cliquez</b> [➕ Ajouter un groupe]",
    'zh': "👩🏽‍💻 <b>点击</b> [➕ 添加群组]",
    'ar': "👩🏽‍💻 <b>انقر</b> [➕ إضافة مجموعة]",
}

l_add_group_text = {
    'ru': "👇🏽 <b>Жми</b> на [➕ Добавить группу], чтобы добавить в свою группу (с настройками по ум) бота: @{0}\n\n<blockquote>👮🏽‍♀️ <b>Или</b> добавь бота как <b>Administrator</b> через настройки своей группы:\n[👤 Добавить администратора]\n\n👮🏽‍♀️ <b>Если</b> не добавляется группа, то измени <b>Должность</b> (см. скрин)</blockquote>",
    'en': "👇🏽 <b>Click</b> on [➕ Add group] to add a bot to your group (with custom settings): @{0}\n\n👮🏽‍♀️ Or add a bot as <b>Administrator </b> through your group settings: [👤Add Admin]\n\n👮🏽‍♀️ If the group is not added, then change <b>Position</b> (see screenshot)",
    'es': "👇🏽 <b>Haga clic</b> en [➕ Agregar grupo] para agregar un bot a su grupo (con configuración personalizada): @{0}\n\n👮🏽‍♀️ O agregue un bot como <b>Administrador </b> a través de la configuración de tu grupo: [👤Agregar administrador]\n\n👮🏽‍♀️ Si el grupo no se agrega, cambia la <b>Posición</b> (ver captura de pantalla)",
    'fr': "👇🏽 <b>Cliquez</b> sur [➕ Ajouter un groupe] pour ajouter un bot à votre groupe (avec des paramètres personnalisés) : @{0}\n\n👮🏽‍♀️ Ou ajoutez un bot en tant qu'<b>Administrateur </b> via les paramètres de votre groupe : [👤Ajouter un administrateur]\n\n👮🏽‍♀️ Si le groupe n'est pas ajouté, modifiez la <b>Position</b> (voir capture d'écran)",
    'zh': "👇🏽<b>点击</b><➕添加组>>将机器人添加到您的组（使用自定义设置）：@{0}\n\n👮🏽‍♀️ 或将机器人添加为<b>管理员</b> 通过您的群组设置：<👤添加管理员]\n\n👮🏽‍♀️ 如果未添加群组，则更改<b>位置</b>（参见屏幕截图）",
    'ar': "👇🏽 <b>انقر</b> على [➕ إضافة مجموعة] لإضافة روبوت إلى مجموعتك (مع إعدادات مخصصة): @{0}\n\n👮🏽‍♀️ أو أضف روبوتًا كـ <b>مسؤول </b> من خلال إعدادات مجموعتك: [👤إضافة مسؤول]\n\n👮🏽‍♀️ إذا لم تتم إضافة المجموعة، فقم بتغيير <b>المنصب</b> (انظر لقطة الشاشة)",
}
l_add_group_button = {
    'ru': "➕ Добавить группу",
    'en': "➕ Add group",
    'es': "➕ Agregar grupo",
    'fr': "➕ Ajouter un groupe",
    'zh': "➕ 添加群组",
    'ar': "➕ إضافة مجموعة",
}
l_grp_already_taken = {
    'ru': "👮🏽 <b>Группа</b> [<b>{0}</b>] уже <i>модерируется</i> в @{1}-боте",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}
l_grp_subscribe_call = {
    'ru': "👩🏽‍💻 Необходима подписка на группу",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}


# region group
l_grp_config = {
    ("ccheck", "👮🏽", "☑"): {
        'ru': "Входной контроль",
        'en': "Incoming control",
        'es': "Control entrante",
        'fr': "Contrôle entrant",
        'zh': "传入控制",
        'ar': "السيطرة الواردة",
    },
    ("chello", "👋🏽", "☐"): {
        'ru': "Авто-приветствие",
        'en': "Auto greeting",
        'es': "Saludo automático",
        'fr': "Message d'accueil automatique",
        'zh': "自动问候语",
        'ar': "تحية تلقائية",
    },
    ("cban", "🕵🏽", "☑"): {
        'ru': "Авто-бан",
        'en': "Auto-ban",
        'es': "Prohibición automática",
        'fr': "Interdiction automatique",
        'zh': "自动禁止",
        'ar': "الحظر التلقائي",
    },
    ("cpost", "🔔", "☐"): {
        'ru': "Авто-постинг",
        'en': "Auto-posting",
        'es': "Publicación automática",
        'fr': "Publication automatique",
        'zh': "自动发布",
        'ar': "النشر التلقائي",
    },
    ("cneuro", "🦾", "☐"): {
        'ru': "Нейро-постинг",
        'en': "Neuro-posting",
        'es': "Neuropublicación",
        'fr': "Neuro-posting",
        'zh': "神经张贴",
        'ar': "النشر العصبي",
    },

    ("csystem", "👣", "☐"): {
        'ru': "Сообщ системные",
        'en': "System messages",
        'es': "Mensajes del sistema",
        'fr': "Messages système",
        'zh': "系统消息",
        'ar': "رسائل النظام",
    },
    ("cchannel", "🫥", "☐"): {
        'ru': "Cообщ от‍ имени канала",
        'en': "Message on behalf of the channel",
        'es': "Mensaje en nombre del canal.",
        'fr': "Message au nom de la chaîne",
        'zh': "代表频道留言",
        'ar': "رسالة باسم القناة",
    },
    ("clink", "🔗", "☑"): {
        'ru': "Cообщ с ссылками",
        'en': "Message with links",
        'es': "Mensaje con enlaces",
        'fr': "Message avec liens",
        'zh': "带有链接的消息",
        'ar': "رسالة مع الروابط",
    },
    ("csymbol", "文", "☐"): {
        'ru': "Cообщ с 文/ب/ȳ̵͘̚",
        'en': "Posted by 文/ب/ȳ̵͘̚",
        'es': "Publicado por 文/ب/ȳ̵͘̚",
        'fr': "Publié par 文/ب/ȳ̵͘̚",
        'zh': "发表者 文/巴/ş̵͘̚",
        'ar': "أرسلت بواسطة 文/ب/ ş̵͘̚",
    },
    ("cmedia", "🗣", "☐"): {
        'ru': "Сообщ с медиа",
        'en': "Message from media",
        'es': "Mensaje de los medios",
        'fr': "Message des médias",
        'zh': "媒体消息",
        'ar': "رسالة من وسائل الإعلام",
    },

    ("cstart", "🚀", "☐"): {
        'ru': "Старт-слова",
        'en': "Start words",
        'es': "Palabras iniciales",
        'fr': "Mots de départ",
        'zh': "起始词",
        'ar': "ابدأ الكلمات",
    },
    ("cstop", "🧾", "☐"): {
        'ru': "Стоп-слова",
        'en': "Safe words",
        'es': "Palabras seguras",
        'fr': "Mots sûrs",
        'zh': "安全词",
        'ar': "كلمات آمنة",
    },
    ("cdialog", "💬", "☑"): {
        'ru': "Нейро-диалог",
        'en': "Stop-flood",
        'es': "Detener la inundación",
        'fr': "Stop-inondation",
        'zh': "止洪",
        'ar': "وقف الفيضانات",
    },
    ("cuser", "👥", "☑"): {
        'ru': "Пользователи",
        'en': "Users",
        'es': "Usuarios",
        'fr': "Utilisateurs",
        'zh': "用户",
        'ar': "المستخدمين",
    },
    ("cadmin", "👮🏽", "☑"): {
        'ru': "Администраторы",
        'en': "Administrators",
        'es': "Administradores",
        'fr': "Administrateurs",
        'zh': "管理员",
        'ar': "المسؤولين",
    },

    ("cpay", "⭐️", "☐"): {
        'ru': "Оплата подписки",
        'en': "Start words",
        'es': "Palabras iniciales",
        'fr': "Mots de départ",
        'zh': "起始词",
        'ar': "ابدأ الكلمات",
    },
    ("ccomment", "🪙", "☐"): {
        'ru': "Оплата кѻмментов",
        'en': "Start words",
        'es': "Palabras iniciales",
        'fr': "Mots de départ",
        'zh': "起始词",
        'ar': "ابدأ الكلمات",
    },
}
l_remove_group = {
    'ru': "🚫Убрать группу",
    'en': "🚫Remove group",
    'es': "🚫Eliminar grupo",
    'fr': "🚫Supprimer le groupe",
    'zh': "🚫删除群组",
    'ar': "🚫إزالة المجموعة",
}
l_show_groups = {
    'ru': "👩🏽‍💻 <b>Добавленные группы</b>\n\n[команды /cmd]",
    'en': "👩🏽‍💻 <b>Added groups</b>\n\n[commands/cmd]",
    'es': "👩🏽‍💻 <b>Grupos agregados</b>\n\n[commands/cmd]",
    'fr': "👩🏽‍💻 <b>Groupes ajoutés</b>\n\n[commands/cmd]",
    'zh': "👩🏽‍💻 <b>已添加组</b>\n\n[命令/cmd]",
    'ar': "👩🏽‍💻 <b>المجموعات المضافة</b>\n\n[commands/cmd]",
}

l_GROUPP_CCHECKBTNNAME = {
    'ru': "✔ Я человек",
    'en': "✔ I'm human",
    'es': "✔soy humano",
    'fr': "✔ Je suis humain",
    'zh': "✔ 我是人类",
    'ar': "✔ أنا إنسان",
}
l_GROUPP_CHELLOTEXT = {
    'ru': "🌱 {name}, добро пожаловать в нашу <b>группу</b> {title}!",
    'en': "🌱 {name}, welcome to our <b>group</b> {title}!",
    'es': "🌱 {name}, ¡bienvenido a nuestro <b>grupo</b> {title}!",
    'fr': "🌱 {name}, bienvenue dans notre <b>groupe</b> {title} !",
    'zh': "🌱 {name}，欢迎加入我们的<b>群组</b> {title}！",
    'ar': "🌱 {name}، مرحبًا بك في <b>مجموعتنا</b> {title}!",
}
l_GROUPP_CCHECKCHANNEL = {
    'ru': "👮🏽 Для <i>проверки подписки</i> необходимо добавить канал командой:\n\n/channel ССЫЛКА НА КАНАЛ",
    'en': "👮🏽 To <i>check subscription</i> you need to add a channel with the command:\n\n/channel LINK TO CHANNEL",
    'es': "👮🏽 Para <i>verificar suscripción</i> necesitas agregar un canal con el comando:\n\n/canal ENLACE AL CANAL",
    'fr': "👮🏽 Pour <i>vérifier l'abonnement</i> vous devez ajouter une chaîne avec la commande :\n\n/channel LIEN VERS LA CHAÎNE",
    'zh': "👮🏽 要<i>检查订阅</i>，您需要使用以下命令添加频道：\n\n/channel LINK TO CHANNEL",
    'ar': "👮🏽 <i>للتحقق من الاشتراك</i>، يلزمك إضافة قناة باستخدام الأمر:\n\n/channel LINK TO CHANNEL",
}
# endregion


# region commands
l_grp_commands_handler = {
    'ru': "⚙️ <b>Команды</b> /cmd для [<b>{0}</b>] {1} [<code>{2}</code>]\n\n<b>⛏ Команды в @{3}</b>\n<blockquote>/info информация о группе\n/stat статистика\n/parse [all|old|premium|active|online|POST_ID]\n/random [1] рандомный лайкнувший пост #1\n/podcast 1 1 анонс видео-подкаста\n<code>/clean</code> очистка от deleted/scam-аккаунтов и по [<b>🕵🏽 Авто-бан</b>] правилам\n/delete <code>FROM TO</code> удаление за период\n/work HH:MM HH:MM часы работы группы\n/transfer передача ADMIN-прав</blockquote>\n\n<b>⛏ Команды администраторов</b>\n<blockquote>/ban 5m|1h|10d удаление на время\n/unban\n/mute 5m|1h|10d ограничение на время\n/unmute\n/warn+сообщ предупреждение\n/status\n/karma [+|-]\n/tag+сообщ случайное @упоминание\n/stop добавить стоп-слово\n/channel NAME канал проверки подписки\n/button NAME имя кнопки входного контроля\n/delay MIN задержка 1го сообщ в мин\n/flood NUM количество сообщ для флуд-режима\n/len MAX max-длина сообщ\n/timer SEC задержка 1го кѻмментария в сек</blockquote>\n\n<b>⛏ Команды пользователей</b>\n<blockquote>/help вывод команд\n/rules правила группы\n/report сообщить о нарушении\n/happy получить радость\n/thanks поблагодарить\n/birthday поздравить</blockquote>\n\n💨 <b>Подписка</b>: <i>{4}</i>",
    'en': "⚙️ <b>Commands</b> /cmd for [<b>{0}</b>] {1}\n\n<b>⛏ Commands in @{2}</b>\n/info < i>group information</i>\n/stat <i>statistics</i>\n/parse <i>[all|old|premium|active|online|'post_id']</i>\n/ podcast 1 1 <i>announcement of a video podcast</i>\n<code>/clean</code> <i>cleaning of deleted/scam accounts and [🕵🏽 Auto-ban] rules</i>\n/delete <code>FROM TO</code> <i>delete for a period</i>\n/work <i>group work hours</i>\n/transfer <i>transfer of admin rights</i>\n\n<b>⛏ Administrator commands</b>\n/ban 5m|1h|10d <i>temporary removal</i>\n/unban\n/mute 5m|1h|10d <i>restriction for a while</i>\n/unmute\n/warn+message <i>warning</i>\n/status\n/karma [+|-]\n/tag+message <i> @tager random-accounts</i>\n/stop <i>add a safe word</i>\n/channel NAME <i>subscription verification channel</i>\n/button NAME <i>input control button name</i >\n/delay MIN <i>delay of the 1st message in min</i>\n/flood NUM <i>number of messages for flood mode</i>\n/len MAX <i>max message length</ i>\n/timer SEC <i>delay of the 1st comment in sec</i>\n\n<b>⛏ User commands</b>\n/help <i>command output</i>\n/rules <i>group rules</i>\n/report <i>report violation</i>\n/happy <i>get joy</i>\n/thanks <i>thank</i>\n/birthday <i>congratulate</i>\n\n💨 <b>Subscription</b>: <i>{3}</i>",
    'es': "⚙️ <b>Comandos</b> /cmd para [<b>{0}</b>] {1}\n\n<b>⛏ Comandos en @{2}</b>\n/info < i>información del grupo</i>\n/stat <i>estadísticas</i>\n/parse <i>[all|old|premium|active|online|'post_id']</i>\n/ podcast 1 1 <i>anuncio de un podcast de vídeo</i>\n<code>/clean</code> <i>limpieza de cuentas eliminadas/estafas y reglas de [🕵🏽 Auto-ban]</i>\n/ eliminar <code>DE HASTA</code> <i>eliminar por un período</i>\n/work <i>horas de trabajo grupal</i>\n/transfer <i>transferencia de derechos de administrador</i>\n\n<b>⛏ Comandos de administrador</b>\n/ban 5m|1h|10d <i>eliminación temporal</i>\n/unban\n/mute 5m|1h|10d <i>restricción para un rato</i>\n/activar silencio\n/warn+mensaje <i>advertencia</i>\n/status\n/karma [+|-]\n/tag+mensaje <i> @tager aleatorio-cuentas</i>\n/stop <i>añadir una palabra segura</i>\n/channel NAME <i>canal de verificación de suscripción</i>\n/button NAME <i>ingrese el nombre del botón de control</i >\n/delay MIN <i>retraso del 1er mensaje en min</i>\n/flood NUM <i>número de mensajes para el modo de inundación</i>\n/len MAX <i>longitud máxima del mensaje< / i>\n/timer SEC <i>retraso del 1er comentario en segundos</i>\n\n<b>⛏ Comandos de usuario</b>\n/help <i>salida del comando</i>\ n/rules <i>reglas del grupo</i>\n/report <i>informar infracción</i>\n/feliz <i>obtener alegría</i>\n/gracias <i>gracias</i>\n/cumpleaños <i>felicitaciones</i>\n\n💨 <b>Suscripción</b>: <i>{3}</i>",
    'fr': "⚙️ <b>Commandes</b> /cmd pour [<b>{0}</b>] {1}\n\n<b>⛏ Commandes dans @{2}</b>\n/info < i>informations sur le groupe</i>\n/stat <i>statistiques</i>\n/parse <i>[all|old|premium|active|online|'post_id']</i>\n/ podcast 1 1 <i>annonce d'un podcast vidéo</i>\n<code>/clean</code> <i>nettoyage des comptes supprimés/arnaqueurs et règles de [🕵🏽 Auto-ban]</i>\n/ supprimer <code>DE VERS</code> <i>supprimer pour une période</i>\n/travail <i>heures de travail en groupe</i>\n/transfert <i>transfert des droits d'administrateur</i>\n\n<b>⛏ Commandes administrateur</b>\n/ban 5m|1h|10d <i>suppression temporaire</i>\n/unban\n/mute 5m|1h|10d <i>restriction pour un moment</i>\n/activer le son\n/warn+message <i>avertissement</i>\n/status\n/karma [+|-]\n/tag+message <i> @tager random-comptes</i>\n/stop <i>ajouter un mot de sécurité</i>\n/nom du canal <i>canal de vérification d'abonnement</i>\n/nom du bouton <i>nom du bouton de contrôle de saisie</i >\n/delay MIN <i>délai du 1er message en min</i>\n/flood NUM <i>nombre de messages pour le mode Flood</i>\n/len MAX <i>longueur max du message< / i>\n/timer SEC <i>délai du 1er commentaire en sec</i>\n\n<b>⛏ Commandes utilisateur</b>\n/help <i>sortie de commande</i>\ n/règles <i>règles de groupe</i>\n/rapport <i>signaler une violation</i>\n/heureux <i>prenez de la joie</i>\n/merci <i>merci</i>\n/anniversaire <i>féliciter</i>\n\n💨 <b>Abonnement</b> : <i>{3}</i>",
    'zh': "⚙️ <b>命令</b> /cmd for [<b>{0}</b>] {1}\n\n<b>⛏ @{2}</b>\n/info 中的命令 < i>群组信息</i>\n/stat <i>统计</i>\n/parse <i>[all|old|premium|active|online|'post_id']</i>\n/ podcast 1 1 <i>视频播客公告</i>\n<code>/clean</code> <i>清理已删除/诈骗帐户和[🕵🏽自动禁止]规则</i>\n/删除<code>从到</code> <i>删除一段时间</i>\n/work <i>小组工作时间</i>\n/transfer <i>管理权限转让</i>\n\n<b>⛏ 管理员命令</b>\n/ban 5m|1h|10d <i>临时删除</i>\n/unban\n/mute 5m|1h|10d <i>限制一会儿</i>\n/unmute\n/warn+message <i>警告</i>\n/status\n/karma [+|-]\n/tag+message <i> @tager random-帐户</i>\n/stop <i>添加安全词</i>\n/channel NAME <i>订阅验证通道</i>\n/button NAME <i>输入控制按钮名称</i >\n/delay MIN <i>第一条消息的延迟时间</i>\n/flood NUM <i>洪水模式的消息数量</i>\n/len MAX <i>最大消息长度< / i>\n/timer SEC <i>以秒为单位延迟第一个注释</i>\n\n<b>⛏ 用户命令</b>\n/help <i>命令输出</i>\ n/rules<i>群组规则</i>\n/report<i>举报违规行为</i>\n/happy<i>获得快乐</i>\n/thanks<i>感谢</i>\n/生日<i>恭喜</i>\n\n💨<b>订阅</b>：<i>{3}</i>",
    'ar': "⚙️ <b>الأوامر</b> /cmd لـ [<b>{0}</b>] {1}\n\n<b>⛏ الأوامر في @{2}</b>\n/info <<i>معلومات المجموعة</i>\n/stat <i>الإحصائيات</i>\n/parse <i>[all|old|premium|active|online|'post_id']</i>\n/ podcast 1 1 <i>إعلان عن بودكاست فيديو</i>\n<code>/clean</code> <i>تنظيف الحسابات المحذوفة/المحتالة وقواعد [🕵🏽 الحظر التلقائي]</i>\n/ حذف <code>من إلى</code> <i>حذف لفترة</i>\n/العمل <i>ساعات عمل جماعية</i>\n/نقل <i>نقل حقوق المسؤول</i>\n\n<b>⛏ أوامر المسؤول</b>\n/ban 5m|1h|10d <i>الإزالة المؤقتة</i>\n/unban\n/mute 5m|1h|10d <i>تقييد لـ فترة</i>\n/unmute\n/warn+message <i>warning</i>\n/status\n/karma [+|-]\n/tag+message <i> @tager عشوائي-الحسابات</i>\n/stop <i>إضافة كلمة آمنة</i>\n/channel NAME <i>قناة التحقق من الاشتراك</i>\n/button NAME <i>اسم زر التحكم في الإدخال</i >\n/delay MIN <i>تأخير الرسالة الأولى في الحد الأدنى</i>\n/flood NUM <i>عدد الرسائل في وضع الفيضان</i>\n/len MAX <i>الحد الأقصى لطول الرسالة< /<i>\n/timer SEC <i>تأخير التعليق الأول في ثانية</i>\n\n<b>⛏ أوامر المستخدم</b>\n/help <i>مخرج الأمر</i>\n/rules <i>قواعد المجموعة</i>\n/report <i>الإبلاغ عن انتهاك</i>\n/happy <i>استمتع</i>\n/شكرًا <i>شكرًا</i>\n/عيد الميلاد <i>تهنئة</i>\n\n💨 <b>الاشتراك</b>: <i>{3}</i>",
}
l_update_handler00 = {
    'ru': "🛡 Для дальнейшего <b>администрирования</b> данной группы запусти @{0}-бота и добавь его в группу как <b>Administrator</b>",
    'en': "🛡 For further <b>administration</b> of this group, launch @{0}-bot and add it to the group as <b>Administrator</b>",
    'es': "🛡 Para una <b>administración</b> adicional de este grupo, inicie @{0}-bot y agréguelo al grupo como <b>Administrador</b>",
    'fr': "🛡 Pour une <b>administration</b> plus poussée de ce groupe, lancez @{0}-bot et ajoutez-le au groupe en tant qu'<b>Administrateur</b>",
    'zh': "🛡 要进一步<b>管理</b>此群组，请启动 @{0}-bot 并将其作为<b>管理员</b>添加到群组中",
    'ar': "🛡 لمزيد من <b>الإدارة</b> لهذه المجموعة، قم بتشغيل @{0}-bot وأضفه إلى المجموعة كـ <b>مسؤول</b>",
}
l_update_handler01 = {
    'ru': "🛡 Группа добавлена в @{0}-бота и готова к администрированию",
    'en': "🛡 The group has been added to @{0}-bot and is ready for administration",
    'es': "🛡 El grupo se agregó a @{0}-bot y está listo para su administración.",
    'fr': "🛡 Le groupe a été ajouté à @{0}-bot et est prêt pour l'administration",
    'zh': "🛡 该组已添加到 @{0}-bot 并准备好进行管理",
    'ar': "🛡 تمت إضافة المجموعة إلى @{0}-bot وهي جاهزة للإدارة",
}
l_update_handler10 = {
    'ru': "🛡 Группа обновлена и администрируется в @{0}-боте",
    'en': "🛡 The group has been updated and is administered by @{0}-bot",
    'es': "🛡 El grupo ha sido actualizado y es administrado por @{0}-bot",
    'fr': "🛡 Le groupe a été mis à jour et est administré par @{0}-bot",
    'zh': "🛡 该群组已更新并由@{0}-bot 管理",
    'ar': "🛡 تم تحديث المجموعة وإدارتها بواسطة @{0}-bot",
}
l_update_handler100 = {
    'ru': "🛡 Группа обновлена, но не подключена @{0}-боту! Для дальнейшего <b>администрирования</b> данной группы зайди в @{0}-бота и нажми /start",
    'en': "🛡 The group has been updated, but the @{0}-bot is not connected! For further <b>administration</b> of this group, go to @{0}-bot and press /start",
    'es': "🛡 ¡El grupo se ha actualizado, pero el @{0}-bot no está conectado! Para una <b>administración</b> adicional de este grupo, vaya a @{0}-bot y presione /iniciar",
    'fr': "🛡 Le groupe a été mis à jour, mais le @{0}-bot n'est pas connecté ! Pour une <b>administration</b> plus poussée de ce groupe, accédez à @{0}-bot et appuyez sur /start",
    'zh': "🛡 群组已更新，但@{0}-bot未连接！要进一步<b>管理</b>此群组，请转至 @{0}-bot 并按 /start",
    'ar': "🛡 تم تحديث المجموعة، ولكن @{0}-bot غير متصل! لمزيد من <b>الإدارة</b> لهذه المجموعة، انتقل إلى @{0}-bot واضغط على /start",
}
l_grp_info_start1 = {
    'ru': "👩🏽‍💻 <b>Информация</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "👩🏽‍💻 <b>Information</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'es': "👩🏽‍💻 <b>Información</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participante]{5}{6}{7}",
    'fr': "👩🏽‍💻 <b>Informations</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'zh': "👩🏽‍💻<b>信息</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3 }</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    'ar': "👩🏽‍💻 <b>المعلومات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>، <u>{4}</u> مشارك]{5}{6}{7}",
}
l_grp_stat_start = {
    'ru': "👩🏽‍💻 <b>Аналитика</b>\n\n",
    'en': "👩🏽‍💻 <b>Analytics</b>\n\n",
    'es': "👩🏽‍💻 <b>Análisis</b>\n\n",
    'fr': "👩🏽‍💻 <b>Analyses</b>\n\n",
    'zh': "👩🏽‍💻<b>分析</b>\n\n",
    'ar': "👩🏽‍💻 <b>التحليلات</b>\n\n",
}
l_grp_stat_start1 = {
    'ru': "👩🏽‍💻 <b>Аналитика</b>\n\n<b>Название</b>: {0} [id=<code>{1}</code>, <i>{2} {3}</i>, <u>{4}</u> участ.]{5}{6}{7}",
    'en': "👩🏽‍💻 <b>Analytics</b>\n\n<b>Name</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'es': "👩🏽‍💻 <b>Análisis</b>\n\n<b>Nombre</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participante]{5}{6}{7}",
    'fr': "👩🏽‍💻 <b>Analytics</b>\n\n<b>Nom</b> : {0} [id=<code>{1}</code>, <i>{2} {3 }</i>, <u>{4}</u> participant]{5}{6}{7}",
    'zh': "👩🏽‍💻<b>分析</b>\n\n<b>名称</b>：{0} [id=<code>{1}</code>，<i>{2} {3 }</i>，<u>{4}</u> 参与者]{5}{6}{7}",
    'ar': "👩🏽‍💻 <b>التحليلات</b>\n\n<b>الاسم</b>: {0} [id=<code>{1}</code>, <i>{2} {3 }</i>، <u>{4}</u> مشارك]{5}{6}{7}",
}
l_grp_stat_start2 = {
    'ru': "\n<b>Ссылка</b>: {0}\n<b>Описание</b>: {1}\n<b>Привязанный канал</b>: <code>{2}</code>\n",
    'en': "\n<b>Link</b>: {0}\n<b>Description</b>: {1}\n<b>Linked channel</b>: <code>{2}</code>\n",
    'es': "\n<b>Enlace</b>: {0}\n<b>Descripción</b>: {1}\n<b>Canal vinculado</b>: <code>{2}</code>\norte",
    'fr': "\n<b>Lien</b> : {0}\n<b>Description</b> : {1}\n<b>Chaîne liée</b> : <code>{2}</code>\n",
    'zh': "\n<b>链接</b>：{0}\n<b>说明</b>：{1}\n<b>链接频道</b>：<code>{2}</code>\n",
    'ar': "\n<b>الرابط</b>: {0}\n<b>الوصف</b>: {1}\n<b>القناة المرتبطة</b>: <code>{2}</code> \ن",
}
l_grp_stat_start3 = {
    'ru': "<b>Сообщения</b>: {0}\n<b>Дата 1го сообщ</b>: ~<code>{1}</code>\n<b>ID последнего сообщ</b>: {2}\n",
    'en': "<b>Messages</b>: {0}\n<b>Date of 1st message</b>: ~<code>{1}</code>\n<b>Last message ID</b>: { 2}\n",
    'es': "<b>Mensajes</b>: {0}\n<b>Fecha del primer mensaje</b>: ~<code>{1}</code>\n<b>ID del último mensaje</b>: { 2}\n",
    'fr': "<b>Messages</b> : {0}\n<b>Date du 1er message</b> : ~<code>{1}</code>\n<b>ID du dernier message</b> : { 2}\n",
    'zh': "<b>消息</b>：{0}\n<b>第一条消息的日期</b>：~<code>{1}</code>\n<b>最后一条消息 ID</b>： { 2}\n",
    'ar': "<b>الرسائل</b>: {0}\n<b>تاريخ الرسالة الأولى</b>: ~<code>{1}</code>\n<b>معرف الرسالة الأخيرة</b>: { 2}\ن",
}
l_participants = {
    'ru': "участ.",
    'en': "participation.",
    'es': "participación.",
    'fr': "participation.",
    'zh': "参与。",
    'ar': "مشاركة.",
}
l_info_opportunity = {
    'ru': "<b>Возможность просмотра увидевших сообщ</b>: Да (до 50участ.)\n",
    'en': "<b>Ability to view messages that have been seen</b>: Yes (up to 50 participants)\n",
    'es': "<b>Posibilidad de ver los mensajes que se han visto</b>: Sí (hasta 50 participantes)\n",
    'fr': "<b>Possibilité d'afficher les messages qui ont été vus</b> : Oui (jusqu'à 50 participants)\n",
    'zh': "<b>能够查看已查看的消息</b>：是（最多 50 名参与者）\n",
    'ar': "<b>القدرة على عرض الرسائل التي تمت رؤيتها</b>: نعم (حتى 50 مشاركًا)\n",
}
l_info_history = {
    'ru': "<b>История для новых участников</b>: ",
    'en': "<b>History for new members</b>:",
    'es': "<b>Historial de nuevos miembros</b>:",
    'fr': "<b>Historique des nouveaux membres</b> :",
    'zh': "<b>新成员的历史记录</b>：",
    'ar': "<b>سجل الأعضاء الجدد</b>:",
}
l_info_history_show = {
    'ru': "видна\n",
    'en': "prominent\n",
    'es': "destacado\n",
    'fr': "proéminent\n",
    'zh': "突出\n",
    'ar': "بارز\n",
}
l_info_history_hide = {
    'ru': "скрыта\n",
    'en': "hidden\n",
    'es': "oculto\n",
    'fr': "caché\n",
    'zh': "隐藏\n",
    'ar': "مخفي\n",
}
l_info_autodel = {
    'ru': "<b>Автоудаление сообщений</b>: ",
    'en': "<b>Auto-delete messages</b>:",
    'es': "<b>Eliminar mensajes automáticamente</b>:",
    'fr': "<b>Messages à suppression automatique</b> :",
    'zh': "<b>自动删除消息</b>：",
    'ar': "<b>حذف الرسائل تلقائيًا</b>:",
}
l_info_slowmode = {
    'ru': "<b>Как часто можно писать</b>: ",
    'en': "<b>How often can you write</b>:",
    'es': "<b>Con qué frecuencia puedes escribir</b>:",
    'fr': "<b>À quelle fréquence pouvez-vous écrire</b> :",
    'zh': "<b>您多久可以写一次</b>：",
    'ar': "<b>كم مرة يمكنك الكتابة</b>:",
}
l_info_slowmode_limitless = {
    'ru': "без ограничений\n",
    'en': "without restrictions\n",
    'es': "sin restricciones\n",
    'fr': "sans restrictions\n",
    'zh': "无限制\n",
    'ar': "بدون قيود\n",
}
l_info_oppforpart = {
    'ru': "Возможности участников",
    'en': "Participants' capabilities",
    'es': "Capacidades de los participantes.",
    'fr': "Capacités des participants",
    'zh': "参与者的能力",
    'ar': "قدرات المشاركين",
}
l_change_group_info = {
    'ru': "Изменение профиля группы",
    'en': "Changing a Group Profile",
    'es': "Cambiar un perfil de grupo",
    'fr': "Modification d'un profil de groupe",
    'zh': "更改群组资料",
    'ar': "تغيير ملف تعريف المجموعة",
}
l_pin_message = {
    'ru': "Закрепление сообщений",
    'en': "Pinning messages",
    'es': "Fijar mensajes",
    'fr': "Épingler des messages",
    'zh': "固定消息",
    'ar': "تثبيت الرسائل",
}
l_add_members = {
    'ru': "Добавление участников",
    'en': "Adding Participants",
    'es': "Agregar participantes",
    'fr': "Ajouter des participants",
    'zh': "添加参与者",
    'ar': "إضافة المشاركين",
}
l_embed_links = {
    'ru': "Предпросмотр ссылок",
    'en': "Link Preview",
    'es': "Vista previa del enlace",
    'fr': "Aperçu du lien",
    'zh': "链接预览",
    'ar': "معاينة الارتباط",
}
l_send_media = {
    'ru': "Отправка фото и видео",
    'en': "Sending photos and videos",
    'es': "Envío de fotos y vídeos",
    'fr': "Envoi de photos et de vidéos",
    'zh': "发送照片和视频",
    'ar': "إرسال الصور ومقاطع الفيديو",
}
l_send_polls = {
    'ru': "Отправка опросов",
    'en': "Submitting surveys",
    'es': "Enviar encuestas",
    'fr': "Soumettre des enquêtes",
    'zh': "提交调查",
    'ar': "تقديم الدراسات الاستقصائية",
}
l_send_stickers = {
    'ru': "Отправка sticker/giff/via_bot",
    'en': "Sending sticker/giff/via_bot",
    'es': "Enviando pegatina/giff/via_bot",
    'fr': "Envoi d'autocollant/giff/via_bot",
    'zh': "发送贴纸/giff/via_bot",
    'ar': "إرسال الملصق/gif/via_bot",
}
l_info_anonymous_for = {
    'ru': "Аноним для",
    'en': "Anonymous for",
    'es': "Anónimo para",
    'fr': "Anonyme pour",
    'zh': "匿名为",
    'ar': "مجهول ل",
}

l_stat_msg_cnt = {
    'ru': "Количество сообщ",
    'en': "Number of messages",
    'es': "Número de mensajes",
    'fr': "Nombre de messages",
    'zh': "消息数量",
    'ar': "عدد الرسائل",
}
l_stat_history_for_new = {
    'ru': "История для новых участников",
    'en': "History for new members",
    'es': "Historia para nuevos miembros",
    'fr': "Histoire pour les nouveaux membres",
    'zh': "新会员的历史",
    'ar': "التاريخ للأعضاء الجدد",
}
l_stat_history_turn_on = {
    'ru': "(для просмотра статистики <u>включите</u> [Историю группы])",
    'en': "(to view statistics, <u>turn on</u> [Group History])",
    'es': "(para ver estadísticas, <u>activa</u> [Historial de grupo])",
    'fr': "(pour afficher les statistiques, <u>activez</u> [Historique du groupe])",
    'zh': "（要查看统计信息，请<u>打开</u>[群组历史记录]）",
    'ar': "(لعرض الإحصائيات، <u>قم بتشغيل</u> [سجل المجموعة])",
}
l_stat_first_msg_date = {
    'ru': "Дата 1-го сообщ",
    'en': "Date of 1st communication",
    'es': "Fecha de la 1.ª comunicación",
    'fr': "Date de la 1ère communication",
    'zh': "第一次沟通的日期",
    'ar': "تاريخ أول اتصال",
}
l_stat_involved = {
    'ru': "Вовлеченность в чате",
    'en': "Chat engagement",
    'es': "Participación en el chat",
    'fr': "Engagement par chat",
    'zh': "聊天参与度",
    'ar': "مشاركة الدردشة",
}
l_stat_sent = {
    'ru': "{0}\n@{1} написал(а): {2}  сообщ",
    'en': "{0}\n@{1} wrote: {2} message",
    'es': "{0}\n@{1} escribió: {2} mensaje",
    'fr': "{0}\n@{1} a écrit : {2} message",
    'zh': "{0}\n@{1} 写道：{2} 条消息",
    'ar': "كتب {0}\n@{1}: {2} رسالة",
}
l_stat_meet = {
    'ru': "{0}\n{1}. <i>{2}</i>..: встретилось {3} раз",
    'en': "{0}\n{1}. <i>{2}</i>..: occurred {3} times",
    'es': "{0}\n{1}. <i>{2}</i>..: ocurrió {3} veces",
    'fr': "{0}\n{1}. <i>{2}</i>.. : s'est produit {3} fois",
    'zh': "{0}\n{1}。 <i>{2}</i>..：发生了 {3} 次",
    'ar': "{0}\n{1}. <i>{2}</i>..: حدث {3} مرة",
}
l_stat_top5users = {
    'ru': "Топ 5 пользователей (на 1000 сообщ)",
    'en': "Top 5 users (per 1000 posts)",
    'es': "5 usuarios principales (por cada 1000 publicaciones)",
    'fr': "5 principaux utilisateurs (pour 1 000 publications)",
    'zh': "前 5 位用户（每 1000 个帖子）",
    'ar': "أعلى 5 مستخدمين (لكل 1000 مشاركة)",
}
l_stat_top5msgs = {
    'ru': "Топ 5 сообщ (из 1000)",
    'en': "Top 5 messages (out of 1000)",
    'es': "Los 5 mensajes principales (de 1000)",
    'fr': "Top 5 des messages (sur 1000)",
    'zh': "前 5 条消息（共 1000 条）",
    'ar': "أفضل 5 رسائل (من 1000)",
}
l_status_for = {
    'ru': "👩🏽‍💻 <b>Статус</b> <b>{0}</b> для {1}:\n\n",
    'en': "👩🏽‍💻 <b>Status</b> <b>{0}</b> for {1}:\n\n",
    'es': "👩🏽‍💻 <b>Estado</b> <b>{0}</b> para {1}:\n\n",
    'fr': "👩🏽‍💻 <b>Statut</b> <b>{0}</b> pour {1} :\n\n",
    'zh': "👩🏽‍💻 <b>状态</b> <b>{0}</b>（{1}）：\n\n",
    'ar': "👩🏽‍💻 <b>الحالة</b> <b>{0}</b> لـ {1}:\n\n",
}

l_transfer_reply = {
    'ru': "👩🏽‍💻 <b>Используй</b> команду /transfer в <b>ответном</b> сообщении пользователя, которому вы хоти передать права\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Use</b> the /transfer command in a <b>reply</b> message from the user to whom you want to transfer rights\n\n⚙️ /cmd commands",
    'es': "👩🏽‍💻 <b>Utilice</b> el comando /transfer en un mensaje de <b>respuesta</b> del usuario al que desea transferir derechos\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Utilisez</b> la commande /transfer dans un message de <b>réponse</b> de l'utilisateur à qui vous souhaitez transférer les droits\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>在要向其转让权限的用户的<b>回复</b>消息中使用</b> /transfer 命令\n\n⚙️ /cmd 命令",
    'ar': "👩🏽‍💻 <b>استخدم</b> الأمر /transfer في رسالة <b>رد</b> من المستخدم الذي تريد نقل الحقوق إليه\n\n⚙️ /cmd الأوامر",
}
l_button_handler = {
    'ru': "👮🏽 <b>Готово!</b> Текущее <b>имя кнопки</b> на <i>входном контроле</i> установлено: {0}\n\n⚙️ Команды /cmd",
    'en': "👮🏽 <b>Done!</b> The current <b>button name</b> on the <i>input control</i> is set to: {0}\n\n⚙️ Commands /cmd",
    'es': "👮🏽 <b>¡Listo!</b> El <b>nombre del botón</b> actual en el <i>control de entrada</i> está configurado en: {0}\n\n⚙️ Comandos /cmd",
    'fr': "👮🏽 <b>Terminé !</b> Le <b>nom du bouton</b> actuel sur le <i>contrôle d'entrée</i> est défini sur : {0}\n\n⚙️ Commandes /cmd",
    'zh': "👮🏽<b>完成！</b><i>输入控件</i>上的当前<b>按钮名称</b>设置为：{0}\n\n⚙️ Commands /cmd",
    'ar': "👮🏽 <b>تم!</b> تم تعيين <b>اسم الزر</b> الحالي في <i>عنصر التحكم في الإدخال</i> على: {0}\n\n⚙️ Commands /cmd",
}
l_button_correct = {
    'ru': "👮🏽 <b>Введи</b> корректное название <i>для имени кнопки</i> 👮🏽 Входного контроля\n\n👩🏽‍💻 Например, <code>/button {0}</code>",
    'en': "👮🏽 <b>Enter</b> the correct name <i>for the name of the button</i> 👮🏽 Input control\n\n👩🏽‍💻 For example, <code>/button {0}</code>",
    'es': "👮🏽 <b>Ingrese</b> el nombre correcto <i>para el nombre del botón</i> 👮🏽 Control de entrada\n\n👩🏽‍💻 Por ejemplo, <código>/botón {0}< /código>",
    'fr': "👮🏽 <b>Entrez</b> le nom correct <i>pour le nom du bouton</i> 👮🏽 Contrôle de saisie\n\n👩🏽‍💻 Par exemple, <code>/bouton {0}< /code>",
    'zh': "👮🏽 <b>输入</b>正确的按钮名称<i></i> 👮🏽 输入控件\n\n👩🏽‍💻 例如，<code>/button {0}< /代码>",
    'ar': "👮🏽 <b>أدخل</b> الاسم الصحيح <i>لاسم الزر</i> 👮🏽 التحكم في الإدخال\n\n👩🏽‍💻 على سبيل المثال، <code>/button {0}< /كود>",
}
l_chn_done = {
    'ru': "👮🏽 <b>Готово!</b> Проверка подписки на {0} настроена\n\nОпцию можно включить в настройках, нажав [✅☑Вкл подписку]\n\n⚙️ Команды /cmd",
    'en': "👮🏽 <b>Done!</b> Subscription check for {0} is configured\n\nThe option can be enabled in the settings by clicking [✅☑On subscription]\n\n⚙️ Commands /cmd",
    'es': "👮🏽 <b>¡Listo!</b> La verificación de suscripción para {0} está configurada\n\nLa opción se puede habilitar en la configuración haciendo clic en [✅☑En suscripción]\n\n⚙️ Comandos /cmd",
    'fr': "👮🏽 <b>Terminé !</b> La vérification de l'abonnement pour {0} est configurée\n\nL'option peut être activée dans les paramètres en cliquant sur [✅☑Sur abonnement]\n\n⚙️ Commandes /cmd",
    'zh': "👮🏽 <b>完成！</b> 已配置 {0} 的订阅检查\n\n可以通过单击 [✅☑订阅时] 在设置中启用该选项\n\n⚙️ 命令 /cmd",
    'ar': "👮🏽 <b>تم!</b> تم تكوين التحقق من الاشتراك لـ {0}\n\nيمكن تمكين الخيار في الإعدادات بالنقر فوق [✅☑عند الاشتراك]\n\n⚙️ الأوامر /cmd",
}
l_chn_correct = {
    'ru': "👮🏽 <b>Добавь</b> @{0}-бота в канал и отправь корректную <i>ссылку</i> этого канала\n\n👩🏽‍💻 Например, <code>/channel {1}</code>",
    'en': "👮🏽 <b>Add</b> @{0}-bot to the channel and send the correct <i>link</i> of this channel\n\n👩🏽‍💻 For example, <code>/channel {1}< /code>",
    'es': "👮🏽 <b>Agrega</b> @{0}-bot al canal y envía el <i>enlace</i> correcto de este canal\n\n👩🏽‍💻 Por ejemplo, <código>/canal {1}< /código>",
    'fr': "👮🏽 <b>Ajoutez</b> @{0}-bot à la chaîne et envoyez le <i>lien</i> correct de cette chaîne\n\n👩🏽‍💻 Par exemple, <code>/channel {1}</code>",
    'zh': "👮🏽<b>添加</b>@{0}-bot到频道并发送该频道的正确<i>链接</i>\n\n👩🏽‍💻例如<code>/channel {1}</code>",
    'ar': "👮🏽 <b>أضف</b> @{0}-bot إلى القناة وأرسل <i>الرابط</i> الصحيح لهذه القناة\n\n👩🏽‍💻 على سبيل المثال، <code>/channel {1}< /كود>",
}
l_delay_correct = {
    'ru': "👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей\n\n👩🏽‍💻 Например, /delay 1\n\nИли используй <b>медленный режим</b> в настройках группы для <u>1</u> сообщения",
    'en': "👥 <b>Enter</b> the correct <i>number</i> minutes for the initial restriction of new users\n\n👩🏽‍💻 For example, /delay 1\n\nOr use <b>slow mode</b > in group settings for <u>1</u> message",
    'es': "👥 <b>Ingrese</b> el <i>número</i> de minutos correcto para la restricción inicial de nuevos usuarios\n\n👩🏽‍💻 Por ejemplo, /delay 1\n\nO use <b>lento modo</b > en la configuración del grupo para <u>1</u> mensaje",
    'fr': "👥 <b>Entrez</b> le <i>nombre</i> de minutes correct pour la restriction initiale des nouveaux utilisateurs\n\n👩🏽‍💻 Par exemple, /delay 1\n\nOu utilisez <b>slow mode</b > dans les paramètres du groupe pour <u>1</u> message",
    'zh': "👥 <b>输入</b>正确的<i>数字</i>分钟，用于新用户的初始限制\n\n👩🏽‍💻 例如，/delay 1\n\n或使用<b>slow <u>1</u> 条消息的群组设置中的模式</b>",
    'ar': "👥 <b>أدخل</b> <i>الرقم</i> الدقائق الصحيحة للقيود الأولية للمستخدمين الجدد\n\n👩🏽‍💻 على سبيل المثال، /delay 1\n\nأو استخدم <b>slow الوضع</b > في إعدادات المجموعة لرسالة <u>1</u>",
}
l_parse_error = {
    'ru': "📇 <b>Осуществить</b> парсинг пользователей  не удалось",
    'en': "📇 <b>Parsing</b> users failed",
    'es': "📇 Error al <b>análisis</b> de usuarios",
    'fr': "📇 L'<b>analyse</b> des utilisateurs a échoué",
    'zh': "📇<b>解析</b>用户失败",
    'ar': "📇 فشل <b>تحليل</b> المستخدمين",
}
l_parse_done = {
    'ru': "👩🏽‍💻 <b>Список</b> реальных участников: <u>{0}</u>",
    'en': "👩🏽‍💻 <b>List</b> of real participants: <u>{0}</u>",
    'es': "👩🏽‍💻 <b>Lista</b> de participantes reales: <u>{0}</u>",
    'fr': "👩🏽‍💻 <b>Liste</b> des vrais participants : <u>{0}</u>",
    'zh': "👩🏽‍💻 真实参与者<b>列表</b>：<u>{0}</u>",
    'ar': "👩🏽‍💻 <b>قائمة</b> من المشاركين الحقيقيين: <u>{0}</u>",
}
l_parse_btnsend = {
    'ru': "📨️ Рассылка",
    'en': "📨️ Newsletter",
    'es': "📨️ Boletín",
    'fr': "📨️Newsletter",
    'zh': "📨️时事通讯",
    'ar': "📨️ النشرة الإخبارية",
}
l_parse_btninvite = {
    'ru': "🚶🏽 Инвайт",
    'en': "🚶🏽 Invite",
    'es': "🚶🏽 Invitar",
    'fr': "🚶🏽 Inviter",
    'zh': "🚶🏽 邀请",
    'ar': "🚶🏽 دعوة",
}
l_parse_start = {
    'ru': "📇 <b>Начинаем</b> парсинг..",
    'en': "📇 <b>Let's start</b> parsing..",
    'es': "📇 <b>Empecemos</b> a analizar.",
    'fr': "📇 <b>Commençons</b> l'analyse..",
    'zh': "📇<b>让我们开始</b>解析..",
    'ar': "📇 <b>لنبدأ</b> بالتحليل..",
}
l_ban_handler = {
    'ru': "🪦 <b>Пользователь</b> {0} в /ban-списке на {1}",
    'en': "🪦 <b>User</b> {0} in /ban list on {1}",
    'es': "🪦 <b>Usuario</b> {0} en la lista /ban en {1}",
    'fr': "🪦 <b>Utilisateur</b> {0} dans la liste /ban sur {1}",
    'zh': "🪦 <b>用户</b> {0} 在 {1} 的 /ban 列表中",
    'ar': "🪦 <b>المستخدم</b> {0} في قائمة /الحظر في {1}",
}
l_ban_error = {
    'ru': "🪦 <b>Формат</b> /ban-команды: /ban (1m|1h|10d)",
    'en': "🪦 <b>Format</b> /ban commands: /ban (1m|1h|10d)",
    'es': "🪦 <b>Formato</b> comandos /ban: /ban (1m|1h|10d)",
    'fr': "🪦 <b>Format</b> commandes /ban : /ban (1m|1h|10j)",
    'zh': "🪦 <b>格式</b> /ban 命令：/ban (1m|1h|10d)",
    'ar': "🪦 أوامر <b>التنسيق</b> /ban: /ban (1m|1h|10d)",
}
l_ban_unban = {
    'ru': "🪦 <b>Пользователь</b> {0} удален из /ban-списка",
    'en': "🪦 <b>User</b> {0} removed from /ban list",
    'es': "🪦 <b>Usuario</b> {0} eliminado de la lista /ban",
    'fr': "🪦 <b>Utilisateur</b> {0} supprimé de la liste /ban",
    'zh': "🪦 <b>用户</b> {0} 已从/禁止列表中删除",
    'ar': "🪦 تمت إزالة <b>المستخدم</b> {0} من قائمة / الحظر",
}
l_mute_handler = {
    'ru': "💤 <b>Пользователь</b> {0} обеззвучен на {1}",
    'en': "💤 <b>User</b> {0} muted on {1}",
    'es': "💤 <b>Usuario</b> {0} silenciado el {1}",
    'fr': "💤 <b>Utilisateur</b> {0} mis en sourdine sur {1}",
    'zh': "💤 <b>用户</b> {0} 在 {1} 静音",
    'ar': "💤 تم تجاهل <b>المستخدم</b> {0} في {1}",
}
l_mute_error = {
    'ru': "💤 <b>Формат</b> /mute-команды: /mute (1m|1h|10d)",
    'en': "💤 <b>Format</b> /mute commands: /mute (1m|1h|10d)",
    'es': "💤 <b>Formato</b> /comandos de silencio: /mute (1m|1h|10d)",
    'fr': "💤 Commandes <b>Formater</b> /mute : /mute (1m|1h|10j)",
    'zh': "💤 <b>格式</b> /mute 命令：/mute (1m|1h|10d)",
    'ar': "💤 أوامر <b>التنسيق</b> /كتم الصوت: /mute (1m|1h|10d)",
}
l_mute_unmute = {
    'ru': "💤 <b>Пользователь</b> {0} больше не обеззвучен",
    'en': "💤 <b>User</b> {0} is no longer muted",
    'es': "💤 El <b>Usuario</b> {0} ya no está silenciado",
    'fr': "💤 L'<b>utilisateur</b> {0} n'est plus mis en sourdine",
    'zh': "💤 <b>用户</b> {0} 不再静音",
    'ar': "💤 لم يعد <b>المستخدم</b> {0} مكتومًا",
}
l_warn_handler = {
    'ru': "👩🏽‍💻 <b>От имени</b> группы <b>{0}</b> выносится предупреждение {1}{2}",
    'en': "👩🏽‍💻 <b>On behalf of</b> group <b>{0}</b> warning {1}{2} is issued",
    'es': "👩🏽‍💻 <b>En nombre del</b> grupo <b>{0}</b> se emite la advertencia {1}{2}",
    'fr': "👩🏽‍💻 <b>Au nom du</b> groupe <b>{0}</b> un avertissement {1}{2} est émis",
    'zh': "👩🏽‍💻 <b>代表</b>组 <b>{0}</b> 发出警告 {1}{2}",
    'ar': "👩🏽‍💻 <b>نيابة عن</b> المجموعة <b>{0}</b> تم إصدار تحذير {1}{2}",
}
l_status_pin = {
    'ru': "Закреп сообщ",
    'en': "Pinned message",
    'es': "Mensaje fijado",
    'fr': "Message épinglé",
    'zh': "固定消息",
    'ar': "رسالة مثبتة",
}
l_status_profile = {
    'ru': "Изменение профиля группы",
    'en': "Changing a Group Profile",
    'es': "Cambiar un perfil de grupo",
    'fr': "Modification d'un profil de groupe",
    'zh': "更改群组资料",
    'ar': "تغيير ملف تعريف المجموعة",
}
l_sendmsg = {
    'ru': "Отправка сообщ",
    'en': "Sending messages",
    'es': "Enviando mensajes",
    'fr': "Envoi de messages",
    'zh': "发送消息",
    'ar': "إرسال الرسائل",
}
l_status_limit = {
    'ru': "Ограничения до",
    'en': "Restrictions to",
    'es': "Restricciones a",
    'fr': "Restrictions à",
    'zh': "限制",
    'ar': "القيود على",
}
l_status_without = {
    'ru': "(отсутствует) для",
    'en': "(missing) for",
    'es': "(desaparecido) para",
    'fr': "(manquant) pour",
    'zh': "（缺失）对于",
    'ar': "(مفقود) ل",
}

l_karma_current = {
    'ru': "<b>Текущая</b> карма пользователя",
    'en': "<b>Current</b> user karma",
    'es': "Karma del usuario <b>actual</b>",
    'fr': "Karma de l'utilisateur <b>actuel</b>",
    'zh': "<b>当前</b>用户业力",
    'ar': "<b>الحالي</b> كارما المستخدم",
}
l_karma_add = {
    'ru': "👩🏽‍💻 <code>/k+</code> добавить карму",
    'en': "👩🏽‍💻 <code>/k+</code> add karma",
    'es': "👩🏽‍💻 <code>/k+</code> agrega karma",
    'fr': "👩🏽‍💻 <code>/k+</code> ajouter du karma",
    'zh': "👩🏽‍💻 <code>/k+</code> 添加业力",
    'ar': "👩🏽‍💻 <code>/k+</code> أضف الكارما",
}
l_karma_in_group = {
    'ru': "в группе",
    'en': "in Group",
    'es': "en grupo",
    'fr': "en groupe",
    'zh': "组内",
    'ar': "في مجموعة",
}
l_karma_all = {
    'ru': "🪺 <b>Карма</b> пользователей группы <b>{0}</b>",
    'en': "🪺 <b>Karma</b> users of group <b>{0}</b>",
    'es': "🪺 Usuarios de <b>Karma</b> del grupo <b>{0}</b>",
    'fr': "🪺 <b>Karma</b> utilisateurs du groupe <b>{0}</b>",
    'zh': "🪺 <b>{0}</b> 组的 <b>Karma</b> 用户",
    'ar': "🪺 مستخدمي <b>الكرمة</b> في المجموعة <b>{0}</b>",
}
l_karma_off = {
    'ru': "🪹 <b>Карма</b> пользователей группы <b>{0}</b> не установлена",
    'en': "🪹 <b>Karma</b> of users of group <b>{0}</b> is not installed",
    'es': "🪹 El <b>Karma</b> de los usuarios del grupo <b>{0}</b> no está instalado",
    'fr': "🪹 Le <b>Karma</b> des utilisateurs du groupe <b>{0}</b> n'est pas installé",
    'zh': "🪹 <b>{0}</b> 组用户的 <b>Karma</b> 未安装",
    'ar': "🪹 <b>الكارما</b> لمستخدمي المجموعة <b>{0}</b> غير مثبتة",
}
l_tag_handler = {
    'ru': "👩🏽‍💻 <b>Введи</b> сообщение при @-упоминании пользователей в формате:\n<code>/tag сообщение</code>",
    'en': "👩🏽‍💻 <b>Enter</b> message when @-mentioning users in the format:\n<code>/tag message</code>",
    'es': "👩🏽‍💻 <b>Ingrese</b> mensaje cuando @-mencione usuarios en el formato:\n<code>/etiqueta de mensaje</code>",
    'fr': "👩🏽‍💻 Message <b>Entrer</b> lorsque @-mentionne des utilisateurs au format :\n<code>/tag message</code>",
    'zh': "👩🏽‍💻 @提及用户时<b>输入</b>消息，格式为：\n<code>/tag message</code>",
    'ar': "👩🏽‍💻 <b>أدخل</b> الرسالة عند الإشارة @ إلى المستخدمين بالتنسيق:\n<code>/tag message</code>",
}
l_help_handler = {
    'ru': "👩🏽‍💻 <b>Команды</b> пользователя:\n\n/rules - правила группы\n/report - сообщить о нарушении\n/happy - получить радость\n/thanks - поблагодарить\n/birthday - поздравление\n\n👩🏽‍💻 <b>Добавь</b> <i>кѻмментарий</i> после команды если необходимо",
    'en': "👩🏽‍💻 <b>Teams</b> user:\n\n/rules-group rules\n/report-report a violation\n/happy-get joy\n/thanks-thank\n/birthday-congratulations\n\n👩🏽‍💻 <b>Add</b> <i>comment</i> after the command if necessary",
    'es': "👩🏽‍💻 Usuario de <b>Teams</b>:\n\n/reglas-reglas del grupo\n/informar-informar una infracción\n/contento-disfrutar\n/gracias-gracias\n/cumpleaños-felicitaciones\n\n👩🏽‍💻 <b>Agregar</b> <i>comentario</i> después del comando si es necesario",
    'fr': "👩🏽‍💻 Utilisateur <b>Teams</b> :\n\n/règles-règles du groupe\n/signaler-signaler une violation\n/heureux-avoir de la joie\n/merci-remercier\n/anniversaire-félicitations\n\n👩🏽‍💻 <b>Ajouter</b> <i>commentaire</i> après la commande si nécessaire",
    'zh': "👩🏽‍💻<b>团队</b>用户：\n\n/rules-群组规则\n/report-报告违规\n/happy-获得快乐\n/thanks-感谢\n/生日-祝贺\n\n👩🏽‍💻 如有必要，<b>在命令后添加</b> <i>注释</i>",
    'ar': "👩🏽‍💻 مستخدم <b>الفرق</b>:\n\n/rules-قواعد المجموعة\n/تقرير-الإبلاغ عن انتهاك\n/سعيد-احصل على السعادة\n/شكرًا-شكرًا\n/عيد ميلاد-تهانينا\n\n👩🏽‍💻 <b>أضف</b> <i>تعليقًا</i> بعد الأمر إذا لزم الأمر",
}
l_report_handler = {
    'ru': "❗️<b>Информация</b> передана администратору. Пользователь {0} взят на карандаш",
    'en': "❗️<b>Information</b> has been transferred to the administrator. User {0} taken on pencil",
    'es': "❗️<b>La información</b> ha sido transferida al administrador. Usuario {0} tomado con lápiz",
    'fr': "❗️<b>Les informations</b> ont été transférées à l'administrateur. Utilisateur {0} pris au crayon",
    'zh': "❗️<b>信息</b>已转移给管理员。用户 {0} 用铅笔拍摄",
    'ar': "❗️<b>المعلومات</b> تم نقلها إلى المسؤول. تم التقاط المستخدم {0} بالقلم الرصاص",
}
l_report_admin = {
    'ru': "❗️ <b>Пользователь</b> {0} в группе <b>{1}</b> просит обратить внимание на сообщение {2}{3}",
    'en': "❗️ <b>User</b> {0} in group <b>{1}</b> asks you to pay attention to the message {2}{3}",
    'es': "❗️ El <b>Usuario</b> {0} del grupo <b>{1}</b> te pide que prestes atención al mensaje {2}{3}",
    'fr': "❗️ L'<b>Utilisateur</b> {0} du groupe <b>{1}</b> vous demande de prêter attention au message {2}{3}",
    'zh': "❗️ <b>{1}</b> 组中的<b>用户</b> {0} 要求您注意消息 {2}{3}",
    'ar': "❗️ <b>المستخدم</b> {0} في المجموعة <b>{1}</b> يطلب منك الانتباه إلى الرسالة {2}{3}",
}
l_report_reply = {
    'ru': "❗ <b>Отправь</b> эту команду в ответ на сообщение",
    'en': "❗ <b>Send</b> this command in response to a message",
    'es': "❗ <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "❗ <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "❗ <b>发送</b>此命令以响应消息",
    'ar': "❗ <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_thanks_handler = {
    'ru': "🎉 <b>От имени</b> группы <b>{0}</b> обьявляется благодарность {1}{2}",
    'en': "🎉 <b>On behalf of</b> the group <b>{0}</b> we express gratitude to {1}{2}",
    'es': "🎉 <b>En nombre de</b> el grupo <b>{0}</b> expresamos nuestro agradecimiento a {1}{2}",
    'fr': "🎉 <b>Au nom</b> du groupe <b>{0}</b> nous exprimons notre gratitude à {1}{2}",
    'zh': "🎉 <b>代表</b>团体<b>{0}</b>，我们向{1}{2}表示感谢",
    'ar': "🎉 <b>بالنيابة عن</b> المجموعة <b>{0}</b> نعرب عن امتناننا لـ {1}{2}",
}
l_thanks_reply = {
    'ru': "🎉 <b>Отправь</b> эту команду в ответ на сообщение",
    'en': "🎉 <b>Send</b> this command in response to a message",
    'es': "🎉 <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "🎉 <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "🎉<b>发送</b>此命令以响应消息",
    'ar': "🎉 <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_birthday_handler = {
    'ru': "🥳 <b>От</b> имени группы <b>{0}</b> поздравляем с днем рождения {1}{2}",
    'en': "🥳 <b>On behalf of</b> the group <b>{0}</b> happy birthday {1}{2}",
    'es': "🥳 <b>En nombre de</b> el grupo <b>{0}</b> feliz cumpleaños {1}{2}",
    'fr': "🥳 <b>Au nom</b> du groupe <b>{0}</b> joyeux anniversaire {1}{2}",
    'zh': "🥳<b>代表</b>群组<b>{0}</b>生日快乐{1}{2}",
    'ar': "🥳 <b>نيابة عن</b> المجموعة <b>{0}</b> عيد ميلاد سعيد {1}{2}",
}
l_cmd_reply = {
    'ru': "👩🏽‍💻 <b>Отправь</b> эту команду в ответ на сообщение",
    'en': "👩🏽‍💻 <b>Send</b> this command in response to a message",
    'es': "👩🏽‍💻 <b>Enviar</b> este comando en respuesta a un mensaje",
    'fr': "👩🏽‍💻 <b>Envoyer</b> cette commande en réponse à un message",
    'zh': "👩🏽‍💻<b>发送</b>此命令以响应消息",
    'ar': "👩🏽‍💻 <b>أرسل</b> هذا الأمر ردًا على رسالة",
}
l_podcast_text = {
    'ru': "🎥 <b>Авто</b>-анонс <b>видео-подкаста</b> [/podcast d h] каждый <u>d</u>-день (1-31) на <u>h</u>-часов (1-168). Текущее значение: /podcast {0}\n\n👩🏽‍💻 Например,\n<code>/podcast 1 1</code>  ежедневный видео-анонс длительностью 1 час\n<code>/podcast 0</code> отключение опции",
    'en': "🎥 <b>Auto</b>-announcement of a <b>video podcast</b> [/podcast d h] every <u>d</u>-day (1-31) on <u>h</u >-hours (1-168). Current value: /podcast {0}\n\n👩🏽‍💻 For example,\n<code>/podcast 1 1</code> daily video announcement lasting 1 hour\n<code>/podcast 0</code> disabling the option",
    'es': "🎥 Anuncio <b>automático</b> de un <b>video podcast</b> [/podcast d h] cada <u>d</u> día (1-31) el <u>h</ u >-horas (1-168). Valor actual: /podcast {0}\n\n👩🏽‍💻 Por ejemplo,\n<code>/podcast 1 1</code> anuncio de vídeo diario que dura 1 hora\n<code>/podcast 0</code> deshabilitando la opción",
    'fr': "🎥 <b>Annonce automatique</b> d'un <b>podcast vidéo</b> [/podcast d h] tous les <u>j</u> jours (1-31) le <u>h</ u >-heures (1-168). Valeur actuelle : /podcast {0}\n\n👩🏽‍💻 Par exemple,\n<code>/podcast 1 1</code> annonce vidéo quotidienne d'une heure\n<code>/podcast 0</code> désactiver l'option",
    'zh': "🎥 <b>自动</b>-<b>视频播客</b> [/podcast d h] 每 <u>d</u> 天 (1-31) <u>h</ 的公告u >-小时 (1-168)。当前值：/podcast {0}\n\n👩🏽‍💻 例如，\n<code>/podcast 1 1</code> 每日视频公告，持续 1 小时\n<code>/podcast 0</code>禁用该选项",
    'ar': "🎥 <b>تلقائي</b>-إعلان عن <b>بودكاست فيديو</b> [/podcast d h] كل <u>d</u>-يوم (1-31) في <u>h</ ش>-الساعات (1-168). القيمة الحالية: /podcast {0}\n\n👩🏽‍💻 على سبيل المثال،\n<code>/podcast 1 1</code> إعلان فيديو يومي مدته ساعة واحدة\n<code>/podcast 0</code> تعطيل الخيار",
}

l_flood_text = {
    'ru': "💬 <b>Введи</b> <i>число</i> подряд идущих флуд сообщений от <u>3</u> до <u>10</u>\n\n👩🏽‍💻 <b>Текущее</b> /flood-значение: {0}\n<code>/flood 3</code> сообщений подряд как флуд\n<code>/flood 0</code>  отключение опции",
    'en': "💬 <b>Enter</b> the <i>number</i> of consecutive flood messages from <u>3</u> to <u>10</u>\n\n👩🏽‍💻 <b> Current</b>/flood-value: {0}\n<code>/flood 3</code> messages in a row as flood\n<code>/flood 0</code> disabling the option",
    'es': "💬 <b>Ingrese</b> el <i>número</i> de mensajes de inundación consecutivos de <u>3</u> a <u>10</u>\n\n👩🏽‍💻 <b > Actual</b>/valor-inundación: {0}\n<code>/flood 3</code> mensajes seguidos como Flood\n<code>/flood 0</code> deshabilitando la opción",
    'fr': "💬 <b>Entrez</b> le <i>nombre</i> de messages d'inondation consécutifs de <u>3</u> à <u>10</u>\n\n👩🏽‍💻 <b > Actuel</b>/flood-value : {0}\n<code>/flood 3</code> messages consécutifs en tant qu'inondation\n<code>/flood 0</code> désactivant l'option",
    'zh': "💬<b>输入</b>从<u>3</u>到<u>10</u>的连续洪水消息的<i>数量</i>\n\n👩🏽‍💻 <b > 当前</b>/flood-value：连续 {0}\n<code>/flood 3</code> 条消息作为洪水\n<code>/flood 0</code> 禁用该选项",
    'ar': "💬 <b>أدخل</b> <i>عدد</i> رسائل الفيضان المتتالية من <u>3</u> إلى <u>10</u>\n\n👩🏽‍💻 <b > الحالي</b>/flood-value: {0}\n<code>/flood 3</code> الرسائل المتتالية كـ Flood\n<code>/flood 0</code> مع تعطيل الخيار",
}
l_flood_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /flood-значение: {0}\n\n<code>/flood 3</code>    сообщений подряд как флуд\n<code>/flood 0</code>  отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /flood-value: {0}\n\n<code>/flood 3</code> messages in a row as flood\n<code>/flood 0</code> disabling the option\n\n⚙️ Commands / cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor-inundación: {0}\n\n<code>/flood 3</code> mensajes seguidos como inundación\n<code>/flood 0</ código> deshabilitando la opción\n\n⚙️ Comandos/cmd",
    'fr': "👩🏽‍💻 <b>Actuel</b> /flood-value : {0}\n\n<code>/flood 3</code> messages consécutifs sous forme d'inondation\n<code>/flood 0</ code> désactivation de l'option\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /flood-value: {0}\n\n<code>/flood 3</code> 条连续消息为洪水\n<code>/flood 0</代码> 禁用该选项\n\n⚙️ 命令 / cmd",
    'ar': "👩🏽‍💻 <b>الحالية</b> /قيمة الفيضان: {0}\n\n<code>/flood 3</code> الرسائل المتتالية مثل الفيضان\n<code>/flood 0</ code> تعطيل الخيار\n\n⚙️ Commands / cmd",
}
l_flood_on = {
    'ru': "💬 <b>Установлен</b> flood-режим: {0} сообщения подряд",
    'en': "💬 <b>Installed</b> flood mode: {0} messages in a row",
    'es': "💬 Modo de inundación <b>instalado</b>: {0} mensajes seguidos",
    'fr': "💬 Mode Flood <b>Installé</b> : {0} messages d'affilée",
    'zh': "💬<b>已安装</b>洪水模式：连续 {0} 条消息",
    'ar': "💬 وضع الفيضان <b>المثبت</b>: {0} رسالة متتالية",
}
l_flood_off = {
    'ru': "💬 <b>Режим</b> flood отключен",
    'en': "💬 <b>Mode</b> flood is disabled",
    'es': "💬 <b>Modo</b> inundación está deshabilitado",
    'fr': "💬 Le <b>Mode</b> Flood est désactivé",
    'zh': "💬<b>模式</b>洪水已禁用",
    'ar': "💬 <b>الوضع</b> معطل",
}
l_delay_text = {
    'ru': "👥 <b>Введи</b> корректное <i>число</i> минут для первичного ограничения новых пользователей (перед написанием их <u>1</u>го сообщ)\n\n👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n<code>/delay 3</code>   ограничение на 3 мин\n<code>/delay 0</code>  отключение опции",
    'en': "👥 <b>Enter</b> the correct <i>number</i> minutes for the initial restriction of new users (before writing their <u>1</u>th message)\n\n👩🏽‍💻 <b> Current</b>/delay value: {0}\n<code>/delay 3</code> 3 minute limit\n<code>/delay 0</code> disable option",
    'es': "👥 <b>Ingrese</b> el <i>número</i> de minutos correcto para la restricción inicial de nuevos usuarios (antes de escribir su <u>1</u> mensaje)\n\n👩🏽‍💻 <b> Valor actual</b>/retraso: {0}\n<code>/retraso 3</code> Límite de 3 minutos\n<code>/retraso 0</code> opción de desactivación",
    'fr': "👥 <b>Entrez</b> le <i>nombre</i> de minutes correct pour la restriction initiale des nouveaux utilisateurs (avant d'écrire leur <u>1</u>ème message)\n\n👩🏽‍💻 <b> Valeur actuelle</b>/délai : {0}\n<code>/delay 3</code> limite de 3 minutes\n<code>/delay 0</code> option de désactivation",
    'zh': "👥<b>输入</b>正确的<i>数字</i>分钟作为新用户的初始限制（在写入第<u>1</u>条消息之前）\n\n👩🏽‍💻 <b> 当前</b>/延迟值：{0}\n<code>/delay 3</code> 3 分钟限制\n<code>/delay 0</code> 禁用选项",
    'ar': "👥 <b>أدخل</b> <i>الرقم</i> الدقائق الصحيحة للقيود الأولية للمستخدمين الجدد (قبل كتابة <u>الرسالة</u>الأولى)\n\n👩🏽‍💻 <b> قيمة</b>/التأخير الحالية: {0}\n<code>/delay 3</code> حد 3 دقائق\n<code>/delay 0</code> خيار التعطيل",
}
l_delay_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /delay-значение: {0}\n\n<code>/delay 3</code>    ограничение на 3 мин\n<code>/delay 0</code>   отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /delay value: {0}\n\n<code>/delay 3</code> limit for 3 minutes\n<code>/delay 0</code> disabling the option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor de retraso: {0}\n\n<code>/retraso 3</code> límite de 3 minutos\n<code>/retraso 0</code> deshabilitación la opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Valeur actuelle</b>/délai : {0}\n\n<code>/delay 3</code> limite pendant 3 minutes\n<code>/delay 0</code> désactivation l'option\n\n⚙️ Commandes / cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /delay 值：{0}\n\n<code>/delay 3</code> 限制 3 分钟\n<code>/delay 0</code> 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>القيمة الحالية</b> /التأخير: {0}\n\n<code>/delay 3</code> حد لمدة 3 دقائق\n<code>/delay 0</code> تعطيل الخيار\n\n⚙️ الأوامر /cmd",
}
l_delay_on = {
    'ru': "👥 <b>Готово!</b> Текущая первичная задержка для <u>новых</u> пользователей (перед написанием их <u>1</u>го сообщ) установлена в значение <u>{0}</u> min",
    'en': "👥 <b>Done!</b> The current initial delay for <u>new</u> users (before writing their <u>1st</u>message) is set to <u>{0}</u >min",
    'es': "👥 <b>¡Listo!</b> El retraso inicial actual para los <u>nuevos</u> usuarios (antes de escribir su <u>primer</u>mensaje) está establecido en <u>{0}</u > mín.",
    'fr': "👥 <b>Terminé !</b> Le délai initial actuel pour les <u>nouveaux</u> utilisateurs (avant d'écrire leur <u>1er</u>message) est piné à <u>{0}</u >min",
    'zh': "👥 <b>完成！</b><u>新</u>用户当前的初始延迟（在写入<u>第一条</u>消息之前）设置为<u>{0}</u >分钟",
    'ar': "👥 <b>تم!</b> تم تعيين التأخير الأولي الحالي للمستخدمين <u>الجدد</u> (قبل كتابة رسالتهم <u>الأولى</u>) على <u>{0}</u > دقيقة",
}
l_delay_off = {
    'ru': "👥 <b>Режим</b> delay отключен",
    'en': "👥 <b>Mode</b> delay is disabled",
    'es': "👥 El retraso del <b>modo</b> está deshabilitado",
    'fr': "👥 Le délai <b>Mode</b> est désactivé",
    'zh': "👥 <b>模式</b>延迟已禁用",
    'ar': "👥 تم تعطيل تأخير <b>الوضع</b>",
}
l_rules_handler = {
    'ru': "👩🏽‍💻 <b>Правила</b> группы <b>{0}</b>:\n\n{1}",
    'en': "👩🏽‍💻 <b>Rules</b> of group <b>{0}</b>:\n\n{1}",
    'es': "👩🏽‍💻 <b>Reglas</b> del grupo <b>{0}</b>:\n\n{1}",
    'fr': "👩🏽‍💻 <b>Règles</b> du groupe <b>{0}</b> :\n\n{1}",
    'zh': "<b>{0}</b> 组的👩🏽‍💻<b>规则</b>：\n\n{1}",
    'ar': "👩🏽‍💻 <b>قواعد</b> المجموعة <b>{0}</b>:\n\n{1}",
}
l_rules_on = {
    'ru': "👩🏽‍💻 <b>Установлены</b> <u>новые</u> <b>правила</b> для группы <b>{0}</b>:\n\n{1}",
    'en': "👩🏽‍💻 <b>Installed</b> <u>new</u> <b>rules</b> for group <b>{0}</b>:\n\n{1}",
    'es': "👩🏽‍💻 <b>Instaladas</b> <u>nuevas</u> <b>reglas</b> para el grupo <b>{0}</b>:\n\n{1}",
    'fr': "👩🏽‍💻 <b>Installé</b> <u>nouvelles</u> <b>règles</b> pour le groupe <b>{0}</b> :\n\n{1}",
    'zh': "👩🏽‍💻 <b>已安装</b><u>新</u>组<b>{0}</b>的<b>规则</b>：\n\n{1}",
    'ar': "👩🏽‍💻 <b>المثبتة</b> <u>القواعد <b>الجديدة</u></b> للمجموعة <b>{0}</b>:\n\n{1}",
}
l_rules_off = {
    'ru': "👩🏽‍💻 <b>Правила</b> в группе <b>{0}</b> не установлены. Необходимо <u>ответить на пост</u> с правилами <b>командой</b> /rules",
    'en': "👩🏽‍💻 <b>Rules</b> in group <b>{0}</b> are not installed. You must <u>reply to the post</u> with the rules using the <b>command</b> /rules",
    'es': "👩🏽‍💻 Las <b>reglas</b> del grupo <b>{0}</b> no están instaladas. Debes <u>responder al post</u> con las reglas usando el <b>comando</b> /rules",
    'fr': "👩🏽‍💻 Les <b>Règles</b> du groupe <b>{0}</b> ne sont pas installées. Vous devez <u>répondre au message</u> avec les règles en utilisant la <b>commande</b> /rules",
    'zh': "👩🏽‍💻 组<b>{0}</b> 中的<b>规则</b>未安装。您必须使用<b>命令</b> /rules<u>回复帖子</u>以及规则",
    'ar': "👩🏽‍💻 <b>القواعد</b> في المجموعة <b>{0}</b> غير مثبتة. يجب عليك <u>الرد على المشاركة</u> بالقواعد باستخدام <b>الأمر</b> /rules",
}

l_len_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> max <i>длину</i> текста сообщения\n\n👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции",
    'en': "👩🏽‍💻 <b>Enter</b> max <i>length</i> of the message text\n\n👩🏽‍💻 <b>Current</b> /len-value: {0}\n< code>/len 160</code> max-length 160 characters\n<code>/len 0</code> disable option",
    'es': "👩🏽‍💻 <b>Ingrese</b> <i>longitud</i> máxima del texto del mensaje\n\n👩🏽‍💻 <b>Actual</b> /valor-len: {0}\ n< code>/len 160</code> longitud máxima 160 caracteres\n<code>/len 0</code> opción de desactivación",
    'fr': "👩🏽‍💻 <b>Entrez</b> la <i>longueur</i> maximale du texte du message\n\n👩🏽‍💻 <b>Actuel</b> /len-value : {0}\ n< code>/len 160</code> longueur maximale 160 caractères\n<code>/len 0</code> option de désactivation",
    'zh': "👩🏽‍💻<b>输入</b>消息文本的最大<i>长度</i>\n\n👩🏽‍💻<b>当前</b>/len-值：{0}\ n<code>/len 160</code> 最大长度 160 个字符\n<code>/len 0</code> 禁用选项",
    'ar': "👩🏽‍💻 <b>أدخل</b> أقصى <i>طول</i> لنص الرسالة\n\n👩🏽‍💻 <b>القيمة الحالية</b> /len-value: {0}\n<code>/len 160</code> الحد الأقصى للطول 160 حرفًا\n<code>/len 0</code> خيار التعطيل",
}
l_len_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /len-значение: {0}\n\n<code>/len 160</code>  max-длина 160 символов\n<code>/len 0</code> отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /len-value: {0}\n\n<code>/len 160</code> max-length 160 characters\n<code>/len 0</code > disable the option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /len-value: {0}\n\n<code>/len 160</code> longitud máxima 160 caracteres\n<code>/len 0</code > desactivar la opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuelle</b> /len-value : {0}\n\n<code>/len 160</code> longueur maximale 160 caractères\n<code>/len 0</code > désactivez l'option\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /len-值：{0}\n\n<code>/len 160</code> 最大长度 160 个字符\n<code>/len 0</code > 禁用该选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>القيمة الحالية</b> /len-value: {0}\n\n<code>/len 160</code> الحد الأقصى للطول 160 حرفًا\n<code>/len 0</code > تعطيل الخيار\n\n⚙️ Commands /cmd",
}

l_timer0_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> <i>число</i> секунд задержки для 1го кѻмментария в привязанном канале {1}\n\n👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n<code>/timer 100</code> задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции",
    'en': "👩🏽‍💻 <b>Enter</b> <i>number</i> seconds of delay for the 1st comment in the linked channel {1}\n\n👩🏽‍💻 <b>Current</b> /timer-value: {0}\n<code>/timer 100</code> delay of 1st comment\n<code>/timer 0</code> disable option",
    'es': "👩🏽‍💻 <b>Ingrese</b> <i>número</i> segundos de retraso para el primer comentario en el canal vinculado {1}\n\n👩🏽‍💻 <b>Actual</b> /timer-valor: {0}\n<code>/timer 100</code> retraso del primer comentario\n<code>/timer 0</code> opción de desactivación",
    'fr': "👩🏽‍💻 <b>Entrez</b> <i>nombre</i> secondes de délai pour le 1er commentaire dans le canal lié {1}\n\n👩🏽‍💻 <b>Actuel</b> /timer-value : {0}\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code> option de désactivation",
    'zh': "👩🏽‍💻 <b>输入</b> 链接频道中第一条评论的延迟<i>数字</i>秒{1}\n\n👩🏽‍💻 <b>当前</b> /timer-值：{0}\n<code>/timer 100</code> 第一条评论延迟\n<code>/timer 0</code> 禁用选项",
    'ar': "👩🏽‍💻 <b>أدخل</b> <i>رقم</i> ثانية من التأخير للتعليق الأول في القناة المرتبطة {1}\n\n👩🏽‍💻 <b>الحالي</b> /timer-value: خيار تعطيل {0}\n<code>/timer 100</code> للتعليق الأول\n<code>/timer 0</code>",
}
l_timer_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /timer-значение: {0}\n\n<code>/timer 100</code>  задержка 1го кѻмментария\n<code>/timer 0</code> отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /timer-value: {0}\n\n<code>/timer 100</code> delay of the 1st comment\n<code>/timer 0</code> disable options\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor-temporizador: {0}\n\n<code>/timer 100</code> retraso del primer comentario\n<code>/timer 0</code > desactivar opciones\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuel</b> /timer-value : {0}\n\n<code>/timer 100</code> délai du 1er commentaire\n<code>/timer 0</code > désactiver les options\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /timer-value：{0}\n\n<code>/timer 100</code> 第一条评论的延迟\n<code>/timer 0</code > 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>الحالية</b> /قيمة المؤقت: {0}\n\n<code>/timer 100</code> تأخير التعليق الأول\n<code>/timer 0</code > تعطيل الخيارات\n\n⚙️ الأوامر /cmd",
}

l_work_text = {
    'ru': "👩🏽‍💻 <b>Введи</b> часы работы (возможность писать в группе)\n\n👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n<code>/work 09:00 21:00</code>   часы работы\n<code>/work 0</code> отключение опции\n\n📍 <b>Текущее</b> время: <u>{1}</u> ({2} по Гринвичу). Отправь <b>геопозицию</b>, чтобы <i>автоматически</i> определить часовой пояс",
    'en': "👩🏽‍💻 <b>Enter</b> working hours (possibility to write in a group)\n\n👩🏽‍💻 <b>Current</b> /work-value: {0}\n<code>/ work 09:00 21:00</code> working hours\n<code>/work 0</code> disabling the option\n\n📍 <b>Current</b> time: <u>{1}</ u> ({2} GMT). Send <b>geolocation</b> to <i>automatically</i> determine the time zone",
    'es': "👩🏽‍💻 <b>Ingrese</b> horas de trabajo (posibilidad de escribir en grupo)\n\n👩🏽‍💻 <b>Actual</b> /valor-trabajo: {0}\n<código >/ trabajo 09:00 21:00</code> horario laboral\n<code>/work 0</code> deshabilitando la opción\n\n📍 Hora <b>actual</b>: <u>{1 }</ u> ({2} GMT). Envía <b>geolocalización</b> para determinar <i>automáticamente</i> la zona horaria",
    'fr': "👩🏽‍💻 <b>Entrer</b> les heures de travail (possibilité d'écrire en groupe)\n\n👩🏽‍💻 <b>Actuel</b> /work-value : {0}\n<code >/ travail 09:00 21:00</code> heures de travail\n<code>/travail 0</code> en désactivant l'option\n\n📍 <b>Heure actuelle</b> : <u>{1 </u> ({2} GMT). Envoyer une <b>géolocalisation</b> pour déterminer <i>automatiquement</i> le fuseau horaire",
    'zh': "👩🏽‍💻<b>输入</b>工作时间（可以在小组中书写）\n\n👩🏽‍💻<b>当前</b>/工作值：{0}\n<code >/ work 09:00 21:00</code> 工作时间\n<code>/work 0</code> 禁用该选项\n\n📍 <b>当前</b>时间：<u>{1 }</u>（{2}GMT）。发送<b>地理位置</b>以<i>自动</i>确定时区",
    'ar': "👩🏽‍💻 <b>أدخل</b> ساعات العمل (إمكانية الكتابة في مجموعة)\n\n👩🏽‍💻 <b>الحالية</b> /قيمة العمل: {0}\n<code >/ العمل 09:00 21:00</code> ساعات العمل\n<code>/work 0</code> تعطيل الخيار\n\n📍 <b>الوقت الحالي</b>: <u>{1 }</ u> ({2} بتوقيت جرينتش). أرسل <b>الموقع الجغرافي</b> لتحديد المنطقة الزمنية <i>تلقائيًا</i>",
}
l_work_finish = {
    'ru': "👩🏽‍💻 <b>Текущее</b> /work-значение: {0}\n\n<code>/work 09:00 21:00</code>    часы работы\n<code>/work 0</code>   отключение опции\n\n⚙️ Команды /cmd",
    'en': "👩🏽‍💻 <b>Current</b> /work-value: {0}\n\n<code>/work 09:00 21:00</code> working hours\n<code>/work 0< /code> disable option\n\n⚙️ Commands /cmd",
    'es': "👩🏽‍💻 <b>Actual</b> /valor-trabajo: {0}\n\n<code>/trabajo 09:00 21:00</code> horas laborables\n<code>/trabajo 0< /code> desactivar opción\n\n⚙️ Comandos /cmd",
    'fr': "👩🏽‍💻 <b>Actuel</b> /work-value : {0}\n\n<code>/work 09h00 21h00</code> heures de travail\n<code>/work 0< /code> désactiver l'option\n\n⚙️ Commandes /cmd",
    'zh': "👩🏽‍💻 <b>当前</b> /工作值：{0}\n\n<code>/work 09:00 21:00</code> 工作时间\n<code>/work 0< /code> 禁用选项\n\n⚙️ 命令 /cmd",
    'ar': "👩🏽‍💻 <b>الحالية</b> /قيمة العمل: {0}\n\n<code>/العمل 09:00 21:00</code> ساعات العمل\n<code>/العمل 0< /code> خيار التعطيل\n\n⚙️ الأوامر /cmd",
}
l_work_msg = {
    'ru': "👩🏽‍💻 <b>Часы</b> работы группы: {0} [UTC: {1}]",
    'en': "👩🏽‍💻 <b>Hours</b> of the group: {0} [UTC: {1}]",
    'es': "👩🏽‍💻 <b>Horario</b> del grupo: {0} [UTC: {1}]",
    'fr': "👩🏽‍💻 <b>Heures</b> du groupe : {0} [UTC : {1}]",
    'zh': "👩🏽‍💻 群组<b>时间</b>：{0} [UTC：{1}]",
    'ar': "👩🏽‍💻 <b>ساعات العمل</b> للمجموعة: {0} [التوقيت العالمي: {1}]",
}
# endregion


# region ccheck
l_ccheck_handler = {
    'ru': "👮🏽 <b>Жми</b> на ✅/🔘, чтобы <b>переключить</b> тип <i>проверки</i> пользователя при <u>вступлении</u> в группу\n\n<blockquote>👩🏽‍💻 Для установки имени <b>нажимаемой кнопки</b>, выполни команду: <code>/button {0}</code>\n\n👩🏽‍💻 Для <b>проверки подписки</b> на канал <i>добавь</i> @{1}-бота в канал и выполни команду: <code>/channel {2}</code>\n\n👩🏽‍💻 Для <i>защиты от атаки</i> на группу включи режим <b>анти-рейд</b> (блокировка <u>всех</u> вступающих)</blockquote>",
    'en': "👮🏽 <b>Press</b> on ✅/🔘 to <b>switch</b> the type of <i>verification</i> of the user when <u>joining</u> to the group\n\n👩 🏽‍💻 To set the name of the <b>button to press</b>, run the command: /button {0}\n\n👩🏽‍💻 To <b>check subscription</b> to the channel <i>add</ i> @{1}-bot into the channel and execute the command: /channel {2}\n\n👩🏽‍💻 To <i>protect against attacks</i> on the group, turn on the <b>anti-raid</i> mode b> (blocking <u>everyone</u> incoming)",
    'es': "👮🏽 <b>Presiona</b> ✅/🔘 para <b>cambiar</b> el tipo de <i>verificación</i> del usuario al <u>unirse</u> al grupo\ n\n👩 🏽‍💻 Para configurar el nombre del <b>botón a presionar</b>, ejecute el comando: /button {0}\n\n👩🏽‍💻 Para <b>verificar suscripción</b > al canal <i>agregue</ i> @{1}-bot al canal y ejecute el comando: /channel {2}\n\n👩🏽‍💻 Para <i>proteger contra ataques</i> en el grupo, active el modo <b>anti-raid</i> b> (bloqueando a <u>todos</u> los entrantes)",
    'fr': "👮🏽 <b>Appuyez</b> sur ✅/🔘 pour <b>changer</b> le type de <i>vérification</i> de l'utilisateur lors de <u>rejoindre</u> au groupe\ n\n👩 🏽‍💻 Pour définir le nom du <b>bouton sur lequel appuyer</b>, exécutez la commande : /button {0}\n\n👩🏽‍💻 Pour <b>vérifier l'abonnement</b > au canal <i>ajoutez</ i> @{1}-bot dans le canal et exécutez la commande : /channel {2}\n\n👩🏽‍💻 Pour <i>protéger contre les attaques</i> sur le groupe, activez le mode <b>anti-raid</i> b> (bloquant <u>tout le monde</u> entrant)",
    'zh': "👮🏽<b>按</b>✅/🔘<b>切换</b>用户<u>加入</u>群组时的<i>验证</i>类型\ n\n👩 🏽‍💻 要设置<b>要按下的按钮的名称</b>，请运行命令：/button {0}\n\n👩🏽‍💻 要<b>检查订阅</b> > 到频道 <i>添加</ i> @{1}-bot 到频道并执行命令：/channel {2}\n\n👩🏽‍💻 <i>防止攻击</i>在群组中，开启<b>防袭击</i>模式b>（阻止<u>所有人</u>传入）",
    'ar': "👮🏽 <b>اضغط</b> على ✅/🔘 <b>لتبديل</b> نوع <i>التحقق</i> للمستخدم عند <u>الانضمام</u> إلى المجموعة\n\n👩 🏽‍💻 لتعيين اسم <b>الزر المراد الضغط عليه</b>، قم بتشغيل الأمر: /button {0}\n\n👩🏽‍💻 <b>للتحقق من الاشتراك</b > إلى القناة <i>أضف</<i> @{1}-bot إلى القناة وقم بتنفيذ الأمر: /channel {2}\n\n👩🏽‍💻 <i>للحماية من الهجمات</i> في المجموعة، قم بتشغيل وضع <b>مكافحة الغارة</i> b> (حظر <u>الجميع</u> الواردين)",
}
l_ccheck_add = {
    'ru': "\n\nВ настройках [Администраторы] вкл для {0}-бота:\n[✅ Удаление сообщ]\n[✅ Блокировка польз]\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "\n\nIn the [Administrators] settings, enable for {0}-bot:\n[✅ Deleting messages]\n[✅ Blocking users]\n[✅ Adding members]\n\n🕚Wait 1min",
    'es': "\n\nEn la configuración de [Administradores], habilítelo para {0}-bot:\n[✅ Eliminar mensajes]\n[✅ Bloquear usuarios]\n[✅ Agregar miembros]\n\n🕚Espere 1 minuto",
    'fr': "\n\nDans les paramètres [Administrateurs], activez {0}-bot :\n[✅ Suppression de messages]\n[✅ Blocage des utilisateurs]\n[✅ Ajout de membres]\n\n🕚Attendez 1 minute",
    'zh': "\n\n在[管理员]设置中，启用 {0}-bot:\n[✅ 删除消息]\n[✅ 阻止用户]\n[✅ 添加成员]\n\n🕚等待 1 分钟",
    'ar': "\n\nفي إعدادات [المسؤولين]، قم بتمكين {0}-bot:\n[✅ حذف الرسائل]\n[✅ حظر المستخدمين]\n[✅ إضافة أعضاء]\n\n🕚انتظر دقيقة واحدة",
}
l_ccheck_call_request_on = {
    'ru': "👮🏽 В настройках [Тип группы] вкл:\n[✅ Заявки на вступление]{0}",
    'en': "👮🏽 In the [Group Type] settings, enable:\n[✅ Applications to join]{0}",
    'es': "👮🏽 En la configuración de [Tipo de grupo], habilite:\n[✅ Solicitudes para unirse]{0}",
    'fr': "👮🏽 Dans les paramètres [Type de groupe], activez :\n[✅ Applications à rejoindre]{0}",
    'zh': "👮🏽 在[群组类型]设置中，启用：\n[✅ 加入申请]{0}",
    'ar': "👮🏽 في إعدادات [نوع المجموعة]، قم بتمكين:\n[✅ تطبيقات الانضمام]{0}",
}
l_ccheck_call_request_off = {
    'ru': "👮🏽 В настройках [Тип группы] выкл:\n[☑️ Заявки на вступление]{0}",
    'en': "👮🏽 In the [Group Type] settings, turn off:\n[☑️ Applications to join]{0}",
    'es': "👮🏽 En la configuración de [Tipo de grupo], desactiva:\n[☑️ Solicitudes para unirse]{0}",
    'fr': "👮🏽 Dans les paramètres [Type de groupe], désactivez :\n[☑️ Applications à rejoindre]{0}",
    'zh': "👮🏽 在[群组类型]设置中，关闭：\n[☑️要加入的申请]{0}",
    'ar': "👮🏽 في إعدادات [نوع المجموعة]، قم بإيقاف تشغيل:\n[☑️ تطبيقات الانضمام]{0}",
}
l_ccheck_other_person = {
    'ru': "👮🏽 Эта кнопка не для тебя",
    'en': "👮🏽 This button is not for you",
    'es': "👮🏽 Este botón no es para ti",
    'fr': "👮🏽 Ce bouton n'est pas pour vous",
    'zh': "👮🏽 此按钮不适合您",
    'ar': "👮🏽 هذا الزر ليس لك",
}
l_ccheckchannel_link = {
    'ru': "👮🏽 Ссылка на {0} не доступна",
    'en': "👮🏽 Link to {0} not available",
    'es': "👮🏽 Enlace a {0} no disponible",
    'fr': "👮🏽 Lien vers {0} non disponible",
    'zh': "👮🏽 指向 {0} 的链接不可用",
    'ar': "👮🏽 الرابط إلى {0} غير متوفر",
}
l_ccheckchannel_chn = {
    'ru': "👮🏽 Ты не вступил в {0}\n\nПопробуй ещё раз позже",
    'en': "👮🏽You haven't joined {0}\n\nTry again later",
    'es': "👮🏽No te has unido a {0}\n\nVuelve a intentarlo más tarde",
    'fr': "👮🏽Vous n'avez pas rejoint {0}\n\nRéessayez plus tard",
    'zh': "👮🏽您尚未加入{0}\n\n请稍后重试",
    'ar': "👮🏽لم تنضم {0}\n\nحاول مرة أخرى لاحقًا",
}
l_ccheck_ban = {
    'ru': "👮🏽‍ <b>Пользователь</b> {0} не прошел входной контроль и был удален из группы",
    'en': "👮🏽‍ <b>User</b> {0} failed entry control and was removed from the group",
    'es': "👮🏽‍ El <b>Usuario</b> {0} falló en el control de entrada y fue eliminado del grupo",
    'fr': "👮🏽‍ <b>Utilisateur</b> {0} a échoué au contrôle d'entrée et a été supprimé du groupe",
    'zh': "👮🏽‍ <b>用户</b> {0} 未通过进入控制并已从群组中删除",
    'ar': "👮🏽‍ <b>المستخدم</b> {0} فشل في التحكم في الدخول وتمت إزالته من المجموعة",
}
l_ccheckchannel_error = {
    'ru': "👮🏽 Ошибка проверки",
    'en': "👮🏽 Validation error",
    'es': "👮🏽 Error de validación",
    'fr': "👮🏽 Erreur de validation",
    'zh': "👮🏽 验证错误",
    'ar': "👮🏽 خطأ في التحقق",
}
l_ccheck_wrong = {
    'ru': "👮🏽 К сожалению, ответ неверный\n\nПопробуй ещё раз позже",
    'en': "👮🏽 Unfortunately, the answer is incorrect\n\nTry again later",
    'es': "👮🏽 Lamentablemente, la respuesta es incorrecta\n\nInténtalo de nuevo más tarde",
    'fr': "👮🏽 Malheureusement, la réponse est incorrecte\n\nRéessayez plus tard",
    'zh': "👮🏽 不幸的是，答案不正确\n\n请稍后再试",
    'ar': "👮🏽 للأسف الإجابة غير صحيحة\n\nحاول مرة أخرى لاحقاً",
}
l_ccheck_time = {
    'ru': "👮🏽 Входной контроль пройден за {0} сек",
    'en': "👮🏽 Input control passed in {0} seconds",
    'es': "👮🏽 El control de entrada pasó en {0} segundos",
    'fr': "👮🏽 Contrôle d'entrée réussi en {0} secondes",
    'zh': "👮🏽 输入控制在 {0} 秒内传递",
    'ar': "👮🏽تم تمرير التحكم في الإدخال خلال {0} ثانية",
}
# endregion


# region chello_
l_chello_call = {
    'ru': "🔔 Нет ни одного приветствия, необходимо ⚙️Настроить",
    'en': "🔔 There is not a single greeting, you need to ⚙️Customize",
    'es': "🔔 No hay un solo saludo, necesitas ⚙️Personalizar",
    'fr': "🔔 Il n'y a pas un seul message d'accueil, vous devez ⚙️Personnaliser",
    'zh': "🔔没有一句问候语，需要⚙️定制",
    'ar': "🔔 ليس هناك تحية واحدة، عليك ⚙️ تخصيصها",
}
l_chello_your_hello = {
    'ru': "Ваше приветствие",
    'en': "Your greeting",
    'es': "Tu saludo",
    'fr': "Votre salutation",
    'zh': "你的问候",
    'ar': "تحية الخاص بك",
}
l_chello_text = {
    'ru': "👋🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> приветствие, а также его ⚙️Настроить\n\n<blockquote>👩🏽‍💻 Например, {0}{1}</blockquote>",
    'en': "👋🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> the greeting, as well as its ⚙️Customize\n\n👩🏽‍💻 For example, {0}{1}",
    'es': "👋🏽 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> el saludo, así como su ⚙️Personalizar\n\n👩🏽‍💻 Por ejemplo, {0}{1 }",
    'fr': "👋🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le message d'accueil, ainsi que son ⚙️Personnaliser\n\n👩🏽‍💻 Par exemple, {0}{1 }",
    'zh': "👋🏽 <b>按</b> ✅/☑️ <b>打开/关闭</b>问候语及其⚙️自定义\n\n👩🏽‍💻 例如，{0}{1 }",
    'ar': "👋🏽 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> التحية، بالإضافة إلى ⚙️تخصيصها\n\n👩🏽‍💻 على سبيل المثال، {0}{1 }",
}
l_btn_on = {
    'ru': "✅☑Вкл",
    'en': "✅☑Incl",
    'es': "✅☑Incl.",
    'fr': "✅☑Inclus",
    'zh': "✅☑包括",
    'ar': "✅☑بما في ذلك",
}
l_btn_off = {
    'ru': "☑️☐Выкл",
    'en': "☑️☐Выкл",
    'es': "☑️☐Выкл",
    'fr': "☑️☐Выкл",
    'zh': "☑️ Выкл",
    'ar': "☑️☐ فيكل",
}
l_btn_settings = {
    'ru': "⚙️Настроить",
    'en': "⚙️Customize",
    'es': "⚙️Personalizar",
    'fr': "⚙️Personnaliser",
    'zh': "⚙️定制",
    'ar': "⚙️تخصيص",
}
l_chellochange_handler = {
    'ru': "👋🏽 <b>Отправь</b> мне <b>текст</b>/<b>медиа</b> контент с текстом: фото/гиф/видео/аудио/документ или запиши голосовое/видео-заметку в кружке\n\n👩🏽‍💻 Например, {0}",
    'en': "👋🏽 <b>Send</b> me <b>text</b>/<b>media</b> content with text: photo/gif/video/audio/document or record a voice/video note in a circle\n\n👩🏽‍💻 For example, {0}",
    'es': "👋🏽 <b>Envíame</b> contenido de <b>texto</b>/<b>medio</b> con texto: foto/gif/vídeo/audio/documento o graba una nota de voz/vídeo en un círculo\n\n👩🏽‍💻 Por ejemplo, {0}",
    'fr': "👋🏽 <b>Envoyez</b> moi du contenu <b>texte</b>/<b>média</b> avec texte : photo/gif/vidéo/audio/document ou enregistrez une note vocale/vidéo dans un cercle\n\n👩🏽‍💻 Par exemple, {0}",
    'zh': "👋🏽 <b>向</b>我发送<b>文本</b>/<b>媒体</b>内容，其中包含文本：照片/gif/视频/音频/文档，或在圆圈\n\n👩🏽‍💻 例如，{0}",
    'ar': "👋🏽 <b>أرسل</b> إليّ محتوى <b>نص</b>/<b>وسائط</b> يتضمن نصًا: صورة/gif/فيديو/صوت/مستند أو تسجيل ملاحظة صوتية/فيديو في دائرة\n\n👩🏽‍💻 على سبيل المثال، {0}",
}
l_fsm_hello_finish = {
    'ru': "👋🏽 Приветствие записано!\n\nОпцию можно включить в настройках [👋🏽Авто-приветствие], нажав [✅☑Вкл]",
    'en': "👋🏽Greeting recorded!\n\nThe option can be enabled in the [👋🏽Auto-Greeting] settings by clicking [✅☑On]",
    'es': "👋🏽¡Saludo grabado!\n\nLa opción se puede habilitar en la configuración de [👋🏽Saludo automático] haciendo clic en [✅☑Activado]",
    'fr': "👋🏽Message d'accueil enregistré !\n\nL'option peut être activée dans les paramètres [👋🏽Greeting automatique] en cliquant sur [✅☑Activé]",
    'zh': "👋🏽问候语已录制！\n\n可以在[👋🏽自动问候语]设置中点击[✅☑开]启用该选项",
    'ar': "👋🏽تم تسجيل الترحيب!\n\nيمكن تفعيل هذا الخيار في إعدادات [👋🏽الترحيب التلقائي] بالنقر فوق [✅☑تشغيل]",
}
# endregion


# region cinvite_
l_cinvite_call = {
    'ru': "👮🏽 В настройках [Разрешения] вкл опцию:\n\n[✅ Добавление участ]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the [Permissions] settings, enable the option:\n\n[✅ Adding a participant]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Permisos], habilita la opción:\n\n[✅ Agregar un participante]\n\n🕚Espera 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez l'option :\n\n[✅ Ajout d'un participant]\n\n🕚Attendez 1min",
    'zh': "👮🏽 在【权限】设置中，启用选项：\n\n[✅ 添加参与者]\n\n🕚等待 1 分钟",
    'ar': "👮🏽 في إعدادات [الأذونات]، قم بتمكين الخيار:\n\n[✅ إضافة مشارك]\n\n🕚انتظر دقيقة واحدة",
}
l_cinvite_text_add = {
    'ru': "\n\n👩🏽‍💻 Приглашается <u>{0}</u> пользователей в сутки из группы {1}",
    'en': "\n\n👩🏽‍💻 <u>{0}</u> users per day from group {1} are invited",
    'es': "\n\n👩🏽‍💻 Están invitados <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "\n\n👩🏽‍💻 <u>{0}</u> les utilisateurs par jour du groupe {1} sont invités",
    'zh': "\n\n👩🏽‍💻 每天邀请来自组 {1} 的 <u>{0}</u> 位用户",
    'ar': "\n\n👩🏽‍💻 <u>{0}</u> مستخدمين يوميًا من المجموعة {1} مدعوون",
}
l_cinvite_text = {
    'ru': "🚶🏽 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-инвайт пользователей в <b>{0}</b>-группу\n\n👩🏽‍💻 <b>Текущие</b> настройки авто-рассылки: {1}",
    'en': "🚶🏽 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-invite users into <b>{0}</b>-group\n\n👩🏽‍ 💻 <b>Current</b> auto-mail settings: {1}",
    'es': "🚶🏽 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> invitar automáticamente a los usuarios al <b>{0}</b>-grupo\n\n👩🏽‍ 💻 Configuración de correo automático <b>actual</b>: {1}",
    'fr': "🚶🏽 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> l'invitation automatique des utilisateurs dans un <b>{0}</b>-groupe\n\n👩🏽‍ 💻 Paramètres de messagerie automatique <b>actuels</b> : {1}",
    'zh': "🚶🏽 <b>按</b> ✅/☑️ 可<b>开启/关闭</b>自动邀请用户加入<b>{0}</b>-组\n\n👩🏽‍ 💻 <b>当前</b>自动邮件设置：{1}",
    'ar': "🚶🏽 <b>اضغط على</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> دعوة المستخدمين تلقائيًا إلى <b>{0}</b>-المجموعة\n\n👩🏽‍ 💻 إعدادات البريد التلقائي <b>الحالية</b>: {1}",
}

l_cinvite_current = {
    'ru': "🚶🏽 <b>Текущие</b> настройки авто-инвайта в группу:\n\n<u>{0}</u> пользователей/сутки\n<u>{1}</u> источник",
    'en': "🚶🏽 <b>Current</b> auto-invite settings to the group:\n\n<u>{0}</u> users/day\n<u>{1}</u> source",
    'es': "🚶🏽 Configuración de invitación automática <b>actual</b> al grupo:\n\n<u>{0}</u> usuarios/día\n<u>{1}</u> fuente",
    'fr': "🚶🏽 <b>Paramètres actuels</b> d'invitation automatique au groupe :\n\n<u>{0}</u> utilisateurs/jour\n<u>{1}</u> source",
    'zh': "🚶🏽<b>当前</b>自动邀请群组设置：\n\n<u>{0}</u> 个用户/天\n<u>{1}</u> 来源",
    'ar': "🚶🏽 إعدادات الدعوة التلقائية <b>الحالية</b> إلى المجموعة:\n\n<u>{0}</u> مستخدمون/يوم\n<u>{1}</u> المصدر",
}
l_cinvite_cnt = {
    'ru': "{0} польз/сутки",
    'en': "{0} users/day",
    'es': "{0} usuarios/día",
    'fr': "{0} utilisateurs/jour",
    'zh': "{0} 位用户/天",
    'ar': "{0} مستخدم/يوم",
}
l_cinvite_src = {
    'ru': "{0} источник",
    'en': "{0} source",
    'es': "{0} fuente",
    'fr': "{0} source",
    'zh': "{0}来源",
    'ar': "{0} المصدر",
}
l_cinvitechange_handler = {
    'ru': "🚶🏽 <b>Отправь</b> мне <b>ссылку</b> на группу, откуда будем брать подписчиков\n\n👩🏽‍💻 Например, <code>https://t.me/likeconcentrat</code> - <b>Жми</b> на ссылку, чтобы скопировать",
    'en': "🚶🏽 <b>Send</b> me a <b>link</b> to the group from where we will get subscribers\n\n👩🏽‍💻 For example, <code> https://t.me/likeconcentrat </ code>-<b>Click</b> on the link to copy",
    'es': "🚶🏽 <b>Envíame</b> un <b>enlace</b> al grupo desde donde obtendremos suscriptores\n\n👩🏽‍💻 Por ejemplo, <código> https://t.me /likeconcentrat </code>-<b>Haga clic</b> en el enlace para copiar",
    'fr': "🚶🏽 <b>Envoyez</b> moi un <b>lien</b> vers le groupe d'où nous obtiendrons des abonnés\n\n👩🏽‍💻 Par exemple, <code> https://t.me /likeconcentrat </ code>-<b>Cliquez</b> sur le lien pour copier",
    'zh': "🚶🏽 <b>向我发送</b><b>链接</b>到我们将获得订阅者的群组\n\n👩🏽‍💻 例如，<code> https://t.me /likeconcentrat </ code>-<b>点击</b>链接进行复制",
    'ar': "🚶🏽 <b>أرسل</b> لي <b>رابطًا</b> للمجموعة التي سنحصل منها على مشتركين\n\n👩🏽‍💻 على سبيل المثال <code> https://t.me /likeconcentrat </code>-<b>انقر</b> على الرابط للنسخ",
}
l_correct_link = {
    'ru': "👩🏽‍💻 <b>Вставь</b> корректные данные или повтори операцию",
    'en': "👩🏽‍💻 <b>Insert</b> correct data or repeat the operation",
    'es': "👩🏽‍💻 <b>Insertar</b> datos correctos o repetir la operación",
    'fr': "👩🏽‍💻 <b>Insérer</b> les données correctes ou répéter l'opération",
    'zh': "👩🏽‍💻<b>插入</b>正确的数据或重复操作",
    'ar': "👩🏽‍💻 <b>أدخل</b> البيانات الصحيحة أو كرر العملية",
}
l_admin_require = {
    'ru': "👩🏽‍💻 Требуются права администратора",
    'en': "👩🏽‍💻Administrator rights required",
    'es': "👩🏽‍💻Se requieren derechos de administrador",
    'fr': "👩🏽‍💻Droits d'administrateur requis",
    'zh': "👩🏽‍💻需要管理员权限",
    'ar': "👩🏽‍💻حقوق المسؤول مطلوبة",
}
l_grp_not_channel = {
    'ru': "🚶🏽 Вставь ссылку на группу, а не канал",
    'en': "🚶🏽 Insert a link to the group, not the channel",
    'es': "🚶🏽 Inserta un enlace al grupo, no al canal.",
    'fr': "🚶🏽 Insérez un lien vers le groupe, pas la chaîne",
    'zh': "🚶🏽 插入群组链接，而不是频道链接",
    'ar': "🚶🏽 أدخل رابط المجموعة وليس القناة",
}
l_no_participants = {
    'ru': "🚶🏽 Нет доступных подписчиков",
    'en': "🚶🏽 No followers available",
    'es': "🚶🏽 No hay suscriptores disponibles",
    'fr': "🚶🏽 Aucun abonné disponible",
    'zh': "🚶🏽 没有可用的订阅者",
    'ar': "🚶🏽 لا يوجد متابعين",
}
l_current_participants = {
    'ru': "🚶🏽 Для {0}<b>текущее количество</b> реальных подписчиков: <u>{1}</u>\n\n▪️ <b>Введи</b> <i>число</i> подписчиков, которое необходимо подписывать <b>ежедневно</b> от 1 до 3 (без 💨Подписки до +{2}):",
    'en': "🚶🏽 For {0}<b>current number</b> of real subscribers: <u>{1}</u>\n\n▪️ <b>Enter</b> <i>number</i> subscribers , which must be subscribed <b>daily</b> from 1 to 3 (without 💨Subscription up to +{2}):",
    'es': "🚶🏽 Para {0}<b>número actual</b> de suscriptores reales: <u>{1}</u>\n\n▪️ <b>Ingrese</b> <i>número</i> suscriptores, los cuales deben estar suscritos <b>diariamente</b> del 1 al 3 (sin 💨Suscripción hasta +{2}):",
    'fr': "🚶🏽 Pour le {0}<b>nombre actuel</b> d'abonnés réels : <u>{1}</u>\n\nnounced️ <b>Entrez</b> <i>numéro</i> abonnés , qui doivent être souscrits <b>quotidiennement</b> de 1 à 3 (sans 💨Abonnement jusqu'à +{2}) :",
    'zh': "🚶🏽 对于{0}<b>当前数量</b>的真实订阅者：<u>{1}</u>\n\n▪️ <b>输入</b> <i>数量</i>订阅者，必须<b>每天</b>从 1 到 3 订阅（不包括💨订阅最多 +{2}）：",
    'ar': "🚶🏽 بالنسبة إلى {0}<b>العدد الحالي</b> من المشتركين الحقيقيين: <u>{1}</u>\n\n▪️ <b>أدخل</b> <i>الرقم</i> المشتركون الذين يجب الاشتراك بهم <b>يوميًا</b> من 1 إلى 3 (بدون 💨اشتراك يصل إلى +{2}):",
}
l_everyday_participants = {
    'ru': "🚶🏽 <b>Введи</b> количество пользователей для ежедневной подписки от 1 до 3 включительно",
    'en': "🚶🏽 <b>Enter</b> the number of users for daily subscription from 1 to 3 inclusive",
    'es': "🚶🏽 <b>Ingrese</b> el número de usuarios para la suscripción diaria del 1 al 3 inclusive",
    'fr': "🚶🏽 <b>Saisissez</b> le nombre d'utilisateurs pour un abonnement quotidien de 1 à 3 inclus",
    'zh': "🚶🏽 <b>输入</b>每日订阅的用户数量（1 到 3（含））",
    'ar': "🚶🏽 <b>أدخل</b> عدد المستخدمين للاشتراك اليومي من 1 إلى 3 شاملاً",
}
l_invite_need_subscribe = {
    'ru': "🚶🏽 Для инвайта > 1 пользователя в день необходимо приобрести 💨Подписку. Оформи 💨Подписку или введи 1:",
    'en': "🚶🏽 To invite > 1 user per day, you need to purchase a 💨Subscription. Subscribe 💨or enter 1:",
    'es': "🚶🏽 Para invitar a > 1 usuario por día, debes comprar una 💨Suscripción. Suscríbete 💨o ingresa 1:",
    'fr': "🚶🏽 Pour inviter > 1 utilisateur par jour, vous devez acheter un 💨Abonnement. Abonnez-vous 💨ou saisissez 1 :",
    'zh': "🚶🏽 要每天邀请 > 1 位用户，您需要购买 💨订阅。订阅💨或输入1：",
    'ar': "🚶🏽 لدعوة > مستخدم واحد يوميًا، يلزمك شراء 💨اشتراك. اشترك 💨أو أدخل 1:",
}
l_invite_correct_num = {
    'ru': "🚶🏽 <b>Введи</b> корректное число",
    'en': "🚶🏽 <b>Enter</b> the correct number",
    'es': "🚶🏽 <b>Ingrese</b> el número correcto",
    'fr': "🚶🏽 <b>Entrez</b> le bon numéro",
    'zh': "🚶🏽<b>输入</b>正确的数字",
    'ar': "🚶🏽 <b>أدخل</b> الرقم الصحيح",
}
l_fsm_invite_finish = {
    'ru': "🚶🏽 <b>Готово!</b> Настроен <b>авто</b>-инвайт <u>{0}</u> пользователей в сутки из группы {1}",
    'en': "🚶🏽 <b>Done!</b> Configured <b>auto</b>-invite <u>{0}</u> users per day from group {1}",
    'es': "🚶🏽 <b>¡Listo!</b> <b>auto</b> configurado: invitar a <u>{0}</u> usuarios por día del grupo {1}",
    'fr': "🚶🏽 <b>Terminé !</b> Configuré <b>auto</b> -inviter <u>{0}</u> utilisateurs par jour à partir du groupe {1}",
    'zh': "🚶🏽<b>完成！</b>已配置<b>自动</b>-每天从组 {1} 邀请 <u>{0}</u> 位用户",
    'ar': "🚶🏽 <b>تم!</b> تم تكوين <b>تلقائي</b>-لدعوة <u>{0}</u> المستخدمين يوميًا من المجموعة {1}",
}
l_cinvite_nosrc = {
    'ru': "🚶🏽 Не задан источник для инвайта пользователей в группу",
    'en': "🚶🏽 The source for inviting users to the group is not specified",
    'es': "🚶🏽 No se especifica la fuente para invitar usuarios al grupo.",
    'fr': "🚶🏽 La source d'invitation des utilisateurs dans le groupe n'est pas précisée",
    'zh': "🚶🏽 未指定邀请用户入群来源",
    'ar': "🚶🏽 لم يتم تحديد مصدر دعوة المستخدمين للمجموعة",
}
l_cinvite_group = {
    'ru': "🚶🏽 Группа",
    'en': "🚶🏽 Group",
    'es': "🚶🏽 Grupo",
    'fr': "🚶🏽 Groupe",
    'zh': "🚶🏽组",
    'ar': "🚶🏽 المجموعة",
}
l_cinvite_file = {
    'ru': "🚶🏽 Файл",
    'en': "🚶🏽 File",
    'es': "🚶🏽 Archivo",
    'fr': "🚶🏽 Fichier",
    'zh': "🚶🏽 文件",
    'ar': "🚶🏽 ملف",
}
l_cinvite_geo = {
    'ru': "🚶🏽 Гео",
    'en': "🚶🏽 Geo",
    'es': "🚶🏽 Geo",
    'fr': "🚶🏽 Géo",
    'zh': "🚶🏽 地理",
    'ar': "🚶🏽 جيو",
}
l_cinvite_choose_src = {
    'ru': "🚶🏽 <b>Выбери источник</b>, откуда будем брать @username для авто-инвайта",
    'en': "🚶🏽 <b>Select a source</b> from where we will take @username for auto-invite",
    'es': "🚶🏽 <b>Seleccione una fuente</b> desde donde tomaremos @username para la invitación automática",
    'fr': "🚶🏽 <b>Sélectionnez une source</b> à partir de laquelle nous prendrons @username pour l'invitation automatique",
    'zh': "🚶🏽 <b>选择来源</b>，我们将从中获取@username进行自动邀请",
    'ar': "🚶🏽 <b>اختر مصدرًا</b> حيث سنأخذ @username للدعوة التلقائية",
}
l_cinvite_choose_cnt = {
    'ru': "🚶🏽 <b>Введи</b> <b>количество</b> пользователей для авто-инвайта, которые будут приглашаться ежедневно (без 💨Подписки: до 1 польз)",
    'en': "🚶🏽 <b>Enter</b> <b>number</b> of auto-invite users who will be invited daily (without 💨Subscription: up to 1 users)",
    'es': "🚶🏽 <b>Ingrese</b> <b>número</b> de usuarios con invitación automática que serán invitados diariamente (sin 💨Suscripción: hasta 1 usuario)",
    'fr': "🚶🏽 <b>Entrez</b> <b>nombre</b> d'utilisateurs à invitation automatique qui seront invités quotidiennement (sans 💨Abonnement : jusqu'à 1 utilisateur)",
    'zh': "🚶🏽<b>输入</b><b>数量</b>每天将被邀请的自动邀请用户（没有💨订阅：最多 1 位用户）",
    'ar': "🚶🏽 <b>أدخل</b> <b>عدد</b> المستخدمين الذين تتم دعوتهم تلقائيًا والذين ستتم دعوتهم يوميًا (بدون 💨الاشتراك: ما يصل إلى مستخدم واحد)",
}
l_cinvite_choose_group = {
    'ru': "🚶🏽 Отправь <b>ссылку</b> на группу, чтобы сделать авто-инвайт по ее @username",
    'en': "🚶🏽 Send a <b>link</b> to the group to auto-invite using its @username",
    'es': "🚶🏽 Envía un <b>enlace</b> al grupo para invitarlo automáticamente usando su @username",
    'fr': "🚶🏽 Envoyez un <b>lien</b> au groupe pour l'inviter automatiquement en utilisant son @username",
    'zh': "🚶🏽 将<b>链接</b>发送到群组，以使用其@username自动邀请",
    'ar': "🚶🏽 أرسل <b>رابطًا</b> إلى المجموعة لإجراء دعوة تلقائية باستخدام @username الخاص بها",
}
l_cinvite_choose_file = {
    'ru': "🚶🏽 Отправь текстовый <b>файл</b> со списком @username, чтобы сделать по ним авто-инвайт",
    'en': "🚶🏽 Send a text <b>file</b> with a list of @username to auto-invite them",
    'es': "🚶🏽 Envía un <b>archivo</b> de texto con una lista de @username para invitarlos automáticamente",
    'fr': "🚶🏽 Envoyez un <b>fichier</b> texte avec une liste de @username pour les inviter automatiquement",
    'zh': "🚶🏽 发送包含@username列表的文本<b>文件</b>以自动邀请他们",
    'ar': "🚶🏽 أرسل <b>ملفًا</b> نصيًا يتضمن قائمة @username لدعوتهم تلقائيًا",
}
l_cinvite_choose_geo = {
    'ru': "🚶🏽 Отправь <b>геопозицию</b>, чтобы получить гео-@username для авто-инвайта",
    'en': "🚶🏽 Send <b>geolocation</b> to receive geo-@username for auto-invite",
    'es': "🚶🏽 Envíe <b>geolocalización</b> para recibir geo-@username para la invitación automática",
    'fr': "🚶🏽 Envoyez une <b>géolocalisation</b> pour recevoir la géo-@username pour une invitation automatique",
    'zh': "🚶🏽 发送<b>地理位置</b>以接收地理@username以进行自动邀请",
    'ar': "🚶🏽 أرسل <b>الموقع الجغرافي</b> لتلقي @username الجغرافي للدعوة التلقائية",
}
l_cinvite_csv_table = {
    'ru': "🚶🏽 В csv-файле @username или ссылка должны быть в 3м столбце",
    'en': "🚶🏽 In the csv file @username or link should be in the 3rd column",
    'es': "🚶🏽 En el archivo csv @username o enlace debe estar en la tercera columna",
    'fr': "🚶🏽 Dans le fichier csv @username ou le lien doit être dans la 3ème colonne",
    'zh': "🚶🏽 在csv文件中@username或链接应该在第三列",
    'ar': "🚶🏽 في ملف CSV، يجب أن يكون @username أو الرابط في العمود الثالث",
}
l_cinvite_csv_file = {
    'ru': "🚶🏽 <b>Отправь</b> корректный текстовый <b>файл</b> со списком @username",
    'en': "🚶🏽 <b>We have arrived</b> correct text <b>file</b> with the list @username",
    'es': "🚶🏽 <b>Hemos llegado</b> texto correcto <b>archivo</b> con la lista @username",
    'fr': "🚶🏽 <b>Nous sommes arrivés</b> texte correct <b>fichier</b> avec la liste @username",
    'zh': "🚶🏽 <b>我们已经到达</b>正确的文本<b>文件</b>与列表@username",
    'ar': "🚶🏽 <b>لقد وصلنا</b> النص <b>الملف</b> الصحيح مع القائمة @username",
}
l_cinvite_src_empty = {
    'ru': "🚶🏽 No @usernames in {0} for {1}",
    'en': "🚶🏽 No @usernames in {0} for {1}",
    'es': "🚶🏽 No @usernames en {0} para {1}",
    'fr': "🚶🏽 Aucun @usernames dans {0} pour {1}",
    'zh': "🚶🏽 {1} 的 {0} 中没有@usernames",
    'ar': "🚶🏽 لا توجد @usernames في {0} لـ {1}",
}
l_cinvite_choose = {
    'ru': "Выбрать",
    'en': "Choose",
    'es': "Elegir",
    'fr': "Choisir",
    'zh': "选择",
    'ar': "يختار",
}
# endregion


# region csystem_
l_csystem_text = {
    'ru': "👣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>системные</i> сообщения\n\n<blockquote>👩🏽‍💻 Например, Закреп сообщения/Начало трансляции/Пользователь вступил в группу</blockquote>",
    'en': "👣 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>system</i> messages\n\n👩🏽‍💻 For example, <i>User has entered( a) to the group</i>",
    'es': "👣 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> mensajes del <i>sistema</i>\n\n👩🏽‍💻 Por ejemplo, <i>El usuario ha ingresado (a) al grupo</i>",
    'fr': "👣 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a entré ( a) au groupe</i>",
    'zh': "👣 <b>按</b> ✅/☑️ <b>开启/关闭</b> <i>系统</i>消息\n\n👩🏽‍💻 例如，<i>用户已输入(a) 到组</i>",
    'ar': "👣 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>رسائل النظام</i>\n\n👩🏽‍💻 على سبيل المثال، <i>قام المستخدم بإدخال (أ) للمجموعة</i>",
}
l_csystem_text_chn = {
    'ru': "👣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>системные</i> сообщения в канале\n\n<blockquote>👩🏽‍💻 Например: Закреп сообщения/Начало трансляции/Название канала изменено</blockquote>",
    'en': "👣 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>system</i> messages\n\n👩🏽‍💻 For example, <i>User has entered( a) to the group</i>",
    'es': "👣 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> mensajes del <i>sistema</i>\n\n👩🏽‍💻 Por ejemplo, <i>El usuario ha ingresado (a) al grupo</i>",
    'fr': "👣 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> les messages <i>système</i>\n\n👩🏽‍💻 Par exemple, <i>L'utilisateur a entré ( a) au groupe</i>",
    'zh': "👣 <b>按</b> ✅/☑️ <b>开启/关闭</b> <i>系统</i>消息\n\n👩🏽‍💻 例如，<i>用户已输入(a) 到组</i>",
    'ar': "👣 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>رسائل النظام</i>\n\n👩🏽‍💻 على سبيل المثال، <i>قام المستخدم بإدخال (أ) للمجموعة</i>",
}
# endregion


# region cchannel_
l_cchannel_text = {
    'ru': "🫥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>разрешение</i> для канала (если привязана эта группа) публиковать посты, а также для пользователя в группе писать <i>анонимно</i> (от имени <b>его</b> канала)",
    'en': "🫥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>permission</i> for the channel (if this group is linked) to publish posts, as well as for the user in the group write <i>anonymously</i> (on behalf of <b>his</b> channel)",
    'es': "🫥 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>permiso</i> para que el canal (si este grupo está vinculado) publique publicaciones, así como para el usuario del grupo escribe <i>anónimamente</i> (en nombre de <b>su</b> canal)",
    'fr': "🫥 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <i>permission</i> pour la chaîne (si ce groupe est lié) de publier des posts, ainsi que pour l'utilisateur du groupe écrit <i>de manière anonyme</i> (au nom de <b>sa</b> chaîne)",
    'zh': "🫥 <b>按</b> ✅/☑️ 可<b>开启/关闭</b><i>权限</i>频道（如果已链接此群组）发布帖子，以及群组中的用户<i>匿名</i>写入（代表<b>他的</b>频道）",
    'ar': "🫥 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>الإذن</i> للقناة (إذا كانت هذه المجموعة مرتبطة) بنشر المنشورات، وكذلك لـ يكتب المستخدم في المجموعة <i>بشكل مجهول</i> (نيابة عن <b>قناته</b>)",
}
l_cchannel_chn_on = {
    'ru': "✅☑Вкл для канала",
    'en': "✅☑On for channel",
    'es': "✅☑Activado para el canal",
    'fr': "✅☑Activé pour la chaîne",
    'zh': "✅☑开启频道",
    'ar': "✅☑مفعل للقناة",
}
l_cchannel_chn_off = {
    'ru': "☑️☐Выкл для канала",
    'en': "☑️☐Off for channel",
    'es': "☑️☐Fuera del canal",
    'fr': "☑️☐Désactivé pour la chaîne",
    'zh': "☑️️频道关闭",
    'ar': "☑️☐مغلق للقناة",
}
l_cchannel_usr_on = {
    'ru': "✅☑Вкл для пользователя",
    'en': "✅☑On for user",
    'es': "✅☑Activado para usuario",
    'fr': "✅☑Activé pour l'utilisateur",
    'zh': "✅☑为用户开启",
    'ar': "✅☑ قيد التشغيل للمستخدم",
}
l_cchannel_usr_off = {
    'ru': "☑️☐Выкл для пользователя",
    'en': "☑️☐Off for user",
    'es': "☑️☐Desactivado para usuario",
    'fr': "☑️☐Désactivé pour l'utilisateur",
    'zh': "☑️️用户关闭",
    'ar': "☑️☐إيقاف للمستخدم",
}
# endregion


# region clink_
l_clink_text = {
    'ru': "🔗 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>внешние <b>ссылки</b>/telegram-<b>ссылки</b>/forward</i>-<b>ссылки</b>\n\n<blockquote>[✅ <b>Вкл forward-ссылки</b>] разрешение <b>forward-пересылки</b> сообщений из <u>других</u> Telegram-<i>каналов/групп/аккаунтов</i> в <u>нашу</u> группу</blockquote>",
    'en': "🔗 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>external <b>links</b>/telegram-<b>links</b>/forward </i>-<b>links</b>\n\n👩🏽‍💻 For example, [✅☑On forward links] means permission to <b>forward forward</b> messages from <u>others </u> Telegram-<i>channels/groups/accounts</i> to <u>our</u> group",
    'es': "🔗 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>enlaces externos</b>/telegram-<b>enlaces</b>/reenviar < /i>-<b>enlaces</b>\n\n👩🏽‍💻 Por ejemplo, [✅☑En enlaces hacia adelante] significa permiso para <b>reenviar</b> mensajes de <u>otros </ u> Telegram-<i>canales/grupos/cuentas</i> a <u>nuestro</u> grupo",
    'fr': "🔗 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <i><b>liens externes</b>/telegram-<b>liens</b>/transférer < /i>-<b>liens</b>\n\n👩🏽‍💻 Par exemple, [✅☑Sur les liens de transfert] signifie l'autorisation de <b>transférer</b> les messages de <u>autres personnes </ u> Telegram-<i>chaînes/groupes/comptes</i> vers <u>notre</u> groupe",
    'zh': "🔗 <b>按</b> ✅/☑️ <b>开/关</b> <i>外部<b>链接</b>/telegram-<b>链接</b>/forward < /i>-<b>链接</b>\n\n👩🏽‍💻 例如，[✅☑在转发链接上] 表示允许<b>转发</b>来自<u>其他人的消息</ u> Telegram-<i>频道/群组/帐户</i>至<u>我们的</u>群组",
    'ar': "🔗 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i><b>روابط</b> خارجية</b>/telegram-<b>روابط</b>/forward < /i>-<b>الروابط</b>\n\n👩🏽‍💻 على سبيل المثال، [✅☑On Forward links] تعني الإذن <b>بإعادة توجيه</b> الرسائل من <u>الآخرين </ u> Telegram-<i>القنوات/المجموعات/الحسابات</i> إلى <u>مجموعتنا</u>",
}
l_clink_http_on = {
    'ru': "✅☑Вкл внешние-ссылки",
    'en': "✅☑On external links",
    'es': "✅☑En enlaces externos",
    'fr': "✅☑Sur les liens externes",
    'zh': "✅☑关于外部链接",
    'ar': "✅☑على الروابط الخارجية",
}
l_clink_http_off = {
    'ru': "☑️☐Выкл внешние-ссылки",
    'en': "☑️☐Off external links",
    'es': "☑️☐Fuera de enlaces externos",
    'fr': "☑️☐Hors liens externes",
    'zh': "☑️️关闭外部链接",
    'ar': "☑️☐إيقاف الروابط الخارجية",
}
l_clink_telegram_on = {
    'ru': "✅☑Вкл @tg-tech-ссылки",
    'en': "✅☑On @tg-tech links",
    'es': "✅☑En enlaces @tg-tech",
    'fr': "✅☑Sur les liens @tg-tech",
    'zh': "✅☑在@tg-tech链接上",
    'ar': "✅☑على روابط @tg-tech",
}
l_clink_telegram_off = {
    'ru': "☑️☐Выкл @tg-tech-ссылки",
    'en': "☑️☐Off @tg-tech links",
    'es': "☑️☐Fuera de los enlaces @tg-tech",
    'fr': "☑️☐Hors liens @tg-tech",
    'zh': "☑️️关闭@tg-tech链接",
    'ar': "☑️☐إيقاف تشغيل روابط @tg-tech",
}
l_clink_forward_on = {
    'ru': "✅☑Вкл forward-ссылки",
    'en': "✅☑On forward links",
    'es': "✅☑En enlaces directos",
    'fr': "✅☑Sur les liens directs",
    'zh': "✅☑关于转发链接",
    'ar': "✅☑على الروابط الأمامية",
}
l_clink_forward_off = {
    'ru': "☑️☐Выкл forward-ссылки",
    'en': "☑️☐Disable forward links",
    'es': "☑️☐Desactivar enlaces directos",
    'fr': "☑️☐Désactiver les liens de transfert",
    'zh': "☑️️禁用前向链接",
    'ar': "☑️☐تعطيل الروابط الأمامية",
}
# endregion


# region csymbol_
l_csymbol_text = {
    'ru': "文 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> разрешение на слова с <i>文-глиф, ب-араб/<a href='https://www.zalgo.org'>zalgo-символами</a></i>\n\n<blockquote>[<b>✅ Вкл zalgo</b>] разрешение сообщений вида: <i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜͝ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝</i></blockquote>",
    'en': "文 <b>Press</b> on ✅/☑️ to <b>On/Off</b> permission for words with <i>文-glyph, ب-Arab/<a href=' https://www .zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 For example, the <b>zalgo</b> option allows messages of the following type: <i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜ ͝ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝</i>",
    'es': "文 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el permiso para palabras con <i>文-glifo, ب-Arab/<a href=' https://www. zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 Por ejemplo, la opción <b>zalgo</b> permite mensajes del siguiente tipo: <i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆ ̕͜ ͝ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝ </i>",
    'fr': "文 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> l'autorisation pour les mots avec <i>文-glyphe, ب-Arab/<a href=' https://www . zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 Par exemple, l'option <b>zalgo</b> autorise les messages du type suivant : <i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆ ̕͜ ͝ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝ </i>",
    'zh': "文 <b>按</b> ✅/☑️ 可以<b>打开/关闭</b>权限，以获取带有 <i>文-字形、 б-Arab/<a href=' https://www 的单词。 zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 例如，<b>zalgo</b> 选项允许以下类型的消息：<i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏̆̕ ͜ ͝ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝ </i>",
    'ar': "文 <b>اضغط</b> على ✅/☑️ للحصول على إذن <b>تشغيل/إيقاف</b> للكلمات التي تحتوي على <i>文-glyph, ب-Arab/<a href=' https://www . zalgo.org '>zalgo-symbols</a></i>\n\n👩🏽‍💻 على سبيل المثال، يتيح خيار <b>zalgo</b> الرسائل من النوع التالي: <i>̢̥l̶̡̡͖͚̥͇͙͈̜̲͚̼̻͇͙̹̔̀̾̾͛͑́̏͆̕͜ ͝. ô̶̒͗͐͝ ͍̼͎͈̬̩̩̰̱͙̐̐͛̾́͗̈́̚͝͝ </أنا>",
}
l_csymbol_symbols_on = {
    'ru': "✅☑Вкл 文ب",
    'en': "✅☑Includes writing",
    'es': "✅☑Incluye escritura",
    'fr': "✅☑Comprend l'écriture",
    'zh': "✅☑包括写作",
    'ar': "✅☑يتضمن الكتابة",
}
l_csymbol_symbols_off = {
    'ru': "☑️☐Выкл 文ب",
    'en': "☑️☐Выкл 文ب",
    'es': "☑️☐Выкл 文ب",
    'fr': "☑️☐Выкл 文ب",
    'zh': "☑️☐Выкл 文ب",
    'ar': "☑️☐Vыкл 文ب",
}
l_csymbol_zalgo_on = {
    'ru': "✅☑Вкл zalgo",
    'en': "✅☑Zalgo on",
    'es': "✅☑Zalgo encendido",
    'fr': "✅☑Zalgo sur",
    'zh': "✅☑扎尔戈",
    'ar': "✅☑ زالغو أون",
}
l_csymbol_zalgo_off = {
    'ru': "☑️☐Выкл zalgo",
    'en': "☑️☐Выкл zalgo",
    'es': "☑️☐Выкл zalgo",
    'fr': "☑️☐Выкл zalgo",
    'zh': "☑️ Выкл 扎尔戈",
    'ar': "☑️☐Выкл زالغو",
}
# endregion


# region cmedia_
l_cmedia_text = {
    'ru': "🗣 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> разрешение на <i>media</i>-сообщения\n\n<blockquote>[☑️☐Выкл видео-заметки]-режим означает запрет на <b>видео-заметки в кружочке</b> в нашей группе\n\n👩🏽‍💻 Чтобы разрешить/запретить конкретный стикерпак, жми [⚙️Настроить]</blockquote>",
    'en': "🗣 <b>Press</b> on ✅/☑️ to <b>On/Off</b> permission for <i>media</i>-messages\n\n[☑️☐Off video notes]-mode means a ban on <b>video notes in a circle</b> in our group\n\n👩🏽‍💻 To allow/prohibit a specific sticker pack, click [⚙️Customize]",
    'es': "🗣 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> el permiso para <i>medios</i>-mensajes\n\n[☑️☐Notas de video desactivadas]-modo significa prohibición de <b>notas de vídeo en un círculo</b> en nuestro grupo\n\n👩🏽‍💻 Para permitir/prohibir un paquete de pegatinas específico, haga clic en [⚙️Personalizar]",
    'fr': "🗣 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> l'autorisation pour les messages <i>médias</i>\n\n[☑️☐Off notes vidéo]-le mode signifie une interdiction des <b>notes vidéo dans un cercle</b> dans notre groupe\n\n👩🏽‍💻 Pour autoriser/interdire un pack d'autocollants spécifique, cliquez sur [⚙️Personnaliser]",
    'zh': "🗣 <b>按</b> ✅/☑️ 即可<b>开启/关闭</b><i>媒体</i>权限-消息\n\n[☑️☐关闭视频笔记]-模式表示禁止我们群组中的<b>圈内视频笔记</b>\n\n👩🏽‍💻 要允许/禁止特定贴纸包，请点击 [⚙️自定义]",
    'ar': "🗣 <b>اضغط</b> على ✅/☑️ للحصول على إذن <b>تشغيل/إيقاف</b> لرسائل <i>الوسائط</i>\n\n[☑️☐إيقاف ملاحظات الفيديو]-يعني الوضع حظر <b>ملاحظات الفيديو في دائرة</b> في مجموعتنا\n\n👩🏽‍💻 للسماح/حظر حزمة ملصقات معينة، انقر فوق [⚙️تخصيص]",
}
l_cmedia_photo_on = {
    'ru': "✅☑Вкл фото",
    'en': "✅☑Photo included",
    'es': "✅☑Foto incluida",
    'fr': "✅☑Photo incluse",
    'zh': "✅☑附有照片",
    'ar': "✅☑الصورة متضمنة",
}
l_cmedia_photo_off = {
    'ru': "☑️☐Выкл фото",
    'en': "☑️☐Выкл photo",
    'es': "☑️☐Выкл foto",
    'fr': "☑️☐Выкл photo",
    'zh': "☑️ Выкл 照片",
    'ar': "☑️☐Vыкл الصورة",
}
l_cmedia_video_on = {
    'ru': "✅☑Вкл видео",
    'en': "✅☑On video",
    'es': "✅☑En vídeo",
    'fr': "✅☑En vidéo",
    'zh': "✅☑视频中",
    'ar': "✅☑بالفيديو",
}
l_cmedia_video_off = {
    'ru': "☑️☐Выкл видео",
    'en': "☑️☐Выкл video",
    'es': "☑️☐Выкл video",
    'fr': "☑️☐Выкл vidéo",
    'zh': "☑️ Выкл 视频",
    'ar': "☑️☐فيديو رائع",
}
l_cmedia_giff_on = {
    'ru': "✅☑Вкл гиф",
    'en': "✅☑ Turn on",
    'es': "✅☑ Enciende",
    'fr': "✅☑ Allumez",
    'zh': "✅☑ 开启",
    'ar': "✅☑ تشغيل",
}
l_cmedia_giff_off = {
    'ru': "☑️☐Выкл гиф",
    'en': "☑️☐ Turn off",
    'es': "☑️☐ Apagar",
    'fr': "☑️☐ Éteignez",
    'zh': "☑️️关闭",
    'ar': "☑️☐ إيقاف",
}
l_cmedia_audio_on = {
    'ru': "✅☑Вкл аудио",
    'en': "✅☑On audio",
    'es': "✅☑En audio",
    'fr': "✅☑Sur l'audio",
    'zh': "✅☑音频",
    'ar': "✅☑على الصوت",
}
l_cmedia_audio_off = {
    'ru': "☑️☐Выкл аудио",
    'en': "☑️☐Выкл audio",
    'es': "☑️☐Выкл audio",
    'fr': "☑️☐Выкл audio",
    'zh': "☑️ Выкл 音频",
    'ar': "☑️☐Vыкл الصوت",
}
l_cmedia_emoji_on = {
    'ru': "✅☑Вкл эмоджи",
    'en': "✅☑Emoji included",
    'es': "✅☑Emoji incluido",
    'fr': "✅☑Emoji inclus",
    'zh': "✅☑包含表情符号",
    'ar': "✅☑الرموز التعبيرية متضمنة",
}
l_cmedia_emoji_off = {
    'ru': "☑️☐Выкл эмоджи",
    'en': "☑️☐Выкл emoji",
    'es': "☑️☐Выкл emoji",
    'fr': "☑️☐Выкл emoji",
    'zh': "☑️ Выкл 表情符号",
    'ar': "☑️☐Vыкл الرموز التعبيرية",
}
l_cmedia_docum_on = {
    'ru': "✅☑Вкл док",
    'en': "✅☑Docum included",
    'es': "✅☑Documento incluido",
    'fr': "✅☑Document inclus",
    'zh': "✅☑附有文件",
    'ar': "✅☑الوثيقة متضمنة",
}
l_cmedia_docum_off = {
    'ru': "☑️☐Выкл док",
    'en': "☑️☐Выкл docum",
    'es': "☑️☐Выкл docum",
    'fr': "☑️☐Выкл docum",
    'zh': "☑️ Выкл 文档",
    'ar': "☑️☐Vыкл مستند",
}
l_cmedia_viabot_on = {
    'ru': "✅☑Вкл @via-бот",
    'en': "✅☑Вкл via_bot",
    'es': "✅☑Вкл via_bot",
    'fr': "✅☑Вкл via_bot",
    'zh': "✅☑Вкл via_bot",
    'ar': "✅☑Вкл via_bot",
}
l_cmedia_viabot_off = {
    'ru': "☑️☐Выкл @via-бот",
    'en': "☑️☐View via_bot",
    'es': "☑️☐Ver vía_bot",
    'fr': "☑️☐Voir via_bot",
    'zh': "☑️️查看via_bot",
    'ar': "☑️☐العرض عبر_bot",
}
l_cmedia_poll_on = {
    'ru': "✅☑Вкл опросы",
    'en': "✅☑On polls",
    'es': "✅☑En encuestas",
    'fr': "✅☑Sur les sondages",
    'zh': "✅☑在民意调查中",
    'ar': "✅☑في استطلاعات الرأي",
}
l_cmedia_poll_off = {
    'ru': "☑️☐Выкл опросы",
    'en': "☑️☐Off polls",
    'es': "☑️☐Fuera de las encuestas",
    'fr': "☑️☐Hors sondages",
    'zh': "☑️️关闭民意调查",
    'ar': "☑️☐ خارج صناديق الاقتراع",
}
l_cmedia_sticker_on = {
    'ru': "✅☑Вкл стикер",
    'en': "✅☑ Sticker included",
    'es': "✅☑ Pegatina incluida",
    'fr': "✅☑ Autocollant inclus",
    'zh': "✅☑ 包含贴纸",
    'ar': "✅☑ الملصق متضمن",
}
l_cmedia_sticker_off = {
    'ru': "☑️☐Выкл стикер",
    'en': "☑️☐Выкл sticker",
    'es': "☑️☐Выкл pegatina",
    'fr': "☑️☐Выкл autocollant",
    'zh': "☑️ Выкл 贴纸",
    'ar': "☑️☐ملصق مميز",
}
l_cmedia_voice_on = {
    'ru': "✅☑Вкл голосовое",
    'en': "✅☑Voice on",
    'es': "✅☑Voz activada",
    'fr': "✅☑Voix activée",
    'zh': "✅☑语音开启",
    'ar': "✅☑تشغيل الصوت",
}
l_cmedia_voice_off = {
    'ru': "☑️☐Выкл голосовое",
    'en': "☑️☐Turn off voice",
    'es': "☑️☐Apagar voz",
    'fr': "☑️☐Éteignez la voix",
    'zh': "☑️️关闭语音",
    'ar': "☑️☐إيقاف الصوت",
}
l_cmedia_videonote_on = {
    'ru': "✅☑Вкл телескоп",
    'en': "✅☑On video notes",
    'es': "✅☑En notas de video",
    'fr': "✅☑Sur les notes vidéo",
    'zh': "✅☑视频笔记",
    'ar': "✅☑في ملاحظات الفيديو",
}
l_cmedia_videonote_off = {
    'ru': "☑️☐Выкл телескоп",
    'en': "☑️☐Turn off video notes",
    'es': "☑️☐Desactivar notas de vídeo",
    'fr': "☑️☐Désactivez les notes vidéo",
    'zh': "☑️️关闭视频笔记",
    'ar': "☑️☐ قم بإيقاف تشغيل ملاحظات الفيديو",
}
l_cmedia_call_photo = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка фото и видео]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the [Permissions] settings, enable the option:\n\n[✅ Sending photos and videos]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Permisos], habilita la opción:\n\n[✅ Envío de fotos y videos]\n\n🕚Espera 1min",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez l'option :\n\n[✅ Envoi de photos et vidéos]\n\n🕚Attendez 1min",
    'zh': "👮🏽 在【权限】设置中，启用选项：\n\n[✅ 发送照片和视频]\n\n🕚等待 1 分钟",
    'ar': "👮🏽 في إعدادات [الأذونات]، قم بتمكين الخيار:\n\n[✅ إرسال الصور ومقاطع الفيديو]\n\n🕚انتظر دقيقة واحدة",
}
l_cmedia_call_sticker_giff = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка стикеров и GIF]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the [Permissions] settings, enable the option:\n\n[✅ Sending stickers and GIFs]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Permisos], habilita la opción:\n\n[✅ Envío de stickers y GIF]\n\n🕚Espera 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez l'option :\n\n[✅ Envoi d'autocollants et de GIF]\n\n🕚Attendez 1 min",
    'zh': "👮🏽 在【权限】设置中，启用选项：\n\n[✅ 发送贴纸和 GIF]\n\n🕚等待 1 分钟",
    'ar': "👮🏽 في إعدادات [الأذونات]، قم بتمكين الخيار:\n\n[✅ إرسال الملصقات وصور GIF]\n\n🕚انتظر دقيقة واحدة",
}
l_cmedia_call_poll = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Отправка опросов]\n\n🕚Подожди 1min",
    'en': "👮🏽 In the [Permissions] settings, enable the option:\n\n[✅ Sending surveys]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Permisos], habilita la opción:\n\n[✅ Envío de encuestas]\n\n🕚Espera 1min",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez l'option :\n\n[✅ Envoi d'enquêtes]\n\n🕚Attendez 1 min",
    'zh': "👮🏽 在【权限】设置中，启用选项：\n\n[✅ 发送调查]\n\n🕚等待 1 分钟",
    'ar': "👮🏽 في إعدادات [الأذونات]، قم بتمكين الخيار:\n\n[✅ إرسال الاستبيانات]\n\n🕚انتظر دقيقة واحدة",
}
l_cstickerconfig_text = {
    'ru': "🦊 <b>Исключения</b> для стикерпаков в {0}-файле:\n\n+ Разрешенные: <u>{1}</u>\n- Запрещенные: <u>{2}</u>\n\n<blockquote>[✅ Разрешить] пропускает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [☑️ Выкл sticker]\n\n[🚫 Запретить] запрещает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [✅ Вкл sticker]</blockquote>",
    'en': "🦊 <b>Exceptions</b> for sticker packs in the {0} file:\n\n+ Allowed: <u>{1}</u>\n-Prohibited: <u>{2}</u>\ n\n[✅ Allow] allows specified sticker packs <i>as an exception</i> when the [☑️☐Off sticker] option is selected\n\n[🚫 Deny] prohibits specified sticker packs <i>as an exception</i > when [✅☑On sticker] option is selected",
    'es': "🦊 <b>Excepciones</b> para paquetes de pegatinas en el archivo {0}:\n\n+ Permitido: <u>{1}</u>\n-Prohibido: <u>{2}</u> \ n\n[✅ Permitir] permite paquetes de stickers específicos <i>como excepción</i> cuando se selecciona la opción [☑️☐Off stickers]\n\n[🚫 Denegar] prohíbe paquetes de stickers específicos <i>como excepción</i > cuando se selecciona la opción [✅☑En etiqueta]",
    'fr': "🦊 <b>Exceptions</b> pour les packs d'autocollants dans le fichier {0} :\n\n+ Autorisé : <u>{1}</u>\n-Interdit : <u>{2}</u> \ n\n[✅ Autoriser] autorise les packs d'autocollants spécifiés <i>à titre d'exception</i> lorsque l'option [☑️☐Désactiver l'autocollant] est sélectionnée\n\n[🚫 Refuser] interdit les packs d'autocollants spécifiés <i>en tant que exception</i > lorsque l'option [✅☑Sur autocollant] est sélectionnée",
    'zh': "🦊 {0} 文件中贴纸包的<b>例外</b>：\n\n+ 允许：<u>{1}</u>\n-禁止：<u>{2}</u> \ n\n[✅ 允许] 在选择 [☑️☐关闭贴纸] 选项时允许指定的贴纸包<i>作为例外</i>\n\n[🚫 拒绝] 禁止指定的贴纸包<i>作为例外当选择[✅☑在贴纸上]选项时例外</i>",
    'ar': "🦊 <b>الاستثناءات</b> لحزم الملصقات في الملف {0}:\n\n+ المسموح به: <u>{1}</u>\n-المحظور: <u>{2}</u>\n\n[✅ السماح] يسمح بحزم الملصقات المحددة <i>كاستثناء</i> عند تحديد خيار [☑️☐إيقاف الملصق]\n\n[🚫 رفض] يحظر حزم الملصقات المحددة <i>ك استثناء</i> عند تحديد خيار [✅☑On label]",
}
l_cstickerpack_1 = {
    'ru': "✅ Разрешить",
    'en': "✅ Allow",
    'es': "✅ Permitir",
    'fr': "✅ Autoriser",
    'zh': "✅ 允许",
    'ar': "✅ السماح",
}
l_cstickerpack_0 = {
    'ru': "🚫 Запретить",
    'en': "🚫 Ban",
    'es': "🚫 Prohibición",
    'fr': "🚫 Interdire",
    'zh': "🚫 禁令",
    'ar': "🚫 الحظر",
}
l_coperation_1 = {
    'ru': "✅ Добавить",
    'en': "✅Add",
    'es': "✅Agregar",
    'fr': "✅Ajouter",
    'zh': "✅添加",
    'ar': "✅إضافة",
}
l_coperation_0 = {
    'ru': "🚫 Удалить",
    'en': "🚫Delete",
    'es': "🚫Eliminar",
    'fr': "🚫Supprimer",
    'zh': "🚫删除",
    'ar': "🚫حذف",
}
l_GROUPP_CSTICKER1_NUM1 = {
    'ru': "🦊 <b>Текущее</b> количество <b>разрешенных</b> стикерпаков в {0}-файле: <u>{1}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> разрешенные стикерпаки",
    'en': "🦊 <b>Current</b> number of <b>allowed</b> sticker packs in the {0} file: <u>{1}</u>\n\n<b>Click</b> on ✅ /🚫 to <b>Add/Remove</b> allowed sticker packs",
    'es': "🦊 Número <b>actual</b> de paquetes de pegatinas <b>permitidos</b> en el archivo {0}: <u>{1}</u>\n\n<b>Haga clic</b> en ✅ /🚫 para <b>Agregar/Eliminar</b> paquetes de stickers permitidos",
    'fr': "🦊 <b>Nombre actuel</b> de packs d'autocollants <b>autorisés</b> dans le fichier {0} : <u>{1}</u>\n\n<b>Cliquez</b> sur ✅ /🚫 pour <b>Ajouter/Supprimer</b> les packs d'autocollants autorisés",
    'zh': "🦊 {0} 文件中<b>当前</b>个<b>允许</b>个贴纸包数量：<u>{1}</u>\n\n<b>点击</b>在 ✅ /🚫 上<b>添加/删除</b>允许的贴纸包",
    'ar': "🦊 <b>العدد <b>الحالي</b> لحزم الملصقات <b>المسموح بها</b> في الملف {0}: <u>{1}</u>\n\n<b>انقر</b> على ✅ /🚫 <b>لإضافة/إزالة</b> حزم الملصقات المسموح بها",
}
l_GROUPP_CSTICKER1_NUM0 = {
    'ru': "🦊 <b>Текущее</b> количество <b>разрешенных</b> стикерпаков: <u>{0}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> разрешенные стикерпаки",
    'en': "🦊 <b>Current</b> number of <b>allowed</b> sticker packs: <u>{0}</u>\n\n<b>Press</b> on ✅/🚫 to <b >Add/Remove</b> allowed sticker packs",
    'es': "🦊 Número <b>actual</b> de paquetes de pegatinas <b>permitidos</b>: <u>{0}</u>\n\n<b>Presiona</b> ✅/🚫 para < b >Agregar/eliminar</b> paquetes de stickers permitidos",
    'fr': "🦊 <b>Nombre actuel</b> de packs d'autocollants <b>autorisés</b> : <u>{0}</u>\n\n<b>Appuyez</b> sur ✅/🚫 pour < b >Ajouter/Supprimer</b> des packs d'autocollants autorisés",
    'zh': "🦊 <b>当前</b><b>允许</b>个贴纸包数量：<u>{0}</u>\n\n<b>按 ✅/🚫 上的</b>到 < b>添加/删除</b>允许的贴纸包",
    'ar': "🦊 <b>العدد</b>الحالي</b> من حزم الملصقات <b>المسموح بها</b>: <u>{0}</u>\n\n<b>اضغط</b> على ✅/🚫 إلى < ب >إضافة/إزالة</b> حزم الملصقات المسموح بها",
}
l_GROUPP_CSTICKER0_NUM1 = {
    'ru': "🦊 <b>Текущее</b> количество <b>запрещенных</b> стикерпаков в {0}-файле: <u>{1}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> запрещенные стикерпаки",
    'en': "🦊 <b>Current</b> number of <b>banned</b> sticker packs in the {0} file: <u>{1}</u>\n\n<b>Click</b> on ✅ /🚫 to <b>Add/Remove</b> prohibited sticker packs",
    'es': "🦊 Número <b>actual</b> de paquetes de pegatinas <b>prohibidas</b> en el archivo {0}: <u>{1}</u>\n\n<b>Haga clic</b> en ✅ /🚫 para <b>Agregar/Eliminar</b> paquetes de stickers prohibidos",
    'fr': "🦊 <b>Nombre actuel</b> de packs d'autocollants <b>interdits</b> dans le fichier {0} : <u>{1}</u>\n\n<b>Cliquez</b> sur ✅ /🚫 pour <b>Ajouter/Supprimer</b> des packs d'autocollants interdits",
    'zh': "🦊 {0} 文件中<b>当前</b> 个<b>禁止</b> 贴纸包数量：<u>{1}</u>\n\n<b>点击</b>在 ✅ /🚫 上<b>添加/删除</b>禁止的贴纸包",
    'ar': "🦊 <b>العدد <b>الحالي</b> لحزم الملصقات <b>المحظورة</b> في الملف {0}: <u>{1}</u>\n\n<b>انقر</b> على ✅ /🚫 <b>لإضافة/إزالة</b> حزم الملصقات المحظورة",
}
l_GROUPP_CSTICKER0_NUM0 = {
    'ru': "🦊 <b>Текущее</b> количество <b>запрещенных</b> стикерпаков: <u>{0}</u>\n\n👩🏽‍💻 <b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> запрещенные стикерпаки",
    'en': "🦊 <b>Current</b> number of <b>banned</b> sticker packs: <u>{0}</u>\n\n<b>Press</b> on ✅/🚫 to <b >Add/Remove</b> prohibited sticker packs",
    'es': "🦊 Número <b>actual</b> de paquetes de pegatinas <b>prohibidas</b>: <u>{0}</u>\n\n<b>Presiona</b> ✅/🚫 para < b >Agregar/eliminar</b> paquetes de stickers prohibidos",
    'fr': "🦊 <b>Nombre actuel</b> de packs d'autocollants <b>interdits</b> : <u>{0}</u>\n\n<b>Appuyez</b> sur ✅/🚫 pour < b >Ajouter/Supprimer</b> des packs d'autocollants interdits",
    'zh': "🦊<b>当前</b>个<b>禁止</b>个贴纸包数量：<u>{0}</u>\n\n<b>按 ✅/🚫 上的</b>到< b >添加/删除</b>禁止的贴纸包",
    'ar': "🦊 <b>العدد</b>الحالي</b> من حزم الملصقات <b>المحظورة</b>: <u>{0}</u>\n\n<b>اضغط</b> على ✅/🚫 إلى < ب >إضافة/إزالة</b> حزم الملصقات المحظورة",
}
l_cstickeroperation_add = {
    'ru': "\n\n👩🏽‍💻 Например, https://t.me/addstickers/HotCherry или HotCherry",
    'en': "\n\n👩🏽‍💻 For example, https://t.me/addstickers/HotCherry or HotCherry",
    'es': "\n\n👩🏽‍💻 Por ejemplo, https://t.me/addstickers/HotCherry o HotCherry",
    'fr': "\n\n👩🏽‍💻 Par exemple, https://t.me/addstickers/HotCherry ou HotCherry",
    'zh': "\n\n👩🏽‍💻 例如， https://t.me/addstickers/HotCherry或 HotCherry",
    'ar': "\n\n👩🏽‍💻 على سبيل المثال https://t.me/addstickers/HotCherry أو HotCherry",
}
l_cstickeroperation_isadd = {
    'ru': "✅ <b>Отправь</b> ссылку или имя <b>стикерпака</b>, чтобы <b>добавить</b> его в список разрешенных{0}",
    'en': "✅ <b>Send</b> a link or name of a <b>sticker pack</b> to <b>add</b> it to the allowed list{0}",
    'es': "✅ <b>Envía</b> un enlace o el nombre de un <b>paquete de pegatinas</b> para <b>añadir</b> a la lista permitida{0}",
    'fr': "✅ <b>Envoyez</b> un lien ou le nom d'un <b>pack d'autocollants</b> pour <b>l'ajouter</b> à la liste autorisée{0}",
    'zh': "✅ <b>发送</b><b>贴纸包</b>的链接或名称，以将其<b>添加</b>到允许的列表中{0}",
    'ar': "✅ <b>أرسل</b> رابطًا أو اسم <b>حزمة الملصقات</b> <b>لإضافتها</b> إلى القائمة المسموح بها{0}",
}
l_cstickeroperation_isnotadd = {
    'ru': "🚫 <b>Отправь</b> ссылку или имя <b>стикерпака</b>, чтобы <b>удалить</b> из списка разрешенных{0}",
    'en': "🚫 <b>Send</b> a link or name of a <b>sticker pack</b> to <b>remove</b> from the allowed list{0}",
    'es': "🚫 <b>Envíe</b> un enlace o el nombre de un <b>paquete de pegatinas</b> para <b>eliminar</b> de la lista permitida{0}",
    'fr': "🚫 <b>Envoyer</b> un lien ou le nom d'un <b>pack d'autocollants</b> à <b>supprimer</b> de la liste autorisée{0}",
    'zh': "🚫 <b>发送</b><b>贴纸包</b>的链接或名称以从允许的列表中<b>删除</b>{0}",
    'ar': "🚫 <b>أرسل</b> رابطًا أو اسم <b>حزمة ملصقات</b> <b>لإزالة</b> من القائمة المسموح بها{0}",
}
l_cstickeroperation_isadd2 = {
    'ru': "✅ <b>Отправь</b> ссылку или имя <b>стикерпака</b>, чтобы <b>добавить</b> его в список запрещенных{0}",
    'en': "✅ <b>Send</b> a link or name of a <b>sticker pack</b> to <b>add</b> it to the banned list{0}",
    'es': "✅ <b>Envía</b> un enlace o el nombre de un <b>paquete de pegatinas</b> para <b>añadir</b> a la lista de prohibidos{0}",
    'fr': "✅ <b>Envoyez</b> un lien ou le nom d'un <b>pack d'autocollants</b> pour <b>l'ajouter</b> à la liste des interdits{0}",
    'zh': "✅ <b>发送</b><b>贴纸包</b>的链接或名称，以将其<b>添加</b>到禁止列表中{0}",
    'ar': "✅ <b>أرسل</b> رابطًا أو اسم <b>حزمة الملصقات</b> <b>لإضافتها</b> إلى قائمة المحظورات{0}",
}
l_cstickeroperation_isnotadd2 = {
    'ru': "🚫 <b>Отправь</b> ссылку или имя <b>стикерпака</b>, чтобы <b>удалить</b> его из списка запрещенных{0}",
    'en': "🚫 <b>Send</b> a link or name of a <b>sticker pack</b> to <b>remove</b> it from the banned list{0}",
    'es': "🚫 <b>Envía</b> un enlace o el nombre de un <b>paquete de pegatinas</b> para <b>eliminarlo</b> de la lista de prohibidos{0}",
    'fr': "🚫 <b>Envoyer</b> un lien ou le nom d'un <b>pack d'autocollants</b> pour <b>le supprimer</b> de la liste des interdits{0}",
    'zh': "🚫 <b>发送</b><b>贴纸包</b>的链接或名称，以将其从禁止列表中<b>删除</b>{0}",
    'ar': "🚫 <b>أرسل</b> رابطًا أو اسم <b>حزمة الملصقات</b> <b>لإزالتها</b> من القائمة المحظورة{0}",
}
l_fsm_sticker_add = {
    'ru': "👩🏽‍💻 <b>Готово!</b> <b>Исключения</b> для стикерпаков:\n\n+ Разрешенные: <u>{0}</u>\n- Запрещенные: <u>{1}</u>\n\n[✅ Разрешить] пропускает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [☑️ Выкл sticker]\n[🚫 Запретить] запрещает указанные стикерпаки <i>в качестве исключения</i>, когда выбрана опция [✅ Вкл sticker]",
    'en': "👩🏽‍💻 <b>Done!</b> <b>Exceptions</b> for sticker packs:\n\n+ Allowed: <u>{0}</u>\n-Prohibited: <u>{1 }</u>\n\n[✅ Allow] allows the specified sticker packs <i>as an exception</i> when the [☑️☐Off sticker] option is selected\n[🚫 Deny] prohibits the specified sticker packs <i>as exceptions</i>when the [✅☑On sticker] option is selected",
    'es': "👩🏽‍💻 <b>¡Listo!</b> <b>Excepciones</b> para paquetes de pegatinas:\n\n+ Permitido: <u>{0}</u>\n-Prohibido: <u>{ 1 }</u>\n\n[✅ Permitir] permite los paquetes de stickers especificados <i>como excepción</i> cuando se selecciona la opción [☑️☐Off stickers]\n[🚫 Denegar] prohíbe el stickers especificado paquetes <i>como excepciones</i>cuando se selecciona la opción [✅☑En etiqueta]",
    'fr': "👩🏽‍💻 <b>Terminé !</b> <b>Exceptions</b> pour les packs d'autocollants :\n\n+ Autorisé : <u>{0}</u>\n-Interdit : <u>{ 1 }</u>\n\n[✅ Autoriser] autorise les packs d'autocollants spécifiés <i>à titre d'exception</i> lorsque l'option [☑️☐Désactiver l'autocollant] est sélectionnée\n[🚫 Refuser] interdit l'autocollant spécifié packs <i>à titre d'exceptions</i> lorsque l'option [✅☑Sur l'autocollant] est sélectionnée",
    'zh': "👩🏽‍💻 <b>完成！</b> <b>贴纸包例外</b>：\n\n+ 允许：<u>{0}</u>\n-禁止：<u>{ 1 }</u>\n\n当选择了 [☑️☐关闭贴纸] 选项时，[✅ 允许] 允许指定的贴纸包<i>作为例外</i>\n[🚫 拒绝] 禁止指定的贴纸当选择[✅☑贴纸]选项时<i>作为例外</i>打包",
    'ar': "👩🏽‍💻 <b>تم!</b> <b>الاستثناءات</b> لحزم الملصقات:\n\n+ المسموح به: <u>{0}</u>\n-محظور: <u>{ 1 }</u>\n\n[✅ السماح] يسمح بحزم الملصقات المحددة <i>كاستثناء</i> عند تحديد خيار [☑️☐إيقاف الملصق]\n[🚫 رفض] يحظر الملصق المحدد الحزم <i>استثناءات</i>عند تحديد خيار [✅☑On label].",
}
# endregion


# region cstart_
l_cstart_text = {
    'ru': "🚀 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-ответ на триггер-сообщения, содержащие конкретные старт-слова\n\n<blockquote>👩🏽‍💻 <b>Текущее</b> количество старт-слов <u>{0}</u></blockquote>",
    'en': "🚀 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-reply to trigger messages containing specific start words\n\n👩🏽‍💻 <b>Current </b> number of start words <u>{0}</u>",
    'es': "🚀 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la respuesta automática y activar mensajes que contengan palabras iniciales específicas\n\n👩🏽‍💻 <b>Actual </b> número de palabras iniciales <u>{0}</u>",
    'fr': "🚀 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la réponse automatique afin de déclencher des messages contenant des mots de début spécifiques\n\n👩🏽‍💻 <b>Actuel </b> nombre de premiers mots <u>{0}</u>",
    'zh': "🚀 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动回复，以触发包含特定起始词的消息\n\n👩🏽‍💻 <b>当前</b>起始词数 <u>{0}</u>",
    'ar': "🚀 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الرد التلقائي لتشغيل الرسائل التي تحتوي على كلمات بداية محددة\n\n👩🏽‍💻 <b>الحالي </b> عدد كلمات البداية <u>{0}</u>",
}
l_cstart_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы одно старт-слово",
    'en': "🔔 You need to ⚙️Customize at least one start word",
    'es': "🔔 Necesitas ⚙️Personalizar al menos una palabra de inicio",
    'fr': "🔔 Vous devez ⚙️Personnaliser au moins un mot de départ",
    'zh': "🔔 您需要⚙️自定义至少一个起始词",
    'ar': "🔔 تحتاج إلى ⚙️تخصيص كلمة بداية واحدة على الأقل",
}
l_cstartconfig_call = {
    'ru': "🚀 Нужно ⚙️Настроить хотя бы один пост через опцию 🔔Авто-постинг",
    'en': "🚀 You need to ⚙️Set up at least one post using the 🔔Auto-posting option",
    'es': "🚀 Debes ⚙️Configurar al menos una publicación usando la opción 🔔Publicación automática",
    'fr': "🚀 Vous devez ⚙️Créer au moins une publication en utilisant l'option 🔔Publication automatique",
    'zh': "🚀 您需要⚙️使用🔔自动发帖选项设置至少一篇帖子",
    'ar': "🚀 يتعين عليك ⚙️ إعداد مشاركة واحدة على الأقل باستخدام خيار 🔔 النشر التلقائي",
}
l_cstartconfig_text = {
    'ru': "🚀 <b>Выбери</b> пост, который будет присылаться в ответ на <b>старт</b>-слова и жми [🚀 <b>Использовать</b>] под выбранным постом\n\n<blockquote>👩🏽‍💻 <b>Общее</b> количество старт-слов: <u>{0}</u></blockquote>",
    'en': "🚀 <b>Select</b> the post that will be sent in response to <b>start</b>-words and click [🚀 <b>Use</b>] under the selected post\n\n👩🏽‍ 💻 <b>Total</b> number of starting words: <u>{0}</u>",
    'es': "🚀 <b>Seleccione</b> la publicación que se enviará en respuesta a las palabras <b>inicio</b> y haga clic en [🚀 <b>Usar</b>] debajo de la publicación seleccionada\n\n👩 🏽‍ 💻 Número <b>Total</b> de palabras iniciales: <u>{0}</u>",
    'fr': "🚀 <b>Sélectionnez</b> le message qui sera envoyé en réponse aux <b>mots de démarrage</b> et cliquez sur [🚀 <b>Utiliser</b>] sous le message sélectionné\n\n👩 🏽‍ 💻 <b>Nombre total</b> de mots de départ : <u>{0}</u>",
    'zh': "🚀 <b>选择</b>将针对<b>开始</b>字词发送的帖子，然后点击所选帖子下的[🚀 <b>使用</b>]\n\n👩 🏽‍ 💻 <b>总</b>个起始单词数：<u>{0}</u>",
    'ar': "🚀 <b>حدد</b> المنشور الذي سيتم إرساله ردًا على <b>ابدأ</b>-الكلمات وانقر على [🚀 <b>استخدام</b>] أسفل المنشور المحدد\n\n👩 🏽‍ 💻 <b>الإجمالي</b> عدد كلمات البداية: <u>{0}</u>",
}
l_cstartconfig_use = {
    'ru': "🚀 Использовать",
    'en': "🚀 Use",
    'es': "🚀 Usar",
    'fr': "🚀 Utiliser",
    'zh': "🚀 使用",
    'ar': "🚀 استخدم",
}
l_cstartoperation_caption = {
    'ru': "🚀 <b>Текущее</b> количество <i>старт-слов</i> для поста #{0} в {1}-файле: <u>{2}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> старт-слова",
    'en': "🚀 <b>Current</b> number of <i>start words</i> for post #{0} in {1} file: <u>{2}</u>\n\n<b> Press</b>on ✅/🚫 to <b>Add/Remove</b> start words",
    'es': "🚀 Número <b>actual</b> de <i>palabras iniciales</i> para la publicación #{0} en el archivo {1}: <u>{2}</u>\n\n<b> Presione </b>en ✅/🚫 para <b>Agregar o quitar</b> palabras iniciales",
    'fr': "🚀 <b>Nombre actuel</b> de <i>mots de début</i> pour le message n° {0} dans le fichier {1} : <u>{2}</u>\n\n<b> Appuyez sur </b>sur ✅/🚫 pour <b>Ajouter/Supprimer</b> les premiers mots",
    'zh': "🚀 {1} 文件中第 #{0} 篇帖子的<b>当前</b><i>起始词</i>数量：<u>{2}</u>\n\n<b> 按</b>在 ✅/🚫 上<b>添加/删除</b>起始词",
    'ar': "🚀 <b>العدد <b>الحالي</b> لكلمات <i>البدء</i> للمنشور رقم {0} في الملف {1}: <u>{2}</u>\n\n<b> اضغط </b>على ✅/🚫 <b>إضافة/إزالة</b> كلمات البداية",
}
l_cstartoperation_text = {
    'ru': "🚀 <b>Текущее</b> количество <i>старт-слов</i> для поста #{0}: <u>{1}</u>\n\n<blockquote><b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> старт-слова</blockquote>",
    'en': "🚀 <b>Current</b> number of <i>start words</i> for post #{0}: <u>{1}</u>\n\n<b>Click</b> on ✅/🚫 to <b>Add/Remove</b> start words",
    'es': "🚀 Número <b>actual</b> de <i>palabras iniciales</i> para la publicación n.°{0}: <u>{1}</u>\n\n<b>Haga clic</b> en ✅/🚫 para <b>Agregar/Quitar</b> palabras iniciales",
    'fr': "🚀 <b>Nombre actuel</b> de <i>mots de début</i> pour le message n°{0} : <u>{1}</u>\n\n<b>Cliquez</b> sur ✅/🚫 pour <b>Ajouter/Supprimer</b> des mots de départ",
    'zh': "🚀 帖子 #{0} 的<b>当前</b><i>起始词</i>数量：<u>{1}</u>\n\n<b>点击</b> ✅/🚫 至<b>添加/删除</b>起始词",
    'ar': "🚀 <b>الحالي</b> عدد <i>كلمات البداية</i> للمشاركة رقم {0}: <u>{1}</u>\n\n<b>انقر</b> على ✅/🚫 <b>لإضافة/إزالة</b> كلمات البداية",
}
l_cstartoperation_handler = {
    'ru': "\n\n▪️регистр не важен\n▪️* в конце слова учитывает вхождение",
    'en': "\n\n▪️case is not important\n▪️* at the end of a word takes into account the occurrence",
    'es': "\n\n▪️el caso no es importante\n▪️* al final de una palabra tiene en cuenta la aparición",
    'fr': "\n\nnounced️la casse n'a pas d'importance\nnoyer* à la fin d'un mot prend en compte l'occurrence",
    'zh': "\n\n▪️大小写并不重要\n▪️* 考虑到单词末尾的出现情况",
    'ar': "\n\n▪️حالة الأحرف ليست مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار حدوثها",
}
l_cstartoperation_answer = {
    'ru': "🚀 <b>Введи</b> <u>старт-слова</u> <b>через</b> пробелы или разделители, чтобы <i>добавить</i> их в базу{0}",
    'en': "🚀 <b>Enter</b> <u>start words</u> <b>separated</b> by spaces or separators to <i>add</i> them to the database{0}",
    'es': "🚀 <b>Ingrese</b> <u>palabras iniciales</u> <b>separadas</b> por espacios o separadores para <i>agregarlas</i> a la base de datos{0}",
    'fr': "🚀 <b>Saisissez</b> <u>mots de début</u> <b>séparés</b> par des espaces ou des séparateurs pour <i>ajouter</i> à la base de données{0}",
    'zh': "🚀 <b>输入</b> <u>起始词</u> <b>用空格或分隔符分隔</b>，将其<i>添加</i>到数据库中{0}",
    'ar': "🚀 <b>أدخل</b> <u>كلمات البداية</u> <b>مفصولة</b> بمسافات أو فواصل <i>لإضافتها</i> إلى قاعدة البيانات{0}",
}
l_cstartoperation_noanswer = {
    'ru': "🚫 <b>Введи</b> <u>старт-слова</u> <b>через</b> пробелы или разделители, чтобы их <i>удалить</i> из базы{0}",
    'en': "🚫 <b>Enter</b> <u>start words</u> <b>separated</b> by spaces or separators to <i>remove</i> them from the database{0}",
    'es': "🚫 <b>Ingrese</b> <u>palabras iniciales</u> <b>separadas</b> por espacios o separadores para <i>eliminar</i> de la base de datos{0}",
    'fr': "🚫 <b>Saisissez</b> <u>mots de début</u> <b>séparés</b> par des espaces ou des séparateurs pour <i>supprimer</i> de la base de données{0}",
    'zh': "🚫 <b>输入</b> <u>起始词</u> <b>用空格或分隔符分隔</b>，以<i>将其从数据库中删除</i>{0}",
    'ar': "🚫 <b>أدخل</b> <u>كلمات البداية</u> <b>مفصولة</b> بمسافات أو فواصل <i>لإزالتها</i> من قاعدة البيانات{0}",
}
l_fsm_start_add_caption = {
    'ru': "🚀 <b>Готово!</b> <b>Текущее</b> количество старт-слов для поста #{0} в {1}-файле: <u>{2}</u>",
    'en': "🚀 <b>Done!</b> <b>Current</b> number of starting words for post #{0} in {1} file: <u>{2}</u>",
    'es': "🚀 <b>¡Listo!</b> Número <b>actual</b> de palabras iniciales para la publicación #{0} en el archivo {1}: <u>{2}</u>",
    'fr': "🚀 <b>Terminé !</b> <b>Nombre actuel</b> de mots de départ pour le message n° {0} dans le fichier {1} : <u>{2}</u>",
    'zh': "🚀 <b>完成！</b> {1} 文件中第 #{0} 篇帖子的<b>当前</b>个起始单词数：<u>{2}</u>",
    'ar': "🚀 <b>تم!</b> <b>العدد الحالي</b> لكلمات البداية للمشاركة رقم {0} في ملف {1}: <u>{2}</u>",
}
l_fsm_start_add_text = {
    'ru': "🚀 <b>Готово!</b> <b>Текущее</b> количество старт-слов для поста #{0}: <u>{1}</u>",
    'en': "🚀 <b>Done!</b> <b>Current</b> number of starting words for post #{0}: <u>{1}</u>",
    'es': "🚀 <b>¡Listo!</b> <b>Número actual</b> de palabras iniciales para la publicación #{0}: <u>{1}</u>",
    'fr': "🚀 <b>Terminé !</b> <b>Nombre actuel</b> de mots de départ pour le message n°{0} : <u>{1}</u>",
    'zh': "🚀 <b>完成！</b> <b>当前</b>帖子 #{0} 的起始单词数：<u>{1}</u>",
    'ar': "🚀 <b>تم!</b> <b>العدد الحالي</b> لكلمات البداية للمشاركة رقم {0}: <u>{1}</u>",
}
l_need_start_word = {
    'ru': "f'🚀 Сначала добавь хотя бы одно старт-слово",
    'en': "f'🚀 First add at least one start word",
    'es': "f'🚀 Primero agregue al menos una palabra inicial",
    'fr': "f'🚀 Ajoutez d'abord au moins un mot de départ",
    'zh': "f'🚀 首先添加至少一个起始词",
    'ar': "f'🚀 أضف أولاً كلمة بداية واحدة على الأقل",
}

# endregion


# region cstop_
l_cstop_text = {
    'ru': "🧾 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> авто-удаление сообщений, содержащие запрещенные стоп-слова\n\n<blockquote>👩🏽‍💻 <b>Текущее</b> количество стоп-слов <u>{0}</u></blockquote>",
    'en': "🧾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-delete messages containing prohibited stop words\n\n👩🏽‍💻 <b>Current</b > number of stop words <u>{0}</u>",
    'es': "🧾 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👩🏽‍💻 Número <b>Actual</b > de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👩🏽‍💻 <b>Actuel</b > nombre de mots vides <u>{0}</u>",
    'zh': "🧾 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动删除包含禁止停用词的消息\n\n👩🏽‍💻 <b>当前</b > 条数停用词<u>{0}</u>",
    'ar': "🧾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الحذف التلقائي للرسائل التي تحتوي على كلمات توقف محظورة\n\n👩🏽‍💻 <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
l_cstop_call = {
    'ru': "🔔 Нужно ⚙️Настроить хотя бы одно стоп-слово",
    'en': "🔔 You need to ⚙️Set up at least one safe word",
    'es': "🔔 Debes ⚙️Configurar al menos una palabra de seguridad",
    'fr': "🔔 Vous devez ⚙️Configurer au moins un mot de sécurité",
    'zh': "🔔 您需要⚙️设置至少一个安全词",
    'ar': "🔔 عليك ⚙️إعداد كلمة آمنة واحدة على الأقل",
}
l_cstopchange_caption = {
    'ru': "🧾 <b>Текущее</b> количество стоп-слов в {0}-файле: <u>{1}</u>\n\n<b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> стоп-слова",
    'en': "🧾 <b>Current</b> number of stop words in the {0} file: <u>{1}</u>\n\n<b>Press</b> on ✅/🚫 to <b >Add/Remove</b>stop words",
    'es': "🧾 Número <b>actual</b> de palabras vacías en el archivo {0}: <u>{1}</u>\n\n<b>Presione</b> ✅/🚫 para <b > Agregar o quitar</b>palabras vacías",
    'fr': "🧾 Nombre <b>actuel</b> de mots vides dans le fichier {0} : <u>{1}</u>\n\n<b>Appuyez</b> sur ✅/🚫 pour <b > Ajouter/Supprimer</b>des mots vides",
    'zh': "🧾 {0} 文件中<b>当前</b> 个停用词数量：<u>{1}</u>\n\n<b>按 ✅/🚫 上的</b> 到 <b >添加/删除</b>停用词",
    'ar': "🧾 <b>العدد</b> الحالي لكلمات التوقف في الملف {0}: <u>{1}</u>\n\n<b>اضغط</b> على ✅/🚫 إلى <b > إضافة/إزالة</b>كلمات التوقف",
}
l_cstopchange_text = {
    'ru': "🧾 <b>Текущее</b> количество стоп-слов <u>{0}</u>\n\n<blockquote><b>Жми</b> на ✅/🚫, чтобы <b>Добавить/Удалить</b> стоп-слова</blockquote>",
    'en': "🧾 <b>Current</b> number of stop words <u>{0}</u>\n\n<b>Press</b> on ✅/🚫 to <b>Add/Remove</b >safe words",
    'es': "🧾 Número <b>actual</b> de palabras vacías <u>{0}</u>\n\n<b>Presiona</b> ✅/🚫 para <b>Agregar o quitar</b > palabras seguras",
    'fr': "🧾 <b>Nombre actuel</b> de mots vides <u>{0}</u>\n\n<b>Appuyez</b> sur ✅/🚫 pour <b>Ajouter/Supprimer</b > mots sûrs",
    'zh': "🧾<b>当前</b>停用词数量<u>{0}</u>\n\n<b>按 ✅/🚫 上的</b><b>添加/删除</b>安全词",
    'ar': "🧾 <b>العدد</b> الحالي لكلمات التوقف <u>{0}</u>\n\n<b>اضغط</b> على ✅/🚫 من أجل <b>إضافة/إزالة</b > كلمات آمنة",
}
l_cstopchange_add = {
    'ru': "\n\n▪️регистр не важен\n▪️* в конце слова учитывает вхождение",
    'en': "\n\n▪️case is not important\n▪️* at the end of a word takes into account the occurrence",
    'es': "\n\n▪️el caso no es importante\n▪️* al final de una palabra tiene en cuenta la aparición",
    'fr': "\n\nnounced️la casse n'a pas d'importance\nnoyer* à la fin d'un mot prend en compte l'occurrence",
    'zh': "\n\n▪️大小写并不重要\n▪️* 考虑到单词末尾的出现情况",
    'ar': "\n\n▪️حالة الأحرف ليست مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار حدوثها",
}
l_cstopchange_answer = {
    'ru': "✅ <b>Введи</b> <u>стоп-слова</u> <b>через</b> пробелы или разделители, чтобы <i>добавить</i> их в базу{0}",
    'en': "✅ <b>Enter</b> <u>stop words</u> <b>through</b> spaces or separators to <i>add</i> them to the database{0}",
    'es': "✅ <b>Ingrese</b> <u>palabras vacías</u> <b>mediante</b> espacios o separadores para <i>agregarlas</i> a la base de datos{0}",
    'fr': "✅ <b>Saisissez</b> <u>mots vides</u> <b>à travers</b> des espaces ou des séparateurs pour <i>ajouter</i> à la base de données{0}",
    'zh': "✅ <b>输入</b> <u>停用词</u> <b>通过</b>空格或分隔符将其<i>添加</i>到数据库中{0}",
    'ar': "✅ <b>أدخل</b> <u>كلمات التوقف</u> <b>من خلال</b> مسافات أو فواصل <i>لإضافتها</i> إلى قاعدة البيانات{0}",
}
l_cstopchange_noanswer = {
    'ru': "🚫 <b>Введи</b> <u>стоп-слова</u> <b>через</b> пробелы или разделители, чтобы их <i>удалить</i> из базы{0}",
    'en': "🚫 <b>Enter</b> <u>stop words</u> <b>separated</b> by spaces or separators to <i>remove</i> them from the database{0}",
    'es': "🚫 <b>Ingrese</b> <u>palabras vacías</u> <b>separadas</b> por espacios o separadores para <i>eliminarlas</i> de la base de datos{0}",
    'fr': "🚫 <b>Saisissez</b> <u>mots vides</u> <b>séparés</b> par des espaces ou des séparateurs pour <i>supprimer</i> de la base de données{0}",
    'zh': "🚫 <b>输入</b> <u>停用词</u> <b>用空格或分隔符分隔</b>，以<i>将其从数据库中删除</i>{0}",
    'ar': "🚫 <b>أدخل</b> <u>كلمات التوقف</u> <b>مفصولة</b> بمسافات أو فواصل <i>لإزالتها</i> من قاعدة البيانات{0}",
}
l_fsm_stop_add_caption = {
    'ru': "🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов в {0}-файле: <u>{1}</u>",
    'en': "🧾 <b>Done!</b> <b>Current</b> number of stop words in the {0} file: <u>{1}</u>",
    'es': "🧾 <b>¡Listo!</b> Número <b>actual</b> de palabras vacías en el archivo {0}: <u>{1}</u>",
    'fr': "🧾 <b>Terminé !</b> <b>Nombre actuel</b> de mots vides dans le fichier {0} : <u>{1}</u>",
    'zh': "🧾 <b>完成！</b> {0} 文件中<b>当前</b> 个停用词数量：<u>{1}</u>",
    'ar': "🧾 <b>تم!</b> <b>العدد الحالي</b> لكلمات التوقف في الملف {0}: <u>{1}</u>",
}
l_fsm_stop_add_text = {
    'ru': "🧾 <b>Готово!</b> <b>Текущее</b> количество стоп-слов <u>{0}</u>",
    'en': "🧾 <b>Done!</b> <b>Current</b> number of stop words <u>{0}</u>",
    'es': "🧾 <b>¡Listo!</b> Número <b>actual</b> de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Terminé !</b> <b>Nombre actuel</b> de mots vides <u>{0}</u>",
    'zh': "🧾<b>完成！</b><b>当前</b>停用词数量<u>{0}</u>",
    'ar': "🧾 <b>تم!</b> <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
# endregion


# region cflood_
l_cflood_text = {
    'ru': "💬 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <i>проверку</i> на частоту подряд написанных сообщ за один промежуток времени\n\n<blockquote>👩🏽‍💻 Например, задай количество сообщ подряд, которое будет считаться флудом командой: <code>/flood 5</code>\n\n👩🏽‍💻 Или используй <b>медленный режим</b> в настройках группы для <u>1</u> сообщения</blockquote>",
    'en': "💬 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>check</i> for the frequency of consecutive messages written in one period of time\n\n👩🏽‍💻 For example, set the number of messages in a row that will be considered a flood with the command: <code>/flood 5</code>\n\n👩🏽‍💻 Or use <b>slow mode</b> in the group settings for <u>1 </u>messages",
    'es': "💬 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>verificar</i> la frecuencia de mensajes consecutivos escritos en un período de tiempo\n\n👩🏽 ‍💻 Por ejemplo, establezca el número de mensajes seguidos que se considerarán una inundación con el comando: <code>/flood 5</code>\n\n👩🏽‍💻 O use el <b>modo lento</ b> en la configuración del grupo para <u>1 </u>mensajes",
    'fr': "💬 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <i>vérifier</i> la fréquence des messages consécutifs écrits au cours d'une période de temps\n\n👩🏽 ‍💻 Par exemple, définissez le nombre de messages consécutifs qui seront considérés comme une inondation avec la commande : <code>/flood 5</code>\n\n👩🏽‍💻 Ou utilisez le <b>mode lent</ b> dans les paramètres du groupe pour <u>1 </u>messages",
    'zh': "💬<b>按</b>✅/☑️<b>开/关</b><i>检查</i>一段时间内写入连续消息的频率\n\n👩🏽 ‍💻 例如，使用以下命令设置将被视为洪水的一行消息数：<code>/flood 5</code>\n\n👩🏽‍💻 或使用<b>慢速模式</ b> 在 <u>1 </u> 条消息的组设置中",
    'ar': "💬 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>حدد</i> تكرار الرسائل المتتالية المكتوبة في فترة زمنية واحدة\n\n👩🏽 ‍💻 على سبيل المثال، قم بتعيين عدد الرسائل في الصف الذي سيتم اعتباره فيضانًا باستخدام الأمر: <code>/flood 5</code>\n\n👩🏽‍💻 أو استخدم <b>الوضع البطيء</b> ب> في إعدادات المجموعة لرسائل <u>1 </u>",
}
l_cflood_count_on = {
    'ru': "✅☑Вкл {0} сообщ",
    'en': "✅☑On {0} message",
    'es': "✅☑En {0} mensaje",
    'fr': "✅☑Sur {0} message",
    'zh': "✅☑在 {0} 条消息中",
    'ar': "✅☑في رسالة {0}.",
}
l_cflood_count_off = {
    'ru': "☑️☐Выкл {0} сообщ",
    'en': "☑️☐Off {0} message",
    'es': "☑️☐Desactivado {0} mensaje",
    'fr': "☑️☐Désactivé le message {0}",
    'zh': "☑️ 已关闭 {0} 条消息",
    'ar': "☑️☐إيقاف تشغيل رسالة {0}.",
}
# endregion


# region cdialog_
l_cdialog_text = {
    'ru': "💬 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> #нейро-диалог на основе постов/описания/контента группы, возможные #нейро-ответы:\n<blockquote>текст/аудио/стикер</blockquote>\n\n👩🏽‍💻 <b>Частота</b> #нейро-диалога без подписки не более раза в час",
    'en': "💬 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <i>check</i> for the frequency of consecutive messages written in one period of time\n\n👩🏽‍💻 For example, set the number of messages in a row that will be considered a flood with the command: <code>/flood 5</code>\n\n👩🏽‍💻 Or use <b>slow mode</b> in the group settings for <u>1 </u>messages",
    'es': "💬 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>verificar</i> la frecuencia de mensajes consecutivos escritos en un período de tiempo\n\n👩🏽 ‍💻 Por ejemplo, establezca el número de mensajes seguidos que se considerarán una inundación con el comando: <code>/flood 5</code>\n\n👩🏽‍💻 O use el <b>modo lento</ b> en la configuración del grupo para <u>1 </u>mensajes",
    'fr': "💬 <b>Appuyez</b> sur ✅/☑️ pour <b>On/Off</b> <i>vérifier</i> la fréquence des messages consécutifs écrits au cours d'une période de temps\n\n👩🏽 ‍💻 Par exemple, définissez le nombre de messages consécutifs qui seront considérés comme une inondation avec la commande : <code>/flood 5</code>\n\n👩🏽‍💻 Ou utilisez le <b>mode lent</ b> dans les paramètres du groupe pour <u>1 </u>messages",
    'zh': "💬<b>按</b>✅/☑️<b>开/关</b><i>检查</i>一段时间内写入连续消息的频率\n\n👩🏽 ‍💻 例如，使用以下命令设置将被视为洪水的一行消息数：<code>/flood 5</code>\n\n👩🏽‍💻 或使用<b>慢速模式</ b> 在 <u>1 </u> 条消息的组设置中",
    'ar': "💬 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>حدد</i> تكرار الرسائل المتتالية المكتوبة في فترة زمنية واحدة\n\n👩🏽 ‍💻 على سبيل المثال، قم بتعيين عدد الرسائل في الصف الذي سيتم اعتباره فيضانًا باستخدام الأمر: <code>/flood 5</code>\n\n👩🏽‍💻 أو استخدم <b>الوضع البطيء</b> ب> في إعدادات المجموعة لرسائل <u>1 </u>",
}
l_cdialog_text_on = {
    'ru': "✅☑Вкл текст",
    'en': "✅☑On for channel",
    'es': "✅☑Activado para el canal",
    'fr': "✅☑Activé pour la chaîne",
    'zh': "✅☑开启频道",
    'ar': "✅☑مفعل للقناة",
}
l_cdialog_text_off = {
    'ru': "☑️☐Выкл текст",
    'en': "☑️☐Off for channel",
    'es': "☑️☐Fuera del canal",
    'fr': "☑️☐Désactivé pour la chaîne",
    'zh': "☑️️频道关闭",
    'ar': "☑️☐مغلق للقناة",
}
l_cdialog_audio_on = {
    'ru': "✅☑Вкл аудио",
    'en': "✅☑On for user",
    'es': "✅☑Activado para usuario",
    'fr': "✅☑Activé pour l'utilisateur",
    'zh': "✅☑为用户开启",
    'ar': "✅☑ قيد التشغيل للمستخدم",
}
l_cdialog_audio_off = {
    'ru': "☑️☐Выкл аудио",
    'en': "☑️☐Off for user",
    'es': "☑️☐Desactivado para usuario",
    'fr': "☑️☐Désactivé pour l'utilisateur",
    'zh': "☑️️用户关闭",
    'ar': "☑️☐إيقاف للمستخدم",
}
l_cdialog_sticker_on = {
    'ru': "✅☑Вкл стикер",
    'en': "✅☑On for user",
    'es': "✅☑Activado para usuario",
    'fr': "✅☑Activé pour l'utilisateur",
    'zh': "✅☑为用户开启",
    'ar': "✅☑ قيد التشغيل للمستخدم",
}
l_cdialog_sticker_off = {
    'ru': "☑️☐Выкл стикер",
    'en': "☑️☐Off for user",
    'es': "☑️☐Desactivado para usuario",
    'fr': "☑️☐Désactivé pour l'utilisateur",
    'zh': "☑️️用户关闭",
    'ar': "☑️☐إيقاف للمستخدم",
}
# endregion


# region cuser_
l_cuser_text = {
    'ru': "👥 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> первичную <i>задержку/свободный вход без входного контроля для premium-аккаунтов/разрешение на инвайт</i> пользователей/ботов в группу или разрешение на <i>редактирование</i> сообщений\n\n<blockquote>[✅ <b>Вкл задержку {0}мин</b>] для <u>новых</u> пользователей (перед написанием их <u>1</u>го сообщ) осуществляется командой: <code>/delay  {0}</code></blockquote>",
    'en': "👥 <b>Press</b> on ✅/☑️ to <b>On/Off</b> primary <i>delay/free entry without entry control for premium accounts/permission to invite</i> users/ bots to a group or permission to <i>edit</i> messages\n\n👩🏽‍💻 For example, <b>delay</b> (<i>min</i>) for <u>new< /u> users (before writing their <u>1st</u>message) is carried out with the command: <code>/delay {0}</code>",
    'es': "👥 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <i>retraso primario/entrada gratuita sin control de entrada para cuentas premium/permiso para invitar</i> usuarios/bots a un grupo o permiso para <i>editar</i> mensajes\n\n👩🏽‍💻 Por ejemplo, <b>retraso</b> (<i>min</i>) para <u>nuevo</i> / u> usuarios (antes de escribir su <u>1er</u>mensaje) se realiza con el comando: <code>/delay {0}</code>",
    'fr': "👥 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> le <i>délai/entrée gratuite sans contrôle d'entrée pour les comptes premium/autorisation d'inviter</i> des utilisateurs/bots à un groupe ou une autorisation pour <i>modifier</i> les messages\n\n👩🏽‍💻 Par exemple, <b>délai</b> (<i>min</i>) pour <u>nouveau< / u> utilisateurs (avant d'écrire leur <u>1er</u>message) s'effectue avec la commande : <code>/delay {0}</code>",
    'zh': "👥<b>按</b>✅/☑️<b>开/关</b>主要<i>延迟/免费进入，无需高级帐户的进入控制/邀请用户/机器人的权限</i> <i>编辑</i>条消息的群组或权限\n\n👩🏽‍💻例如，<b>延迟</b>（<i>分钟</i>）<u>新消息</ u> 用户（在编写他们的<u>第一条</u>消息之前）使用以下命令执行：<code>/delay {0}</code>",
    'ar': "👥 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <i>تأخير/دخول مجاني بدون التحكم في الدخول للحسابات المميزة/إذن لدعوة</i> المستخدمين/الروبوتات إلى مجموعة أو إذن <i>لتحرير</i> الرسائل\n\n👩🏽‍💻 على سبيل المثال، <b>تأخير</b> (<i>دقيقة</i>) لـ <u>الجديد< / u> المستخدمين (قبل كتابة رسالتهم <u>الأولى</u>) يتم تنفيذها باستخدام الأمر: <code>/delay {0}</code>",
}
l_cuser_call = {
    'ru': "👮🏽 В настройках [Разрешения] включи опцию:\n\n[✅ Добавление участ]\n\n🕚Подожди 1 мин",
    'en': "👮🏽 In the [Permissions] settings, enable the option:\n\n[✅ Adding a participant]\n\n🕚Wait 1min",
    'es': "👮🏽 En la configuración de [Permisos], habilita la opción:\n\n[✅ Agregar un participante]\n\n🕚Espera 1 minuto",
    'fr': "👮🏽 Dans les paramètres [Autorisations], activez l'option :\n\n[✅ Ajout d'un participant]\n\n🕚Attendez 1min",
    'zh': "👮🏽 在【权限】设置中，启用选项：\n\n[✅ 添加参与者]\n\n🕚等待 1 分钟",
    'ar': "👮🏽 في إعدادات [الأذونات]، قم بتمكين الخيار:\n\n[✅ إضافة مشارك]\n\n🕚انتظر دقيقة واحدة",
}
l_cuser_delay_on = {
    'ru': "✅☑Вкл задержку {0} мин",
    'en': "✅☑Enable delay {0}min",
    'es': "✅☑Habilitar retraso {0}min",
    'fr': "✅☑Activer le délai de {0} min",
    'zh': "✅☑启用延迟 {0} 分钟",
    'ar': "✅☑تمكين التأخير لمدة {0}دقيقة",
}
l_cuser_delay_off = {
    'ru': "☑️☐Выкл задержку {0}min",
    'en': "☑️☐Disable delay {0}min",
    'es': "☑️☐Desactivar retraso {0}min",
    'fr': "☑️☐Désactiver le délai de {0} min",
    'zh': "☑️☐禁用延迟 {0} 分钟",
    'ar': "☑️☐تعطيل التأخير لمدة {0}دقيقة",
}
l_cuser_invite_user_on = {
    'ru': "✅☑Вкл инвайт польз.",
    'en': "✅☑On invite users.",
    'es': "✅☑Al invitar usuarios.",
    'fr': "✅☑Sur invitation d'utilisateurs.",
    'zh': "✅☑邀请用户。",
    'ar': "✅☑عند دعوة المستخدمين.",
}
l_cuser_invite_user_off = {
    'ru': "☑️☐Выкл инвайт польз.",
    'en': "☑️☐Disable user invite.",
    'es': "☑️☐Desactivar invitación de usuario.",
    'fr': "☑️☐Désactivez l'invitation d'utilisateur.",
    'zh': "☑️️禁用用户邀请。",
    'ar': "☑️☐تعطيل دعوة المستخدم.",
}

l_cuser_invite_bot_on = {
    'ru': "✅☑Вкл инвайт ботов",
    'en': "✅☑Enable invite bots",
    'es': "✅☑Habilitar bots de invitación",
    'fr': "✅☑Activer les robots d'invitation",
    'zh': "✅☑启用邀请机器人",
    'ar': "✅☑تمكين دعوة الروبوتات",
}
l_cuser_invite_bot_off = {
    'ru': "☑️☐Выкл инвайт ботов",
    'en': "☑️☐Disable invite bots",
    'es': "☑️☐Desactivar los robots de invitación",
    'fr': "☑️☐Désactiver les robots d'invitation",
    'zh': "☑️️禁用邀请机器人",
    'ar': "☑️☐تعطيل روبوتات الدعوة",
}
l_cuser_premium_on = {
    'ru': "✅☑Вкл premium-вход",
    'en': "✅☑Includes premium entry",
    'es': "✅☑Incluye entrada premium",
    'fr': "✅☑Comprend une entrée premium",
    'zh': "✅☑包括高级门票",
    'ar': "✅☑يتضمن دخول مميز",
}
l_cuser_premium_off = {
    'ru': "☑️☐Выкл premium-вход",
    'en': "☑️☐Off premium-login",
    'es': "☑️☐Desactivado inicio de sesión premium",
    'fr': "☑️☐Hors connexion premium",
    'zh': "☑️️关闭高级登录",
    'ar': "☑️☐ خارج تسجيل الدخول المتميز",
}
l_cuser_edit_on = {
    'ru': "✅☑Вкл редактирование сообщ",
    'en': "✅☑On message editing",
    'es': "✅☑Sobre la edición de mensajes",
    'fr': "✅☑Sur l'édition des messages",
    'zh': "✅☑关于消息编辑",
    'ar': "✅☑في تحرير الرسائل",
}
l_cuser_edit_off = {
    'ru': "☑️☐Выкл редактирование сообщ",
    'en': "☑️☐Turn off message editing",
    'es': "☑️☐Desactivar la edición de mensajes",
    'fr': "☑️☐Désactivez l'édition des messages",
    'zh': "☑️️关闭消息编辑",
    'ar': "☑️☐ قم بإيقاف تشغيل تحرير الرسائل",
}
# endregion


# region cadmin_
l_cadmin_text = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> <u>admin-доступ</u> (только к /cmd-командам для <i>других</i> администраторов) и <u>god-режим</u> (без ограничений для администраторов)\n\n<blockquote>👩🏽‍💻 <b>Текущие администраторы</b>:\n{0}</blockquote>",
    'en': "👩🏽‍💻 <b>Press</b> on ✅/☑️ to <b>On/Off</b> <u>admin access</u> (only to / cmd commands for <i>others </i> administrators) and <u>god-mode</u> (no restrictions for administrators)\n\n👩🏽‍💻 <b>Current administrators</b>:\n{0}",
    'es': "👩🏽‍💻 <b>Presione</b> en ✅/☑️ para <b>Activar/Desactivar</b> <u>acceso de administrador</u> (solo para comandos / cmd para <i>otros </i > administradores) y <u>modo dios</u> (sin restricciones para administradores)\n\n👩🏽‍💻 <b>Administradores actuales</b>:\n{0}",
    'fr': "👩🏽‍💻 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> <u>l'accès administrateur</u> (uniquement aux commandes / cmd pour <i>les autres </i > administrateurs) et <u>mode divin</u> (aucune restriction pour les administrateurs)\n\n👩🏽‍💻 <b>Administrateurs actuels</b> :\n{0}",
    'zh': "👩🏽‍💻<b>按</b> ✅/☑️<b>开/关</b><u>管理员访问</u>（仅限<i>其他</i的/ cmd命令） > 管理员）和<u>上帝模式</u>（对管理员没有限制）\n\n👩🏽‍💻<b>当前管理员</b>：\n{0}",
    'ar': "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> <u>وصول المسؤول</u> (فقط لأوامر / cmd <i>للآخرين </i > المسؤولين) و<u>وضع الله</u> (لا توجد قيود على المسؤولين)\n\n👩🏽‍💻 <b>المسؤولين الحاليين</b>:\n{0}",
}
l_cadmin_admin_on = {
    'ru': "✅☑Вкл admin-доступ",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_cadmin_admin_off = {
    'ru': "☑️☐Выкл admin-доступ",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cadmin_god_on = {
    'ru': "✅☑Вкл god-режим",
    'en': "✅☑Inc year-mode",
    'es': "✅☑Inc modo año",
    'fr': "✅☑Inc mode année",
    'zh': "✅☑Inc 年模式",
    'ar': "✅☑Inc وضع العام",
}
l_cadmin_god_off = {
    'ru': "☑️☐Выкл god-режим",
    'en': "☑️☐Vykl god-mode",
    'es': "☑️☐Vykl modo dios",
    'fr': "☑️☐Vykl mode divin",
    'zh': "☑️☐Vykl 上帝模式",
    'ar': "☑️☐Vykl god-mode",
}
# endregion


# region cpay
l_cpay_text = {
    'ru': "🪙 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> удаление пользователя из {0} при невыполнении условий подписки",
    'en': "🧾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-delete messages containing prohibited stop words\n\n👩🏽‍💻 <b>Current</b > number of stop words <u>{0}</u>",
    'es': "🧾 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👩🏽‍💻 Número <b>Actual</b > de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👩🏽‍💻 <b>Actuel</b > nombre de mots vides <u>{0}</u>",
    'zh': "🧾 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动删除包含禁止停用词的消息\n\n👩🏽‍💻 <b>当前</b > 条数停用词<u>{0}</u>",
    'ar': "🧾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الحذف التلقائي للرسائل التي تحتوي على كلمات توقف محظورة\n\n👩🏽‍💻 <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
l_cpay_config = {
    'ru': "⭐️ <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> контроль подписки на {0}: проверка наличия жетонов/NFT\n\n<blockquote>👩🏽‍💻 <b>Текущая</b> стоимость подписки: {1}\n<a href='https://t.me/FereyGroupBot/web?startapp={2}_upay'>⭐️ Ссылка на подписку</a>\n<a href='https://t.me/FereyGroupBot/web?startapp={2}_donations'>🪙 Ссылка на донаты</a></blockquote>",
    'en': "🧾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-delete messages containing prohibited stop words\n\n👩🏽‍💻 <b>Current</b > number of stop words <u>{0}</u>",
    'es': "🧾 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👩🏽‍💻 Número <b>Actual</b > de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👩🏽‍💻 <b>Actuel</b > nombre de mots vides <u>{0}</u>",
    'zh': "🧾 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动删除包含禁止停用词的消息\n\n👩🏽‍💻 <b>当前</b > 条数停用词<u>{0}</u>",
    'ar': "🧾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الحذف التلقائي للرسائل التي تحتوي على كلمات توقف محظورة\n\n👩🏽‍💻 <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
l_cpay_webapp = {
    'ru': "⭐️ Настроить стоимость",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_cpay_period_on = {
    'ru': "✅ Вкл проверка подписки",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_cpay_period_off = {
    'ru': "☑️ Выкл проверка подписки",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_nft_on = {
    'ru': "✅ Вкл проверка жетоны/NFT",
    'en': "✅ On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_cpay_nft_off = {
    'ru': "☑️ Выкл проверка жетоны/NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}

l_cpay_need_type_subscribe = {
    'ru': "👩🏽‍💻 Жми ⚙️Настроить, чтобы выбрать тип подписки",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_need_cost_subscribe = {
    'ru': "👩🏽‍💻 Жми ⭐️Настроить стоимость, чтобы задать стоимость подписки",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_need_address_col = {
    'ru': "👩🏽‍💻 Жми ⭐️Настроить стоимость, чтобы ввести адрес коллекции NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_subscription = {
    'ru': "Подписка ⭐️:",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_sub = {
    'ru': "Подписка",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_pay = {
    'ru': "Оплатить",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_in_once = {
    'ru': "разово",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_in_week = {
    'ru': "в неделю",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_in_month = {
    'ru': "в месяц",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_in_year = {
    'ru': "в год",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_address_wallet_text = {
    'ru': "Адрес кошелька {0}:*",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_address_wallet_part = {
    'ru': "Адрес кошелька",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_address_wallet_placeholder = {
    'ru': "для другой валюты",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_address_collection_text = {
    'ru': "Адрес коллекции NFT:*",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_address_collection_placeholder = {
    'ru': "для проверки NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_optional_fields = {
    'ru': "*не обязательные поля",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_save = {
    'ru': "Сохранить",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_need_wallet = {
    'ru': "👩🏽‍💻 Необходимо подключить TON-кошелек",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_txt_need_wallet_address = {
    'ru': "👩🏽‍💻 При указании других валют необходимо заполнить адрес кошелька монет",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_second_chk = {
    'ru': "Проверка наличия:",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_subscribe_chk = {
    'ru': "Проверка:*",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_address_wallet_lbl = {
    'ru': "Адрес мастера жетонов:*",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_address_wallet_placeholder = {
    'ru': "для проверки жетонов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_address_collection_lbl = {
    'ru': "Адрес NFT коллекции:*",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_address_collection_placeholder = {
    'ru': "для проверки NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_donate_lbl = {
    'ru': "Ссылка на веб3-донаты:",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_donate_lnk = {
    'ru': "жми [💎 Подключить кошелек] для получения донатов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_need_price = {
    'ru': "👩🏽‍💻 Необходимо указать стоимость подписки в ⭐️",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_need_token = {
    'ru': "👩🏽‍💻 Необходим токен бота, владельцу которого будут идти выплаты в ⭐️",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_bot_token_placeholder = {
    'ru': "токен бота из @BotFather",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}

l_upay_txt_checking_ft = {
    'ru': "Проверка жетонов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_send = {
    'ru': "Отправить",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_ft_link_no = {
    'ru': "нет активной подписки",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_ft_link_yes_once = {
    'ru': "подписка активна",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_ft_link_yes = {
    'ru': "подписка активна до {0}",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_checking_nft = {
    'ru': "Проверка наличия NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_get_nft = {
    'ru': "Приобрести NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_check_nft = {
    'ru': "Проверить наличие NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_hint_address_nft = {
    'ru': "адрес полученного NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_nft_link_no = {
    'ru': "нет необходимого NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_nft_link_yes = {
    'ru': "NFT уже получен",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_txt_open_group = {
    'ru': "Открыть группу",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_button = {
    'ru': "⭐️ Оплата подписки",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_need_stars = {
    'ru': "👩🏽‍💻 Неоходимо оплатить подписку",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_need_ft = {
    'ru': "👩🏽‍💻 Неоходимо отправить жетоны",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_need_nft = {
    'ru': "👩🏽‍💻 Неоходимо приобрести NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_upay_nft_address_incorrect = {
    'ru': "👩🏽‍💻 Адрес или владелец не корректен",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_cpay_null_amount = {
    'ru': "👩🏽‍💻 Необходимо указать стоимость",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
# endregion


# region ccomment
l_ccomment_text = {
    'ru': "🪙 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> оплату кѻмментов в {0}",
    'en': "🧾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-delete messages containing prohibited stop words\n\n👩🏽‍💻 <b>Current</b > number of stop words <u>{0}</u>",
    'es': "🧾 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👩🏽‍💻 Número <b>Actual</b > de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👩🏽‍💻 <b>Actuel</b > nombre de mots vides <u>{0}</u>",
    'zh': "🧾 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动删除包含禁止停用词的消息\n\n👩🏽‍💻 <b>当前</b > 条数停用词<u>{0}</u>",
    'ar': "🧾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الحذف التلقائي للرسائل التي تحتوي على كلمات توقف محظورة\n\n👩🏽‍💻 <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
l_ccomment_config = {
    'ru': "🪙 <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> бесплатный доступ в {0} к кѻмментам для премиум-пользователей/<b>пользователей</b>, оформивших <a href='https://t.me/FereyGroupBot/web?startapp={3}_upay'>подписку</a>\n\n<blockquote>👩🏽‍💻 <b>Текущая</b> стоимость кѻммента: {1}\n👩🏽‍💻 <b>Текущий</b> адрес коллекции NFT: {2}</blockquote>\n\n<blockquote><a href='https://t.me/FereyGroupBot/web?startapp={3}_ucomment'>⭐️ Ссылка на плату</a>\n<a href='https://t.me/FereyGroupBot/web?startapp={3}_donations'>💎 Ссылка на донаты</a></blockquote>",
    'en': "🧾 <b>Press</b> on ✅/☑️ to <b>On/Off</b> auto-delete messages containing prohibited stop words\n\n👩🏽‍💻 <b>Current</b > number of stop words <u>{0}</u>",
    'es': "🧾 <b>Presiona</b> en ✅/☑️ para <b>Activar/Desactivar</b> la eliminación automática de mensajes que contengan palabras vacías prohibidas\n\n👩🏽‍💻 Número <b>Actual</b > de palabras vacías <u>{0}</u>",
    'fr': "🧾 <b>Appuyez</b> sur ✅/☑️ pour <b>Activer/Désactiver</b> la suppression automatique des messages contenant des mots vides interdits\n\n👩🏽‍💻 <b>Actuel</b > nombre de mots vides <u>{0}</u>",
    'zh': "🧾 <b>按</b> ✅/☑️ <b>开启/关闭</b>自动删除包含禁止停用词的消息\n\n👩🏽‍💻 <b>当前</b > 条数停用词<u>{0}</u>",
    'ar': "🧾 <b>اضغط</b> على ✅/☑️ من أجل <b>تشغيل/إيقاف</b> الحذف التلقائي للرسائل التي تحتوي على كلمات توقف محظورة\n\n👩🏽‍💻 <b>العدد الحالي</b> من كلمات التوقف <u>{0}</u>",
}
l_ccomment_need_type_subscribe = {
    'ru': "👩🏽‍💻 Жми ⚙️Настроить, чтобы задать стоимость кѻммента",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}

l_ccomment_access_on = {
    'ru': "✅ Вкл премиум доступ",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_ccomment_access_off = {
    'ru': "☑️ Выкл премиум доступ",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_subscribe_on = {
    'ru': "✅ Вкл доступ по ⭐️Подписке",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_ccomment_subscribe_off = {
    'ru': "☑️ Выкл доступ по ⭐️Подписке",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}

l_ccomment_webapp = {
    'ru': "🪙 Настроить стоимость",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_ccomment_need_address_col = {
    'ru': "👩🏽‍💻 Жми 🪙Настроить стоимость, чтобы ввести адрес коллекции NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_need_cost_subscribe = {
    'ru': "👩🏽‍💻 Жми 🪙Настроить стоимость, чтобы задать стоимость кѻммента",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_cost = {
    'ru': "Cтоимость:",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_ccomment_per_comment = {
    'ru': "за кѻммент",
    'en': "✅☑On admin access",
    'es': "✅☑En acceso de administrador",
    'fr': "✅☑Sur l'accès administrateur",
    'zh': "✅☑管理员访问权限",
    'ar': "✅☑عند وصول المسؤول",
}
l_ccomment_get = {
    'ru': "Приобрести:",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_got = {
    'ru': "Доступно",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}

l_ucomment_txt_ft_link_no = {
    'ru': "нет доступных кѻмментов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ucomment_txt_ft_link_yes = {
    'ru': "Доступно: {0} кѻмментов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ucomment_txt_nft_link_no = {
    'ru': "нет необходимого NFT",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ucomment_txt_nft_link_yes = {
    'ru': "NFT уже получен",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_comment = {
    'ru': "ко́ммента",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ucomment_comments = {
    'ru': "кѻмментов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ucomment_need_ft = {
    'ru': "👩🏽‍💻 Неоходимо оплатить хотя бы один кѻммент",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_do_comment = {
    'ru': "Написать кѻммент",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
l_ccomment_button = {
    'ru': "🪙 Оплата кѻмментов",
    'en': "☑️☐Off admin access",
    'es': "☑️☐Fuera del acceso de administrador",
    'fr': "☑️☐Hors accès administrateur",
    'zh': "☑️️关闭管理员访问权限",
    'ar': "☑️☐إيقاف وصول المشرف",
}
# endregion


# region handlers
l_content_types_invite_user_bot = {
    'ru': "🚶🏽 <b>Приглашение</b> @username/@name_bot не разрешено",
    'en': "🚶🏽 <b>Invite</b> @username / @name_bot not allowed",
    'es': "🚶🏽 <b>Invitar</b> @username / @name_bot no permitido",
    'fr': "🚶🏽 <b>Inviter</b> @username / @name_bot non autorisé",
    'zh': "🚶🏽 <b>邀请</b> @username / @name_bot不允许",
    'ar': "🚶🏽 <b>دعوة</b> @username / @name_bot غير مسموح بها",
}
l_content_types_invite_user = {
    'ru': "🚶🏽 <b>Приглашение</b> @username не разрешено",
    'en': "🚶🏽 <b>Invite</b> @username not allowed",
    'es': "🚶🏽 <b>Invitar</b> @username no permitido",
    'fr': "🚶🏽 <b>Inviter</b> @username non autorisé",
    'zh': "🚶🏽 <b>邀请</b> @username不允许",
    'ar': "🚶🏽 <b>الدعوة</b> @username غير مسموح به",
}
l_content_types_invite_bot = {
    'ru': "🚶🏽 <b>Приглашение</b> @name_bot не разрешено",
    'en': "🚶🏽 <b>Invitation</b> @name_bot is not allowed",
    'es': "🚶🏽 <b>Invitación</b> @name_bot no está permitida",
    'fr': "🚶🏽 <b>Invitation</b> @name_bot n'est pas autorisé",
    'zh': "🚶🏽 不允许<b>邀请</b> @name_bot",
    'ar': "🚶🏽 <b>الدعوة</b> @name_bot غير مسموح بها",
}
l_content_types_button = {
    'ru': "👮🏽 {0}, <b>жми</b> на кнопку, чтобы вс︎тупить в группу",
    'en': "👮🏽 {0}, <b>click</b> the button to join the group",
    'es': "👮🏽 {0}, <b>haz clic</b> en el botón para unirte al grupo",
    'fr': "👮🏽 {0}, <b>cliquez</b> sur le bouton pour rejoindre le groupe",
    'zh': "👮🏽 {0}，<b>点击</b>按钮加入群组",
    'ar': "👮🏽 {0}, <b>انقر</b> على الزر للانضمام إلى المجموعة",
}
l_content_types_captcha = {
    'ru': "👮🏽 {0}, выбери <i>правильный вариант</i> ответа, чтобы вс︎тупить в группу:\n\n{1}",
    'en': "👮🏽 {0}, choose the <i>correct</i> answer to join the group:\n\n{1}",
    'es': "👮🏽 {0}, elige la respuesta <i>correcta</i> para unirte al grupo:\n\n{1}",
    'fr': "👮🏽 {0}, choisissez la réponse <i>bonne</i> pour rejoindre le groupe :\n\n{1}",
    'zh': "👮🏽 {0}，选择<i>正确</i>答案加入群组：\n\n{1}",
    'ar': "👮🏽 {0}، اختر الإجابة <i>الصحيحة</i> للانضمام إلى المجموعة:\n\n{1}",
}
l_hand_msg_FLOOD_USERNAME = {
    'ru': "💬 <b>Пользователь</b> @{0} изменил <b>name/@username</b>! Возможно, шпион!",
    'en': "💬 <b>User</b> @{0} changed <b>name/ @username </b>! Possibly a spy!",
    'es': "💬 ¡El <b>Usuario</b> @{0} cambió <b>nombre/ @username </b>! ¡Posiblemente un espía!",
    'fr': "💬 <b>Utilisateur</b> @{0} a changé <b>nom/ @username </b> ! Peut-être un espion !",
    'zh': "💬<b>用户</b>@{0}更改了<b>名称/ @username </b>！可能是间谍！",
    'ar': "💬 قام <b>المستخدم</b> @{0} بتغيير <b>الاسم/ @username </b>! ربما جاسوس!",
}
l_hand_msg_flood = {
    'ru': "💬 <i>Flood</i>-сообщения",
    'en': "💬 <i>Flood</i>-messages",
    'es': "💬 <i>Inundación</i>-mensajes",
    'fr': "💬 <i>Inondations</i>-messages",
    'zh': "💬<i>洪水</i>-消息",
    'ar': "💬<i>الفيضانات</i>-رسائل",
}
l_hand_msg_via_bot = {
    'ru': "🗣 <b>Сообщения</b> <i>от имени бота</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>on behalf of a bot</i> are not allowed",
    'es': "🗣 <b>Mensajes</b> <i>en nombre de un bot</i> no están permitidos",
    'fr': "🗣 Les <b>Messages</b> <i>de la part d'un bot</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b> <i>代表机器人</i>",
    'ar': "🗣 <b>الرسائل</b> <i>بالنيابة عن الروبوت</i> غير مسموح بها",
}
l_hand_msg_channel = {
    'ru': "🫥 <b>Сообщения</b> <i>от имени канала</i> не разрешены",
    'en': "🫥 <b>Messages</b> <i>on behalf of the channel</i> are not allowed",
    'es': "🫥 <b>Mensajes</b> <i>en nombre del canal</i> no están permitidos",
    'fr': "🫥 Les <b>Messages</b> <i>au nom de la chaîne</i> ne sont pas autorisés",
    'zh': "🫥 不允许<b>消息</b> <i>代表频道</i>",
    'ar': "🫥 <b>الرسائل</b> <i>بالنيابة عن القناة</i> غير مسموح بها",
}
l_hand_msg_emoji = {
    'ru': "🗣 <b>Сообщения</b> <i>c emoji</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with emoji</i> are not allowed",
    'es': "🗣 <b>Mensajes</b> <i>con emoji</i> no están permitidos",
    'fr': "🗣 Les <b>Messages</b> <i>avec emoji</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b> <i>带有表情符号</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على رموز تعبيرية</i> غير مسموح بها",
}
l_hand_msg_http = {
    'ru': "🔗 <b>Сообщения</b> <i>c внешними ссылками</i> не разрешены",
    'en': "🔗 <b>Messages</b> <i>with external links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces externos</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec des liens externes</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有外部链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>ذات الروابط الخارجية</i> غير مسموح بها",
}
l_hand_msg_telegram = {
    'ru': "🔗 <b>Сообщения</b> <i>c telegram-ссылками</i> не разрешены",
    'en': "🔗 <b>Messages</b> <i>with telegram links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces de Telegram</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec des liens de télégramme</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有电报链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>التي تحتوي على روابط تيليجرام</i> غير مسموح بها",
}
l_hand_msg_forward = {
    'ru': "🔗 <b>Сообщения</b> <i>c forward-ссылками</i> не разрешены",
    'en': "🔗 <b>Messages</b> <i>with forward links</i> are not allowed",
    'es': "🔗 No se permiten <b>Mensajes</b> <i>con enlaces directos</i>",
    'fr': "🔗 Les <b>Messages</b> <i>avec liens de transfert</i> ne sont pas autorisés",
    'zh': "🔗 不允许<b>消息</b> <i>带有转发链接</i>",
    'ar': "🔗 <b>الرسائل</b> <i>ذات الروابط الأمامية</i> غير مسموح بها",
}
l_hand_msg_zalgo = {
    'ru': "文 <b>Сообщения</b> <i>c <a href='https://www.zalgo.org'>zalgo-символами</a></i> не разрешены",
    'en': "文 <b>Messages</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> are not allowed",
    'es': "文 <b>Mensajes</b> <i>c <a href=' https://www.zalgo.org '> caracteres-zalgo</a></i> no están permitidos",
    'fr': "文 <b>Messages</b> <i>c <a href=' https://www.zalgo.org '> les caractères zalgo</a></i> ne sont pas autorisés",
    'zh': "文 <b>消息</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> 不允许",
    'ar': "文 <b>الرسائل</b> <i>c <a href=' https://www.zalgo.org '> zalgo-characters</a></i> غير مسموح بها",
}
l_hand_msg_symbols = {
    'ru': "文 <b>Сообщения</b> <i>c 文ب-алфавитами</i> не разрешены",
    'en': "文 <b>Messages</b> <i>with 文ب-alphabets</i> are not allowed",
    'es': "文 <b>Mensajes</b> <i>con 文ب-alfabetos</i> no están permitidos",
    'fr': "文 <b>Les messages</b> <i>avec les alphabets 文ب</i> ne sont pas autorisés",
    'zh': "不允许使用带有文巴字母的<b>消息</b><i>",
    'ar': "文 <b>الرسائل</b> <i>التي تحتوي على حروف 文ب</i> غير مسموح بها",
}
l_hand_msg_stop = {
    'ru': "🧾 <b>Сообщение</b> содержит <i>стоп-слова</i>",
    'en': "🧾 <b>Message</b> contains <i>safe words</i>",
    'es': "🧾 El <b>Mensaje</b> contiene <i>palabras seguras</i>",
    'fr': "🧾 <b>Le message</b> contient des <i>mots sûrs</i>",
    'zh': "🧾<b>消息</b>包含<i>安全词</i>",
    'ar': "🧾 <b>الرسالة</b> تحتوي على <i>كلمات آمنة</i>",
}
l_hand_msg_edit = {
    'ru': "👥 <b>Редактирование</b> сообщений не разрешено",
    'en': "👥 <b>Editing</b> messages is not allowed",
    'es': "👥 No se permite <b>editar</b> mensajes",
    'fr': "👥 <b>Modifier</b> les messages n'est pas autorisé",
    'zh': "👥 不允许<b>编辑</b>消息",
    'ar': "👥 <b>تحرير</b> الرسائل غير مسموح به",
}
l_scheduler_autoinvite_is_over = {
    'ru': "🚶🏽 <b>Закончились</b> пользователи для инвайта в группе {0}",
    'en': "🚶🏽 <b>Out of</b> users for invite in group {0}",
    'es': "🚶🏽 <b>No hay</b> usuarios por invitación en el grupo {0}",
    'fr': "🚶🏽 <b>Plus</b> d'utilisateurs à inviter dans le groupe {0}",
    'zh': "🚶🏽 <b>超过</b> 位可邀请加入群组 {0} 的用户",
    'ar': "🚶🏽 <b>من</b> المستخدمين المطلوب دعوتهم إلى المجموعة {0}",
}
l_scheduler_autoinvite_success = {
    'ru': "🚶🏽 <b>Успешный</b> инвайт пользователя {0} в группу {1}",
    'en': "🚶🏽 <b>Successful</b> invite user {0} to group {1}",
    'es': "🚶🏽 <b>Invitación exitosa</b> al usuario {0} al grupo {1}",
    'fr': "🚶🏽 <b>Réussite</b> de l'invitation de l'utilisateur {0} au groupe {1}",
    'zh': "🚶🏽 <b>成功</b>邀请用户 {0} 加入群组 {1}",
    'ar': "🚶🏽 <b>نجحت</b> دعوة المستخدم {0} إلى المجموعة {1}",
}
l_hand_msg_photo = {
    'ru': "🗣 <b>Сообщения</b> <i>с фото</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with photos</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con fotos</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec photos</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有照片</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على صور</i> غير مسموح بها",
}
l_hand_msg_video = {
    'ru': "🗣 <b>Сообщения</b> <i>с видео</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with video</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con vídeo</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec vidéo</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有视频</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على فيديو</i> غير مسموح بها",
}
l_hand_msg_giff = {
    'ru': "🗣 <b>Сообщения</b> <i>с гиф</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with GIF</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con GIF</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec GIF</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有GIF</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على GIF</i> غير مسموح بها",
}
l_hand_msg_audio = {
    'ru': "🗣 <b>Сообщения</b> <i>с аудио</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with audio</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con audio</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec audio</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有音频</i>",
    'ar': "🗣 <b>الرسائل</b> <i>المحتوية على صوت</i> غير مسموح بها",
}
l_hand_msg_sticker = {
    'ru': "🗣 <b>Сообщения</b> <i>со стикерами</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with stickers</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con stickers</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec autocollants</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有贴纸</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على ملصقات</i> غير مسموح بها",
}
l_hand_msg_sticker_ex = {
    'ru': "🗣 <b>Сообщения</b> <i>со стикерами</i> разрешены, но есть исключения",
    'en': "🗣 <b>Messages</b> <i>with stickers</i> are allowed, but there are exceptions",
    'es': "🗣 Se permiten <b>Mensajes</b> <i>con stickers</i>, pero hay excepciones",
    'fr': "🗣 Les <b>Messages</b> <i>avec autocollants</i> sont autorisés, mais il y a des exceptions",
    'zh': "🗣 允许<b>消息</b><i>带有贴纸</i>，但也有例外",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على ملصقات</i> مسموح بها، ولكن هناك استثناءات",
}
l_hand_msg_docum = {
    'ru': "🗣 <b>Сообщения</b> <i>с документами</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with documents</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con documentos</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec documents</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有文档</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على مستندات</i> غير مسموح بها",
}
l_hand_msg_poll = {
    'ru': "🗣 <b>Сообщения</b> <i>с опросами</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with surveys</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con encuestas</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec enquêtes</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b> <i>带有调查的消息</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على استطلاعات</i> غير مسموح بها",
}
l_hand_msg_voice = {
    'ru': "🗣 <b>Голосовые</b> сообщения не разрешены",
    'en': "🗣 <b>Voice messages</b> are not allowed",
    'es': "🗣 No se permiten <b>mensajes de voz</b>",
    'fr': "🗣 Les <b>messages vocaux</b> ne sont pas autorisés",
    'zh': "🗣 不允许<b>语音消息</b>",
    'ar': "🗣 <b>الرسائل الصوتية</b> غير مسموح بها",
}
l_hand_msg_video_note = {
    'ru': "🗣 <b>Сообщения</b> <i>с видео-заметками</i> не разрешены",
    'en': "🗣 <b>Messages</b> <i>with video notes</i> are not allowed",
    'es': "🗣 No se permiten <b>Mensajes</b> <i>con notas de vídeo</i>",
    'fr': "🗣 Les <b>Messages</b> <i>avec notes vidéo</i> ne sont pas autorisés",
    'zh': "🗣 不允许<b>消息</b><i>带有视频笔记</i>",
    'ar': "🗣 <b>الرسائل</b> <i>التي تحتوي على ملاحظات فيديو</i> غير مسموح بها",
}

l_hand_msg_len = {
    'ru': "👩🏽‍💻 <b>Сообщение</b> более {0} символов",
    'en': "👩🏽‍💻 <b>Message</b> more than {0} characters",
    'es': "👩🏽‍💻 <b>Mensaje</b> más de {0} caracteres",
    'fr': "👩🏽‍💻 <b>Message</b> de plus de {0} caractères",
    'zh': "👩🏽‍💻<b>消息</b>超过 {0} 个字符",
    'ar': "👩🏽‍💻 <b>الرسالة</b> أكثر من {0} حرف",
}
l_hand_msg_timer = {
    'ru': "👩🏽‍💻 <b>кѻмментарий</b> написан слишком быстро",
    'en': "👩🏽‍💻 <b>Comment</b> written too quickly",
    'es': "👩🏽‍💻 <b>Comentario</b> escrito demasiado rápido",
    'fr': "👩🏽‍💻 <b>Commentaire</b> écrit trop vite",
    'zh': "👩🏽‍💻<b>评论</b>写得太快",
    'ar': "👩🏽‍💻 <b>التعليق</b> مكتوب بسرعة كبيرة",
}
# endregion

# endregion


# region FereyPostBot
l_post_btn1 = {
    'ru': "👩🏽‍💻 Посты",
    'en': "👩🏽‍💻 Posts",
    'es': "👩🏽‍💻 Publicaciones",
    'fr': "👩🏽‍💻 Messages",
    'zh': "👩🏽‍💻 帖子",
    'ar': "👩🏽‍💻 المشاركات",
}
l_post_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_post_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> создания креативных постов:\n\n<blockquote>▪️<b>кнопочный</b> счетчик\n▪️инлайн-<b>телескопы</b>\n▪️парсинг/уведомления о <b>кликах</b>\n▪️<b>шёпот</b>-сообщения</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> for creating creative posts:\n\n▪️<b>button</b> counter\n▪️inline-<b >telescopes</b>\n▪️parsing/<b>click notifications</b>\n▪️<b>whisper</b>-messages\n\n❗️<b>Regularly</b>-updated / content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> para crear publicaciones creativas:\n\n▪️<b>botón</b> contador\n▪️inline-<b >telescopios</b>\n▪️análisis/<b>notificaciones de clic</b>\n▪️<b>susurros</b>-mensajes\n\n❗️<b>Regularmente</b>-actualizado/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> pour créer des publications créatives :\n\nwithout >télescopes</b>\nƒ️analyse/<b>notifications de clic</b>\nƒ️<b>chuchotement</b>-messages\n\n❗️<b>Régulièrement</b>-mis à jour/contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用<i>登陆机器人</i>来创建创意帖子：\n\n▪️<b>按钮</b>计数器\n▪️内联-<b >望远镜</b>\n▪️解析/<b>点击通知</b>\n▪️<b>窃窃私语</b>-消息\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء مشاركات إبداعية:\n\n▪️<b>زر</b> عداد\n▪️inline-<b >التلسكوبات</b>\n▪️parsing/<b>انقر فوق الإشعارات</b>\n▪️<b>whisper</b>-الرسائل\n\n❗️<b>بانتظام</b>-يتم التحديث / المحتوى",
}
l_post_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyPostBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_post = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>нотис</b>-уведомления о кликах\n(<i>ссылка на пользователя</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>notice</b>-click notifications\n(<i>user link</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>aviso</b>-notificaciones de clic\n(<i>enlace de usuario</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>notification</b>-notifications de clic\n(<i>lien utilisateur</i>)\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>通知</b>-点击通知\n（<i>用户链接</i>）\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إشعار</b>-انقر على الإشعارات\n(<i>رابط المستخدم</i>)\n\n👩🏽‍💻 /balance",
}

l_post_bot_button_push = {
    'ru': "👩🏽‍💻 <b>Пользователь</b>: {0} нажал на: [{1}] (пост #<u>{2}</u>)\n\n<code>/parse {3}</code> - все клики поста",
    'en': "👩🏽‍💻 <b>User</b>: {0} clicked on: [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3} </code>-all post clicks",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} hizo clic en: [{1}] (publicación #<u>{2}</u>)\n\n<code>/parse {3} </code>-todos los clics en publicaciones",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} a cliqué sur : [{1}] (post #<u>{2}</u>)\n\n<code>/parse {3} </code>-tous les clics sur les publications",
    'zh': "👩🏽‍💻<b>用户</b>：{0}点击了：[{1}]（帖子#<u>{2}</u>）\n\n<code>/parse {3} </code>-所有帖子点击",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} تم النقر عليه: [{1}] (المشاركة #<u>{2}</u>)\n\n<code>/parse {3} </code>-جميع النقرات على المنشور",
}
l_post_parse = {
    'ru': "👩🏽‍💻 <b>Список</b> кликов поста #{0}: <u>{1}</u>\n\n<blockquote>👩🏽‍💻 <b>Оформи</b> <a href='{2}'>💨Подписку</a> для получения имен пользователей</blockquote>",
    'en': "👩🏽‍💻 <b>List</b> of post #{0} clicks: <u>{1}</u>\n\n👩🏽‍💻 <b>Check out</b> <a href=' {2}'>💨Subscribe</a> to receive usernames",
    'es': "👩🏽‍💻 <b>Lista</b> de publicaciones #{0} clics: <u>{1}</u>\n\n👩🏽‍💻 <b>Consultar</b> <a href =' {2}'>💨Suscríbete</a> para recibir nombres de usuario",
    'fr': "👩🏽‍💻 <b>Liste</b> des publications #{0} clics : <u>{1}</u>\n\n👩🏽‍💻 <b>Découvrez</b> <a href =' {2}'>💨Abonnez-vous</a> pour recevoir les noms d'utilisateurs",
    'zh': "👩🏽‍💻 <b>列表</b>，帖子 #{0} 次点击：<u>{1}</u>\n\n👩🏽‍💻 <b>查看</b> <a href =' {2}'>💨订阅</a>以接收用户名",
    'ar': "👩🏽‍💻 <b>قائمة</b> المنشورات التي #{0} نقرات: <u>{1}</u>\n\n👩🏽‍💻 <b>الخروج</b> <a href =' {2}'>💨اشترك</a> لتلقي أسماء المستخدمين",
}
l_post_whisper_btn = {
    'ru': "Показать",
    'en': "Show",
    'es': "Espectáculo",
    'fr': "Montrer",
    'zh': "展示",
    'ar': "يعرض",
}
l_post_whisper_message_text = {
    'ru': "👩🏽‍💻 <b>Секретный</b> шёпот только для: ",
    'en': "👩🏽‍💻 <b>Secret</b> whisper only for:",
    'es': "👩🏽‍💻 Susurro <b>Secreto</b> solo para:",
    'fr': "👩🏽‍💻 <b>Secret</b> murmure uniquement pour :",
    'zh': "👩🏽‍💻<b>秘密</b>耳语仅适用于：",
    'ar': "👩🏽‍💻 همس <b>سري</b> فقط لـ:",
}
l_post_whisper_title = {
    'ru': "👩🏽‍💻 Шёпот",
    'en': "👩🏽‍💻 Whisper",
    'es': "👩🏽‍💻 Susurro",
    'fr': "👩🏽‍💻 Chuchotement",
    'zh': "👩🏽‍💻 耳语",
    'ar': "👩🏽‍💻 همس",
}
l_post_whisper_deleted = {
    'ru': "👩🏽‍💻 Шёпот удален",
    'en': "👩🏽‍💻 Whisper removed",
    'es': "👩🏽‍💻 Susurro eliminado",
    'fr': "👩🏽‍💻 Chuchotement supprimé",
    'zh': "👩🏽‍💻 低语已移除",
    'ar': "👩🏽‍💻 تم إزالة الهمس",
}
l_post_whisper_outdate = {
    'ru': "👩🏽‍💻 Шёпот просрочен после 3х дней",
    'en': "👩🏽‍💻 Whisper expired after 3 days",
    'es': "👩🏽‍💻 Whisper expiró después de 3 días",
    'fr': "👩🏽‍💻 Whisper a expiré après 3 jours",
    'zh': "👩🏽‍💻 Whisper 3 天后过期",
    'ar': "👩🏽‍💻 انتهت صلاحية الهمس بعد 3 أيام",
}
l_post_whisper_skip = {
    'ru': "👩🏽‍💻 Ты не видишь этот шёпот, потому что он был отправлен не тебе",
    'en': "👩🏽‍💻 You don’t see this whisper because it was not sent to you",
    'es': "👩🏽‍💻 No ves este susurro porque no te lo enviaron",
    'fr': "👩🏽‍💻 Vous ne voyez pas ce murmure car il ne vous a pas été envoyé",
    'zh': "👩🏽‍💻 您看不到这条私语，因为它不是发送给您的",
    'ar': "👩🏽‍💻 أنت لا ترى هذا الهمس لأنه لم يُرسل إليك",
}
l_post_whisper_alert = {
    'ru': "👩🏽‍💻 <b>Пользователь</b>: {0} прочитал шёпот: [{1}]",
    'en': "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} lee el susurro: [{1}]",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} lit le murmure : [{1}]",
    'zh': "👩🏽‍💻<b>用户</b>：{0}阅读私语：[{1}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} اقرأ الهمس: [{1}]",
}
l_post_whisper_text = {
    'ru': "👩🏽‍💻 <b>Шепот</b> - секретные сообщения для заданного количества пользователей в группе, которые открываются нажатием на кнопку",
    'en': "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} lee el susurro: [{1}]",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} lit le murmure : [{1}]",
    'zh': "👩🏽‍💻<b>用户</b>：{0}阅读私语：[{1}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} اقرأ الهمس: [{1}]",
}
l_post_whisper_txt = {
    'ru': "посмотри личные сообщения",
    'en': "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} lee el susurro: [{1}]",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} lit le murmure : [{1}]",
    'zh': "👩🏽‍💻<b>用户</b>：{0}阅读私语：[{1}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} اقرأ الهمس: [{1}]",
}
l_post_whisper_example = {
    'ru': "💨 Например",
    'en': "👩🏽‍💻 <b>User</b>: {0} read the whisper: [{1}]",
    'es': "👩🏽‍💻 <b>Usuario</b>: {0} lee el susurro: [{1}]",
    'fr': "👩🏽‍💻 <b>Utilisateur</b> : {0} lit le murmure : [{1}]",
    'zh': "👩🏽‍💻<b>用户</b>：{0}阅读私语：[{1}]",
    'ar': "👩🏽‍💻 <b>المستخدم</b>: {0} اقرأ الهمس: [{1}]",
}

l_boost_parse = {
    'ru': "👩🏽‍💻 <b>Boost</b> список",
    'en': "👩🏽‍💻 <b>List</b> of post #{0} clicks: <u>{1}</u>\n\n👩🏽‍💻 <b>Check out</b> <a href=' {2}'>💨Subscribe</a> to receive usernames",
    'es': "👩🏽‍💻 <b>Lista</b> de publicaciones #{0} clics: <u>{1}</u>\n\n👩🏽‍💻 <b>Consultar</b> <a href =' {2}'>💨Suscríbete</a> para recibir nombres de usuario",
    'fr': "👩🏽‍💻 <b>Liste</b> des publications #{0} clics : <u>{1}</u>\n\n👩🏽‍💻 <b>Découvrez</b> <a href =' {2}'>💨Abonnez-vous</a> pour recevoir les noms d'utilisateurs",
    'zh': "👩🏽‍💻 <b>列表</b>，帖子 #{0} 次点击：<u>{1}</u>\n\n👩🏽‍💻 <b>查看</b> <a href =' {2}'>💨订阅</a>以接收用户名",
    'ar': "👩🏽‍💻 <b>قائمة</b> المنشورات التي #{0} نقرات: <u>{1}</u>\n\n👩🏽‍💻 <b>الخروج</b> <a href =' {2}'>💨اشترك</a> لتلقي أسماء المستخدمين",
}
# endregion


# region FereyMediaBot
l_media_btn1 = {
    'ru': "👩🏽‍💻 Медиа",
    'en': "👩🏽‍💻 Media",
    'es': "👩🏽‍💻 Medios",
    'fr': "👩🏽‍💻 Médias",
    'zh': "👩🏽‍💻媒体",
    'ar': "👩🏽‍💻 وسائل الإعلام",
}
l_media_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_media_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> создания медиа-заметок:\n\n<blockquote>▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-тренды</b>\n▪️<b>видео-заметки</b>\n▪️инлайн-<b>телескопы</b>\n▪️<b>кнопочные</b> #нейро-титры</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to <i>landing bot</i> creating media notes:\n\n▪️<b>stickers</b> from text and photos\n▪️ <b>audio trends</b>\n▪️<b>video notes</b>\n▪️online <b>telescopes</b>\n▪️<b>push-button</b> media\n\n❗️<b>Regular</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> que crea notas multimedia:\n\n▪️<b>pegatinas</b> a partir de texto y fotos\n▪️ <b> tendencias de audio</b>\n▪️<b>notas de vídeo</b>\n▪️<b>telescopios en línea</b>\n▪️<b>medios de comunicación mediante botón</b>\n\n❗️< b>Regular</b>-actualizado /contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue dans le <i>bot d'atterrissage</i> qui crée des notes multimédias :\n\nnoyer<b>autocollants</b> à partir de texte et de photos\nnoyance <b> tendances audio</b>\nnounced<b>notes vidéo</b>\nnoyer <b>télescopes</b> en ligne</b>\nnoyam<b>médias à bouton-poussoir</b>\n\n❗️< b>Contenu régulièrement mis à jour</b>",
    'zh': "🌱 <b>{0}</b>，欢迎<i>登陆机器人</i>创建媒体笔记：\n\n▪️来自文本和照片的<b>贴纸</b>\n▪️ <b>音频趋势</b>\n▪️<b>视频笔记</b>\n▪️在线<b>望远镜</b>\n▪️<b>按钮</b>媒体\n\n❗️< b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء ملاحظات الوسائط:\n\n▪️<b>الملصقات</b> من النصوص والصور\n▪️ <b> الاتجاهات الصوتية</b>\n▪️<b>ملاحظات الفيديو</b>\n▪️على الإنترنت <b>التلسكوبات</b>\n▪️<b>ضغط الزر</b> الوسائط\n\n❗️< ب>عادي</b>-محدث/محتوى",
}
l_media_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyMediaBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_media = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>кнопочные</b> #нейро-титры\n(<i>динамические медиа</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>button</b> media\n(<i>dynamic media</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>botón</b> medios\n(<i>medios dinámicos</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>bouton</b> média\n(<i>média dynamique</i>)\n\n👩🏽‍💻 /balance",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>按钮</b>媒体\n（<i>动态媒体</i>）\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>زر</b> الوسائط\n(<i>الوسائط الديناميكية</i>)\n\n👩🏽‍💻 /balance",
}

l_media_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> тип выпадающих media-заметок (/add | /del)",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_media_del = {
    'ru': "👩🏽‍💻 <b>Выбери</b> media-заметку для удаления",
    'en': "👩🏽‍💻 <b>Select</b> media note to delete",
    'es': "👩🏽‍💻 <b>Seleccione</b> nota multimedia para eliminar",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> la note média à supprimer",
    'zh': "👩🏽‍💻<b>选择</b>要删除的媒体笔记",
    'ar': "👩🏽‍💻 <b>اختر</b> ملاحظة الوسائط لحذفها",
}
l_media_show = {
    'ru': "👩🏽‍💻 <b>Введи</b> текст для поиска по media-заметкам",
    'en': "👩🏽‍💻 <b>Enter</b> text to search in media notes",
    'es': "👩🏽‍💻 <b>Ingrese</b> texto para buscar en notas multimedia",
    'fr': "👩🏽‍💻 <b>Saisissez</b> le texte à rechercher dans les notes des médias",
    'zh': "👩🏽‍💻 <b>输入</b>文本以在媒体笔记中搜索",
    'ar': "👩🏽‍💻 <b>أدخل</b> النص للبحث في ملاحظات الوسائط",
}
l_media_random = {
    'ru': "🎲 Случайный выбор",
    'en': "🎲 Random selection",
    'es': "🎲 Selección aleatoria",
    'fr': "🎲 Sélection aléatoire",
    'zh': "🎲 随机选择",
    'ar': "🎲 اختيار عشوائي",
}
l_media_none = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметок не найдено",
    'en': "👩🏽‍💻 <b>Media</b>-notes not found",
    'es': "👩🏽‍💻 <b>Notas multimedia</b> no encontradas",
    'fr': "👩🏽‍💻 <b>Media</b>-notes introuvables",
    'zh': "👩🏽‍💻<b>媒体</b>-找不到注释",
    'ar': "👩🏽‍💻 <b>الوسائط</b>-لم يتم العثور على الملاحظات",
}
l_media_file = {
    'ru': "👩🏽‍💻 1/2. <b>Прикрепи</b> audio/video, text/photo контент для создания media-заметки",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media note",
    'es': "👩🏽‍💻 1/2. <b>Adjunte</b> contenido de audio/vídeo, texto/foto para crear una nota multimedia.",
    'fr': "👩🏽‍💻 1/2. <b>Joindre</b> du contenu audio/vidéo, texte/photo pour créer une note média",
    'zh': "👩🏽‍💻 1/2。 <b>附加</b>音频/视频、文本/照片内容以创建媒体注释",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى الصوت/الفيديو والنص/الصورة لإنشاء ملاحظة إعلامية",
}
l_media_title1 = {
    'ru': "👩🏽‍💻 2/2. <b>Введи</b> <code>ключевые слова</code> для твоей media-заметки\n\n<blockquote>изменить ключевые слова нельзя</blockquote>",
    'en': "👩🏽‍💻 2/2. <b>Enter</b> <code>keywords</code> for your media note\n[you cannot change <code>keywords</code>]",
    'es': "👩🏽‍💻 2/2. <b>Ingrese</b> <code>palabras clave</code> para su nota multimedia\n[no puede cambiar las <code>palabras clave</code>]",
    'fr': "👩🏽‍💻 2/2. <b>Saisissez</b> les <code>mots-clés</code> pour votre note média\n[vous ne pouvez pas modifier les <code>mots-clés</code>]",
    'zh': "👩🏽‍💻 2/2。 <b>输入</b>媒体注释的<code>关键字</code>\n[您无法更改<code>关键字</code>]",
    'ar': "👩🏽‍💻 2/2. <b>أدخل</b> <code>الكلمات الرئيسية</code> لملاحظة الوسائط الخاصة بك\n[لا يمكنك تغيير <code>الكلمات الرئيسية</code>]",
}
l_media_title2 = {
    'ru': "👩🏽‍💻 2/2. <b>Текущие</b> ключевые слова для твоей media-заметки\n\n<blockquote>{0}</blockquote>\n\n[отправь новые или жми {1}]",
    'en': "👩🏽‍💻 2/2. <b>Current</b> keywords for your media note\n\n{0}\n\n[new ones arrived or press {1}]",
    'es': "👩🏽‍💻 2/2. Palabras clave <b>actuales</b> para su nota multimedia\n\n{0}\n\n[llegaron nuevas o presione {1}]",
    'fr': "👩🏽‍💻 2/2. <b>Mots clés actuels</b> pour votre note média\n\n{0}\n\n[de nouveaux mots sont arrivés ou appuyez sur {1}]",
    'zh': "👩🏽‍💻 2/2。媒体记事的<b>当前</b>关键字\n\n{0}\n\n[新关键字已到达或按 {1}]",
    'ar': "👩🏽‍💻 2/2. الكلمات الرئيسية <b>الحالية</b> لمذكرة الوسائط الخاصة بك\n\n{0}\n\n[وصلت كلمات رئيسية جديدة أو اضغط على {1}]",
}
l_media_confirm = {
    'ru': "🏁 Завершить",
    'en': "🏁 Complete",
    'es': "🏁 Completo",
    'fr': "🏁 Terminé",
    'zh': "🏁 完成",
    'ar': "🏁 كاملة",
}
l_media_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b>: попробуй позже или загрузи другой media-файл",
    'en': "👩🏽‍💻 <b>Error</b> (try later or load another media)",
    'es': "👩🏽‍💻 <b>Error</b> (inténtalo más tarde o carga otro medio)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (essayez plus tard ou chargez un autre média)",
    'zh': "👩🏽‍💻<b>错误</b>（稍后再试或加载其他媒体）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (حاول لاحقًا أو قم بتحميل وسائط أخرى)",
}
l_media_finish = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметка успешно создана",
    'en': "👩🏽‍💻 <b>Media</b>-note successfully created",
    'es': "👩🏽‍💻 <b>Nota multimedia</b> creada correctamente",
    'fr': "👩🏽‍💻 <b>Media</b>-note créée avec succès",
    'zh': "👩🏽‍💻<b>媒体</b>-笔记已成功创建",
    'ar': "👩🏽‍💻 <b>الوسائط</b>-تم إنشاء الملاحظة بنجاح",
}
l_media_publish = {
    'ru': "🔗 Список",
    'en': "🔗 List",
    'es': "🔗 Lista",
    'fr': "🔗 Liste",
    'zh': "🔗 列表",
    'ar': "🔗 القائمة",
}
l_media_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Consultar",
    'fr': "🔗 Vérifiez",
    'zh': "🔗 检查",
    'ar': "🔗 فحص",
}
l_media_hasdeleted = {
    'ru': "👩🏽‍💻 <b>Media</b>-заметка удалена",
    'en': "👩🏽‍💻 <b>Media</b>-note deleted",
    'es': "👩🏽‍💻 <b>Nota multimedia</b> eliminada",
    'fr': "👩🏽‍💻 <b>Médias</b>-note supprimée",
    'zh': "👩🏽‍💻<b>媒体</b>-注释已删除",
    'ar': "👩🏽‍💻 <b>الوسائط</b>-تم حذف الملاحظة",
}
l_media_delprepare = {
    'ru': "🔗 Выбрать",
    'en': "🔗 Select",
    'es': "🔗 Seleccionar",
    'fr': "🔗 Sélectionnez",
    'zh': "🔗 选择",
    'ar': "🔗 اختر",
}


l_titles_file = {
    'ru': "👩🏽‍💻 1/2. <b>Прикрепи</b> audio/video-контент со звуком для создания #нейро-титров",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media note",
    'es': "👩🏽‍💻 1/2. <b>Adjunte</b> contenido de audio/vídeo, texto/foto para crear una nota multimedia.",
    'fr': "👩🏽‍💻 1/2. <b>Joindre</b> du contenu audio/vidéo, texte/photo pour créer une note média",
    'zh': "👩🏽‍💻 1/2。 <b>附加</b>音频/视频、文本/照片内容以创建媒体注释",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى الصوت/الفيديو والنص/الصورة لإنشاء ملاحظة إعلامية",
}
l_titles_needpaid = {
    'ru': "👩🏽‍💻 <b>Оформи</b> <a href='{0}'>подписку</a> для создания титров/субтитров",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media note",
    'es': "👩🏽‍💻 1/2. <b>Adjunte</b> contenido de audio/vídeo, texto/foto para crear una nota multimedia.",
    'fr': "👩🏽‍💻 1/2. <b>Joindre</b> du contenu audio/vidéo, texte/photo pour créer une note média",
    'zh': "👩🏽‍💻 1/2。 <b>附加</b>音频/视频、文本/照片内容以创建媒体注释",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى الصوت/الفيديو والنص/الصورة لإنشاء ملاحظة إعلامية",
}
l_titles_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> создания титров к медиа-заметке: пропробуй еще раз позже или загрузи другой медиа-файл",
    'en': "👩🏽‍💻 1/2. <b>Attach</b> audio/video, text/photo content to create a media note",
    'es': "👩🏽‍💻 1/2. <b>Adjunte</b> contenido de audio/vídeo, texto/foto para crear una nota multimedia.",
    'fr': "👩🏽‍💻 1/2. <b>Joindre</b> du contenu audio/vidéo, texte/photo pour créer une note média",
    'zh': "👩🏽‍💻 1/2。 <b>附加</b>音频/视频、文本/照片内容以创建媒体注释",
    'ar': "👩🏽‍💻 1/2. <b>أرفق</b> محتوى الصوت/الفيديو والنص/الصورة لإنشاء ملاحظة إعلامية",
}
# endregion


# region FereyFindBot
l_find_btn1 = {
    'ru': "👩🏽‍💻 Поиск",
    'en': "👩🏽‍💻 Search",
    'es': "👩🏽‍💻 Buscar",
    'fr': "👩🏽‍💻 Rechercher",
    'zh': "👩🏽‍💻 搜索",
    'ar': "👩🏽‍💻 بحث",
}
l_find_btn2 = {
    'ru': "📍 Гео поиск",
    'en': "📍 Geo search",
    'es': "📍 Búsqueda geográfica",
    'fr': "📍 Recherche géographique",
    'zh': "📍 地理搜索",
    'ar': "📍 البحث الجغرافي",
}
l_find_btn3 = {
    'ru': "🔔 Уведомления",
    'en': "🔔 Notifications",
    'es': "🔔 Notificaciones",
    'fr': "🔔Notifications",
    'zh': "🔔 通知",
    'ar': "🔔 الإخطارات",
}
l_find_btn4 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_find_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> премиум поиска в <b>Telegram</b>:\n\n<blockquote>▪️<b><code>top</code></b> каналы/группы\n▪️<b><code>vip</code></b> пользователи/боты\n▪️<b><code>geo</code></b> парсинг\n▪️<b><code>smm</code></b> пассивный маркетинг</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to <i>landing bot</i> premium search in <b>Telegram</b>:\n\n▪️<b>top</b> channels/groups\n▪️<b>vip</b> users/bots\n▪️<b>geo</b> parsing\n▪️<b>smm</b> passive marketing\n\n❗️<b> Regularly</b>updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido a la búsqueda premium del <i>bot de aterrizaje</i> en <b>Telegram</b>:\n\n▪️<b>principales</b> canales/ grupos\n▪️<b>vip</b> usuarios/bots\n▪️<b>geo</b> análisis\n▪️<b>smm</b> marketing pasivo\n\n❗️<b> Regularmente< /b>actualizado /contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue dans la recherche premium du <i>landing bot</i> dans <b>Telegram</b> :\n\nproducer<b>meilleures</b> chaînes/ groupes\nְ️<b>utilisateurs/bots vip</b>\n▪️<b>géo</b> analyse\nproducer<b>smm</b> marketing passif\n\n❗️<b> Régulièrement< /b>mis à jour /contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用 <b>Telegram</b> 中的<i>登陆机器人</i>高级搜索：\n\n▪️<b>热门</b>频道/群组\n▪️<b>vip</b>用户/机器人\n▪️<b>geo</b>解析\n▪️<b>smm</b>被动营销\n\n❗️<b>定期< /b>更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>landing bot</i> البحث المتميز في <b>Telegram</b>:\n\n▪️<b>أهم</b> القنوات/ المجموعات\n▪️<b>vip</b> المستخدمون/الروبوتات\n▪️<b>الموقع الجغرافي</b> التحليل\n▪️<b>smm</b> التسويق السلبي\n\n❗️<b> بانتظام< /ب>تم التحديث /المحتوى",
}
l_find_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyFindBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_find = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️<b>уведомления</b> о ключевых словах\n(<i>ссылка на сообщение</i>)\n▪️<b>увеличение</b> лимитов уведомлений\n(<i>до 10 ключевых слов/групп/каналов</i>)\n▪️<b>приоритетная</b> выдача при поиске\n(<i>выше чем premium/verified</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>notifications</b> about keywords\n(<i>link to message</i>)\n▪️<b>increase</b> notification limits\n(< i>up to 10 keywords/groups/channels</i>)\n▪️<b>priority</b> search results\n(<i>higher than premium/verified</i>)\n\n👩 🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>notificaciones</b> sobre palabras clave\n(<i>enlace al mensaje</i>)\n▪️<b>aumentar</b> límites de notificaciones\n( < i>hasta 10 palabras clave/grupos/canales</i>)\n▪️<b>resultados de búsqueda prioritarios</b>\n(<i>superiores a premium/verificados</i>)\n\n👩 🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>notifications</b> concernant les mots clés\n(<i>lien vers le message</i>)\nnoyance<b>augmenter</b> les limites de notification\n( < i>jusqu'à 10 mots clés/groupes/chaînes</i>)\nnounced<b>priorité</b> résultats de recherche\n(<i>supérieur à premium/vérifié</i>)\n\n👩 🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️关于关键字的<b>通知</b>\n（<i>消息链接</i>）\n▪️<b>增加</b>通知限制\n( <i>最多 10 个关键字/组/频道</i>)\n▪️<b>优先级</b>搜索结果\n（<i>高于高级/已验证</i>）\n\n👩 🏽‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إشعارات</b> حول الكلمات الرئيسية\n(<i>رابط إلى الرسالة</i>)\n▪️<b>زيادة</b> حدود الإشعارات\n( <<i>ما يصل إلى 10 كلمات رئيسية/مجموعات/قنوات</i>)\n▪️<b>أولوية</b> نتائج البحث\n(<i>أعلى من المميزة/التي تم التحقق منها</i>)\n\n👩 🏽‍💻 /التوازن",
}
l_find_bot_text_find = {
    'ru': "👩🏽‍💻 <b>Источник</b>: {0}, ссылка на публикацию: [{1}] (ключевое слово: <u>{2}</u>)",
    'en': "👩🏽‍💻 <b>Source</b>: {0}, publication link: [{1}] (keyword: <u>{2}</u>)",
    'es': "👩🏽‍💻 <b>Fuente</b>: {0}, enlace de publicación: [{1}] (palabra clave: <u>{2}</u>)",
    'fr': "👩🏽‍💻 <b>Source</b> : {0}, lien de publication : [{1}] (mot clé : <u>{2}</u>)",
    'zh': "👩🏽‍💻<b>来源</b>：{0}，发布链接：[{1}]（关键字：<u>{2}</u>）",
    'ar': "👩🏽‍💻 <b>المصدر</b>: {0}، رابط النشر: [{1}] (الكلمة الرئيسية: <u>{2}</u>)",
}

l_geo_minus = {
    'ru': "-",
    'en': "-",
    'es': "-",
    'fr': "-",
    'zh': "-",
    'ar': "-",
}
l_geo_current = {
    'ru': "📍R: {0}m",
    'en': "📍R: {0}m",
    'es': "📍R: {0}m",
    'fr': "📍R : {0}mois",
    'zh': "📍R：{0}米",
    'ar': "📍ر: {0}م",
}
l_geo_plus = {
    'ru': "+",
    'en': "+",
    'es': "+",
    'fr': "+",
    'zh': "+",
    'ar': "+",
}
l_geo_text1 = {
    'ru': "📍 <b>Гео</b>-поиск пользователей\n\n<blockquote>👩🏽‍💻 <b>Жми</b> на -/+, чтобы настроить [<b>📍Radius</b>]</blockquote>",
    'en': "📍 <b>GEO search</b> users\n\n👩🏽‍💻 <b>Press</b> on-/+ to configure 📍Radius",
    'es': "📍 Usuarios de <b>búsqueda GEO</b>\n\n👩🏽‍💻 <b>Presione</b> en-/+ para configurar 📍Radio",
    'fr': "📍 <b>Utilisateurs de recherche GEO</b>\n\n👩🏽‍💻 <b>Appuyez</b> sur-/+ pour configurer 📍Radius",
    'zh': "📍 <b>GEO 搜索</b>用户\n\n👩🏽‍💻 <b>按</b>-/+ 配置📍Radius",
    'ar': "📍 <b>بحث الموقع الجغرافي</b> المستخدمين\n\n👩🏽‍💻 <b>اضغط</b> على-/+ لتهيئة 📍Radius",
}
l_geo_text2 = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> геопозицию через 📎-меню вложений или <b>жми</b> на кнопку ниже:\n\n<blockquote>[📍Отправить гео]</blockquote>",
    'en': "👩🏽‍💻 <b>Attach</b> your geolocation via the 📎 attachment menu or <b>click</b> on the button below\n[📍Send geo] 👇🏽",
    'es': "👩🏽‍💻 <b>Adjunte</b> su geolocalización a través del 📎 menú de archivos adjuntos o <b>haga clic</b> en el botón a continuación\n[📍Enviar geo] 👇🏽",
    'fr': "👩🏽‍💻 <b>Joignez</b> votre géolocalisation via le menu 📎 pièce jointe ou <b>cliquez</b> sur le bouton ci-dessous\n[📍Envoyer la géo] 👇🏽",
    'zh': "👩🏽‍💻通过📎附件菜单<b>附加</b>您的地理位置或<b>点击</b>下面的按钮\n[📍发送地理信息]👇🏽",
    'ar': "👩🏽‍💻 <b>أرفق</b> موقعك الجغرافي عبر قائمة 📎 المرفقات أو <b>انقر</b> على الزر أدناه\n[📍أرسل الموقع الجغرافي] 👇🏽",
}
l_geo_send = {
    'ru': "📍Отправить гео",
    'en': "📍Send geo",
    'es': "📍Enviar geo",
    'fr': "📍Envoyer la géo",
    'zh': "📍发送地理信息",
    'ar': "📍أرسل الموقع الجغرافي",
}
l_geo_start = {
    'ru': "🔎 <b>Начинаем</b> поиск..",
    'en': "🔎 <b>Let's start</b> the search..",
    'es': "🔎 <b>Comencemos</b> la búsqueda..",
    'fr': "🔎 <b>Commençons</b> la recherche..",
    'zh': "🔎<b>让我们开始</b>搜索..",
    'ar': "🔎 <b>لنبدأ</b> البحث..",
}
l_geo_no = {
    'ru': "📍 Пользователей (@username) в данной геопозиции не найдено",
    'en': "📍 No users ( @username ) found in this location",
    'es': "📍 No se encontraron usuarios ( @username ) en esta ubicación",
    'fr': "📍 Aucun utilisateur ( @username ) trouvé à cet endroit",
    'zh': "📍 在此位置找不到用户 ( @username )",
    'ar': "📍 لم يتم العثور على مستخدمين ( @username ) في هذا الموقع",
}
l_geo_finish = {
    'ru': "📍 <b>В <a href='https://maps.google.com/?q={0},{1}'>геолокации</a></b> найдено пользователей: <u>{2}</u>",
    'en': "📍 <b>Users found in <a href=' https://maps.google.com/?q={0},{1} '> geolocation</a></b>: <u>{2} </u>",
    'es': "📍 <b>Usuarios encontrados en <a href=' https://maps.google.com/?q={0},{1} '> geolocalización</a></b>: <u>{2} </u>",
    'fr': "📍 <b>Utilisateurs trouvés dans la <a href=' https://maps.google.com/?q={0},{1} '> géolocalisation</a></b> : <u>{2} </u>",
    'zh': "📍<b>在<a href=' https://maps.google.com/?q={0},{1} '>地理位置</a></b>中找到的用户：<u>{2} </u>",
    'ar': "📍 <b>تم العثور على المستخدمين في <a href=' https://maps.google.com/?q={0},{1} '> الموقع الجغرافي</a></b>: <u>{2} </ش>",
}

l_find_add_cmd = {
    'ru': "👩🏽‍💻 <b>Отправь</b> ссылку на канал/группу/пользователя/бота",
    'en': "👩🏽‍💻 <b>Come</b> link to channel/group/user/bot",
    'es': "👩🏽‍💻 <b>Ven</b> enlace al canal/grupo/usuario/bot",
    'fr': "👩🏽‍💻 <b>Viens</b> lien vers le canal/groupe/utilisateur/bot",
    'zh': "👩🏽‍💻<b>来</b>链接到频道/组/用户/机器人",
    'ar': "👩🏽‍💻 <b>تعال</b> رابط القناة/المجموعة/المستخدم/الروبوت",
}
l_find_err_cmd = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    'en': "👩🏽‍💻 <b>Error</b> (insert the correct link or try again later)",
    'es': "👩🏽‍💻 <b>Error</b> (inserta el enlace correcto o vuelve a intentarlo más tarde)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (insérez le bon lien ou réessayez plus tard)",
    'zh': "👩🏽‍💻<b>错误</b>（插入正确的链接或稍后重试）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (أدخل الرابط الصحيح أو حاول مرة أخرى لاحقًا)",
}
l_find_ok_cmd = {
    'ru': "👩🏽‍💻 <b>Ссылка</b> успешно добавлена!",
    'en': "👩🏽‍💻 <b>Link</b> successfully added!",
    'es': "👩🏽‍💻 ¡<b>Enlace</b> agregado exitosamente!",
    'fr': "👩🏽‍💻 <b>Lien</b> ajouté avec succès !",
    'zh': "👩🏽‍💻 <b>链接</b>已成功添加！",
    'ar': "👩🏽‍💻 تمت إضافة <b>الرابط</b> بنجاح!",
}
l_find_check = {
    'ru': "🔗 Проверка",
    'en': "🔗 Check",
    'es': "🔗 Consultar",
    'fr': "🔗 Vérifiez",
    'zh': "🔗 检查",
    'ar': "🔗 فحص",
}

l_find_menu = {
    'ru': "↩ Menu",
    'en': "↩ Menu",
    'es': "↩ Menú",
    'fr': "↩ Menu",
    'zh': "↩ 菜单",
    'ar': "↩ القائمة",
}
l_find_text = {
    'ru': "<b>🔎 Сбор целевой аудитории (ЦА)</b>\n\n<blockquote>▪️<b>top</b> каналы/группы ЦА\n▪️<b>lead</b> конкуренты по нише\n▪️каталог <b>vip</b> ботов</blockquote>",
    'en': "<b>🔎 Gathering the target audience (TA)</b>\n\n▪️thematic <b>top</b> channels/TA groups\n▪️uploading <b>lead</b> competitors in the niche\n▪️ catalog of <b>vip</b> bots",
    'es': "<b>🔎 Reunir el público objetivo (TA)</b>\n\n▪️canales/grupos de TA <b>principales</b> temáticos\n▪️subir competidores <b>principales</b> en el nicho\ n▪️ catálogo de bots <b>vip</b>",
    'fr': "<b>🔎 Rassembler le public cible (TA)</b>\n\nnoyer les <b>meilleures</b> chaînes thématiques/groupes TA\nnoyer️télécharger les <b>principaux</b> concurrents dans la niche\ n ▪️ catalogue de robots <b>vip</b>",
    'zh': "<b>🔎收集目标受众 (TA)</b>\n\n▪️主题<b>顶级</b>频道/TA 群体\n▪️上传利基市场中的<b>领先</b>竞争对手\ n▪️ <b>vip</b> 机器人目录",
    'ar': "<b>🔎 جمع الجمهور المستهدف (TA)</b>\n\n▪️القنوات <b>أهم</b> المواضيعية/مجموعات TA\n▪️تحميل <b>الرائد</b> المنافسين في المجال المتخصص\n▪️ كتالوج لروبوتات <b>vip</b>",
}
l_find_category_typing = {
    'ru': "✅ ввести свои параметры",
    'en': "✅ ввести your parameters",
    'es': "✅ ввести tus parámetros",
    'fr': "✅ ввести vos paramètres",
    'zh': "✅ ввести您的参数",
    'ar': "✅ ввести معلماتك",
}
l_find_desc = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Description :</b> {0}",
    'zh': "<b>说明：</b>{0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_reacts = {
    'ru': "<b>Реакции:</b> {0}",
    'en': "<b>Reactions:</b> {0}",
    'es': "<b>Reacciones:</b> {0}",
    'fr': "<b>Réactions :</b> {0}",
    'zh': "<b>反应：</b>{0}",
    'ar': "<b>ردود الفعل:</b> {0}",
}
l_find_send = {
    'ru': "<b>Сообщ/медиа/инлайн/инвайт:</b> {0}/{1}/{2}/{3}",
    'en': "<b>Message/media/online/invite:</b> {0}/{1}/{2}/{3}",
    'es': "<b>Mensaje/medios/en línea/invitación:</b> {0}/{1}/{2}/{3}",
    'fr': "<b>Message/média/en ligne/invitation :</b> {0}/{1}/{2}/{3}",
    'zh': "<b>消息/媒体/在线/邀请：</b> {0}/{1}/{2}/{3}",
    'ar': "<b>رسالة/وسائط/متصل/دعوة:</b> {0}/{1}/{2}/{3}",
}
l_find_bio = {
    'ru': "<b>Био:</b> {0}",
    'en': "<b>Was:</b> {0}",
    'es': "<b>Era:</b> {0}",
    'fr': "<b>Était :</b> {0}",
    'zh': "<b>曾经：</b> {0}",
    'ar': "<b>كان:</b> {0}",
}
l_find_about = {
    'ru': "<b>Описание:</b> {0}",
    'en': "<b>Description:</b> {0}",
    'es': "<b>Descripción:</b> {0}",
    'fr': "<b>Description :</b> {0}",
    'zh': "<b>说明：</b>{0}",
    'ar': "<b>الوصف:</b> {0}",
}
l_find_description = {
    'ru': "<b>Подробнее:</b> {0}",
    'en': "<b>More details:</b> {0}",
    'es': "<b>Más detalles:</b> {0}",
    'fr': "<b>Plus de détails :</b> {0}",
    'zh': "<b>更多详细信息：</b>{0}",
    'ar': "<b>مزيد من التفاصيل:</b> {0}",
}
l_find_commands = {
    'ru': "<b>Команды:</b> {0}",
    'en': "<b>Commands:</b> {0}",
    'es': "<b>Comandos:</b> {0}",
    'fr': "<b>Commandes :</b> {0}",
    'zh': "<b>命令：</b> {0}",
    'ar': "<b>الأوامر:</b> {0}",
}

l_find_chn = {
    'ru': "📰 Каналы",
    'en': "📰 Channels",
    'es': "📰 Canales",
    'fr': "📰 Chaînes",
    'zh': "📰 频道",
    'ar': "📰 القنوات",
}
l_find_grp = {
    'ru': "📁 Группы",
    'en': "📁 Groups",
    'es': "📁 Grupos",
    'fr': "📁 Groupes",
    'zh': "📁 团体",
    'ar': "📁 المجموعات",
}
l_find_usr = {
    'ru': "🕵️ Конкуренты",
    'en': "🕵️Competitors",
    'es': "🕵️Competidores",
    'fr': "🕵️Concurrents",
    'zh': "🕵️竞争对手",
    'ar': "🕵️المنافسون",
}
l_find_bot = {
    'ru': "🫥 Боты",
    'en': "🫥 Boots",
    'es': "🫥 Botas",
    'fr': "🫥 Bottes",
    'zh': "🫥 靴子",
    'ar': "🫥حذاء",
}

l_find_chn_choose = {
    'ru': "📰 <b>Выбери категорию</b> для выгрузки каналов",
    'en': "📰 <b>Select a category</b> to download channels",
    'es': "📰 <b>Seleccione una categoría</b> para descargar canales",
    'fr': "📰 <b>Sélectionnez une catégorie</b> pour télécharger les chaînes",
    'zh': "📰<b>选择类别</b>下载频道",
    'ar': "📰 <b>اختر فئة</b> لتنزيل القنوات",
}
l_find_grp_choose = {
    'ru': "📁 <b>Выбери категорию</b> для выгрузки групп",
    'en': "📁 <b>Select a category</b> to upload groups",
    'es': "📁 <b>Seleccione una categoría</b> para cargar grupos",
    'fr': "📁 <b>Sélectionnez une catégorie</b> pour télécharger des groupes",
    'zh': "📁 <b>选择类别</b>以上传群组",
    'ar': "📁 <b>اختر فئة</b> لتحميل المجموعات",
}
l_find_usr_choose = {
    'ru': "🕵️ <b>Выбери категорию</b> для выгрузки пользователей",
    'en': "🕵️ <b>Select a category</b> to upload users",
    'es': "🕵️ <b>Seleccione una categoría</b> para subir usuarios",
    'fr': "🕵️ <b>Sélectionnez une catégorie</b> pour télécharger des utilisateurs",
    'zh': "🕵️ <b>选择类别</b>来上传用户",
    'ar': "🕵️ <b>حدد فئة</b> لتحميل المستخدمين",
}
l_find_bot_choose = {
    'ru': "🫥 <b>Выбери категорию</b> для выгрузки ботов",
    'en': "🫥 <b>Select a category</b> to upload bots",
    'es': "🫥 <b>Seleccione una categoría</b> para cargar bots",
    'fr': "🫥 <b>Sélectionnez une catégorie</b> pour télécharger des robots",
    'zh': "🫥<b>选择类别</b>以上传机器人",
    'ar': "🫥 <b>حدد فئة</b> لتحميل الروبوتات",
}

l_find_chn_find = {
    'ru': "🔎 Поиск каналов",
    'en': "🔎 Channel search",
    'es': "🔎 Búsqueda de canales",
    'fr': "🔎 Recherche de chaînes",
    'zh': "🔎 频道搜索",
    'ar': "🔎 البحث عن القناة",
}
l_find_grp_find = {
    'ru': "🔎 Поиск групп",
    'en': "🔎 Search for groups",
    'es': "🔎 Búsqueda de grupos",
    'fr': "🔎 Rechercher des groupes",
    'zh': "🔎 搜索群组",
    'ar': "🔎 البحث عن المجموعات",
}
l_find_usr_find = {
    'ru': "🔎 Поиск конкурентов",
    'en': "🔎 Search for competitors",
    'es': "🔎 Búsqueda de competidores",
    'fr': "🔎 Recherche de concurrents",
    'zh': "🔎 寻找竞争对手",
    'ar': "🔎 البحث عن المنافسين",
}
l_find_bot_find = {
    'ru': "🔎 Поиск ботов",
    'en': "🔎 Search for bots",
    'es': "🔎 Búsqueda de robots",
    'fr': "🔎 Rechercher des robots",
    'zh': "🔎 搜索机器人",
    'ar': "🔎 البحث عن الروبوتات",
}

l_find_chn_link = {
    'ru': "🔗 Перейти к каналу",
    'en': "🔗 Go to channel",
    'es': "🔗 Ir al canal",
    'fr': "🔗 Accédez à la chaîne",
    'zh': "🔗 前往频道",
    'ar': "🔗 اذهب إلى القناة",
}
l_find_grp_link = {
    'ru': "🔗 Перейти к группе",
    'en': "🔗 Go to group",
    'es': "🔗 Ir al grupo",
    'fr': "🔗 Aller au groupe",
    'zh': "🔗 进群",
    'ar': "🔗 اذهب إلى المجموعة",
}
l_find_usr_link = {
    'ru': "🔗 Перейти к пользователю",
    'en': "🔗 Go to user",
    'es': "🔗 Ir al usuario",
    'fr': "🔗 Accédez à l'utilisateur",
    'zh': "🔗 转到用户",
    'ar': "🔗 اذهب إلى المستخدم",
}
l_find_bot_link = {
    'ru': "🔗 Перейти к боту",
    'en': "🔗 Go to bot",
    'es': "🔗 Ir al bot",
    'fr': "🔗 Aller au bot",
    'zh': "🔗 前往机器人",
    'ar': "🔗 اذهب إلى البوت",
}

l_find_category_blog = {
    'ru': "#блогер",
    'en': "#blogger",
    'es': "#blogger",
    'fr': "#blogueur",
    'zh': "#博主",
    'ar': "#مدَّوِن",
}
l_find_category_digit = {
    'ru': "#оцифровка",
    'en': "#digitizer",
    'es': "#digitalizador",
    'fr': "#numériseur",
    'zh': "#数字化仪",
    'ar': "#محول الأرقام",
}
l_find_category_smm = {
    'ru': "#смм",
    'en': "#smm",
    'es': "#mmm",
    'fr': "#mmm",
    'zh': "#斯姆",
    'ar': "#smm",
}
l_find_category_recruit = {
    'ru': "#рекрут",
    'en': "#recruit",
    'es': "#recluta",
    'fr': "#recruter",
    'zh': "#招募",
    'ar': "#تجنيد",
}
l_find_category_design = {
    'ru': "#дизайн",
    'en': "#design",
    'es': "#diseño",
    'fr': "#conception",
    'zh': "#设计",
    'ar': "#تصميم",
}
l_find_category_coach = {
    'ru': "#коуч",
    'en': "#coach",
    'es': "#entrenador",
    'fr': "#entraîneur",
    'zh': "#教练",
    'ar': "#مدرب",
}
l_find_category_it = {
    'ru': "#ИТ",
    'en': "#DOG",
    'es': "#PERRO",
    'fr': "#CHIEN",
    'zh': "#狗",
    'ar': "#كلب",
}
l_find_category_course = {
    'ru': "#курсы",
    'en': "#courses",
    'es': "#cursos",
    'fr': "#cours",
    'zh': "#培训班",
    'ar': "#الدورات",
}
l_find_category_business = {
    'ru': "#бизнес",
    'en': "#business",
    'es': "#negocio",
    'fr': "#entreprise",
    'zh': "#商业",
    'ar': "#عمل",
}
l_find_category_goods = {
    'ru': "#товарка",
    'en': "#cargo",
    'es': "#carga",
    'fr': "#cargaison",
    'zh': "#货物",
    'ar': "#البضائع",
}
l_find_category_offline = {
    'ru': "#оффлайн",
    'en': "#offline",
    'es': "#desconectado",
    'fr': "#hors ligne",
    'zh': "#离线",
    'ar': "#غير متصل على الانترنت",
}
l_find_category_lawyer = {
    'ru': "#юрист",
    'en': "#lawyer",
    'es': "#abogado",
    'fr': "#avocat",
    'zh': "#律师",
    'ar': "#محامي",
}
l_find_category_verified = {
    'ru': "#верифиц",
    'en': "#verification",
    'es': "#verificación",
    'fr': "#vérification",
    'zh': "#确认",
    'ar': "#تَحَقّق",
}
l_find_category_premium = {
    'ru': "#премиум",
    'en': "#premium",
    'es': "#de primera calidad",
    'fr': "#prime",
    'zh': "#优质的",
    'ar': "#غالي",
}
l_find_category_health = {
    'ru': "#здоровье",
    'en': "#health",
    'es': "#salud",
    'fr': "#santé",
    'zh': "#健康",
    'ar': "#صحة",
}

l_find_category_getting = {
    'ru': "🔎 Выгружаем <b>категорию</b> {0}..\n\n#длительность 0мин",
    'en': "🔎 Upload <b>category</b> {0}..\n\n#duration 0 min",
    'es': "🔎 Subir <b>categoría</b> {0}..\n\n#duración 0 min",
    'fr': "🔎 Télécharger <b>catégorie</b> {0}..\n\n#durée 0 min",
    'zh': "🔎 上传<b>类别</b> {0}..\n\n#duration 0 分钟",
    'ar': "🔎 تحميل <b>الفئة</b> {0}..\n\n#duration 0 min",
}
l_find_keyword_getting = {
    'ru': "🔎 Выгружаем базу по ключевым словам <i>{0}</i>..\n\n#длительность 1мин",
    'en': "🔎 Unload the database using the keywords <i>{0}</i>..\n\n#duration 1 min",
    'es': "🔎 Descargue la base de datos usando las palabras clave <i>{0}</i>..\n\n#duración 1 min",
    'fr': "🔎 Déchargez la base de données en utilisant les mots-clés <i>{0}</i>..\n\n#durée 1 min",
    'zh': "🔎 使用关键字 <i>{0}</i> 卸载数据库..\n\n#duration 1 分钟",
    'ar': "🔎 قم بإلغاء تحميل قاعدة البيانات باستخدام الكلمات الأساسية <i>{0}</i>..\n\n#duration 1 min",
}
l_find_category_keywords = {
    'ru': "📰 <b>Введи</b> ключевые слова для поиска через пробелы или разделители",
    'en': "📰 <b>Enter</b> keywords to search using spaces or delimiters",
    'es': "📰 <b>Ingrese</b> palabras clave para buscar usando espacios o delimitadores",
    'fr': "📰 <b>Saisissez</b> des mots-clés à rechercher à l'aide d'espaces ou de délimiteurs",
    'zh': "📰 <b>输入</b>关键字以使用空格或分隔符进行搜索",
    'ar': "📰 <b>أدخل</b> الكلمات الرئيسية للبحث باستخدام المسافات أو المحددات",
}
l_find_reached = {
    'ru': "<b>Охват</b>: <u>{0}</u> польз.",
    'en': "<b>Coverage</b>: <u>{0}</u> user.",
    'es': "<b>Cobertura</b>: <u>{0}</u> usuario.",
    'fr': "<b>Couverture</b> : <u>{0}</u> utilisateur.",
    'zh': "<b>覆盖范围</b>：<u>{0}</u> 位用户。",
    'ar': "<b>التغطية</b>: <u>{0}</u> مستخدم.",
}
l_find_watch = {
    'ru': "🔎 Просмотр",
    'en': "🔎 View",
    'es': "🔎 Ver",
    'fr': "🔎 Voir",
    'zh': "🔎 查看",
    'ar': "🔎 عرض",
}
l_add_join_err = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> (вставь корректную ссылку или повтори позже)",
    'en': "👩🏽‍💻 <b>Error</b> (insert the correct link or try again later)",
    'es': "👩🏽‍💻 <b>Error</b> (inserta el enlace correcto o vuelve a intentarlo más tarde)",
    'fr': "👩🏽‍💻 <b>Erreur</b> (insérez le bon lien ou réessayez plus tard)",
    'zh': "👩🏽‍💻<b>错误</b>（插入正确的链接或稍后重试）",
    'ar': "👩🏽‍💻 <b>خطأ</b> (أدخل الرابط الصحيح أو حاول مرة أخرى لاحقًا)",
}

l_add_chn_fail = {
    'ru': "🚫 <b>Канал</b> {0} не добавлен в базу\n\n{1} аватар\n{2} описание\n{3} более {4} подписчиков\n{5} последний пост менее {6} дней назад\n{7} скам",
    'en': "🚫 <b>Channel</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} more than {4} subscribers\n{5} last post less than {6 } days ago\n{7} scam",
    'es': "🚫 <b>Canal</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} más de {4} suscriptores\n{5} última publicación menos hace más de {6 } días\n{7} estafa",
    'fr': "🚫 <b>Chaîne</b> {0} non ajoutée à la base de données\n\n{1} avatar\n{2} description\n{3} plus de {4} abonnés\n{5} dernier message moins il y a plus de {6 } jours\n{7} arnaque",
    'zh': "🚫 <b>频道</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 说明\n{3} 超过 {4} 个订阅者\n{5} 最新帖子较少{6 } 天前\n{7} 诈骗",
    'ar': "🚫 <b>القناة</b> {0} لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} مشتركين\n{5} آخر مشاركة أقل قبل أكثر من {6 } أيام\n{7} عملية احتيال",
}
l_add_grp_fail = {
    'ru': "🚫 <b>Группа</b> {0} не добавлена в базу\n\n{1} аватар\n{2} описание\n{3} более {4} участников\n{5} последний пост менее {6} дней назад\n{7} скам",
    'en': "🚫 <b>Group</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} more than {4} members\n{5} last post less than {6 } days ago\n{7} scam",
    'es': "🚫 <b>Grupo</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} más de {4} miembros\n{5} última publicación menos hace más de {6 } días\n{7} estafa",
    'fr': "🚫 <b>Groupe</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} description\n{3} plus de {4} membres\n{5} dernier message moins il y a plus de {6 } jours\n{7} arnaque",
    'zh': "🚫 <b>群组</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 描述\n{3} 超过 {4} 个成员\n{5} 上次发帖较少{6 } 天前\n{7} 诈骗",
    'ar': "🚫 <b>المجموعة</b> {0} لم تتم إضافتها إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} أكثر من {4} أعضاء\n{5} آخر مشاركة أقل قبل أكثر من {6 } أيام\n{7} عملية احتيال",
}
l_add_usr_fail = {
    'ru': "🚫 <b>Пользователь</b> {0} не добавлен в базу\n\n{1} аватар\n{2} @username\n{3} био\n{4} скам",
    'en': "🚫 <b>User</b> {0} not added to the database\n\n{1} avatar\n{2} @username\n{3} bio\n{4} scam",
    'es': "🚫 <b>Usuario</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} @username\n{3} biografía\n{4} estafa",
    'fr': "🚫 <b>Utilisateur</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} @username\n{3} bio\n{4} arnaque",
    'zh': "🚫 <b>用户</b> {0} 未添加到数据库\n\n{1} 头像\n{2} @username\n{3} 简介\n{4} 骗局",
    'ar': "🚫 <b>المستخدم</b> {0} لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} @username\n{3} السيرة الذاتية\n{4} عملية احتيال",
}
l_add_bot_fail = {
    'ru': "🚫 <b>Бот</b> {0} не добавлен в базу\n\n{1} аватар\n{2} описание\n{3} скам",
    'en': "🚫 <b>Bot</b> {0} not added to the database\n\n{1} avatar\n{2} description\n{3} scam",
    'es': "🚫 <b>Bot</b> {0} no agregado a la base de datos\n\n{1} avatar\n{2} descripción\n{3} estafa",
    'fr': "🚫 <b>Bot</b> {0} non ajouté à la base de données\n\n{1} avatar\n{2} description\n{3} arnaque",
    'zh': "🚫 <b>机器人</b> {0} 未添加到数据库\n\n{1} 头像\n{2} 描述\n{3} 骗局",
    'ar': "🚫 <b>الروبوت</b> {0} لم تتم إضافته إلى قاعدة البيانات\n\n{1} الصورة الرمزية\n{2} الوصف\n{3} عملية احتيال",
}

l_add_chn_done = {
    'ru': "✅ <b>Канал</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>Channel</b> {0}-added to the database and updated",
    'es': "✅ <b>Canal</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Chaîne</b> {0}-ajoutée à la base de données et mise à jour",
    'zh': "✅ <b>频道</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>القناة</b> {0}-تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_grp_done = {
    'ru': "✅ <b>Группа</b> {0} - добавлена в базу и обновлена",
    'en': "✅ <b>Group</b> {0}-added to the database and updated",
    'es': "✅ <b>Grupo</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Groupe</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>组</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>المجموعة</b> {0}-تمت إضافتها إلى قاعدة البيانات وتحديثها",
}
l_add_usr_done = {
    'ru': "✅ <b>Пользователь</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>User</b> {0}-added to the database and updated",
    'es': "✅ <b>Usuario</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Utilisateur</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>用户</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>المستخدم</b> {0}-تمت إضافته إلى قاعدة البيانات وتحديثه",
}
l_add_bot_done = {
    'ru': "✅ <b>Бот</b> {0} - добавлен в базу и обновлен",
    'en': "✅ <b>Bot</b> {0}-added to the database and updated",
    'es': "✅ <b>Bot</b> {0}: agregado a la base de datos y actualizado",
    'fr': "✅ <b>Bot</b> {0}-ajouté à la base de données et mis à jour",
    'zh': "✅ <b>Bot</b> {0}-添加到数据库并更新",
    'ar': "✅ <b>Bot</b> {0}-تمت إضافته إلى قاعدة البيانات وتحديثه",
}

l_find_chn_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> каналов, сегментированных по <i>ключевым</i> словам\n\n<b>Охват</b>: <u>{2}</u> польз\n\nМожно связаться с администраторами каналов, чтобы заказать рекламу",
    'en': "👩🏽‍💻 <b>Ready!</b> {0} collected <u>{1}</u> channels, segmented by <i>key</i> words\n\n<b>Coverage< /b>: <u>{2}</u> user\n\nYou can contact channel administrators to order advertising",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} canales <u>{1}</u> recopilados, segmentados por palabras <i>clave</i>\n\n<b>Cobertura</i> / b>: <u>{2}</u> usuario\n\nPuedes contactar con los administradores del canal para solicitar publicidad",
    'fr': "👩🏽‍💻 <b>Prêt !</b> {0} chaînes <u>{1}</u> collectées, segmentées par <i>mots clés</i>\n\n<b>Couverture< / b> : <u>{2}</u> utilisateur\n\nVous pouvez contacter les administrateurs de chaîne pour commander de la publicité.",
    'zh': "👩🏽‍💻 <b>准备好了！</b> {0} 收集了 <u>{1}</u> 个频道，按<i>关键词</i>个词进行细分\n\n<b>覆盖范围</ b>：<u>{2}</u>用户\n\n您可以联系频道管理员订购广告",
    'ar': "👩🏽‍💻 <b>جاهز!</b> {0} تم جمع <u>{1}</u> القنوات، مقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>التغطية< / b>: <u>{2}</u> user\n\nيمكنك الاتصال بمسؤولي القناة لطلب الإعلانات",
}
l_find_grp_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> чатов, сегментированных по <i>ключевым</i> словам\n\n<b>Охват</b>: <u>{2}</u> польз\n\nМожно сделать <b>рассылку</b> по группам",
    'en': "👩🏽‍💻 <b>Done!</b> {0} collected <u>{1}</u> chats, segmented by <i>key</i> words\n\n<b>Coverage< /b>: <u>{2}</u> user\n\nYou can make <b>mailing</b> to groups",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} chats <u>{1}</u> recopilados, segmentados por palabras <i>clave</i>\n\n<b>Cobertura</i> b>: <u>{2}</u> usuario\n\nPuedes realizar <b>envíos de correo</b> a grupos",
    'fr': "👩🏽‍💻 <b>Terminé !</b> {0} <u>{1}</u> chats collectés, segmentés par <i>mots clés</i>\n\n<b>Couverture< / b> : <u>{2}</u> utilisateur\n\nVous pouvez effectuer des <b>envois</b> à des groupes",
    'zh': "👩🏽‍💻 <b>完成！</b> {0} 收集了 <u>{1}</u> 条聊天记录，按<i>关键词</i>个字进行细分\n\n<b>覆盖范围</ b>：<u>{2}</u> 用户\n\n您可以向群组<b>发送邮件</b>",
    'ar': "👩🏽‍💻 <b>تم!</b> {0} تم جمع <u>{1}</u> الدردشات، مقسمة حسب <i>الكلمات الرئيسية</i>\n\n<b>التغطية< / b>: <u>{2}</u> مستخدم\n\nيمكنك إرسال <b>بريد</b> إلى المجموعات",
}
l_find_usr_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> пользователей, сегментированных по <i>ключевым</i> словам",
    'en': "👩🏽‍💻 <b>Done!</b> {0} collected <u>{1}</u> users, segmented by <i>key</i> words",
    'es': "👩🏽‍💻 <b>¡Listo!</b> {0} usuarios recopilados <u>{1}</u>, segmentados por palabras <i>clave</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> {0} utilisateurs <u>{1}</u> collectés, segmentés par mots <i>clés</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> {0} 收集了 <u>{1}</u> 个用户，按<i>关键词</i>个词进行细分",
    'ar': "👩🏽‍💻 <b>تم!</b> {0} تم جمع <u>{1}</u> من المستخدمين، مقسمين حسب الكلمات <i>الرئيسية</i>",
}
l_find_bot_done = {
    'ru': "👩🏽‍💻 <b>Готово!</b> По {0} собрано <u>{1}</u> ботов, сегментированных по <i>ключевым</i> словам",
    'en': "👩🏽‍💻 <b>Done!</b> <u>{1}</u> bots have been collected for {0}, segmented by <i>key</i> words",
    'es': "👩🏽‍💻 <b>¡Listo!</b> Se han recopilado <u>{1}</u> bots para {0}, segmentados por palabras <i>clave</i>",
    'fr': "👩🏽‍💻 <b>Terminé !</b> <u>{1}</u> des robots ont été collectés pour {0}, segmentés par mots <i>clés</i>",
    'zh': "👩🏽‍💻 <b>完成！</b> 已为 {0} 收集 <u>{1}</u> 个机器人，并按<i>关键字</i>个词进行细分",
    'ar': "👩🏽‍💻 <b>تم!</b> <u>{1}</u> تم جمع الروبوتات لـ {0}، مقسمة حسب الكلمات <i>الرئيسية</i>",
}
l_hashtag_categories = {
    "BLOG": ["blog", "блог", "влог", "блогер", "контентмейкер", 'contentmaker', 'youtube', 'путешестви',
             "курс", 'getcourse', 'геткурс', "английск", 'школ', "school", "запуск", 'заняти', 'урок', 'воркшоп',
             "language", "онлайн-школ", "онлайн школ", 'лингвист', 'linguist', 'марафон', 'практикум', 'семинар',
             'вебинар', 'лаборатор', 'хакатон', 'интенсив', 'обучени', 'запуск', 'колледж', 'институт',
             'университет', 'лекци', 'мастермайнд', 'симпозиум', 'тренинг', 'тимбилдинг', 'мастерск', 'образовани',
             'المدونة', 'blogue', '博客',
             ],
    "DIGIT": ['оцифров', "фин.", 'финан', 'бух', 'инвест', 'франш', 'трейд', 'бирж', 'кредит', "учет",
              "банк", "торг", "кассы", "денежн", "консалт", 'consult', 'finan', 'business', "доход",
              '数字化', 'digitalización', 'numérisation', 'الرقمنة',
              'استشارة', '谘询', 'consulter', 'consultar',
              ],
    "SMM": ['smm', 'смм', 'инста', 'inst', "facebook", 'tiktok', "тикток", 'tik-tok', "тик-ток", 'youtube', 'маркето',
            'маркети', 'market', 'таргет', "target", 'распаковка', 'продвижение', 'seo', 'сео', 'бренд', "агентство",
            "лиды", "vkontakte", "вконтакте", "лидов", "реклам", 'taplink', "прогрев", "блог", "визуал", "запуск",
            "трафик", "mvp", "редакция", 'директ',
            'سم', '市场推广', 'التسويق', 'comercialización', 'commercialisation', '',
            ],
    "RECRUIT": ["рекрут", "роп", "работа", "фриланc", "freela", "найм", "hr", "pr", "персонал", "менеджер",
                "продаж", "ассист", "риелтор", 'млм', 'mlm', "управлен", "наем", "сотрудн", "делегир", "карьер",
                'recruit', 'تجنيد', '招聘人员', 'recruter', 'recluta',
                'لحسابهم الخاص', '自由撰稿人', 'indépendant',
                ],
    "DESIGN": ["дизайн", "design", "интерьер", "декор", "мебел", "3d", "архитект", "двери", "ремонт", "строител",
               "фасад", 'тексти', "рису", "креатив", "визуал", "ландшафт", "художн", "картин",
               "имидж", "камин", "монтаж", 'граф', 'искусств', 'рукодел',
               '设计', 'التصميم', 'conception', 'diseño',
               'interior', 'interior', 'intérieur', 'الداخلية', 'الداخلية',
               'architecture', 'architecture', 'arquitectura', '建筑设计', 'العمارة',
               'creative', '创意', 'creativo', 'créativité', 'الإبداع',
               ],
    "COACH": ["коуч", "coach", 'консульт', 'продюсер', "бизнес", "наставн", "оратор", "энерг", "эксперт", "психо",
              "трекер", 'гайд',
              "практик", "бренд", "тайм", "мотива", "логопед", "мышлен", "нумеролог", "таролог", "йог",
              "ментор", "тренер", "гештальт", "предприним", "метафори", "денеж", "диагност", "icf",
              '教练', 'مدرب',
              'producer', 'productor', 'producteur', '生产商', 'المنتج',
              'mentor', '导师', 'مينتور', '',
              ],
    "IT": ["лендинг", "crm", 'kotlin', 'swift', 'flutter', 'c++', 'c#', 'unity', 'angular',
           'amocrm', "powerbi", 'программирова', 'tilda', 'frontend', 'backend', 'python', 'ux/ui',
           "битрикс", 'автоматизаци', 'автоворон', 'разработч', 'java',
           "developer", 'блокчейн', 'blockchain', 'startup', 'coding',
           'développeur', 'desarrollador', '开发人员', 'المطور',
           ],
    "BUSINESS": ["business", "бизнес", "инвест", "франш", "кредит", "торг", "консалт", "consult",
                 "доход", "представит", "предпринимат", "коммерц", "фирм", "предприят", "компани", "промышл",
                 "производст", "invest", "капитал", "capital", "корпорац", "агентств", "пассив",
                 "дистриб", "акцио", "холдин", "прибыл", "рубл", "стартап", 'startup',
                 'الأعمال', '业务', 'negocios', 'affaires',
                 ],
    "GOODS": ["wildbe", "вайлд", 'ozon', "озон", 'avito', "авито", "авторск", "одежд", "китай",
              "китая", "складчина", "подарк", 'модн', 'маркетплейс', 'вещи',
              'clothes', 'vêtements', 'ropa', '衣服', 'الملابس',
              'السوق', '市场', 'mercado', 'marketplace',
              ],
    "OFFLINE": ["салон", "студи", "логист", "грузопер", 'свечи', "букеты", "клиник",
                "магазин", "производств", 'эпиляц', 'парикмах', "кондитер",
                "пищев", 'кулинар', 'оффлайн', 'offline', 'адрес', 'храм', 'церковь', 'транспорт',
                'temple', 'church',
                'барбер', 'barber', 'barbero', 'coiffeur', '理发师', 'الحلاق',
                'salon', 'salón', 'صالون', '沙龙',
                'недвижимость', 'real estate', 'inmueble', 'immobilier', '房地产', 'العقارات',
                'shop', 'tienda', 'boutique', '商店', 'تسوق',
                'كوك', '库克', 'cuisinier', 'gastrónomo',
                'ресторан', 'restaurant', 'restaurant', 'restaurante', '食肆', 'مطعم',
                ],
    "HEALTH": ["beautifull", "beauty", "бьюти", "красота", "здоров", 'нутрициолог', 'косметик', 'косметол', 'йога',
               'питани', 'доктор', 'диет', 'похуден', 'волос', 'маникюр', 'макияж', 'клиник', 'ресниц', 'эпиляц',
               'парикмах', 'nutrition', 'krasota', 'zdorov', 'dietol', 'медицин', 'medic', 'стоматол',
               'врач', 'vrach', 'yoga', 'фитнес', 'fitnes', 'медиц', 'медик', 'лекарств', 'спортив', 'sport',
               'семья', 'дети', 'ребенок',
               'health', 'الصحة', '健康', 'salud', 'santé',
               'beauté', 'belleza', '美貌', 'الجمال',
               'medicine', '医学', 'الطب', 'medicina', 'médecine',
               ],
}
l_hashtag_translate = {
    "BLOG": {
        'ru': "#блогер",
        'en': "#blogger",
        'es': "#blogger",
        'fr': "#blogueur",
        'zh': "#博客作者",
        'ar': "#مدون",
    },
    "DIGIT": {
        'ru': "#оцифровка",
        'en': "#digit",
        'es': "#digitalización",
        'fr': "#numérisation",
        'zh': "#数字化",
        'ar': "#الرقمنة",
    },
    "SMM": {
        'ru': "#смм",
        'en': "#smm",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#سم",
    },
    "RECRUIT": {
        'ru': "#рекрут",
        'en': "#recruit",
        'es': "#recluta",
        'fr': "#recruter",
        'zh': "#招聘人员",
        'ar': "#تجنيد",
    },
    "DESIGN": {
        'ru': "#дизайн",
        'en': "#design",
        'es': "#diseño",
        'fr': "#conception",
        'zh': "#设计",
        'ar': "#التصميم",
    },
    "COACH": {
        'ru': "#коуч",
        'en': "#coach",
        'es': "#entrenador",
        'fr': "#entraîneur",
        'zh': "#教练",
        'ar': "#مدرب",
    },
    "IT": {
        'ru': "#ИТ",
        'en': "#IT",
        'es': "#IT",
        'fr': "#IT",
        'zh': "#信息技术",
        'ar': "#تقانةالمعلومات",
    },
    "BUSINESS": {
        'ru': "#бизнес",
        'en': "#business",
        'es': "#negocios",
        'fr': "#affaires",
        'zh': "#业务",
        'ar': "#الأعمال",
    },
    "GOODS": {
        'ru': "#товарка",
        'en': "#products",
        'es': "#mercancía",
        'fr': "#articles",
        'zh': "#产品中心",
        'ar': "#المنتجات",
    },
    "OFFLINE": {
        'ru': "#оффлайн",
        'en': "#offline",
        'es': "#fueradelínea",
        'fr': "#horsligne",
        'zh': "#离线状态",
        'ar': "#غيرمتصل",
    },
    "HEALTH": {
        'ru': "#здоровье",
        'en': "#health",
        'es': "#blogger",
        'fr': "#blogger",
        'zh': "#blogger",
        'ar': "#blogger",
    },
    "ISVERIFIED": {
        'ru': "#верифиц",
        'en': "#verified",
        'es': "#verificado",
        'fr': "#vérifié",
        'zh': "#已核实",
        'ar': "#التحقق",
    },
    "ISPREMIUM": {
        'ru': "#премиум",
        'en': "#premium",
        'es': "#prima",
        'fr': "#prime",
        'zh': "#保费",
        'ar': "#قسط",
    },
}

l_find_alert = {
    'ru': "👩🏽‍💻 <b>Жми</b> на ✅/☑️, чтобы вкл/выкл <i>уведомления</i> о появлении отслеживаемых слов в публичных группах/каналах\n\n<blockquote>🔔 <b>Отслеживаемые</b> слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>Press</b> on ✅/☑️ to turn on/off <i>notifications</i> about the appearance of tracked words in public groups/channels\n\n🔔 <b>Tracked</b > words: <code>{0}</code>\n🔔 <b>Monitored</b> groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>Presiona</b> en ✅/☑️ para activar/desactivar las <i>notificaciones</i> sobre la aparición de palabras rastreadas en grupos/canales públicos\n\n🔔 <b>Rastreado< /b > palabras: <code>{0}</code>\n🔔 Grupos/canales <b>monitoreados</b>: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>Appuyez</b> sur ✅/☑️ pour activer/désactiver les <i>notifications</i> concernant l'apparition de mots suivis dans les groupes/chaînes publics\n\n🔔 <b>Suivi< /b > mots : <code>{0}</code>\n🔔 <b>Groupes/canaux surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>按 ✅/☑️ 上的</b> 打开/关闭有关公共群组/频道中所跟踪单词出现的<i>通知</i>\n\n🔔 <b>已跟踪< /b > 单词：<code>{0}</code>\n🔔 <b>受监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻 <b>اضغط</b> على ✅/☑️ لتشغيل/إيقاف <i>الإشعارات</i> حول ظهور الكلمات التي يتم تتبعها في المجموعات/القنوات العامة\n\n🔔 <b>تم تتبعها< /b > الكلمات: <code>{0}</code>\n🔔 المجموعات/القنوات <b>المراقبة</b>: <code>{1}</code>",
}
l_find_alert_alert = {
    'ru': "🔔 Нет отслеживаемых слов/групп/каналов\nЖми ⚙️Настроить",
    'en': "🔔 No words/groups/channels to track\nClick ⚙️Customize",
    'es': "🔔 No hay palabras/grupos/canales para rastrear\nHaga clic en ⚙️Personalizar",
    'fr': "🔔 Aucun mot/groupe/canal à suivre\nCliquez sur ⚙️Personnaliser",
    'zh': "🔔 没有要跟踪的单词/组/频道\n单击 ⚙️自定义",
    'ar': "🔔 لا توجد كلمات/مجموعات/قنوات لتتبعها\nانقر على ⚙️تخصيص",
}
l_find_alert_words = {
    'ru': "👩🏽‍💻 <b>1. Вставь</b> отслеживаемые слова (более <u>3</u> символов) через <i>пробельные или разделительные</i> символы (без 💨Подписки: <u>1</u> слово)\n\n<blockquote>▪️регистр не важен\n▪️* в конце слова учитывает вхождение</blockquote>\n\n👩🏽‍💻 <b>Например</b>, для <b>психо*</b> отслеживание сработает на фразы: <i>анти<u>психо</u>лог, <u>Психо</u>терапевт..</i>\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>1. Insert</b>tracked words (more than <u>3</u> characters) separated by <i>space or separator</i> characters (without 💨Subscription: <u>1</u> word)\n▪️case not important\n▪️* at the end of the word takes into account the occurrence\n\n👩🏽‍💻 <b>For example</b>, for <b>psycho*</b> tracking will work on the phrases: <i>anti<u> psycho</u>logist, <u>Psycho</u>therapist..</i>\n🔔 <b>Tracked</b> words: <code>{0}</code>\n🔔 <b >Monitored</b>groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>1. Insertar</b>palabras rastreadas (más de <u>3</u> caracteres) separadas por <i>espacio o separador</i> caracteres (sin 💨Suscripción: <u>1</u> palabra)\n▪️caso no importante\n▪️* al final de la palabra tiene en cuenta la ocurrencia\n\n👩🏽‍💻 <b>Por ejemplo</b>, para <b>psico*</b> el seguimiento funcionará en las frases: <i>anti<u> psico</u>logista, <u>Psico</u>terapeuta...</i>\n🔔 Palabras <b>seguidas</b>: <code>{ 0}</code>\n🔔 <b >Grupos/canales</b>monitoreados: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>1. Insérer</b>des mots suivis (plus de <u>3</u> caractères) séparés par des caractères <i>espace ou séparateur</i> (sans 💨Abonnement : <u>1</u> mot)\n▪️cas sans importance\n▪️* à la fin du mot prend en compte l'occurrence\n\n👩🏽‍💻 <b>Par exemple</b>, pour le <b>psycho*</b> le tracking fonctionnera sur les phrases : <i>anti<u>psychologue</u>logue, <u>Psycho</u>thérapeute..</i>\n🔔 <b>Mots suivis</b> : <code>{ 0}</code>\n🔔 <b >Groupes/canaux surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>1.插入</b>跟踪的单词（超过<u>3</u>个字符），并用<i>空格或分隔符</i>个字符分隔（不含💨订阅：<u>1</u>个单词）\n▪️大小写不重要\n▪️* 位于单词末尾会考虑出现情况\n\n👩🏽‍💻 <b>例如</b>，对于 <b>psycho*</b> 跟踪将起作用关于短语：<i>反<u>心理学家</u>，<u>心理</u>治疗师..</i>\n🔔<b>跟踪</b>单词：<code>{ 0}</code>\n🔔<b>监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻<b>1. أدخل</b>الكلمات المتعقبة (أكثر من <u>3</u> أحرف) مفصولة بأحرف <i>مسافة أو فاصل</i> (بدون 💨الاشتراك: <u>1</u> كلمة)\n▪️الحالة غير مهمة\n▪️* في نهاية الكلمة تأخذ في الاعتبار حدوث\n\n👩🏽‍💻 <b>على سبيل المثال</b>، بالنسبة إلى <b>النفسية*</b> سيعمل التتبع على العبارات: <i>أخصائي <u> نفسي</u>، معالج <u>نفسي</u>..</i>\n🔔 <b>كلمات متعقبة</b>: <code>{ 0}</code>\n🔔 <b >المجموعات/القنوات</b>المراقبة: <code>{1}</code>",
}
l_find_alert_sources = {
    'ru': "👩🏽‍💻 <b>2. Вставь</b> публичные ссылки на группы/каналы (для отслеживаемых слов) через <i>пробелы/раздели</i> (без 💨Подписки: <u>1</u> группа/канал)\n\n<blockquote>🔔 <b>Отслеживаемые</b>  слова: <code>{0}</code>\n🔔 <b>Отслеживаемые</b> группы/каналы: <code>{1}</code></blockquote>",
    'en': "👩🏽‍💻 <b>2. Insert</b> public links to groups/channels (for tracked words) separated by <i>spaces/separated</i> (without 💨Subscription: <u>1</u> group/channel)\n\n🔔 < b>Watched</b> words: <code>{0}</code>\n🔔 <b>Monitored</b> groups/channels: <code>{1}</code>",
    'es': "👩🏽‍💻 <b>2. Insertar</b> enlaces públicos a grupos/canales (para palabras rastreadas) separados por <i>espacios/separados</i> (sin 💨Suscripción: <u>1</u> grupo/canal)\n\n🔔 < b>Palabras vistas</b>: <code>{0}</code>\n🔔 Grupos/canales <b>monitoreados</b>: <code>{1}</code>",
    'fr': "👩🏽‍💻 <b>2. Insérer</b> des liens publics vers des groupes/canaux (pour les mots suivis) séparés par des <i>espaces/séparés</i> (sans 💨Abonnement : <u>1</u> groupe/canal)\n\n🔔 < b>Mots surveillés</b> : <code>{0}</code>\n🔔 <b>Groupes/chaînes surveillés</b> : <code>{1}</code>",
    'zh': "👩🏽‍💻 <b>2.插入</b>到群组/频道的公共链接（用于跟踪的单词），以<i>空格/分隔</i>分隔（无💨订阅：<u>1</u>群组/频道）\n\n🔔 <b>观看</b>字词：<code>{0}</code>\n🔔<b>监控</b>组/频道：<code>{1}</code>",
    'ar': "👩🏽‍💻<b>2. أدخل</b> روابط عامة للمجموعات/القنوات (للكلمات المتعقبة) مفصولة <i>بمسافات/مفصولة</i> (بدون 💨الاشتراك: <u>1</u> مجموعة/قناة)\n\n🔔 < b>الكلمات</b> التي تمت مشاهدتها: <code>{0}</code>\n🔔 المجموعات/القنوات <b>المراقبة</b>: <code>{1}</code>",
}
l_find_need_subscribe = {
    'ru': "👩🏽‍💻 <b>Для</b> получения ссылки на сообщение и заказчика оформи 💨Подписку на @FereyFindBot-бота:\n\nhttps://t.me",
    'en': "👩🏽‍💻 <b>To</b> receive a link to the message and the customer, subscribe 💨Subscribe to @FereyFindBot-bot:\n\nhttps://t.me",
    'es': "👩🏽‍💻 <b>Para</b> recibir un enlace al mensaje y al cliente, suscríbete 💨Suscríbete a @FereyFindBot-bot:\n\nhttps://t.me",
    'fr': "👩🏽‍💻 <b>Pour</b> recevoir un lien vers le message et le client, abonnez-vous 💨Abonnez-vous à @FereyFindBot-bot :\n\nhttps://t.me",
    'zh': "👩🏽‍💻<b>要</b>接收消息和客户的链接，请订阅💨订阅@FereyFindBot-bot：\n\nhttps://t.me",
    'ar': "👩🏽‍💻 <b>للحصول</b> على رابط الرسالة والعميل، اشترك 💨Subscribe to @FereyFindBot-bot:\n\nhttps://t.me",
}
# endregion


# region FereyAIBot
l_ai_btn1 = {
    'ru': "👩🏽‍💻 Нейросети",
    'en': "👩🏽‍💻 Neural networks",
    'es': "👩🏽‍💻 Redes neuronales",
    'fr': "👩🏽‍💻 Réseaux de neurones",
    'zh': "👩🏽‍💻 神经网络",
    'ar': "👩🏽‍💻 الشبكات العصبية",
}
l_ai_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_ai_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> для #нейро-генерации контента:\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>#нейро-анализ</b> @tg-каналов\n▪️<b>распознавание</b> речи\n▪️<b>генерация</b> голоса\n▪️<b>очистка ⁰истории</b> /start</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> for neuro-generation of content:\n\n▪️<b>text/image</b>\n▪️< b>neuro-analysis</b> @tg-tech channels\n▪️<b>speech recognition</b>\n▪️<b>cleaning ⁰history</b> /start\n\n❗️<b>Regularly</ b>-updatable /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> para la neurogeneración de contenido:\n\n▪️<b>texto/imagen</b>\n▪️< b>neuroanálisis</b> canales @tg-tech\n▪️<b>reconocimiento de voz</b>\n▪️<b>limpieza ⁰historial</b> /inicio\n\n❗️<b>Regularmente</ b >-actualizable/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> pour la neuro-génération de contenu :\n\nwithout b>neuro-analyse</b> @tg-tech télégrammes\nnounced️<b>reconnaissance vocale</b>\nnouncement<b>nettoyage de l'⁰historique</b> /démarrage\n\n❗️<b>Régulièrement</ b >-mis à jour /contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用<i>登陆机器人</i>来神经生成内容：\n\n▪️<b>文本/图像</b>\n▪️< b>神经分析</b> @tg-tech频道\n▪️<b>语音识别</b>\n▪️<b>清理⁰历史记录</b> /start\n\n❗️<b>定期</b >-可更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء المحتوى العصبي:\n\n▪️<b>نص/صورة</b>\n▪️< b>تحليل الأعصاب</b> قنوات @tg-tech\n▪️<b>التعرف على الكلام</b>\n▪️<b>تنظيف ⁰التاريخ</b> /بدء\n\n❗️<b>بانتظام</ b >-قابل للتحديث/المحتوى",
}
l_ai_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyAIBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_ai = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️отсутствие <b>режима ожидания</b>\n▪️аналитика постов канала\n(<i>+финансовый потенциал</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️lack of <b>standby mode</b>\n▪️channel post analytics\n(<i>+financial potential</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️falta de <b>modo de espera</b>\n▪️análisis de publicaciones del canal\n(<i>+potencial financiero</i>)\n\n👩🏽‍💻 / balance",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\n▪️manque de <b>mode veille</b>\n▪️analyse des publications de chaîne\n(<i>+potentiel financier</i>)\n\n👩🏽‍💻 / équilibre",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️缺乏<b>待机模式</b>\n▪️频道后期分析\n(<i>+财务潜力</i>)\n\n👩🏽‍💻 /平衡",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️عدم وجود <b>وضع الاستعداد</b>\n▪️تحليلات منشورات القناة\n(<i>+الإمكانات المالية</i>)\n\n👩🏽‍💻 / توازن",
}

l_gen_txt = {
    'ru': "📘 Текст{0}",
    'en': "📘 Text{0}",
    'es': "📘 Texto{0}",
    'fr': "📘 SMS{0}",
    'zh': "📘 文字{0}",
    'ar': "📘 نص{0}",
}
l_gen_voice = {
    'ru': "🗣️ Голос",
    'en': "🌌 Image",
    'es': "🌌 Imagen",
    'fr': "🌌Image",
    'zh': "🌌 图片",
    'ar': "🌌 صورة",
}
l_gen_img = {
    'ru': "🌌 Образ",
    'en': "🌌 Image",
    'es': "🌌 Imagen",
    'fr': "🌌Image",
    'zh': "🌌 图片",
    'ar': "🌌 صورة",
}

l_gen_tlg = {
    'ru': "👩🏽‍💻 @tg-канал",
    'en': "👩🏽‍💻 Analysis of @tg-tech channel",
    'es': "👩🏽‍💻 Análisis del canal @tg-tech",
    'fr': "👩🏽‍💻 Analyse de la chaîne @tg-tech",
    'zh': "👩🏽‍💻 @tg-tech频道分析",
    'ar': "👩🏽‍💻تحليل قناة @tg-tech",
}
l_generate_main = {
    'ru': "👩🏽‍💻 <b>Выбери режим</b>",
    'en': "👩🏽‍💻 <b>Select mode</b>",
    'es': "👩🏽‍💻 <b>Seleccionar modo</b>",
    'fr': "👩🏽‍💻 <b>Sélectionner le mode</b>",
    'zh': "👩🏽‍💻<b>选择模式</b>",
    'ar': "👩🏽‍💻 <b>اختر الوضع</b>",
}
l_generate_prompt = {
    'ru': "👩🏽‍💻 <b>Введи</b> запрос для <b>{0}</b> 👇🏼..",
    'en': "👩🏽‍💻 <b>Enter</b> a request for <b>{0}</b> 👇🏼..",
    'es': "👩🏽‍💻 <b>Ingrese</b> una solicitud para <b>{0}</b> 👇🏼..",
    'fr': "👩🏽‍💻 <b>Saisissez</b> une demande de <b>{0}</b> 👇🏼..",
    'zh': "👩🏽‍💻 <b>输入</b> <b>{0}</b> 👇🏼..",
    'ar': "👩🏽‍💻 <b>أدخل</b> طلب <b>{0}</b> 👇🏼..",
}
l_generate_chn = {
    'ru': "👩🏽‍💻 <b>Вставь</b> ссылку на @tg-канал для анализа финансовых показателей",
    'en': "👩🏽‍💻 <b>Insert</b> link to @tg-tech channel for analyzing financial indicators",
    'es': "👩🏽‍💻 <b>Insertar</b> enlace al canal @tg-tech para analizar indicadores financieros",
    'fr': "👩🏽‍💻 <b>Insérer</b> un lien vers la chaîne @tg-tech pour analyser les indicateurs financiers",
    'zh': "👩🏽‍💻<b>插入</b>链接到@tg-tech频道以分析财务指标",
    'ar': "👩🏽‍💻 <b>أدخل</b> رابط قناة @tg-tech لتحليل المؤشرات المالية",
}
l_generate_wait = {
    'ru': "👩🏽‍💻 <b>Выбери режим</b> или <b>дождись</b> окончания генерации..",
    'en': "👩🏽‍💻 <b>Select mode</b> or <b>wait</b> for the end of generation..",
    'es': "👩🏽‍💻 <b>Seleccione modo</b> o <b>espera</b> hasta el final de la generación.",
    'fr': "👩🏽‍💻 <b>Sélectionner le mode</b> ou <b>attendre</b> la fin de la génération.",
    'zh': "👩🏽‍💻<b>选择模式</b>或<b>等待</b>生成结束..",
    'ar': "👩🏽‍💻 <b>اختر الوضع</b> أو <b>انتظر</b> حتى نهاية الجيل..",
}
l_generate_subcribe = {
    'ru': "👩🏽‍💻 Подожди {0}сек или оформи 💨Подписку",
    'en': "👩🏽‍💻 Wait {0}sec or subscribe 💨",
    'es': "👩🏽‍💻 Espere {0}seg o suscríbase 💨",
    'fr': "👩🏽‍💻 Attendez {0}sec ou abonnez-vous 💨",
    'zh': "👩🏽‍💻 等待 {0} 秒或订阅 💨",
    'ar': "👩🏽‍💻 انتظر {0}ثانية أو اشترك 💨",
}
l_generate_subcribe2 = {
    'ru': "👩🏽‍💻 <b>Подожди</b> <i>{0}сек или <a href='{1}'>оформи 💨Подписку</a></i>",
    'en': "👩🏽‍💻 <b>Wait</b> <i>{0}sec or <a href='{1}'>subscribe 💨Subscribe</a></i>",
    'es': "👩🏽‍💻 <b>Espera</b> <i>{0}seg o <a href='{1}'>suscríbete 💨Suscríbete</a></i>",
    'fr': "👩🏽‍💻 <b>Attendez</b> <i>{0}sec ou <a href='{1}'>abonnez-vous 💨Abonnez-vous</a></i>",
    'zh': "👩🏽‍💻<b>等待</b><i>{0}秒或<a href='{1}'>订阅💨订阅</a></i>",
    'ar': "👩🏽‍💻 <b>انتظر</b> <i>{0}ثانية أو <a href='{1}'>اشترك 💨Subscribe</a></i>",
}
l_generate_subcribe_channel = {
    'ru': "👩🏽‍💻 Оформи 💨Подписку, чтобы узнать финансовый потенциал твоего @tg-tech-канала",
    'en': "👩🏽‍💻 Subscribe 💨to find out the financial potential of your @tg-tech channel",
    'es': "👩🏽‍💻 Suscríbete 💨para conocer el potencial financiero de tu canal @tg-tech",
    'fr': "👩🏽‍💻 Abonnez-vous 💨pour découvrir le potentiel financier de votre chaîne @tg-tech",
    'zh': "👩🏽‍💻订阅💨以了解您的@tg-tech频道的财务潜力",
    'ar': "👩🏽‍💻 اشترك 💨 لمعرفة الإمكانيات المالية لقناتك @tg-tech",
}
l_generate_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> генерации, повтори запрос позже",
    'en': "👩🏽‍💻 <b>Error</b> generation",
    'es': "👩🏽‍💻 Generación de <b>Error</b>",
    'fr': "👩🏽‍💻 <b>Génération d'erreur</b>",
    'zh': "👩🏽‍💻<b>错误</b>生成",
    'ar': "👩🏽‍💻 جيل <b>الخطأ</b>",
}
l_generate_error_clear = {
    'ru': "Ошибка генерации",
    'en': "👩🏽‍💻 <b>Error</b> generation",
    'es': "👩🏽‍💻 Generación de <b>Error</b>",
    'fr': "👩🏽‍💻 <b>Génération d'erreur</b>",
    'zh': "👩🏽‍💻<b>错误</b>生成",
    'ar': "👩🏽‍💻 جيل <b>الخطأ</b>",
}
l_process_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> преобразования",
    'en': "👩🏽‍💻 <b>Error</b> conversion",
    'es': "👩🏽‍💻 <b>Error</b> de conversión",
    'fr': "👩🏽‍💻 Conversion <b>Erreur</b>",
    'zh': "👩🏽‍💻<b>错误</b>转换",
    'ar': "👩🏽‍💻 <b>خطأ</b> في التحويل",
}
l_generate_errchn = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> доступа к каналу (попробуй позже или сделай канал публичным)",
    'en': "👩🏽‍💻 <b>Error</b> accessing the channel (try later or make the channel public)",
    'es': "👩🏽‍💻 <b>Error</b> al acceder al canal (inténtalo más tarde o haz público el canal)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de l'accès à la chaîne (essayez plus tard ou rendez la chaîne publique)",
    'zh': "👩🏽‍💻 <b>访问频道时出错</b>（稍后重试或将频道公开）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في الدخول إلى القناة (حاول لاحقًا أو اجعل القناة عامة)",
}
l_ai_request = {
    'ru': "👩🏽‍💻 <i><b>Обработка</b> запроса..\n#длительность 0мин</i>",
    'en': "👩🏽‍💻 <i><b>Processing</b> request..\n#duration 0 min</i>",
    'es': "👩🏽‍💻 <i><b>Procesando</b> solicitud..\n#duración 0 min</i>",
    'fr': "👩🏽‍💻 <i><b>Traitement</b> demande..\n#durée 0 min</i>",
    'zh': "👩🏽‍💻<i><b>正在处理</b>请求..\n#duration 0 分钟</i>",
    'ar': "👩🏽‍💻 <i><b>جارٍ معالجة</b> الطلب..\n#المدة 0 دقيقة</i>",
}
# endregion


# region FereyToolsBot
l_tools_btn1 = {
    'ru': "👩🏽‍💻 Инструменты",
    'en': "👩🏽‍💻Tools",
    'es': "👩🏽‍💻Herramientas",
    'fr': "👩🏽‍💻Outils",
    'zh': "👩🏽‍💻工具",
    'ar': "👩🏽‍💻الأدوات",
}
l_tools_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tools_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> <b>Telegram</b>-инструментов:\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/бота\n▪️конвертация в <b>телескопы</b>\n▪️<b>/telegraph</b> фото/видео-ссылка\n▪️пустое сообщение <b>0-длины</b>\n▪️скачивание tg-сторис/<b>x/ig/tt/yt</b> видео</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to <i>landing bot</i> Telegram tools:\n\n▪️<b>content conversion</b>\n▪️<b>/ json</b> message information\n▪️<b>removal</b> background\n▪️<b>/id</b> group/channel/bot\n▪️conversion to <b>telescopes</b>\n▪️<b>/telegraph</b> photo/video link\n▪️empty message <b>0-length</b>\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido a las herramientas de Telegram del <i>bot de aterrizaje</i>:\n\n▪️<b>conversión de contenido</b>\n▪️<b>/ json</ b> información del mensaje\n▪️<b>eliminación</b> fondo\n▪️<b>/id</b> grupo/canal/bot\n▪️conversión a <b>telescopios</b>\n▪️< b>/telegraph</b> enlace de foto/vídeo\n▪️mensaje vacío <b>0 longitud</b>\n\n❗️<b>Contenido/actualizado periódicamente</b>",
    'fr': "🌱 <b>{0}</b>, bienvenue dans le <i>bot d'atterrissage</i> Outils Telegram :\n\nproducer<b>conversion de contenu</b>\nnoyam<b>/ json</ b> informations sur le message\nwithout b>/télégraphe</b> lien photo/vidéo\n▪️message vide <b>longueur 0</b>\n\n❗️<b>Régulièrement</b> mis à jour /contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用<i>登陆机器人</i> Telegram 工具：\n\n▪️<b>内容转换</b>\n▪️<b>/ json</ b> 消息信息\n▪️<b>删除</b>背景\n▪️<b>/id</b> 组/频道/机器人\n▪️转换为<b>望远镜</b>\n▪️< b>/telegraph</b> 照片/视频链接\n▪️空消息<b>0长度</b>\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> أدوات Telegram:\n\n▪️<b>تحويل المحتوى</b>\n▪️<b>/ json</ b> معلومات الرسالة\n▪️<b>إزالة</b> الخلفية\n▪️<b>/id</b> المجموعة/القناة/bot\n▪️التحويل إلى <b>التلسكوبات</b>\n▪️< b>/telegraph</b> رابط الصورة/الفيديو\n▪️رسالة فارغة <b>0-الطول</b>\n\n❗️<b>بانتظام</b>-يتم التحديث /المحتوى",
}
l_tools_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyToolsBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_tools = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}

l_image_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>изображения</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>images</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>imágenes</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir les <i>images</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>图像</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الصور</i> إلى",
}
l_image_jpg = {
    'ru': "🏞️ jpg",
    'en': "🏞️ jpg",
    'es': "🏞️jpg",
    'fr': "🏞️jpg",
    'zh': "🏞️.jpg",
    'ar': "🏞️ JPG",
}
l_image_png = {
    'ru': "🌁 png",
    'en': "🌁 png",
    'es': "🌁png",
    'fr': "🌁 png",
    'zh': "🌁.png",
    'ar': "🌁 png",
}
l_image_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥mp4",
    'fr': "🎥mp4",
    'zh': "🎥mp4",
    'ar': "🎥 mp4",
}
l_image_album = {
    'ru': "9️⃣ альбом⁹",
    'en': "9️⃣ album⁹",
    'es': "9️⃣ álbum⁹",
    'fr': "9️⃣album⁹",
    'zh': "9️⃣ 专辑⁹",
    'ar': "9️⃣ الألبوم⁹",
}
l_image_collage = {
    'ru': "1️⃣ коллаж¹",
    'en': "1️⃣ collage¹",
    'es': "1️⃣ collage¹",
    'fr': "1️⃣ collage¹",
    'zh': "1️⃣ 拼贴画¶",
    'ar': "1️⃣ الكولاج¹",
}
l_image_ico = {
    'ru': "🖼️ ico",
    'en': "🖼️ ico",
    'es': "🖼️ico",
    'fr': "🖼️icône",
    'zh': "🖼️ ico",
    'ar': "🖼️ إيكو",
}
l_image_sticker = {
    'ru': "🌌 стикер",
    'en': "🌌 sticker",
    'es': "🌌 pegatina",
    'fr': "🌌 autocollant",
    'zh': "🌌 贴纸",
    'ar': "🌌 ملصق",
}
l_image_rbg = {
    'ru': "🙌🏽 удалить фон",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}
l_image_slice = {
    'ru': "🔪 Срез",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}
l_image_slice_mini = {
    'ru': "🔪 срез",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}
l_image_descpic = {
    'ru': "⿴ Bot Desc Pic",
    'en': "⿴ Bot Desc Pic",
    'es': "⿴ Imagen de descripción del bot",
    'fr': "⿴ Bot Desc Pic",
    'zh': "⿴机器人描述图片",
    'ar': "⿴ بوت ديسك بيك",
}
l_image_watermark = {
    'ru': "🪼 Водяной знак",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}

l_image_jpg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в jpg",
    'en': "👩🏽‍💻 <b>Attach</b> photo to convert to jpg",
    'es': "👩🏽‍💻 <b>Adjunte</b> foto para convertir a jpg",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en jpg",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为jpg",
    'ar': "👩🏽‍💻 <b>أرفق</b> الصورة لتحويلها إلى jpg",
}
l_image_png_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в png",
    'en': "👩🏽‍💻 <b>Attach</b> photo to convert to png",
    'es': "👩🏽‍💻 <b>Adjunte</b> foto para convertir a png",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en png",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为png",
    'ar': "👩🏽‍💻 <b>أرفق</b> الصورة لتحويلها إلى png",
}
l_image_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в mp4 (Telegram-аватарку)",
    'en': "👩🏽‍💻 <b>Attach</b> photo to convert to mp4 (Telegram avatar)",
    'es': "👩🏽‍💻 <b>Adjunte</b> foto para convertir a mp4 (avatar de Telegram)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en mp4 (avatar Telegram)",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为mp4（电报头像）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى mp4 (الصورة الرمزية في Telegram)",
}
l_image_ico_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в ico-иконку (320x320)",
    'en': "👩🏽‍💻 <b>Attach</b> photo to convert into ico-icon (320x320)",
    'es': "👩🏽‍💻 <b>Adjunte</b> foto para convertirla en ico-icono (320x320)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo à convertir en ico-icône (320x320)",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为ico图标（320x320）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى أيقونة ico (160×160)",
}
l_image_sticker_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в стикер",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert into a sticker",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla en una pegatina",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour la convertir en autocollant",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为贴纸",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ملصق",
}
l_image_album_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в альбом из 9 частей",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert into a 9-part album",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla en un álbum de 9 partes",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour la convertir en album en 9 parties",
    'zh': "👩🏽‍💻<b>附加</b>照片以转换为 9 部分相册",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى ألبوم مكون من 9 أجزاء",
}
l_image_collage_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> альбом для преобразования в 1-единый коллаж",
    'en': "👩🏽‍💻 <b>Attach</b> the album to convert into a single collage",
    'es': "👩🏽‍💻 <b>Adjunte</b> el álbum para convertirlo en un solo collage",
    'fr': "👩🏽‍💻 <b>Joindre</b> l'album pour le convertir en un seul collage",
    'zh': "👩🏽‍💻<b>附加</b>相册以转换为单个拼贴画",
    'ar': "👩🏽‍💻 <b>أرفق</b> الألبوم لتحويله إلى مجموعة واحدة",
}
l_image_rbg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для удаления фона",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to remove the background",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para eliminar el fondo",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour supprimer l'arrière-plan",
    'zh': "👩🏽‍💻<b>附加</b>照片以删除背景",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لإزالة الخلفية",
}
l_image_slice_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в узкую полоску фото (срез)",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}
l_image_descpic_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото для преобразования в формат, необходимый для установки Description Picture для бота в @BotFather (640x360)",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert it to the format required to set the Description Picture for the bot in @BotFather (640x360)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla al formato requerido para configurar la imagen de descripción para el bot en @BotFather (640x360)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour la convertir au format requis pour définir l'image de description du bot dans @BotFather (640x360)",
    'zh': "👩🏽‍💻<b>附加</b>一张照片，将其转换为在@BotFather中为机器人设置描述图片所需的格式（640x360）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى التنسيق المطلوب لتعيين صورة الوصف للروبوت في @BotFather (640x360)",
}
l_image_watermark_attach = {
    'ru': "👩🏽‍💻 <b>Отправь</b> фото с подписью для текста водяного знака до 32 символов",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert it to the format required to set the Description Picture for the bot in @BotFather (640x360)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla al formato requerido para configurar la imagen de descripción para el bot en @BotFather (640x360)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour la convertir au format requis pour définir l'image de description du bot dans @BotFather (640x360)",
    'zh': "👩🏽‍💻<b>附加</b>一张照片，将其转换为在@BotFather中为机器人设置描述图片所需的格式（640x360）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى التنسيق المطلوب لتعيين صورة الوصف للروبوت في @BotFather (640x360)",
}
l_image_watermark_error = {
    'ru': "👩🏽‍💻 <b>Необходимо</b> отправить файл вместе с подписью",
    'en': "👩🏽‍💻 <b>Attach</b> a photo to convert it to the format required to set the Description Picture for the bot in @BotFather (640x360)",
    'es': "👩🏽‍💻 <b>Adjunte</b> una foto para convertirla al formato requerido para configurar la imagen de descripción para el bot en @BotFather (640x360)",
    'fr': "👩🏽‍💻 <b>Joindre</b> une photo pour la convertir au format requis pour définir l'image de description du bot dans @BotFather (640x360)",
    'zh': "👩🏽‍💻<b>附加</b>一张照片，将其转换为在@BotFather中为机器人设置描述图片所需的格式（640x360）",
    'ar': "👩🏽‍💻 <b>أرفق</b> صورة لتحويلها إلى التنسيق المطلوب لتعيين صورة الوصف للروبوت في @BotFather (640x360)",
}

l_gif_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>гиф</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>GIF</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>GIF</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir les <i>GIF</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>GIF</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>GIF</i> إلى",
}
l_gif_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥mp4",
    'fr': "🎥mp4",
    'zh': "🎥mp4",
    'ar': "🎥 mp4",
}
l_gif_thumb = {
    'ru': "🖼️ ico",
    'en': "🖼️ ico",
    'es': "🖼️ico",
    'fr': "🖼️icône",
    'zh': "🖼️ ico",
    'ar': "🖼️ إيكو",
}
l_gif_descgif = {
    'ru': "⿴ Bot Desc Gif",
    'en': "⿴ Bottom Desc Gif",
    'es': "⿴ Gif de descripción inferior",
    'fr': "⿴ Gif de description du bas",
    'zh': "⿴ 底部描述 Gif",
    'ar': "⿴ صورة متحركة للأسفل",
}
l_gif_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в mp4",
    'en': "👩🏽‍💻 <b>Attach</b> GIF to convert to mp4",
    'es': "👩🏽‍💻 <b>Adjunte</b> GIF para convertir a mp4",
    'fr': "👩🏽‍💻 <b>Joindre</b> GIF pour convertir en mp4",
    'zh': "👩🏽‍💻 <b>附加</b> GIF 以转换为 mp4",
    'ar': "👩🏽‍💻 <b>أرفق</b> ملف GIF للتحويل إلى mp4",
}
l_gif_thumb_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в ico-иконку (320x320)",
    'en': "👩🏽‍💻 <b>Attach</b> GIF to convert to ico icon (320x320)",
    'es': "👩🏽‍💻 <b>Adjunte</b> GIF para convertirlo en ícono ico (320x320)",
    'fr': "👩🏽‍💻 <b>Joindre</b> GIF pour convertir en icône ico (320x320)",
    'zh': "👩🏽‍💻 <b>附加</b> GIF 转换为 ico 图标 (320x320)",
    'ar': "👩🏽‍💻 <b>أرفق</b> ملف GIF لتحويله إلى أيقونة ico (160×160)",
}
l_gif_descgif_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> гиф для преобразования в формат, необходимый для установки Description Gif для бота в @BotFather (640x360). После формирования GIF нажимаем на нее через <u>мобильное</u> приложение (ожидая загрузки), далее Поделиться - приложение Telegram - @BotFather",
    'en': "👩🏽‍💻 <b>Attach</b> the GIF to convert to the format required to set the Description Gif for the bot in @BotFather (640x360). After generating the GIF, click on it through the <u>mobile</u> application (waiting for loading), then Share-Telegram application-@BotFather",
    'es': "👩🏽‍💻 <b>Adjunte</b> el GIF para convertirlo al formato requerido para configurar el GIF de descripción para el bot en @BotFather (640x360). Después de generar el GIF, haga clic en él a través de la aplicación <u>móvil</u> (esperando a que se cargue), luego Compartir-Aplicación Telegram-@BotFather",
    'fr': "👩🏽‍💻 <b>Joignez</b> le GIF à convertir au format requis pour définir le Gif de description du bot dans @BotFather (640x360). Après avoir généré le GIF, cliquez dessus via l'application <u>mobile</u> (en attente de chargement), puis Partager-Application Telegram-@BotFather",
    'zh': "👩🏽‍💻 <b>附加</b> GIF 以转换为在@BotFather (640x360) 中为机器人设置说明 Gif 所需的格式。生成 GIF 后，通过<u>移动</u>应用程序点击它（等待加载），然后分享-Telegram 应用程序-@BotFather",
    'ar': "👩🏽‍💻 <b>أرفق</b> ملف GIF للتحويل إلى التنسيق المطلوب لتعيين ملف Gif الوصفي للروبوت في @BotFather (640x360). بعد إنشاء الصورة المتحركة GIF اضغط عليها عبر تطبيق <u>الموبايل</u> (في انتظار التحميل)، ثم مشاركة-تطبيق تيليجرام-@BotFather",
}

l_video_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>видео</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>video</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>vídeo</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir la <i>vidéo</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>视频</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>الفيديو</i> إلى",
}
l_video_mp3 = {
    'ru': "▶️ mp3",
    'en': "▶️ mp3",
    'es': "▶️mp3",
    'fr': "▶️mp3",
    'zh': "▶️mp3",
    'ar': "▶️ mp3",
}
l_video_mp4 = {
    'ru': "🎥 mp4",
    'en': "🎥 mp4",
    'es': "🎥mp4",
    'fr': "🎥mp4",
    'zh': "🎥mp4",
    'ar': "🎥 mp4",
}
l_video_album = {
    'ru': "9️⃣ альбом⁹",
    'en': "9️⃣ album⁹",
    'es': "9️⃣ álbum⁹",
    'fr': "9️⃣album⁹",
    'zh': "9️⃣ 专辑⁹",
    'ar': "9️⃣ الألبوم⁹",
}
l_video_slide = {
    'ru': "1️⃣ слайд¹",
    'en': "9️⃣ album⁹",
    'es': "9️⃣ álbum⁹",
    'fr': "9️⃣album⁹",
    'zh': "9️⃣ 专辑⁹",
    'ar': "9️⃣ الألبوم⁹",
}
l_video_thumb = {
    'ru': "🖼️ ico",
    'en': "🖼️ ico",
    'es': "🖼️ico",
    'fr': "🖼️icône",
    'zh': "🖼️ ico",
    'ar': "🖼️ إيكو",
}
l_video_gif = {
    'ru': "📽️ gif",
    'en': "📽️ gif",
    'es': "📽️ gif",
    'fr': "📽️ gifs",
    'zh': "📽️gif",
    'ar': "📽️ جيف",
}
l_video_sticker = {
    'ru': "🌌 стикер",
    'en': "🖼️ ico",
    'es': "🖼️ico",
    'fr': "🖼️icône",
    'zh': "🖼️ ico",
    'ar': "🖼️ إيكو",
}
l_video_videonote = {
    'ru': "⚫️ телескоп",
    'en': "⚫️ telescope",
    'es': "⚫️ telescopio",
    'fr': "⚫️ télescope",
    'zh': "⚫️望远镜",
    'ar': "⚫️ التلسكوب",
}
l_video_slice = {
    'ru': "🔪 Срез",
    'en': "⚫️ telescope",
    'es': "⚫️ telescopio",
    'fr': "⚫️ télescope",
    'zh': "⚫️望远镜",
    'ar': "⚫️ التلسكوب",
}
l_video_slice_mini = {
    'ru': "🔪 срез",
    'en': "⚫️ telescope",
    'es': "⚫️ telescopio",
    'fr': "⚫️ télescope",
    'zh': "⚫️望远镜",
    'ar': "⚫️ التلسكوب",
}
l_video_transcribe = {
    'ru': "🗣️ транскрибация",
    'en': "🗣️ transcription",
    'es': "🗣️ transcripción",
    'fr': "🗣️ transcription",
    'zh': "🗣️转录",
    'ar': "🗣️ النسخ",
}
l_video_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp3-аудио",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to mp3 audio",
    'es': "👩🏽‍💻 <b>Adjunte</b> video para convertir a audio mp3",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo pour la convertir en audio mp3",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为mp3音频",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى صوت mp3",
}
l_video_mp4_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в mp4",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to mp4",
    'es': "👩🏽‍💻 <b>Adjunte</b> video para convertir a mp4",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en mp4",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为mp4",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى mp4",
}
l_video_gif_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в гиф",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to GIF",
    'es': "👩🏽‍💻 <b>Adjunte</b> vídeo para convertirlo a GIF",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en GIF",
    'zh': "👩🏽‍💻 <b>附加</b>视频以转换为 GIF",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى GIF",
}
l_video_thumb_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в ico-иконку (320x320)",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to ico icon (320x320)",
    'es': "👩🏽‍💻 <b>Adjunte</b> video para convertirlo en ícono ico (320x320)",
    'fr': "👩🏽‍💻 <b>Joindre</b> la vidéo à convertir en icône ico (320x320)",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为ico图标（320x320）",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى أيقونة ico (160×160)",
}
l_video_sticker_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> фото/видео для преобразования в видео-стикер",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to GIF",
    'es': "👩🏽‍💻 <b>Adjunte</b> vídeo para convertirlo a GIF",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo à convertir en GIF",
    'zh': "👩🏽‍💻 <b>附加</b>视频以转换为 GIF",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى GIF",
}
l_video_album_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в альбом из 9 частей",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert into a 9-part album",
    'es': "👩🏽‍💻 <b>Adjunte</b> vídeo para convertirlo en un álbum de 9 partes",
    'fr': "👩🏽‍💻 <b>Joindre</b> la vidéo pour la convertir en un album en 9 parties",
    'zh': "👩🏽‍💻 <b>附加</b>视频以转换为 9 部分专辑",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى ألبوم مكون من 9 أجزاء",
}
l_video_slide_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> альбом из нескольких видео до 1мин для преобразования в слайдшоу",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert into a 9-part album",
    'es': "👩🏽‍💻 <b>Adjunte</b> vídeo para convertirlo en un álbum de 9 partes",
    'fr': "👩🏽‍💻 <b>Joindre</b> la vidéo pour la convertir en un album en 9 parties",
    'zh': "👩🏽‍💻 <b>附加</b>视频以转换为 9 部分专辑",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو لتحويله إلى ألبوم مكون من 9 أجزاء",
}
l_video_videonote_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в телескоп (круглую видео-заметку)",
    'en': "👩🏽‍💻 <b>Attach</b> video to convert to telescope (round video note)",
    'es': "👩🏽‍💻 <b>Adjunte</b> video para convertir a telescopio (nota de video redonda)",
    'fr': "👩🏽‍💻 <b>Joindre</b> la vidéo à convertir en télescope (note vidéo ronde)",
    'zh': "👩🏽‍💻<b>附加</b>视频以转换为望远镜（圆形视频注释）",
    'ar': "👩🏽‍💻 <b>أرفق</b> فيديو لتحويله إلى تلسكوب (ملاحظة فيديو مستديرة)",
}
l_video_slice_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> видео для преобразования в узкую видео-полоску (срез)",
    'en': "🙌🏽 remove background",
    'es': "🙌🏽 eliminar fondo",
    'fr': "🙌🏽 supprimer l'arrière-plan",
    'zh': "🙌🏽 删除背景",
    'ar': "🙌🏽 إزالة الخلفية",
}
l_video_transcribe_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> круглую видео-заметку для преобразования в текст",
    'en': "👩🏽‍💻 <b>Attach</b> round video to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> video redondo para convertirlo a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo ronde à convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>圆形视频以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو دائريًا لتحويله إلى نص",
}

l_audio_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>audio</i> в",
    'en': "👩🏽‍💻 <b>Select</b> tools to convert <i>audio</i> to",
    'es': "👩🏽‍💻 <b>Seleccione</b> herramientas para convertir <i>audio</i> a",
    'fr': "👩🏽‍💻 <b>Sélectionnez</b> les outils pour convertir l'<i>audio</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>音频</i>转换为",
    'ar': "👩🏽‍💻 <b>حدد</b> الأدوات لتحويل <i>الصوت</i> إلى",
}
l_audio_mp3 = {
    'ru': "▶️ mp3-аудио",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ mp3-audio",
    'zh': "▶️ mp3音频",
    'ar': "◀️ mp3-صوت",
}
l_audio_ogg = {
    'ru': "🎤 ogg-голосовое",
    'en': "🎤 ogg-voice",
    'es': "🎤 voz-ogg",
    'fr': "🎤 ogg-voix",
    'zh': "🎤 ogg 声音",
    'ar': "🎤 صوت البيض",
}
l_audio_transcribe = {
    'ru': "🗣️ транскрибация",
    'en': "🗣️ transcription",
    'es': "🗣️ transcripción",
    'fr': "🗣️ transcription",
    'zh': "🗣️转录",
    'ar': "🗣️ النسخ",
}
l_audio_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в mp3",
    'en': "👩🏽‍💻 <b>Attach</b> voice to convert to mp3",
    'es': "👩🏽‍💻 <b>Adjunte</b> voz para convertir a mp3",
    'fr': "👩🏽‍💻 <b>Joindre</b> la voix pour convertir en mp3",
    'zh': "👩🏽‍💻<b>附加</b>语音以转换为mp3",
    'ar': "👩🏽‍💻 <b>أرفق</b> صوتًا لتحويله إلى mp3",
}
l_audio_ogg_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> audio для преобразования в голосовое",
    'en': "👩🏽‍💻 <b>Attach</b> audio to convert to voice",
    'es': "👩🏽‍💻 <b>Adjunte</b> audio para convertirlo a voz",
    'fr': "👩🏽‍💻 <b>Joindre</b> l'audio pour le convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>音频以转换为语音",
    'ar': "👩🏽‍💻 <b>أرفق</b> الصوت لتحويله إلى صوت",
}
l_audio_transcribe_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> голосовое для преобразования в текст",
    'en': "👩🏽‍💻 <b>Attach</b> voice to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> voz para convertir a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> la voix pour la convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>语音以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> صوتًا لتحويله إلى نص",
}
l_audio_recognize = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> распознавания речи",
    'en': "👩🏽‍💻 <b>Error</b> speech recognition",
    'es': "👩🏽‍💻 <b>Error</b> en reconocimiento de voz",
    'fr': "👩🏽‍💻 <b>Erreur</b> reconnaissance vocale",
    'zh': "👩🏽‍💻<b>错误</b>语音识别",
    'ar': "👩🏽‍💻 <b>خطأ</b> في التعرف على الكلام",
}

l_text_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> инструменты для преобразования <i>текста</i> в",
    'en': "👩🏽‍💻 <b>Choose</b> tools to convert <i>text</i> to",
    'es': "👩🏽‍💻 <b>Elija</b> herramientas para convertir <i>texto</i> a",
    'fr': "👩🏽‍💻 <b>Choisissez</b> les outils pour convertir le <i>texte</i> en",
    'zh': "👩🏽‍💻<b>选择</b>工具将<i>文本</i>转换为",
    'ar': "👩🏽‍💻 <b>اختر</b> الأدوات لتحويل <i>النص</i> إلى",
}
l_text_ocr = {
    'ru': "🔣 ocr",
    'en': "🔣 ocr",
    'es': "🔣ocr",
    'fr': "🔣ocr",
    'zh': "🔣OCR",
    'ar': "🔣 أوكر",
}
l_text_bin = {
    'ru': "🔢 bin",
    'en': "🔢 bin",
    'es': "🔢 contenedor",
    'fr': "🔢 poubelle",
    'zh': "🔢 垃圾箱",
    'ar': "🔢 بن",
}
l_text_hex = {
    'ru': "🔠 hex",
    'en': "🔠 hex",
    'es': "🔠 maleficio",
    'fr': "🔠hexagone",
    'zh': "🔠 十六进制",
    'ar': "🔠 عرافة",
}
l_text_null = {
    'ru': "0️⃣ null",
    'en': "0️⃣ null",
    'es': "0️⃣ nulo",
    'fr': "0️⃣ nul",
    'zh': "0️⃣ 空",
    'ar': "0️⃣ لاغية",
}
l_text_mp3 = {
    'ru': "▶️ mp3-аудио",
    'en': "▶️ mp3-audio",
    'es': "▶️ audio mp3",
    'fr': "▶️ mp3-audio",
    'zh': "▶️ mp3音频",
    'ar': "◀️ mp3-صوت",
}
l_text_url = {
    'ru': "️🧾 url-encode",
    'en': "️🧾 url-encode",
    'es': "️🧾 codificación de URL",
    'fr': "️🧾 encodage d'url",
    'zh': "️🧾 url 编码",
    'ar': "️🧾 ترميز URL",
}
l_text_ocr_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> файл для оптического распознавания текста",
    'en': "👩🏽‍💻 <b>Attach</b> file for optical text recognition",
    'es': "👩🏽‍💻 <b>Adjuntar</b> archivo para reconocimiento óptico de texto",
    'fr': "👩🏽‍💻 Fichier <b>Joindre</b> pour la reconnaissance optique de texte",
    'zh': "👩🏽‍💻<b>附加</b>文件以进行光学文本识别",
    'ar': "👩🏽‍💻 <b>أرفق</b> ملفًا للتعرف البصري على النص",
}
l_text_bin_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в байтовый вид",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to byte form",
    'es': "👩🏽‍💻 <b>Adjunte</b> texto para convertirlo a formato de bytes",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte à convertir en octet",
    'zh': "👩🏽‍💻 <b>附加</b>文本以转换为字节形式",
    'ar': "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى نموذج بايت",
}
l_text_hex_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в hex-символы (шестнадцатиричное представление байт)",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to hex characters (hexadecimal representation of bytes)",
    'es': "👩🏽‍💻 <b>Adjunte</b> texto para convertir a caracteres hexadecimales (representación hexadecimal de bytes)",
    'fr': "👩🏽‍💻 <b>Joindre</b> le texte à convertir en caractères hexadécimaux (représentation hexadécimale des octets)",
    'zh': "👩🏽‍💻 <b>附加</b>文本以转换为十六进制字符（字节的十六进制表示）",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويله إلى أحرف سداسية (تمثيل سداسي عشري للبايتات)",
}
l_text_mp3_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для преобразования в голосовое",
    'en': "👩🏽‍💻 <b>Attach</b> text to convert to voice",
    'es': "👩🏽‍💻 <b>Adjunte</b> texto para convertir a voz",
    'fr': "👩🏽‍💻 <b>Joindre</b> du texte à convertir en voix",
    'zh': "👩🏽‍💻<b>附加</b>文本以转换为语音",
    'ar': "👩🏽‍💻 <b>أرفق</b> نصًا لتحويله إلى صوت",
}
l_text_url_attach = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> текст для url-encode-преобразования (процентное и шестнадцатиричное кодирование как правило https-ссылок)",
    'en': "👩🏽‍💻 <b>Attach</b> text for url-encode conversion (percentage and hex encoding, usually https links)",
    'es': "👩🏽‍💻 <b>Adjunte</b> texto para la conversión de codificación de URL (codificación porcentual y hexadecimal, generalmente enlaces https)",
    'fr': "👩🏽‍💻 Texte <b>Joindre</b> pour la conversion encodage URL (en pourcentage et encodage hexadécimal, généralement des liens https)",
    'zh': "👩🏽‍💻<b>附加</b>文本进行url编码转换（百分比和十六进制编码，通常是https链接）",
    'ar': "👩🏽‍💻 <b>إرفاق</b> نص لتحويل ترميز URL (النسبة المئوية والتشفير السداسي، عادةً روابط https)",
}
l_text_text1024 = {
    'ru': "💭 Текст 1024 символа",
    'en': "💭 Text 1024 characters",
    'es': "💭 Texto de 1024 caracteres",
    'fr': "💭 Texte 1024 caractères",
    'zh': "💭 文本 1024 个字符",
    'ar': "💭 نص 1024 حرفًا",
}
l_text_text4096 = {
    'ru': "🗯️ Текст 4096 символа",
    'en': "🗯️ Text 4096 characters",
    'es': "🗯️ Texto de 4096 caracteres",
    'fr': "🗯️ Texte de 4096 caractères",
    'zh': "🗯️短信4096个字符",
    'ar': "🗯️ أرسل 4096 حرفًا",
}

l_convert_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> преобразования контента (попробуй позже или загрузи другой файл)",
    'en': "👩🏽‍💻 <b>Error</b> content conversion (try later or upload another file)",
    'es': "👩🏽‍💻 <b>Error</b> en la conversión de contenido (inténtalo más tarde o sube otro archivo)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de la conversion du contenu (essayez plus tard ou téléchargez un autre fichier)",
    'zh': "👩🏽‍💻 <b>错误</b>内容转换（稍后尝试或上传其他文件）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في تحويل المحتوى (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_convert_more_one = {
    'ru': "👩🏽‍💻 <b>Загрузи</b> более 1го файла как альбом",
    'en': "👩🏽‍💻 <b>Error</b> content conversion (try later or upload another file)",
    'es': "👩🏽‍💻 <b>Error</b> en la conversión de contenido (inténtalo más tarde o sube otro archivo)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de la conversion du contenu (essayez plus tard ou téléchargez un autre fichier)",
    'zh': "👩🏽‍💻 <b>错误</b>内容转换（稍后尝试或上传其他文件）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في تحويل المحتوى (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_telegraph_text = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> .jpg/.png/.gif/.mp4 - контент, чтобы создать ссылку",
    'en': "👩🏽‍💻 <b>Attach</b> .jpg/.png/.gif/.mp4-content to create a link",
    'es': "👩🏽‍💻 <b>Adjuntar</b> .jpg/.png/.gif/.mp4-contenido para crear un enlace",
    'fr': "👩🏽‍💻 <b>Joindre</b> .jpg/.png/.gif/.mp4-contenu pour créer un lien",
    'zh': "👩🏽‍💻 <b>附加</b> .jpg/.png/.gif/.mp4-用于创建链接的内容",
    'ar': "👩🏽‍💻 <b>أرفق</b> .jpg/.png/.gif/.mp4-محتوى لإنشاء رابط",
}
l_telegraph_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> получения ссылки (попробуй позже или загрузи другой файл)",
    'en': "👩🏽‍💻 <b>Error</b> receiving link (try later or upload another file)",
    'es': "👩🏽‍💻 <b>Error</b> al recibir el enlace (inténtalo más tarde o sube otro archivo)",
    'fr': "👩🏽‍💻 <b>Erreur</b> lors de la réception du lien (essayez plus tard ou téléchargez un autre fichier)",
    'zh': "👩🏽‍💻 <b>接收链接时出错</b>（稍后再试或上传其他文件）",
    'ar': "👩🏽‍💻 <b>خطأ</b> في استلام الرابط (حاول لاحقًا أو قم بتحميل ملف آخر)",
}
l_json_text = {
    'ru': "👩🏽‍💻 <b>Прикрепи</b> любое сообщение или сделай пересылку",
    'en': "👩🏽‍💻 <b>Attach</b> any message or forward",
    'es': "👩🏽‍💻 <b>Adjuntar</b> cualquier mensaje o reenviar",
    'fr': "👩🏽‍💻 <b>Joindre</b> n'importe quel message ou transférer",
    'zh': "👩🏽‍💻<b>附加</b>任何消息或转发",
    'ar': "👩🏽‍💻 <b>أرفق</b> أي رسالة أو أعد توجيهها",
}

l_sticker_circle_on = {
    'ru': "✅ Закруглить",
    'en': "👩🏽‍💻 <b>Attach</b> round video to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> video redondo para convertirlo a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo ronde à convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>圆形视频以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو دائريًا لتحويله إلى نص",
}
l_sticker_circle_off = {
    'ru': "☑️ Закруглить",
    'en': "👩🏽‍💻 <b>Attach</b> round video to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> video redondo para convertirlo a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo ronde à convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>圆形视频以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو دائريًا لتحويله إلى نص",
}
l_sticker_rbg_on = {
    'ru': "✅ Удалить фон",
    'en': "👩🏽‍💻 <b>Attach</b> round video to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> video redondo para convertirlo a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo ronde à convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>圆形视频以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو دائريًا لتحويله إلى نص",
}
l_sticker_rbg_off = {
    'ru': "☑️ Удалить фон",
    'en': "👩🏽‍💻 <b>Attach</b> round video to convert to text",
    'es': "👩🏽‍💻 <b>Adjunte</b> video redondo para convertirlo a texto",
    'fr': "👩🏽‍💻 <b>Joindre</b> une vidéo ronde à convertir en texte",
    'zh': "👩🏽‍💻<b>附加</b>圆形视频以转换为文本",
    'ar': "👩🏽‍💻 <b>أرفق</b> مقطع فيديو دائريًا لتحويله إلى نص",
}
# endregion


# region FereyTargetBot
l_subscribe_target = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [<b>Донат</b> на баланс]:\n<blockquote>▪️рассылка/приглашения\n▪️редактирование чаевых\n(<i>чтобы указать точную сумму</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [<b> Donate</b>to balance]:\n▪️mailing/invitations\n▪️editing tips\n(<i>to indicate the exact amount</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [< b> Donar</b>al saldo]:\n▪️correo/invitaciones\n▪️consejos de edición\n(<i>para indicar la cantidad exacta</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [< b> Faire un don</b>pour équilibrer] :\n▪️mailing/invitations\n▪️conseils d'édition\n(<i>pour indiquer le montant exact</i>)\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [< b> 捐款</b>达到余额]：\n▪️邮寄/邀请\n▪️编辑提示\n（<i>指明确切金额</i>）\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [< b> التبرع</b>للرصيد]:\n▪️mailing/invitations\n▪️نصائح التحرير\n(<i>للإشارة إلى المبلغ المحدد</i>)\n\n👩🏽‍💻 /balance",
}
# endregion


# region FereyAdsBot
l_ads_btn1 = {
    'ru': "👩🏽‍💻 Посты",
    'en': "👩🏽‍💻 Posts",
    'es': "👩🏽‍💻 Publicaciones",
    'fr': "👩🏽‍💻 Messages",
    'zh': "👩🏽‍💻 帖子",
    'ar': "👩🏽‍💻 المشاركات",
}
l_ads_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_ads_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> создания креативных постов:\n\n<blockquote>▪️️реклама в ferey-проектах\n▪️️заказ рекламы на канале</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> for creating creative posts <b>Ferey</b>:\n\n▪️️advertising in ferey-projects\n▪️ ️order advertising on the channel\n\n❗️<b>Regular</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> para crear publicaciones creativas <b>Ferey</b>:\n\n▪️️publicidad en ferey-projects\n▪️ ️pedir publicidad en el canal\n\n❗️<b>Regular</b>-actualizado /contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> pour créer des publications créatives <b>Ferey</b> :\n\nƒ️️publicité dans les projets ferey\nwithout ️commander de la publicité sur la chaîne\n\n❗️<b>Régulier</b>-mis à jour/contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i>来创建创意帖子<b>Ferey</b>：\n\n▪️️ferey-projects 中的广告\n▪️ ️在频道上订购广告\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء منشورات إبداعية <b>Ferey</b>:\n\n▪️️الإعلان في مشاريع ferey\n▪️ ️اطلب الإعلان على القناة\n\n❗️<b>عادي</b>-محدث/محتوى",
}

l_subscribe_ads = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [<b>Донат</b> на баланс]:\n<blockquote>▪️рассылка по всем ботам\n▪️редактирование чаевых\n(<i>чтобы указать точную сумму</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [<b> Donate</b>to balance]:\n▪️mailing to all bots\n▪️editing tips\n(<i>to indicate the exact amount</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [< b> Donar</b>al saldo]:\n▪️enviar por correo a todos los bots\n▪️consejos de edición\n(<i>para indicar la cantidad exacta</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [< b> Faire un don</b> pour équilibrer] :\n▪️envoi par mail à tous les robots\n▪️conseils d'édition\n(<i>pour indiquer le montant exact</i>)\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [< b> 捐赠</b>以平衡]：\n▪️邮寄给所有机器人\n▪️编辑提示\n（<i>指示确切金额</i>）\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [< b> التبرع</b>للرصيد]:\n▪️إرسال بريد إلكتروني إلى جميع الروبوتات\n▪️نصائح التعديل\n(<i>للإشارة إلى المبلغ الدقيق</i>)\n\n👩🏽‍💻 /balance",
}

l_post_media_ads = {
    'ru': "✏️ 2. Прикрепи <b>медиа</b> контент: фото/гиф/видео до 5Mb\n\n<blockquote>или жми «➡️️/Next», чтобы пропустить этот шаг</blockquote>",
    'en': "✏️ 2. Attach <b>media</b> content: photo/GIF/video up to 5Mb\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 2. Adjunte contenido <b>media</b>: foto/GIF/vídeo de hasta 5 Mb\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 2. Joignez du contenu <b>média</b> : photo/GIF/vidéo jusqu'à 5 Mo\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 2. 附加<b>媒体</b>内容：照片/GIF/视频，最大5Mb\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 2. قم بإرفاق محتوى <b>وسائط</b>: صورة/GIF/فيديو يصل حجمه إلى 5 ميجابايت\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
# endregion


# region FereyVPNBot
l_vpn_btn1 = {
    'ru': "👩🏽‍💻 VPN",
    'en': "👩🏽‍💻 VPN",
    'es': "👩🏽‍💻VPN",
    'fr': "👩🏽‍💻VPN",
    'zh': "👩🏽‍💻VPN",
    'ar': "👩🏽‍💻 VPN",
}
l_vpn_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_vpn_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i>:\n\n<blockquote>▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b></blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> of the Ferey project:\n\n▪️<b>open vpn</b>\n▪️<b>wire guard </b>\n▪️<b>shadow socks</b>\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> del proyecto Ferey:\n\n▪️<b>open vpn</b>\n▪️<b>wire guardia </b>\n▪️<b>calcetines de sombra</b>\n\n❗️<b>Actualizado periódicamente</b>/content",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> du projet Ferey :\n\nnoyer<b>open vpn</b>\nnoyer<b>wire garde </b>\n▪️<b>chaussettes fantômes</b>\n\n❗️<b>Régulièrement</b>-mis à jour / contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用 Ferey 项目的<i>登陆机器人</i>：\n\n▪️<b>开放VPN</b>\n▪️<b>wire守护</b>\n▪️<b>影子袜子</b>\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت الهبوطي</i> لمشروع Ferey:\n\n▪️<b>open vpn</b>\n▪️<b>wire حارس </b>\n▪️<b>جوارب الظل</b>\n\n❗️<b>بانتظام</b>-يتم تحديث /المحتوى",
}
l_subscribe_vpn = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}

l_vpn_1 = {
    'ru': "👩🏽‍💻 <b>Open vpn</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Open vpn</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Abrir VPN</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Ouvrir le VPN</b>\n\n{0}",
    'zh': "👩🏽‍💻 <b>打开 VPN</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>فتح VPN</b>\n\n{0}",
}
l_vpn_2 = {
    'ru': "👩🏽‍💻 <b>Wire guard</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Wire guard</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Protector de alambre</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Grille de protection</b>\n\n{0}",
    'zh': "👩🏽‍💻<b>电线护罩</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>واقي الأسلاك</b>\n\n{0}",
}
l_vpn_3 = {
    'ru': "👩🏽‍💻 <b>Shadow socks</b>\n\n{0}",
    'en': "👩🏽‍💻 <b>Shadow socks</b>\n\n{0}",
    'es': "👩🏽‍💻 <b>Calcetines de sombras</b>\n\n{0}",
    'fr': "👩🏽‍💻 <b>Chaussettes ombre</b>\n\n{0}",
    'zh': "👩🏽‍💻 <b>影子袜子</b>\n\n{0}",
    'ar': "👩🏽‍💻 <b>جوارب الظل</b>\n\n{0}",
}
# endregion


# region FereyWorkBot
l_work_btn1 = {
    'ru': "👩🏽‍💻 Вакансии",
    'en': "👩🏽‍💻Vacancies",
    'es': "👩🏽‍💻Vacantes",
    'fr': "👩🏽‍💻Postes vacants",
    'zh': "👩🏽‍💻职位空缺",
    'ar': "👩🏽‍💻 وظائف شاغرة",
}
l_work_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_work_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> вакансий <b>Ferey</b>-проекта:\n\n<blockquote>▪️<b>вакансии</b> проекта\n▪️конкурсы и <b>задания</b>\n▪️<b>партнеры</b> и инвесторы\n▪️услуги и <b>пожертвования</b></blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> vacancies of the <b>Ferey</b>-project:\n\n▪️<b>vacancies</b> project\n▪️competitions and <b>tasks</b>\n▪️<b>partners</b> and investors\n▪️services and <b>donations</b>\n\n❗️<b>Regularly< /b>-updatable /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> vacantes del proyecto <b>Ferey</b>:\n\n▪️<b>vacantes</b > proyecto\n▪️concursos y <b>tareas</b>\n▪️<b>socios</b> e inversores\n▪️servicios y <b>donaciones</b>\n\n❗️<b>Regularmente < /b>-actualizable /contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur les <i>landing bot</i> postes vacants du <b>projet Ferey</b> :\n\nnoyer<b>postes vacants</b > projets\n▪️compétitions et <b>tâches</b>\n▪️<b>partenaires</b> et investisseurs\n▪️services et <b>dons</b>\n\n❗️<b>Régulièrement < /b>-modifiable /content",
    'zh': "🌱 <b>{0}</b>，欢迎使用 <b>Ferey</b> 项目的<i>登陆机器人</i>职位空缺：\n\n▪️<b>空缺</b > 项目\n▪️竞赛和<b>任务</b>\n▪️<b>合作伙伴</b>和投资者\n▪️服务和<b>捐赠</b>\n\n❗️<b>定期</b>-可更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الهبوط الآلي</i> الوظائف الشاغرة في <b>Ferey</b>-project:\n\n▪️<b>الوظائف الشاغرة</b > المشروع\n▪️المسابقات و<b>المهام</b>\n▪️<b>الشركاء</b> والمستثمرون\n▪️الخدمات و<b>التبرعات</b>\n\n❗️<b>بانتظام </b>-محتوى /قابل للتحديث",
}
l_subscribe_work = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}

l_vacancy_1 = {
    'ru': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\n<blockquote><b>Tasks</b>: create <i>ferey-masks</i> (realistic video) for any human\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Text to video ai-designer</b>\n\n<b>Tasks</b>: create <i>ferey-masks</i> (realistic video) for any human\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Diseñador de texto a vídeo</b>\n\n<b>Tareas</b>: crear <i>máscaras ferey</i> (vídeo realista) para cualquier humano\n<b>Género</b>: niña\n<b>Edad</b>: menos de 30\n<b>Pago</b>: participación en la empresa",
    'fr': "👩🏽‍💻 <b>Texte vers vidéo ai-designer</b>\n\n<b>Tâches</b> : créer des <i>masques ferey</i> (vidéo réaliste) pour n'importe quel humain\n<b>Sexe</b> : fille\n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : part de l'entreprise",
    'zh': "👩🏽‍💻<b>文本到视频人工智能设计师</b>\n\n<b>任务</b>：为任何人创建<i>ferey-masks</i>（逼真的视频）\n<b>性别</b>：女孩\n<b>年龄</b>：30岁以下\n<b>薪酬</b>：公司股份",
    'ar': "👩🏽‍💻 <b>مصمم الذكاء الاصطناعي لتحويل النص إلى فيديو</b>\n\n<b>المهام</b>: إنشاء <i>أقنعة فيري</i> (فيديو واقعي) لأي إنسان\n<b>الجنس</b>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_2 = {
    'ru': "👩🏽‍💻 <b>Content/video maker</b>\n\n<blockquote><b>Tasks</b>: generate creatives for all <i>ferey-socials</i>\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: 1 TON per 1 post</blockquote>",
    'en': "👩🏽‍💻 <b>Content/video maker</b>\n\n<b>Tasks</b>: generate creatives for all <i>ferey-socials</i>\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: 1 TON per 1 post",
    'es': "👩🏽‍💻 <b>Creador de contenido/video</b>\n\n<b>Tareas</b>: generar creatividades para todos los <i>ferey-socials</i>\n<b>Género</ b>: chica\n<b>Edad</b>: menos de 30\n<b>Pago</b>: 1 TONELADA por 1 publicación",
    'fr': "👩🏽‍💻 <b>Créateur de contenu/vidéo</b>\n\n<b>Tâches</b> : générer des créations pour tous les <i>ferey-socials</i>\n<b>Genre</ b> : fille\n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : 1 TON pour 1 message",
    'zh': "👩🏽‍💻<b>内容/视频制作者</b>\n\n<b>任务</b>：为所有<i>ferey-socials</i>\n<b>性别生成广告素材</b> b>：女孩\n<b>年龄</b>：小于 30\n<b>报酬</b>：每 1 个帖子 1 TON",
    'ar': "👩🏽‍💻 <b>صانع المحتوى/الفيديو</b>\n\n<b>المهام</b>: إنشاء تصميمات إبداعية لجميع <i>الشبكات الاجتماعية</i>\n<b>الجنس</ ب>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: 1 طن لكل مشاركة واحدة",
}
l_vacancy_3 = {
    'ru': "👩🏽‍💻 <b>TON-api-space/TWA/Aio/pyro/hydro-gram developer</b>\n\n<blockquote><b>Tasks</b>: dev and support all projects\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>TWA/Aio/pyro-gram developer</b>\n\n<b>Tasks</b>: dev and support all projects\n<b>Gender</b>: girl\n<b>Age</b>: less than 30\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Desarrollador TWA/Aio/pyro-gram</b>\n\n<b>Tareas</b>: desarrollo y soporte de todos los proyectos\n<b>Género</b>: niña\ n<b>Edad</b>: menos de 30\n<b>Pago</b>: participación en la empresa",
    'fr': "👩🏽‍💻 <b>Développeur TWA/Aio/pyro-gram</b>\n\n<b>Tâches</b> : développer et soutenir tous les projets\n<b>Genre</b> : fille\ n<b>Âge</b> : moins de 30 ans\n<b>Salaire</b> : part de l'entreprise",
    'zh': "👩🏽‍💻 <b>TWA/Aio/pyro-gram 开发人员</b>\n\n<b>任务</b>：开发和支持所有项目\n<b>性别</b>：女孩\ n<b>年龄</b>：30岁以下\n<b>薪酬</b>：公司股份",
    'ar': "👩🏽‍💻 <b>مطور TWA/Aio/pyro-gram</b>\n\n<b>المهام</b>: تطوير ودعم جميع المشاريع\n<b>الجنس</b>: فتاة\n<b>العمر</b>: أقل من 30\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_4 = {
    'ru': "👩🏽‍💻 <b>Telegram Ads - partner/investor</b>\n\n<blockquote><b>Investment</b>: <a href='https://promote.telegram.org/account/budget/add_funds'>€2,000,000</a>\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Telegram Ads-partner/investor</b>\n\n<b>Investment</b>: <a href='https://promote.telegram.org/account/budget/add_funds'>€2,000,000</a>\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Anuncios de Telegram: socio/inversor</b>\n\n<b>Inversión</b>: <a href=' https://promote.telegram.org/account/budget/add_funds '>2.000.000€</a>\n<b>Pago</b>: participación de la empresa",
    'fr': "👩🏽‍💻 <b>Telegram Ads-partenaire/investisseur</b>\n\n<b>Investissement</b> : <a href=' https://promote.telegram.org/account/budget/add_funds '>2 000 000€</a>\n<b>Salaire</b> : part de la société",
    'zh': "👩🏽‍💻 <b>Telegram 广告-合作伙伴/投资者</b>\n\n<b>投资</b>：<a href=' https://promote.telegram.org/account/budget/add_funds '>2,000,000 欧元</a>\n<b>支付</b>：公司股份",
    'ar': "👩🏽‍💻 <b>إعلانات تيليجرام-شريك/مستثمر</b>\n\n<b>الاستثمار</b>: <a href=' https://promote.telegram.org/account/budget/add_funds '>2,000,000 يورو</a>\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_5 = {
    'ru': "👩🏽‍💻 <b>Philanthropist</b>\n\n<blockquote><b>Requirements</b>: any simple game for @gamee-project as <i>ferey-company</i>\n<b>Pay</b>: 10 TON</blockquote>",
    'en': "👩🏽‍💻 <b>Philanthropist</b>\n\n<b>Requirements</b>: any simple game for @gamee-project as <i>ferey-company</i>\n<b>Pay</b>: 10 TON",
    'es': "👩🏽‍💻 <b>Filántropo</b>\n\n<b>Requisitos</b>: cualquier juego simple para @gamee-proyecto como <i>ferey-company</i>\n<b>Pagar </b>: 10 TONELADAS",
    'fr': "👩🏽‍💻 <b>Philanthrope</b>\n\n<b>Exigences</b> : n'importe quel jeu simple pour @gamee-project en tant que <i>ferey-company</i>\n<b>Payer </b> : 10 TONNES",
    'zh': "👩🏽‍💻 <b>慈善家</b>\n\n<b>要求</b>： @gamee-project 作为<i>ferey-company</i>\n<b>支付的任何简单游戏</b>：10 吨",
    'ar': "👩🏽‍💻 <b>فاعل خير</b>\n\n<b>المتطلبات</b>: أي لعبة بسيطة لـ @gamee-project كـ <i>ferey-company</i>\n<b>الدفع </b>: 10 طن",
}
l_vacancy_6 = {
    'ru': "👩🏽‍💻 <b>Bot Premium</b>\n\n<blockquote><b>Requirements</b>: <a href='https://fragment.com/my/assets'><s>5000</s> 1000 TON</a>\n<b>Pay</b>: share of the company</blockquote>",
    'en': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Requirements</b>: <a href='https://fragment.com/my/assets'>5000 TON</a>\n<b>Pay</b>: share of the company",
    'es': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Requisitos</b>: <a href=' https://fragment.com/my/assets '> 5000 TON</a>\n<b>Pago</b>: participación de la empresa",
    'fr': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>Exigences</b> : <a href=' https://fragment.com/my/assets '> 5000 TON</a>\n<b>Rémunération</b> : part de l'entreprise",
    'zh': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>要求</b>： <a href=' https://fragment.com/my/assets '> 5000 吨</a>\n<b>支付</b>：公司股份",
    'ar': "👩🏽‍💻 <b>Bot Premium</b>\n\n<b>المتطلبات</b>: <a href=' https://fragment.com/my/assets '> 5000 طن</a>\n<b>الدفع</b>: حصة الشركة",
}
l_vacancy_7 = {
    'ru': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<blockquote><b>Requirements</b>: creative idea for <code>@YourBot</code>\n<b>Cost</b>: 500 TON for <code>@YourBot</code>-template.bot</blockquote>",
    'en': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Requirements</b>: creative idea for <code>@YourBot</code>\n<b>Cost</b>: 500 TON for <code>@YourBot</code>-template.bot",
    'es': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Requisitos</b>: idea creativa para <code> @YourBot </code>\n<b>Costo</b>: 500 TON para <code> @YourBot </code>-template.bot",
    'fr': "👩🏽‍💻 <b>Aesthetic Bot</b>\n\n<b>Exigences</b> : idée créative pour <code> @YourBot </code>\n<b>Coût</b> : 500 TON pour <code> @YourBot </code>-template.bot",
    'zh': "👩🏽‍💻 <b>美学机器人</b>\n\n<b>要求</b>：<code> @YourBot的创意</code>\n<b>成本</b>：500 TON for <code> @YourBot </code>-template.bot",
    'ar': "👩🏽‍💻 <b>الروبوت الجمالي</b>\n\n<b>المتطلبات</b>: فكرة إبداعية لـ <code> @YourBot </code>\n<b>التكلفة</b>: 500 TON لـ <code> @YourBot </code>-template.bot",
}
# endregion


# region FereyStickerBot
l_sticker_btn1 = {
    'ru': "👩🏽‍💻 Стикеры",
    'en': "👩🏽‍💻 Posts",
    'es': "👩🏽‍💻 Publicaciones",
    'fr': "👩🏽‍💻 Messages",
    'zh': "👩🏽‍💻 帖子",
    'ar': "👩🏽‍💻 المشاركات",
}
l_sticker_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_sticker_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> создания эмоджи/стикер наборов:\n\n<blockquote>▪️<b>static/video/animated</b>\n▪️преобразование фото в видео</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> for creating creative posts:\n\n▪️<b>button</b> counter\n▪️inline-<b >telescopes</b>\n▪️parsing/<b>click notifications</b>\n▪️<b>whisper</b>-messages\n\n❗️<b>Regularly</b>-updated / content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> para crear publicaciones creativas:\n\n▪️<b>botón</b> contador\n▪️inline-<b >telescopios</b>\n▪️análisis/<b>notificaciones de clic</b>\n▪️<b>susurros</b>-mensajes\n\n❗️<b>Regularmente</b>-actualizado/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> pour créer des publications créatives :\n\nwithout >télescopes</b>\nƒ️analyse/<b>notifications de clic</b>\nƒ️<b>chuchotement</b>-messages\n\n❗️<b>Régulièrement</b>-mis à jour/contenu",
    'zh': "🌱 <b>{0}</b>，欢迎使用<i>登陆机器人</i>来创建创意帖子：\n\n▪️<b>按钮</b>计数器\n▪️内联-<b >望远镜</b>\n▪️解析/<b>点击通知</b>\n▪️<b>窃窃私语</b>-消息\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>الروبوت المقصود</i> لإنشاء مشاركات إبداعية:\n\n▪️<b>زر</b> عداد\n▪️inline-<b >التلسكوبات</b>\n▪️parsing/<b>انقر فوق الإشعارات</b>\n▪️<b>whisper</b>-الرسائل\n\n❗️<b>بانتظام</b>-يتم التحديث / المحتوى",
}
l_sticker_welcome_instruction = {
    'ru': 'https://telegra.ph/FereyPostBot-11-15',
    'en': 'https://telegra.ph/FereyBotBot-11-13',
    'es': 'https://telegra.ph/FereyBotBot-11-13',
    'fr': 'https://telegra.ph/FereyBotBot-11-13',
    'zh': 'https://telegra.ph/FereyBotBot-11-13',
    'ar': 'https://telegra.ph/FereyBotBot-11-13',
}
l_subscribe_sticker = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n² [@{0 }-bot]:\n▪️<b>notice</b>-click notifications\n(<i>user link</i>)\n\n👩🏽‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>aviso</b>-notificaciones de clic\n(<i>enlace de usuario</i>)\n\n👩🏽‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n² [@ {0 }-bot] :\nnoyance<b>notification</b>-notifications de clic\n(<i>lien utilisateur</i>)\n\n👩🏽‍💻 /solde",
    'zh': "👩🏽‍💻<b>订阅</b>按月订阅：\n\n1 [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n² [@ {0 }-bot]：\n▪️<b>通知</b>-点击通知\n（<i>用户链接</i>）\n\n👩🏽‍💻 /balance",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n² [@ {0 }-bot]:\n▪️<b>إشعار</b>-انقر على الإشعارات\n(<i>رابط المستخدم</i>)\n\n👩🏽‍💻 /balance",
}

l_pack_type = {
    'ru': "✏️ 1. <b>Выбери</b> тип создаваемого набора <a href='https://t.me/addstickers/ResistanceDog'>sticker</a>/<a href='https://t.me/addemoji/PumpkinEmoji'>emoji</a>\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_username = {
    'ru': "✏️ 2. <b>Введи</b> @username <b>{0}</b>-набора (до 64 символов), отображаемого в ссылке\n\n<i>или жми «➡️️/Next», чтобы использовать рандомный:\n<blockquote>{1}</blockquote></i>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_title = {
    'ru': "✏️ 3. <b>Введи</b> название <b>{0}</b>-набора (до 64 символов), отображаемого в заголовке: <b>Title</b>\n\n<i>или жми «➡️️/Next», чтобы использовать рандомное:\n<blockquote>{1}</blockquote></i>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_kind = {
    'ru': "✏️ 4. <b>Укажи</b> вид <b>{0}</b>-набора: ¹<a href='{1}'>статический</a>/²<a href='{2}'>видео</a>/³<a href='{3}'>анимация</a>\n\n<blockquote>¹static (.webp/.png, px: {7}, 512Kb, max: {4})\n²video (.webm/3 сек, px: {7}, 256Kb, max: {5})\n³animated (.tgs/3 сек, px: {7}, 64Kb, max: {6})</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pck_new = {
    'ru': "🏔️ Создать",
    'en': "⛰ Create",
    'es': "⛰ Crear",
    'fr': "⛰ Créer",
    'zh': "⛰ 创建",
    'ar': "⛰ إنشاء",
}
l_pck_edt = {
    'ru': "♻️ Изменить",
    'en': "♻️ Edit",
    'es': "♻️ Editar",
    'fr': "♻️ Modifier",
    'zh': "♻️编辑",
    'ar': "♻️ تحرير",
}
l_pck_del = {
    'ru': "🚫 Удалить",
    'en': "🚫Delete",
    'es': "🚫Eliminar",
    'fr': "🚫Supprimer",
    'zh': "🚫删除",
    'ar': "🚫حذف",
}
l_pack_sticker = {
    'ru': "стикер",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_emoji = {
    'ru': "эмоджи",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_static = {
    'ru': "статический",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_video = {
    'ru': "видео",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_animation = {
    'ru': "анимация",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_item_media = {
    'ru': "✏️ 1. <b>Отправь</b> sticker/emoji или photo/video/gif (<i>жми ⚫️/🙌🏽, чтобы закруглить/удалить фон</i>) для добавления в [{0}]\n\n<blockquote>или выбери из набора существующий <b>{1}</b> для редактирования/удаления - чтобы ускорить изменения в наборе удали и добавь его снова</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_format = {
    'ru': "✏️ 2. <b>Выбери</b> формат для <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_emoji = {
    'ru': "✏️ 2. <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_keyword = {
    'ru': "✏️ 3. <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n<blockquote>или жми «➡️️/Next», чтобы перейти к следующему шагу</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pck_title = {
    'ru': "🏔️ Название",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_words = {
    'ru': "💬 Слова",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_emoji = {
    'ru': "❤️ Эмоджи",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_delete = {
    'ru': "❌ Удалить",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_thumb = {
    'ru': "🖼️ Обложка",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_shift = {
    'ru': "🔛 Сдвиг",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_itm_back = {
    'ru': "🔙 Назад",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_pack_warn = {
    'ru': "👩🏽‍💻 <b>@username набора</b> не может начинаться с цифр/подчеркиваний, содержать не латинские символы и несколько подчеркиваний подряд",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_exist = {
    'ru': "👩🏽‍💻 {0} уже существует, выбери другой @username-набора",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_error = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> создания набора: повтори попытку позже или загрузи другой media-файл",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_full = {
    'ru': "👩🏽‍💻 {0}-набор уже заполнен ({1}/{2}). Выбери из набора существующий <b>{3}</b> для редактирования/удаления",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_pack_full2 = {
    'ru': "👩🏽‍💻 Набор уже заполнен ({1}/{2}). Выбери из набора существующий {3} для редактирования/удаления",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_pack_delete = {
    'ru': "👩🏽‍💻 <b>Удалить</b> набор: {0}",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_thumb = {
    'ru': "✏️ 3. <b>Жми</b> на ✅/☑️, чтобы <b>Вкл/Выкл</b> режим обложки для загруженного файла\n\n(<i>жми «➡️️/Next», чтобы перейти к следующему шагу</i>)",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_choose_from_pack = {
    'ru': "👩🏽‍💻 Выбрать из набора",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_unawailable = {
    'ru': "👩🏽‍💻 Преобразование недоступно",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_notfound = {
    'ru': "👩🏽‍💻 Стикер/эмоджи не найден в {0}",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_incorrect = {
    'ru': "👩🏽‍💻 <b>Тип</b> загружаемого <b>{0}-{1}</b> не соответствует типу набора <b>{2}-{3}</b>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_pack_title_edit = {
    'ru': "🏔️ <b>Введи</b> новое название для [<b>{0}</b>]-набора (до 64 символов), отображаемого в заголовке\n\n👩🏽‍💻 <b>Текущее название</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить название</i>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_words_edit = {
    'ru': "💬 <b>Укажи</b> ключевые слова (до 64 символов), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие слова</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить ключевые слова</i>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_emoji_edit = {
    'ru': "❤️ <b>Укажи</b> эмоджи (до 20), которые будут ассоциированы с загруженным <b>{0}</b>\n\n👩🏽‍💻 <b>Текущие эмоджи</b>: {1}\n(<i>отправь <code>0</code>, чтобы очистить эмоджи</i>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_delete_edit = {
    'ru': "❌ <b>Удалить</b> выбранный <b>{0}</b> из набора [{1}]",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_thumb_edit = {
    'ru': "🖼️ <b>Установить</b> выбранный <b>{0}</b> в качестве обложки [{1}]-набора",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_shift_edit = {
    'ru': "🔛 <b>Жми</b> на ⬅️/➡️, чтобы сдвинуть <b>Влево/Вправо</b> выбранный <b>{0}</b> в наборе [{1}]\n\n<blockquote>позиция обновится в течение часа</blockquote>",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_pack_title_done = {
    'ru': "🏔️ <b>Название</b>: <b>{0}</b> установлено",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_words_done = {
    'ru': "💬 <b>Ключевые слова</b>: [<b>{0}</b>] установлены",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_emoji_done = {
    'ru': "❤️ <b>Эмоджи</b>: <b>{0}</b> установлены",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_delete_done = {
    'ru': "❌ <b>{0}</b> удален",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_thumb_done = {
    'ru': "🖼️ <b>{0}</b> установлен в качестве обложки",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_shift_done = {
    'ru': "🔛 <b>{0}</b> сдвинут",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_need_animated = {
    'ru': "👩🏽‍💻 <b>Необходимо</b> загрузить .tgs-файл для <b>animated</b>-набора",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}

l_pack_title_error = {
    'ru': "🏔️ <b>Ошибка</b> установки названия",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_words_error = {
    'ru': "💬 <b>Ошибка</b> установки ключевых слов",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_emoji_error = {
    'ru': "❤️ <b>Ошибка</b> установки эмоджи",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_delete_error = {
    'ru': "❌ <b>Ошибка</b> удаления",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_thumb_error = {
    'ru': "🖼️ <b>Ошибка</b> установки обложки",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_shift_error = {
    'ru': "🔛 <b>Ошибка</b> установки сдвига",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_restart = {
    'ru': "(удали и сразу добавь набор снова для ускорения изменений)",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_shift_thumb = {
    'ru': "🖼️ Используй [🔛 Cдвиг] на первую позицию для видео-обложки",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
l_item_rbg_only_photo = {
    'ru': "🙌🏽 Удаление фона доступно только для фото",
    'en': "✏️ 1. <b>Attach media</b> content for the post: <i>photo/gif/video/audio/document/sticker</i> or write a <i>voice/video note</i> in a circle\n\n(<i>or click “➡️️/Next” to skip this step</i>)",
    'es': "✏️ 1. <b>Adjunte contenido multimedia</b> para la publicación: <i>foto/gif/video/audio/document/sticker</i> o escriba una <i>nota de voz/video</i> en un círculo\n\n(<i>o haga clic en “➡️️/Siguiente” para omitir este paso</i>)",
    'fr': "✏️ 1. <b>Joignez du contenu média</b> pour la publication : <i>photo/gif/video/audio/document/sticker</i> ou écrivez une <i>note vocale/vidéo</i> dans un cercle\n\n(<i>ou cliquez sur « ➡️️/Suivant » pour ignorer cette étape</i>)",
    'zh': "✏️ 1. 为帖子<b>附加媒体</b>内容：<i>照片/gif/视频/音频/文档/贴纸</i>或在其中写入<i>语音/视频注释</i>一个圆圈\n\n（<i>或点击“➡️️/下一步”跳过此步骤</i>）",
    'ar': "✏️ 1. <b>أرفق محتوى الوسائط</b> للمنشور: <i>صورة/gif/فيديو/صوت/مستند/ملصق</i> أو اكتب <i>ملاحظة صوتية/فيديو</i> في دائرة\n\n(<i>أو انقر على '➡️️/التالي' لتخطي هذه الخطوة</i>)",
}
# endregion


# region FereyDemoBot
l_demo_btn1 = {
    'ru': "👩🏽‍💻 Проекты",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_demo_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_demo_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> <b>Ferey</b>-проекта:\n\n<blockquote>▪️<b>информация</b> о проектах\n▪️<b>telegraph</b>-/blog</blockquote>\n\n❗️<b>Регулярно</b>-обновляемый /content",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_demo = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}

l_kind_1 = {
    'ru': "<b>👩🏽‍💻@FereyDemoBot</b>\n\n<blockquote>▪️<b>информация</b> о проектах\n▪️<b>telegraph</b>-/blog</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_kind_2 = {
    'ru': "<b>👩🏽‍💻@FereyBotBot</b> - нейро-конструктор ботов\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️авто-<b>перевод/оповещения</b>\n▪️<b>интеграции</b> и платежи\n▪️нейро-<b>генерация/клон</b> бота\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyBotBot </b>-#neuro-bot designer\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️auto-<b>translation/alerts</b >\n▪️<b>integration</b>and payments\n▪️neuro-<b>generation/clone</b>bot\n▪️<b>web-app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyBotBot </b>-diseñador de neurobots\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️auto-<b>traducción/alertas</b >\n▪️<b>integración</b>y pagos\n▪️neuro-<b>generación/clon</b>bot\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyBotBot </b>-concepteur de neuro-bots\n\nwithout >\n▪️<b>intégration</b>et paiements\n▪️neuro-<b>génération/clone</b>bot\nnoyer<b>web-app/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyBotBot </b>-神经机器人设计师\n\n▪️<b>收集/禁止/分析</b>订阅者\n▪️自动-<b>翻译/警报</b >\n▪️<b>集成</b>和支付\n▪️neuro-<b>生成/克隆</b>机器人\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyBotBot </b>-مصمم الروبوتات العصبية\n\n▪️<b>جمع/حظر/تحليلات</b> المشتركين\n▪️auto-<b>ترجمة/تنبيهات</b >\n▪️<b>التكامل</b>والمدفوعات\n▪️neuro-<b>الجيل/الاستنساخ</b>bot\n▪️<b>web-app/neuro</b>-النشر",
}
l_kind_3 = {
    'ru': "<b>👩🏽‍💻@FereyChannelBot</b> - администрирование каналов\n\n<blockquote>▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️<b>авто-декор/подкасты</b> поста\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyChannelBot </b>-channel #administration\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️<b>auto-decor/podcasts</b> posts\n▪️button <b>counter</b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyChannelBot </b>-administración del canal\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️<b>autodecoración/podcasts</b> publicaciones\n▪️botón <b>contador</b>\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyChannelBot </b>-administration des chaînes\n\nwithout\n▪️bouton <b>compteur</b>\n▪️<b>application web/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyChannelBot </b>-频道管理\n\n▪️<b>集合/禁止/分析</b>订阅者\n▪️<b>自动装饰/播客</b>帖子\n▪️按钮<b>计数器</b>\n▪️<b>网络应用程序/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyChannelBot </b>-إدارة القناة\n\n▪️<b>مجموعة/حظر/تحليلات</b> المشتركين\n▪️<b>ديكور تلقائي/بودكاست</b> منشورات\n▪️زر <b>عداد</b>\n▪️<b>تطبيق ويب/عصبي</b>-النشر",
}
l_kind_4 = {
    'ru': "<b>👩🏽‍💻@FereyGroupBot</b> - модерация групп\n\n<blockquote>▪️<b>защита</b> группы от шпионов\n▪️ограничение прав до <b>подписки</b>\n▪️<b>организация</b> бана/анти-флуда\n▪️аналитика и <b>вовлеченность</b>\n▪️<b>авто-ответы</b> и стоп-слова\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyGroupBot </b>-group #moderation\n\n▪️<b>protection</b> of the group from spies\n▪️limitation of rights to <b>subscription</b>\n▪️< b>organization</b> ban/anti-flood\n▪️analytics and <b>engagement</b>\n▪️<b>auto-responses</b> and stop words\n▪️button <b>counter </b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyGroupBot </b>-moderación del grupo\n\n▪️<b>protección</b> del grupo contra espías\n▪️limitación de derechos de <b>suscripción</b>\ n▪️< b>organización</b> prohibición/anti-inundación\n▪️análisis y <b>compromiso</b>\n▪️<b>respuestas automáticas</b> y palabras vacías\n▪️botón <b >contador </b>\n▪️<b>aplicación web/publicación neuro</b>",
    'fr': "<b>👩🏽‍💻 @FereyGroupBot </b>-modération du groupe\n\nnounced<b>protection</b> du groupe contre les espions\nproducerlimitation des droits d'<b>abonnement</b>\ nְ️< b>organisation</b> interdiction/lutte contre les inondations\nwithout >compteur </b>\n▪️<b>web app/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyGroupBot </b>-群组审核\n\n▪️<b>保护</b>群组免受间谍侵害\n▪️<b>订阅权利限制</b>\ n▪️<b>组织</b>禁止/反泛洪\n▪️分析和<b>参与度</b>\n▪️<b>自动回复</b>和停用词\n▪️按钮<b >计数器</b>\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyGroupBot </b>-الإشراف على المجموعة\n\n▪️<b>حماية</b> المجموعة من الجواسيس\n▪️تحديد حقوق <b>الاشتراك</b>\n▪️< b>المنظمة</b> الحظر/مكافحة الفيضانات\n▪️التحليلات و<b>المشاركة</b>\n▪️<b>الردود التلقائية</b> وكلمات الإيقاف\n▪️زر <b >العداد </b>\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_kind_5 = {
    'ru': "<b>👩🏽‍💻@FereyUserBot</b> - автоматизация аккаунтов\n\n<blockquote>▪️<b>авто</b>-перевод/транскрибация\n▪️<b>нейро-генерация</b> бота\n▪️<b>мониторинг</b> гео/слов\n▪️<b>авто-формат</b> и подкасты\n▪️<b>веб-мини/нейро</b>-постинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyUserBot </b>-account automation\n\n▪️<b>automatic</b>-translation/transcription\n▪️<b>neuro-generation</b> bot\n▪️ <b>monitoring</b> geo/words\n▪️<b>auto-format</b> and podcasts\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyUserBot </b>-automatización de cuentas\n\n▪️<b>traducción/transcripción automática</b>\n▪️<b>bot de neurogeneración</b>\n▪️ <b>monitoreo</b> geo/words\n▪️<b>formato automático</b> y podcasts\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyUserBot </b>-automatisation de compte\n\n▪️<b>automatique</b>-traduction/transcription\nnounced<b>bot de neuro-génération</b>\nwithout <b>surveillance</b> géo/mots\nnoyer️<b>formatage automatique</b> et podcasts\nnoyer️<b>application web/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyUserBot </b>-账户自动化\n\n▪️<b>自动</b>-翻译/转录\n▪️<b>神经生成</b>机器人\n▪️ <b>监控</b>地理/单词\n▪️<b>自动格式</b>和播客\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyUserBot </b>-أتمتة الحساب\n\n▪️<b>تلقائي</b>-ترجمة/نسخ\n▪️<b>روبوت التوليد العصبي</b>\n▪️ <b>مراقبة</b> الموقع الجغرافي/الكلمات\n▪️<b>التنسيق التلقائي</b> والبودكاست\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_kind_6 = {
    'ru': "<b>👩🏽‍💻@FereyPostBot</b> - приватные посты\n\n<blockquote>▪️<b>кнопочный</b> счетчик\n▪️инлайн-<b>телескопы</b>\n▪️парсинг/уведомления о <b>кликах</b>\n▪️<b>шёпот</b>-сообщения</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyPostBot </b>-private posts\n\n▪️<b>button</b> counter\n▪️inline-<b>telescopes</b>\n▪️parsing/notifications <b>clicks</b>\n▪️<b>whispers</b>-messages",
    'es': "<b>👩🏽‍💻 @FereyPostBot </b>-publicaciones privadas\n\n▪️<b>botón</b> contador\n▪️en línea-<b>telescopios</b>\n▪️análisis/notificaciones < b>clics</b>\n▪️<b>susurros</b>-mensajes",
    'fr': "<b>👩🏽‍💻 @FereyPostBot </b>-messages privés\n\nnoyer<b>compteur de boutons</b>\nArmoires en ligne-<b>télescopes</b>\n▪️analyse/notifications < b>clics</b>\n▪️<b>chuchotements</b>-messages",
    'zh': "<b>👩🏽‍💻 @FereyPostBot </b>-私人帖子\n\n▪️<b>按钮</b>计数器\n▪️内联-<b>望远镜</b>\n▪️解析/通知 < b>点击</b>\n▪️<b>窃窃私语</b>-消息",
    'ar': "<b>👩🏽‍💻 @FereyPostBot </b>-المنشورات الخاصة\n\n▪️<b>زر</b> عداد\n▪️inline-<b>التلسكوبات</b>\n▪️parsing/notifications < b>النقرات</b>\n▪️<b>همسات</b>-الرسائل",
}
l_kind_7 = {
    'ru': "<b>👩🏽‍💻@FereyMediaBot</b> - публичные медиа-заметки\n\n<blockquote>▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-тренды</b>\n▪️<b>видео-заметки</b>\n▪️инлайн-<b>телескопы</b>\n▪️<b>кнопочные</b> #нейро-титры</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyMediaBot </b>-public media notes\n\n▪️<b>stickers</b> from text and photos\n▪️<b>audio trends</b>\n▪️<b>video notes</b>\n▪️online<b>telescopes</b>\n▪️<b>button</b> media",
    'es': "<b>👩🏽‍💻 @FereyMediaBot </b>-notas de medios públicos\n\n▪️<b>pegatinas</b> de texto y fotos\n▪️<b>tendencias de audio</b>\n▪️< b>notas de vídeo</b>\n▪️online<b>telescopios</b>\n▪️<b>botón</b> medios",
    'fr': "<b>👩🏽‍💻 @FereyMediaBot </b> - notes des médias publics\n\nwithout b>notes vidéo</b>\nƒ️en ligne<b>télescopes</b>\nƒ️<b>bouton</b> média",
    'zh': "<b>👩🏽‍💻 @FereyMediaBot </b>-公共媒体笔记\n\n▪️来自文本和照片的<b>贴纸</b>\n▪️<b>音频趋势</b>\n▪️< b>视频笔记</b>\n▪️在线<b>望远镜</b>\n▪️<b>按钮</b>媒体",
    'ar': "<b>👩🏽‍💻 @FereyMediaBot </b>-ملاحظات الوسائط العامة\n\n▪️<b>ملصقات</b> من النصوص والصور\n▪️<b>الاتجاهات الصوتية</b>\n▪️< b>ملاحظات الفيديو</b>\n▪️على الإنترنت<b>التلسكوبات</b>\n▪️<b>زر</b> الوسائط",
}
l_kind_8 = {
    'ru': "<b>👩🏽‍💻@FereyFindBot</b> - премиум поиск\n\n<blockquote>▪️<b>top</b> каналы/группы\n▪️<b>vip</b> пользователи/боты\n▪️<b>geo</b> парсинг\n▪️<b>smm</b> пассивный маркетинг</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyFindBot </b>-premium search\n\n▪️<b>top</b> channels/groups\n▪️<b>vip</b> users/bots\n▪️< b>geo</b> parsing\n▪️<b>smm</b> passive marketing",
    'es': "<b>👩🏽‍💻 @FereyFindBot </b>-búsqueda premium\n\n▪️<b>canales/grupos principales</b>\n▪️usuarios/bots<b>vip</b>\n▪️< b>geo</b> análisis\n▪️<b>smm</b> marketing pasivo",
    'fr': "<b>👩🏽‍💻 @FereyFindBot </b> - recherche premium\n\nwithout b>géo</b> analyse\n▪️<b>smm</b> marketing passif",
    'zh': "<b>👩🏽‍💻 @FereyFindBot </b>-高级搜索\n\n▪️<b>热门</b>频道/组\n▪️<b>vip</b>用户/机器人\n▪️< b>geo</b>解析\n▪️<b>smm</b>被动营销",
    'ar': "<b>👩🏽‍💻 @FereyFindBot </b>-بحث متميز\n\n▪️<b>أهم</b> القنوات/المجموعات\n▪️<b>vip</b> المستخدمين/الروبوتات\n▪️< b>التحليل الجغرافي</b>\n▪️<b>smm</b> التسويق السلبي",
}
l_kind_9 = {
    'ru': "<b>👩🏽‍💻 @FereyAIBot</b> - нейро-генерация контента\n\n<blockquote>▪️<b>текст/изображение</b>\n▪️<b>нейро-анализ</b> @tg-tech-канала\n▪️<b>распознавание</b> речи\n▪️<b>очистка ⁰истории</b> /start</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-generation of content\n\n▪️<b>text/image</b>\n▪️<b>neuro-analysis</b> @tg-tech channel\n▪️<b>speech recognition</b>\n▪️<b>clearing ⁰history</b> /start",
    'es': "<b>👩🏽‍💻 @FereyAIBot </b>-neurogeneración de contenido\n\n▪️<b>texto/imagen</b>\n▪️<b>neuroanálisis</b> canal @tg-tech\n▪️<b>reconocimiento de voz</b>\n▪️<b>borrando ⁰historial</b> /inicio",
    'fr': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-génération de contenu\n\nnounced<b>texte/image</b>\nnoyam<b>neuro-analyse</b> @tg-tech canal\n▪️<b>reconnaissance vocale</b>\n▪️<b>effacer l'⁰historique</b> /start",
    'zh': "<b>👩🏽‍💻 @FereyAIBot </b>-内容的神经生成\n\n▪️<b>文本/图像</b>\n▪️<b>神经分析</b> @tg-tech频道\n▪️<b>语音识别</b>\n▪️<b>清除⁰历史记录</b> /start",
    'ar': "<b>👩🏽‍💻 @FereyAIBot </b>-التوليد العصبي للمحتوى\n\n▪️<b>نص/صورة</b>\n▪️<b>التحليل العصبي</b> قناة @tg-tech\n▪️<b>التعرف على الكلام</b>\n▪️<b>مسح ⁰السجل</b> /بدء",
}
l_kind_10 = {
    'ru': "<b>👩🏽‍💻 @FereyVPNBot</b> - vpn настройки\n\n<blockquote>▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b></blockquote>",
    'en': "<b>👩🏽‍💻@FereyVPNBot</b>-vpn настройки\n\n▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b>",
    'es': "<b>👩🏽‍💻 @FereyVPNBot </b>-vpn настройки\n\n▪️<b>vpn abierto</b>\n▪️<b>protección de cables</b>\n▪️<b>calcetines de sombra </b>",
    'fr': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\nƒ️<b>open vpn</b>\nƒ️<b>grille de protection</b>\nƒ️<b>chaussettes fantômes </b>",
    'zh': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\n▪️<b>开放VPN</b>\n▪️<b>线卫</b>\n▪️<b>影子袜子</b>",
    'ar': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\n▪️<b>فتح VPN</b>\n▪️<b>واير الحرس</b>\n▪️<b>جوارب الظل </ب>",
}
l_kind_11 = {
    'ru': "<b>👩🏽‍💻 @FereyTargetBot</b> - телеграмм таргет\n\n<blockquote>▪️парсинг\n▪️гео-мониторинг\n▪️проверка номеров</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyTargetBot </b>-telegram target\n\n▪️parsing\n▪️geo-monitoring\n▪️checking numbers",
    'es': "<b>👩🏽‍💻 @FereyTargetBot </b>-objetivo de telegrama\n\n▪️análisis\n▪️geo-monitoreo\n▪️comprobación de números",
    'fr': "<b>👩🏽‍💻 @FereyTargetBot </b>-cible de télégramme\n\nnoyeranalyser\nnoyergéosurveillance\nnoyervérifier les numéros",
    'zh': "<b>👩🏽‍💻 @FereyTargetBot </b>-电报目标\n\n▪️解析\n▪️地理监控\n▪️检查数字",
    'ar': "<b>👩🏽‍💻 @FereyTargetBot </b>-هدف التليجرام\n\n▪️parsing\n▪️المراقبة الجغرافية\n▪️التحقق من الأرقام",
}
l_kind_12 = {
    'ru': "<b>👩🏽‍💻 @FereyToolsBot</b> - телеграм инструменты\n\n<blockquote>▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/бота\n▪️конвертация в <b>телескопы</b>\n▪️<b>/telegraph</b> фото/видео-ссылка\n▪️пустое сообщение <b>0-длины</b></blockquote>",
    'en': "<b>👩🏽‍💻 @FereyToolsBot </b>-telegram tools\n\n▪️<b>conversion</b> of content\n▪️<b>/json</b> message information\n▪️<b >removal</b> background\n▪️<b>/id</b> group/channel/bot\n▪️conversion to <b>telescopes</b>\n▪️<b>/telegraph</b> photo /video link\n▪️empty message <b>0-length</b>",
    'es': "<b>👩🏽‍💻 @FereyToolsBot </b>-herramientas de Telegram\n\n▪️<b>conversión</b> de contenido\n▪️<b>/json</b> información del mensaje\n▪️<b >eliminación</b> de fondo\n▪️<b>/id</b> grupo/canal/bot\n▪️conversión a <b>telescopios</b>\n▪️<b>/telegraph</b> foto /enlace de vídeo\n▪️mensaje vacío <b>0 longitud</b>",
    'fr': "<b>👩🏽‍💻 @FereyToolsBot </b>-outils de télégramme\n\nnoyer<b>conversion</b> du contenu\nnounced️<b>/json</b> informations sur les messages\nlessly️<b >suppression</b> de l'arrière-plan\nproduced</b> groupe/canal/bot\nwithout /lien vidéo\n▪️message vide <b>longueur 0</b>",
    'zh': "<b>👩🏽‍💻 @FereyToolsBot </b>-电报工具\n\n▪️<b>内容转换</b>\n▪️<b>/json</b>消息信息\n▪️<b >删除</b>背景\n▪️<b>/id</b>组/频道/机器人\n▪️转换为<b>望远镜</b>\n▪️<b>/电报</b>照片/视频链接\n▪️空消息<b>0-长度</b>",
    'ar': "<b>👩🏽‍💻 @FereyToolsBot </b>-أدوات التليجرام\n\n▪️<b>تحويل</b> المحتوى\n▪️<b>/json</b> معلومات الرسالة\n▪️<b >إزالة</b> الخلفية\n▪️<b>/id</b> المجموعة/القناة/bot\n▪️التحويل إلى صورة <b>التلسكوبات</b>\n▪️<b>/telegraph</b> /رابط الفيديو\n▪️رسالة فارغة <b>0-الطول</b>",
}
l_kind_13 = {
    'ru': "<b>👩🏽‍💻 @FereyStickerBot</b> - стикеры/эмоджи наборы\n\n<blockquote>▪️️стикеры static/video/animated\n▪️️эмоджи static/video/animated\n▪️️преобразование photo в video-стикер/эмоджи</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
l_kind_14 = {
    'ru': "<b>👩🏽‍💻 @FereyTONestBot</b> - блокчейн проекты\n\n<blockquote>▪️️соло/альбом NFT\n▪️️монеты (жетоны) FT\n▪️️нейро-парсинг смарт-контрактов</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
l_kind_15 = {
    'ru': "<b>👩🏽‍💻 @FereyWorkBot</b> - вакансии проекта\n\n<blockquote>▪️<b>вакансии</b> проекта\n▪️конкурсы и <b>задания</b>\n▪️<b>партнеры</b> и инвесторы\n▪️услуги и <b>пожертвования</b></blockquote>",
    'en': "<b>👩🏽‍💻 @FereyWorkBot </b>-project vacancies\n\n▪️<b>vacancies</b> project\n▪️competitions and <b>tasks</b>\n▪️<b>partners </b> and investors\n▪️services and <b>donations</b>",
    'es': "<b>👩🏽‍💻 @FereyWorkBot </b>-vacantes de proyecto\n\n▪️<b>vacantes</b> proyecto\n▪️concursos y <b>tareas</b>\n▪️<b>socios </b> e inversores\n▪️servicios y <b>donaciones</b>",
    'fr': "<b>👩🏽‍💻 @FereyWorkBot </b>-postes vacants du projet\n\nwithout </b> et investisseurs\n▪️services et <b>dons</b>",
    'zh': "<b>👩🏽‍💻 @FereyWorkBot </b>-项目空缺\n\n▪️<b>空缺</b>项目\n▪️竞赛和<b>任务</b>\n▪️<b>合作伙伴</b>和投资者\n▪️服务和<b>捐赠</b>",
    'ar': "<b>👩🏽‍💻 @FereyWorkBot </b>-الوظائف الشاغرة بالمشروع\n\n▪️<b>الوظائف الشاغرة</b> المشروع\n▪️المسابقات و<b>المهام</b>\n▪️<b>الشركاء </b> والمستثمرون\n▪️الخدمات و<b>التبرعات</b>",
}
# endregion


# region FereySupportBot
l_support_btn1 = {
    'ru': "👩🏽‍💻 Проекты",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_support_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_support_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i>: служба <b>заботы</b> Ferey-проекта:\n\n<blockquote>▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы</blockquote>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_support = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}
# endregion


# region FereyCodexBot
l_codex_btn1 = {
    'ru': "👩🏽‍💻 Кодекс",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_codex_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_codex_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в [<b>Кодекс {1}</b>] - лэндинг-бот быстрого погружения в новые @tg-инструменты #нейро-маркетинга:\n\n▪️<b>экспресс</b>-интенсив 23мин\n▪️<b>нейро-инструменты</b> в Telegram",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}

l_codex_warm1 = {
    'ru': "👩🏽‍💻 <b>Кодекс {0}</b> - это программа практического обзора новых <code>@tg</code>-инструментов #нейро-маркетинга:\n\n<blockquote>за несколько минут познакомишься с новым @tg-функционалом, чтобы сэкономить несколько часов</blockquote>\n<blockquote>увидишь связки нейросетей и @tg-приложений, чтобы снизить затраты на подрядчиков</blockquote>\n<blockquote>узнаешь новые способы генерации/администрирования/поиска @tg-контента, чтобы обогнать конкурентов</blockquote>\n\n🌱 После изучения <b>кодекса</b>, ты сможешь подробнее разобрать @tg-функционал на <i>экспертном</i> уровне в нашем <u>реалити-фесте</u>, ссылка на который будет в конце кодекса\n\n🍃 <b>Жми [🪙 Кодекс: взнос], чтобы открыть кодекс</b>\n\n©️ данный текст написан нейросетью",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_codex_warm2 = {
    'ru': "👩🏽‍💻 <b>Содержание Кодекса {0}:</b>\n\n<b>Акт #1</b>: <code>введение</code>\n\n<b>Акт #2</b>: <code>мастер генераций</code>\n<blockquote>• нейро-блоки\n• нейро-цепочки\n• нейро-постинг\n• нейро-ответ\n• нейро-диалог</blockquote>\n\n<b>Акт #3</b>: <code>мастер администрирования</code>\n<blockquote>• авто-бан\n• авто-декор\n• авто-вход\n• авто-постинг\n• авто-подкаст\n• авто-ответ</blockquote>\n\n<b>Акт #4</b>: <code>мастер поиска</code>\n<blockquote>• премиум поиск\n• пассивный поиск\n• встроенный поиск\n• поиск креативов\n• нейро поиск\n• лайк поиск\n• гео поиск</blockquote>\n\n<b>Акт #5</b>: <code>заключение</code>\n\n🌱 После изучения <b>кодекса</b>, ты сможешь стать резидентом <u>закрытого канала</u> и получить доступ к обновляемой рабочей книге со всеми @tg-инструментами\n\n🍃 <b>Жми [🪙 Кодекс: взнос], чтобы открыть кодекс</b>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_codex_warm3 = {
    'ru': "👩🏽‍💻 <b>Все</b> @tg-инструменты <b>Кодекса {0}</b> поддерживаются официальными сервисами <b>Ferey</b>-проекта:\n\n<blockquote>• Bot\n• User\n• Channel\n• Group\n• Post\n• Media\n• AI\n• Find\n• Tools\n• Target\n• и другие •</blockquote>\n\n🌱 После изучения <b>кодекса</b>, ты будешь знать как работать с каждым из <u>сервисов</u>, ссылки на которые найдешь внутри кодекса\n\n🍃 <b>Жми [🪙 Кодекс: взнос], чтобы открыть кодекс</b>",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_codex_pay_text = {
    'ru': "🪙 Кодекс: взнос",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_codex_pay_check = {
    'ru': "👩🏽‍💻 Проверка взноса",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_codex_transcribation_btn = {
    'ru': "💨 Конспект",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}

l_codex_caption_1 = {
    'ru': "👩🏽‍💻 <b>Акт #1</b>: <code>введение</code>\n\n00:03 - актуальность\n00:05 - цель\n00:07 - задачи\n\n<blockquote>Жми на • 2 • страницу, чтобы перейти к следующему акту</blockquote>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_codex_caption_2 = {
    'ru': "👩🏽‍💻 <b>Акт #2</b>: <code>мастер генераций</code>\n\n00:01 - нейро-блоки\n00:02 - нейро-цепочки\n00:03 - нейро-постинг\n00:04 - нейро-ответ\n00:05 - нейро-диалог\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_codex_caption_3 = {
    'ru': "👩🏽‍💻 <b>Акт #3</b>: <code>мастер автоматизации</code>\n\n00:01 - авто-бан\n00:02 - авто-декор\n00:03 - авто-вход\n00:04 - авто-постинг\n00:05 - авто-подкаст\n00:06 - авто-ответ\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyChannelBot?start=codex'>@FereyChannelBot</a>\n<a href='https://t.me/FereyGroupBot?start=codex'>@FereyGroupBot</a>\n<a href='https://t.me/FereyBotBot?start=codex'>@FereyBotBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_codex_caption_4 = {
    'ru': "👩🏽‍💻 <b>Акт #4</b>: <code>мастер поиска</code>\n\n00:01 - премиум-поиск\n00:02 - пассивный-поиск\n00:03 - встроенный-поиск\n00:04 - поиск-креативов\n00:05 - нейро-поиск\n00:06 - лайк-поиск\n00:07 - гео-поиск\n\n<blockquote>Используемые в видео @tg-приложения:</blockquote>\n<a href='https://t.me/FereyFindBot?start=codex'>@FereyFindBot</a>\n<a href='https://t.me/FereyPostBot?start=codex'>@FereyPostBot</a>\n<a href='https://t.me/FereyMediaBot?start=codex'>@FereyMediaBot</a>\n<a href='https://t.me/FereyAIBot?start=codex'>@FereyAIBot</a>\n<a href='https://t.me/FereyTargetBot?start=codex'>@FereyTargetBot</a>\n<a href='https://t.me/FereyUserBot?start=codex'>@FereyUserBot</a>",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_codex_caption_5 = {
    'ru': "👩🏽‍💻 <b>Акт #5</b>: <code>заключение</code>\n\n00:03 - генерация\n00:05 - администрирование\n00:07 - поиск\n\n<blockquote>Рассмотрены @tg-приложения #нейро-генерации/администрирования/поиска. Сэкономлено время на изучении новых @tg-инструментов #нейро-маркетинга</blockquote>\n\n🌱 <b>Переходи</b> к <a href='{0}'>реалити-фесту</a>, чтобы подробно в режиме <b>реального времени</b> собрать все @tg-инструменты для развития своего продукта/услуги\n\n🍃 <b>Становись</b> резидентом <a href='{1}'>закрытого канала</a>, чтобы приобрести <b>рабочую книгу</b> с актуальными знаниями и в числе первых получать инструкции нового @tg-функционала",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}


l_codex_1 = {
    'ru': "<b>👩🏽‍💻 Акт #1 - мастер генераций</b>\n\n▪️<b>информация</b> о проектах\n▪️<b>telegraph</b>-/blog",
    'en': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog",
    'es': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog",
    'fr': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\nnounced<b>informations</b> sur les projets\nnounced️<b>télégraphe</b>-/blog",
    'zh': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客",
    'ar': "<b>👩🏽‍💻 @FereyDemoBot </b>\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog",
}
l_codex_2 = {
    'ru': "<b>👩🏽‍💻@FereyBotBot</b> - нейро-конструктор ботов\n\n▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️авто-<b>перевод/оповещения</b>\n▪️<b>интеграции</b> и платежи\n▪️нейро-<b>генерация/клон</b> бота\n▪️<b>веб-мини/нейро</b>-постинг",
    'en': "<b>👩🏽‍💻 @FereyBotBot </b>-#neuro-bot designer\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️auto-<b>translation/alerts</b >\n▪️<b>integration</b>and payments\n▪️neuro-<b>generation/clone</b>bot\n▪️<b>web-app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyBotBot </b>-diseñador de neurobots\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️auto-<b>traducción/alertas</b >\n▪️<b>integración</b>y pagos\n▪️neuro-<b>generación/clon</b>bot\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyBotBot </b>-concepteur de neuro-bots\n\nwithout >\n▪️<b>intégration</b>et paiements\n▪️neuro-<b>génération/clone</b>bot\nnoyer<b>web-app/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyBotBot </b>-神经机器人设计师\n\n▪️<b>收集/禁止/分析</b>订阅者\n▪️自动-<b>翻译/警报</b >\n▪️<b>集成</b>和支付\n▪️neuro-<b>生成/克隆</b>机器人\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyBotBot </b>-مصمم الروبوتات العصبية\n\n▪️<b>جمع/حظر/تحليلات</b> المشتركين\n▪️auto-<b>ترجمة/تنبيهات</b >\n▪️<b>التكامل</b>والمدفوعات\n▪️neuro-<b>الجيل/الاستنساخ</b>bot\n▪️<b>web-app/neuro</b>-النشر",
}
l_codex_3 = {
    'ru': "<b>👩🏽‍💻@FereyChannelBot</b> - администрирование каналов\n\n▪️<b>сбор/бан/аналитика</b> подписчиков\n▪️<b>авто-декор/подкасты</b> поста\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг",
    'en': "<b>👩🏽‍💻 @FereyChannelBot </b>-channel #administration\n\n▪️<b>collection/ban/analytics</b> subscribers\n▪️<b>auto-decor/podcasts</b> posts\n▪️button <b>counter</b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyChannelBot </b>-administración del canal\n\n▪️<b>colección/ban/analítica</b> suscriptores\n▪️<b>autodecoración/podcasts</b> publicaciones\n▪️botón <b>contador</b>\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyChannelBot </b>-administration des chaînes\n\nwithout\n▪️bouton <b>compteur</b>\n▪️<b>application web/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyChannelBot </b>-频道管理\n\n▪️<b>集合/禁止/分析</b>订阅者\n▪️<b>自动装饰/播客</b>帖子\n▪️按钮<b>计数器</b>\n▪️<b>网络应用程序/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyChannelBot </b>-إدارة القناة\n\n▪️<b>مجموعة/حظر/تحليلات</b> المشتركين\n▪️<b>ديكور تلقائي/بودكاست</b> منشورات\n▪️زر <b>عداد</b>\n▪️<b>تطبيق ويب/عصبي</b>-النشر",
}
l_codex_4 = {
    'ru': "<b>👩🏽‍💻@FereyGroupBot</b> - модерация групп\n\n▪️<b>защита</b> группы от шпионов\n▪️ограничение прав до <b>подписки</b>\n▪️<b>организация</b> бана/анти-флуда\n▪️аналитика и <b>вовлеченность</b>\n▪️<b>авто-ответы</b> и стоп-слова\n▪️кнопочный <b>счетчик</b>\n▪️<b>веб-мини/нейро</b>-постинг",
    'en': "<b>👩🏽‍💻 @FereyGroupBot </b>-group #moderation\n\n▪️<b>protection</b> of the group from spies\n▪️limitation of rights to <b>subscription</b>\n▪️< b>organization</b> ban/anti-flood\n▪️analytics and <b>engagement</b>\n▪️<b>auto-responses</b> and stop words\n▪️button <b>counter </b>\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyGroupBot </b>-moderación del grupo\n\n▪️<b>protección</b> del grupo contra espías\n▪️limitación de derechos de <b>suscripción</b>\ n▪️< b>organización</b> prohibición/anti-inundación\n▪️análisis y <b>compromiso</b>\n▪️<b>respuestas automáticas</b> y palabras vacías\n▪️botón <b >contador </b>\n▪️<b>aplicación web/publicación neuro</b>",
    'fr': "<b>👩🏽‍💻 @FereyGroupBot </b>-modération du groupe\n\nnounced<b>protection</b> du groupe contre les espions\nproducerlimitation des droits d'<b>abonnement</b>\ nְ️< b>organisation</b> interdiction/lutte contre les inondations\nwithout >compteur </b>\n▪️<b>web app/neuro</b>-posting",
    'zh': "<b>👩🏽‍💻 @FereyGroupBot </b>-群组审核\n\n▪️<b>保护</b>群组免受间谍侵害\n▪️<b>订阅权利限制</b>\ n▪️<b>组织</b>禁止/反泛洪\n▪️分析和<b>参与度</b>\n▪️<b>自动回复</b>和停用词\n▪️按钮<b >计数器</b>\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyGroupBot </b>-الإشراف على المجموعة\n\n▪️<b>حماية</b> المجموعة من الجواسيس\n▪️تحديد حقوق <b>الاشتراك</b>\n▪️< b>المنظمة</b> الحظر/مكافحة الفيضانات\n▪️التحليلات و<b>المشاركة</b>\n▪️<b>الردود التلقائية</b> وكلمات الإيقاف\n▪️زر <b >العداد </b>\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_codex_5 = {
    'ru': "<b>👩🏽‍💻@FereyUserBot</b> - автоматизация аккаунтов\n\n▪️<b>авто</b>-перевод/транскрибация\n▪️<b>нейро-генерация</b> бота\n▪️<b>мониторинг</b> гео/слов\n▪️<b>авто-формат</b> и подкасты\n▪️<b>веб-мини/нейро</b>-постинг",
    'en': "<b>👩🏽‍💻 @FereyUserBot </b>-account automation\n\n▪️<b>automatic</b>-translation/transcription\n▪️<b>neuro-generation</b> bot\n▪️ <b>monitoring</b> geo/words\n▪️<b>auto-format</b> and podcasts\n▪️<b>web app/neuro</b>-posting",
    'es': "<b>👩🏽‍💻 @FereyUserBot </b>-automatización de cuentas\n\n▪️<b>traducción/transcripción automática</b>\n▪️<b>bot de neurogeneración</b>\n▪️ <b>monitoreo</b> geo/words\n▪️<b>formato automático</b> y podcasts\n▪️<b>aplicación web/neuro</b>-publicación",
    'fr': "<b>👩🏽‍💻 @FereyUserBot </b>-automatisation de compte\n\n▪️<b>automatique</b>-traduction/transcription\nnounced<b>bot de neuro-génération</b>\nwithout <b>surveillance</b> géo/mots\nnoyer️<b>formatage automatique</b> et podcasts\nnoyer️<b>application web/neuro</b>-publication",
    'zh': "<b>👩🏽‍💻 @FereyUserBot </b>-账户自动化\n\n▪️<b>自动</b>-翻译/转录\n▪️<b>神经生成</b>机器人\n▪️ <b>监控</b>地理/单词\n▪️<b>自动格式</b>和播客\n▪️<b>网络应用/神经</b>-发布",
    'ar': "<b>👩🏽‍💻 @FereyUserBot </b>-أتمتة الحساب\n\n▪️<b>تلقائي</b>-ترجمة/نسخ\n▪️<b>روبوت التوليد العصبي</b>\n▪️ <b>مراقبة</b> الموقع الجغرافي/الكلمات\n▪️<b>التنسيق التلقائي</b> والبودكاست\n▪️<b>تطبيق الويب/العصبي</b>-النشر",
}
l_codex_6 = {
    'ru': "<b>👩🏽‍💻@FereyPostBot</b> - приватные посты\n\n▪️<b>кнопочный</b> счетчик\n▪️инлайн-<b>телескопы</b>\n▪️парсинг/уведомления о <b>кликах</b>\n▪️<b>шёпот</b>-сообщения",
    'en': "<b>👩🏽‍💻 @FereyPostBot </b>-private posts\n\n▪️<b>button</b> counter\n▪️inline-<b>telescopes</b>\n▪️parsing/notifications <b>clicks</b>\n▪️<b>whispers</b>-messages",
    'es': "<b>👩🏽‍💻 @FereyPostBot </b>-publicaciones privadas\n\n▪️<b>botón</b> contador\n▪️en línea-<b>telescopios</b>\n▪️análisis/notificaciones < b>clics</b>\n▪️<b>susurros</b>-mensajes",
    'fr': "<b>👩🏽‍💻 @FereyPostBot </b>-messages privés\n\nnoyer<b>compteur de boutons</b>\nArmoires en ligne-<b>télescopes</b>\n▪️analyse/notifications < b>clics</b>\n▪️<b>chuchotements</b>-messages",
    'zh': "<b>👩🏽‍💻 @FereyPostBot </b>-私人帖子\n\n▪️<b>按钮</b>计数器\n▪️内联-<b>望远镜</b>\n▪️解析/通知 < b>点击</b>\n▪️<b>窃窃私语</b>-消息",
    'ar': "<b>👩🏽‍💻 @FereyPostBot </b>-المنشورات الخاصة\n\n▪️<b>زر</b> عداد\n▪️inline-<b>التلسكوبات</b>\n▪️parsing/notifications < b>النقرات</b>\n▪️<b>همسات</b>-الرسائل",
}
l_codex_7 = {
    'ru': "<b>👩🏽‍💻@FereyMediaBot</b> - публичные медиа-заметки\n\n▪️<b>стикеры</b> из текста и фото\n▪️<b>аудио-тренды</b>\n▪️<b>видео-заметки</b>\n▪️инлайн-<b>телескопы</b>\n▪️<b>кнопочные</b> #нейро-титры",
    'en': "<b>👩🏽‍💻 @FereyMediaBot </b>-public media notes\n\n▪️<b>stickers</b> from text and photos\n▪️<b>audio trends</b>\n▪️<b>video notes</b>\n▪️online<b>telescopes</b>\n▪️<b>button</b> media",
    'es': "<b>👩🏽‍💻 @FereyMediaBot </b>-notas de medios públicos\n\n▪️<b>pegatinas</b> de texto y fotos\n▪️<b>tendencias de audio</b>\n▪️< b>notas de vídeo</b>\n▪️online<b>telescopios</b>\n▪️<b>botón</b> medios",
    'fr': "<b>👩🏽‍💻 @FereyMediaBot </b> - notes des médias publics\n\nwithout b>notes vidéo</b>\nƒ️en ligne<b>télescopes</b>\nƒ️<b>bouton</b> média",
    'zh': "<b>👩🏽‍💻 @FereyMediaBot </b>-公共媒体笔记\n\n▪️来自文本和照片的<b>贴纸</b>\n▪️<b>音频趋势</b>\n▪️< b>视频笔记</b>\n▪️在线<b>望远镜</b>\n▪️<b>按钮</b>媒体",
    'ar': "<b>👩🏽‍💻 @FereyMediaBot </b>-ملاحظات الوسائط العامة\n\n▪️<b>ملصقات</b> من النصوص والصور\n▪️<b>الاتجاهات الصوتية</b>\n▪️< b>ملاحظات الفيديو</b>\n▪️على الإنترنت<b>التلسكوبات</b>\n▪️<b>زر</b> الوسائط",
}
l_codex_8 = {
    'ru': "<b>👩🏽‍💻@FereyFindBot</b> - премиум поиск\n\n▪️<b>top</b> каналы/группы\n▪️<b>vip</b> пользователи/боты\n▪️<b>geo</b> парсинг\n▪️<b>smm</b> пассивный маркетинг",
    'en': "<b>👩🏽‍💻 @FereyFindBot </b>-premium search\n\n▪️<b>top</b> channels/groups\n▪️<b>vip</b> users/bots\n▪️< b>geo</b> parsing\n▪️<b>smm</b> passive marketing",
    'es': "<b>👩🏽‍💻 @FereyFindBot </b>-búsqueda premium\n\n▪️<b>canales/grupos principales</b>\n▪️usuarios/bots<b>vip</b>\n▪️< b>geo</b> análisis\n▪️<b>smm</b> marketing pasivo",
    'fr': "<b>👩🏽‍💻 @FereyFindBot </b> - recherche premium\n\nwithout b>géo</b> analyse\n▪️<b>smm</b> marketing passif",
    'zh': "<b>👩🏽‍💻 @FereyFindBot </b>-高级搜索\n\n▪️<b>热门</b>频道/组\n▪️<b>vip</b>用户/机器人\n▪️< b>geo</b>解析\n▪️<b>smm</b>被动营销",
    'ar': "<b>👩🏽‍💻 @FereyFindBot </b>-بحث متميز\n\n▪️<b>أهم</b> القنوات/المجموعات\n▪️<b>vip</b> المستخدمين/الروبوتات\n▪️< b>التحليل الجغرافي</b>\n▪️<b>smm</b> التسويق السلبي",
}
l_codex_9 = {
    'ru': "<b>👩🏽‍💻@FereyAIBot</b> - нейро-генерация контента\n\n▪️<b>текст/изображение</b>\n▪️<b>нейро-анализ</b> @tg-tech-канала\n▪️<b>распознавание</b> речи\n▪️<b>очистка ⁰истории</b> /start",
    'en': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-generation of content\n\n▪️<b>text/image</b>\n▪️<b>neuro-analysis</b> @tg-tech channel\n▪️<b>speech recognition</b>\n▪️<b>clearing ⁰history</b> /start",
    'es': "<b>👩🏽‍💻 @FereyAIBot </b>-neurogeneración de contenido\n\n▪️<b>texto/imagen</b>\n▪️<b>neuroanálisis</b> canal @tg-tech\n▪️<b>reconocimiento de voz</b>\n▪️<b>borrando ⁰historial</b> /inicio",
    'fr': "<b>👩🏽‍💻 @FereyAIBot </b>-neuro-génération de contenu\n\nnounced<b>texte/image</b>\nnoyam<b>neuro-analyse</b> @tg-tech canal\n▪️<b>reconnaissance vocale</b>\n▪️<b>effacer l'⁰historique</b> /start",
    'zh': "<b>👩🏽‍💻 @FereyAIBot </b>-内容的神经生成\n\n▪️<b>文本/图像</b>\n▪️<b>神经分析</b> @tg-tech频道\n▪️<b>语音识别</b>\n▪️<b>清除⁰历史记录</b> /start",
    'ar': "<b>👩🏽‍💻 @FereyAIBot </b>-التوليد العصبي للمحتوى\n\n▪️<b>نص/صورة</b>\n▪️<b>التحليل العصبي</b> قناة @tg-tech\n▪️<b>التعرف على الكلام</b>\n▪️<b>مسح ⁰السجل</b> /بدء",
}
l_codex_10 = {
    'ru': "<b>👩🏽‍💻@FereyVPNBot</b> - vpn настройки\n\n▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b>",
    'en': "<b>👩🏽‍💻@FereyVPNBot</b>-vpn настройки\n\n▪️<b>open vpn</b>\n▪️<b>wire guard</b>\n▪️<b>shadow socks</b>",
    'es': "<b>👩🏽‍💻 @FereyVPNBot </b>-vpn настройки\n\n▪️<b>vpn abierto</b>\n▪️<b>protección de cables</b>\n▪️<b>calcetines de sombra </b>",
    'fr': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\nƒ️<b>open vpn</b>\nƒ️<b>grille de protection</b>\nƒ️<b>chaussettes fantômes </b>",
    'zh': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\n▪️<b>开放VPN</b>\n▪️<b>线卫</b>\n▪️<b>影子袜子</b>",
    'ar': "<b>👩🏽‍💻 @FereyVPNBot </b>-VPN настройки\n\n▪️<b>فتح VPN</b>\n▪️<b>واير الحرس</b>\n▪️<b>جوارب الظل </ب>",
}
l_codex_11 = {
    'ru': "<b>👩🏽‍💻@FereyTargetBot</b> - телеграмм таргет\n\n▪️парсинг\n▪️гео-мониторинг\n▪️проверка номеров",
    'en': "<b>👩🏽‍💻 @FereyTargetBot </b>-telegram target\n\n▪️parsing\n▪️geo-monitoring\n▪️checking numbers",
    'es': "<b>👩🏽‍💻 @FereyTargetBot </b>-objetivo de telegrama\n\n▪️análisis\n▪️geo-monitoreo\n▪️comprobación de números",
    'fr': "<b>👩🏽‍💻 @FereyTargetBot </b>-cible de télégramme\n\nnoyeranalyser\nnoyergéosurveillance\nnoyervérifier les numéros",
    'zh': "<b>👩🏽‍💻 @FereyTargetBot </b>-电报目标\n\n▪️解析\n▪️地理监控\n▪️检查数字",
    'ar': "<b>👩🏽‍💻 @FereyTargetBot </b>-هدف التليجرام\n\n▪️parsing\n▪️المراقبة الجغرافية\n▪️التحقق من الأرقام",
}
l_codex_12 = {
    'ru': "<b>👩🏽‍💻@FereyToolsBot</b> - телеграм инструменты\n\n▪️<b>преобразование</b> контента\n▪️<b>/json</b> информация о сообщ\n▪️<b>удаление</b> фона\n▪️<b>/id</b> группы/канала/бота\n▪️конвертация в <b>телескопы</b>\n▪️<b>/telegraph</b> фото/видео-ссылка\n▪️пустое сообщение <b>0-длины</b>",
    'en': "<b>👩🏽‍💻 @FereyToolsBot </b>-telegram tools\n\n▪️<b>conversion</b> of content\n▪️<b>/json</b> message information\n▪️<b >removal</b> background\n▪️<b>/id</b> group/channel/bot\n▪️conversion to <b>telescopes</b>\n▪️<b>/telegraph</b> photo /video link\n▪️empty message <b>0-length</b>",
    'es': "<b>👩🏽‍💻 @FereyToolsBot </b>-herramientas de Telegram\n\n▪️<b>conversión</b> de contenido\n▪️<b>/json</b> información del mensaje\n▪️<b >eliminación</b> de fondo\n▪️<b>/id</b> grupo/canal/bot\n▪️conversión a <b>telescopios</b>\n▪️<b>/telegraph</b> foto /enlace de vídeo\n▪️mensaje vacío <b>0 longitud</b>",
    'fr': "<b>👩🏽‍💻 @FereyToolsBot </b>-outils de télégramme\n\nnoyer<b>conversion</b> du contenu\nnounced️<b>/json</b> informations sur les messages\nlessly️<b >suppression</b> de l'arrière-plan\nproduced</b> groupe/canal/bot\nwithout /lien vidéo\n▪️message vide <b>longueur 0</b>",
    'zh': "<b>👩🏽‍💻 @FereyToolsBot </b>-电报工具\n\n▪️<b>内容转换</b>\n▪️<b>/json</b>消息信息\n▪️<b >删除</b>背景\n▪️<b>/id</b>组/频道/机器人\n▪️转换为<b>望远镜</b>\n▪️<b>/电报</b>照片/视频链接\n▪️空消息<b>0-长度</b>",
    'ar': "<b>👩🏽‍💻 @FereyToolsBot </b>-أدوات التليجرام\n\n▪️<b>تحويل</b> المحتوى\n▪️<b>/json</b> معلومات الرسالة\n▪️<b >إزالة</b> الخلفية\n▪️<b>/id</b> المجموعة/القناة/bot\n▪️التحويل إلى صورة <b>التلسكوبات</b>\n▪️<b>/telegraph</b> /رابط الفيديو\n▪️رسالة فارغة <b>0-الطول</b>",
}
l_codex_13 = {
    'ru': "<b>👩🏽‍💻@FereyAdsBot</b> - ferey реклама\n\n▪️️реклама в ferey-проектах\n▪️️заказ рекламы на канале",
    'en': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey advertising\n\n▪️️advertising in ferey-projects\n▪️️ordering advertising on the channel",
    'es': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicidad de ferey\n\n▪️️publicidad en proyectos de ferey\n▪️️pedido de publicidad en el canal",
    'fr': "<b>👩🏽‍💻 @FereyAdsBot </b>-publicité ferey\n\nnoyer️publicité dans les projets ferey\nnoyer️commander de la publicité sur la chaîne",
    'zh': "<b>👩🏽‍💻 @FereyAdsBot </b>-ferey 广告\n\n▪️️ferey 项目中的广告\n▪️️在频道上订购广告",
    'ar': "<b>👩🏽‍💻 @FereyAdsBot </b>-إعلانات فيري\n\n▪️️إعلان في مشاريع فيري\n▪️️طلب إعلان على القناة",
}
l_codex_14 = {
    'ru': "<b>👩🏽‍💻@FereyWorkBot</b> - вакансии проекта\n\n▪️<b>вакансии</b> проекта\n▪️конкурсы и <b>задания</b>\n▪️<b>партнеры</b> и инвесторы\n▪️услуги и <b>пожертвования</b>",
    'en': "<b>👩🏽‍💻 @FereyWorkBot </b>-project vacancies\n\n▪️<b>vacancies</b> project\n▪️competitions and <b>tasks</b>\n▪️<b>partners </b> and investors\n▪️services and <b>donations</b>",
    'es': "<b>👩🏽‍💻 @FereyWorkBot </b>-vacantes de proyecto\n\n▪️<b>vacantes</b> proyecto\n▪️concursos y <b>tareas</b>\n▪️<b>socios </b> e inversores\n▪️servicios y <b>donaciones</b>",
    'fr': "<b>👩🏽‍💻 @FereyWorkBot </b>-postes vacants du projet\n\nwithout </b> et investisseurs\n▪️services et <b>dons</b>",
    'zh': "<b>👩🏽‍💻 @FereyWorkBot </b>-项目空缺\n\n▪️<b>空缺</b>项目\n▪️竞赛和<b>任务</b>\n▪️<b>合作伙伴</b>和投资者\n▪️服务和<b>捐赠</b>",
    'ar': "<b>👩🏽‍💻 @FereyWorkBot </b>-الوظائف الشاغرة بالمشروع\n\n▪️<b>الوظائف الشاغرة</b> المشروع\n▪️المسابقات و<b>المهام</b>\n▪️<b>الشركاء </b> والمستثمرون\n▪️الخدمات و<b>التبرعات</b>",
}
# endregion


# region FereyFestBot
l_fest_btn1 = {
    'ru': "👩🏽‍💻 Реалити",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_fest_btn2 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_fest_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> службу <b>заботы</b> Ferey-проекта:\n\n▪️<b>задавай</b> вопросы\n▪️<b>присылай</b> любые медиа-файлы",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_fest = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}
# endregion


# region FereyTONestBot
l_tonest_btn1 = {
    'ru': "🏞️ Коллекции",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_tonest_btn2 = {
    'ru': "🪙 Монеты",
    'en': "👩🏽‍💻 Projects",
    'es': "👩🏽‍💻 Proyectos",
    'fr': "👩🏽‍💻 Projets",
    'zh': "👩🏽‍💻 项目",
    'ar': "👩🏽‍💻 المشاريع",
}
l_tonest_btn3 = {
    'ru': "💨 Подписка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_welcome = {
    'ru': "🌱 <b>{0}</b>, добро пожаловать в <i>лендинг-бот</i> создания Web3ᵀᴼᴺ-проектов на блокчейне:\n\n▪️<b>памятные</b> коллекции (альбомы)\n▪️<b>монеты</b> (жетоны) сообщества",
    'en': "🌱 <b>{0}</b>, welcome to the <i>landing bot</i> <b>Ferey</b>-project:\n\n▪️<b>information</b> about projects\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Regularly</b>-updated /content",
    'es': "🌱 <b>{0}</b>, bienvenido al <i>bot de aterrizaje</i> <b>Ferey</b>-proyecto:\n\n▪️<b>información</b> sobre proyectos\n▪️<b>telegraph</b>-/blog\n\n❗️<b>Actualizado periódicamente</b>/contenido",
    'fr': "🌱 <b>{0}</b>, bienvenue sur le <i>landing bot</i> <b>Ferey</b>-projet :\n\nlessly<b>informations</b> sur les projets\n▪️<b>télégraphe</b>-/blog\n\n❗️<b>Régulièrement</b>-mis à jour /contenu",
    'zh': "🌱<b>{0}</b>，欢迎使用<i>登陆机器人</i><b>Ferey</b>-项目：\n\n▪️有关项目的<b>信息</b>\n▪️<b>电报</b>-/博客\n\n❗️<b>定期</b>-更新/内容",
    'ar': "🌱 <b>{0}</b>، مرحبًا بك في <i>روبوت الهبوط</i> <b>Ferey</b>-project:\n\n▪️<b>معلومات</b> حول المشاريع\n▪️<b>تلغراف</b>-/blog\n\n❗️<b>بانتظام</b>-يتم تحديثه /المحتوى",
}
l_subscribe_tonest = {
    'ru': "👩🏽‍💻 <b>Оформи</b> ежемесячную подписку:\n\n¹ [<b>Все боты</b> и проекты (-<u>5</u>%)]\n² [@{0}-бот]:\n<blockquote>▪️> 10 <b>NFT</b> в > 1 <b>коллекции</b>\n(<i>+редактирование</i>)\n▪️> 1 млн FT-<b>монет</b>\n(<i>+редактирование</i>)</blockquote>\n\n👩🏽‍💻 /balance",
    'en': "👩🏽‍💻 <b>Subscribe</b> to a monthly subscription:\n\n¹ [<b>All bots</b> and projects (-<u>5</u>%)]\n\n👩🏽 ‍💻 /balance",
    'es': "👩🏽‍💻 <b>Suscríbete</b> a una suscripción mensual:\n\n¹ [<b>Todos los bots</b> y proyectos (-<u>5</u>%)]\n\n👩🏽 ‍💻 /saldo",
    'fr': "👩🏽‍💻 <b>S'abonner</b> à un abonnement mensuel :\n\n¹ [<b>Tous les robots</b> et projets (-<u>5</u>%)]\n\n👩🏽 ‍💻 /solde",
    'zh': "👩🏽‍💻 <b>订阅</b>按月订阅：\n\n¹ [<b>所有机器人</b>和项目 (-<u>5</u>%)]\n\n👩🏽 ‍💻 /余额",
    'ar': "👩🏽‍💻 <b>اشترك</b> في اشتراك شهري:\n\n¹ [<b>جميع الروبوتات</b> والمشاريع (-<u>5</u>%)]\n\n👩🏽‍💻/التوازن",
}
l_file_is_not_correct = {
    'ru': "👩🏽‍💻 Файл или размер некорректные",
    'en': "👩🏽‍💻 File or size is not correct",
    'es': "👩🏽‍💻 El archivo o el tamaño no es correcto",
    'fr': "👩🏽‍💻 Le fichier ou la taille n'est pas correct",
    'zh': "👩🏽‍💻 文件或大小不正确",
    'ar': "👩🏽‍💻 الملف أو الحجم غير صحيح",
}

# region other
l_tonest_text2 = {
    'ru': "👩🏽‍💻 <b>Загрузи</b> альбом, чтобы запечатлеть его в блокчейн-коллекции на память (архивный/авторский/медицинский/дизайнерский медиа-контент)\n\nСоздаение (чеканка) нфт из медиа-контента",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_text = {
    'ru': "👩🏽‍💻 <b>Выбери</b> направление:",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_content = {
    'ru': "🏞️ Памятный контент (nft)",      #  🖼️
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_currency = {
    'ru': "🪙 Монеты сообщества (ft)",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_collection_private = {
    'ru': "👩🏽‍💻 <b>Выбери</b> тип <i>создаваемой</i> коллекции:",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_dialog = {
    'ru': "📜 Памятный диалог (текст)",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_album = {
    'ru': "🏞️ Памятный альбом (медиа)",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_collection_public = {
    'ru': "👩🏽‍💻 <b>Выбери</b> тип <i>существующей</i> коллекции:",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_message = {
    'ru': "📜 Памятные сообщения",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_data = {
    'ru': "📇 Мета данные",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_media = {
    'ru': "🏞️ Стоковые медиа",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_collection = {
    'ru': "🏞️ <b>Сделай</b> пересылку txt-сообщений или прикрепи media-контент/архив, чтобы создать памятную коллекцию:\n\n<blockquote>▪️авторская (личная): диалог/альбом\n▪️стоковая (публичная): сообщение/данные/медиа</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_collection_start = {
    'ru': "🏞️ 1/2 <b>Выбери</b> тип коллекции:\n\n<blockquote>▪️авторская (личная, 1 NFT и более, с правом владения): диалог c пользователем (группой)/альбом (фото или фото-архив)\n▪️стоковая (публичная): сообщение или пост/мета-данные/стоковое фото</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_author = {
    'ru': "▪️авторская",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_stock = {
    'ru': "▪️стоковая",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_author = {
    'ru': "🏞️ 2/2 <b>Выбери</b> вид памятной коллекции (личная, 1 NFT и более, с правом владения):\n\n<blockquote>▪️txt-диалог c пользователем/группой\n▪️media-альбом (фото или фото-архив)</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_author_dialog = {
    'ru': "▪️диалог",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_author_album = {
    'ru': "▪️альбом",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_stock = {
    'ru': "🏞️ <b>2/2 Выбери</b> вид памятной коллекции (публичная):\n\n<blockquote>▪️ сообщение или пост из канала/группы\n▪️мета-данные канала/группы/пользователя/бота\n▪️стоковый медиа-контент (фото)</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_stock_post = {
    'ru': "▪️сообщение/пост",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_stock_data = {
    'ru': "▪️мета-данные",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_stock_media = {
    'ru': "▪️медиа-контент",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_stock_finish = {
    'ru': "🏞️ <b>Открой</b> памятную <a href='https://t.me/FereyTONestBot/web?startapp=nft_all'>коллекцию</a>, чтобы подтвердить создание <a href='https://telegra.ph/FereyTONestBot-05-20'>NFT</a>",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_start2 = {
    'ru': "🏞️ 1/2 <b>Выбери</b> тип коллекции:\n\n<blockquote>▪️памятный альбом (фото/фото-архив, 1 NFT и более, с правом владения)\n▪️авторский контент (сообщения/посты)</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_author2 = {
    'ru': "▪️памятный альбом",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_stock2 = {
    'ru': "▪️авторский контент",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
# endregion

# region collection
l_tonest_collections = {
    'ru': "🏞️ <b>Открой</b> памятную <a href='https://t.me/FereyTONestBot/web?startapp=nft_all'>коллекцию</a>, чтобы подтвердить создание <a href='https://telegra.ph/FereyTONestBot-05-20'>NFT</a>",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_start_text = {
    'ru': "🏞️ <b>Выбери</b> тип коллекции:\n\n<blockquote>▪️соло (единичный NFT)\n▪️памятный альбом (фото/медиа-архив/<a href='https://telegra.ph/FereyTONestBot-05-20'>json</a>)\n▪️авторский контент (сообщения/посты)</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_collection_start_media = {
    'ru': "🏞️ <b>Выбери</b> тип коллекции:\n\n<blockquote>▪️соло (единичный NFT)\n▪️памятный альбом (фото/медиа-архив/<a href='https://telegra.ph/FereyTONestBot-05-20'>json</a>)</blockquote>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_btn_solo3 = {
    'ru': "▪️соло",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_album3 = {
    'ru': "▪️альбом",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_btn_content3 = {
    'ru': "▪️авторский контент",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_none_content = {
    'ru': "👩🏽‍💻 <b>Ошибка</b> получения источника пересылки",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}

l_tonest_address_datalist_list_collection = {
    'ru': "🔍 UQ: адрес коллекции/NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_address_datalist_list_solo = {
    'ru': "создать единичный NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_address_datalist_list_album = {
    'ru': "создать памятный альбом",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_address_datalist_list_fragmentus = {
    'ru': "сохранить авторские фрагменты",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_total_title_collection = {
    'ru': "Количество NFT:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_title_collection = {
    'ru': "Адрес коллекции:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_admin_title_collection = {
    'ru': "Админ коллекции:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_image = {
    'ru': "Обложка:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_name_collection = {
    'ru': "💨 Name: название коллекции",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_name_collection = {
    'ru': "1-3 слова с заглавной буквы",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_description_collection = {
    'ru': "💨 Desc: описание коллекции",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_description_collection = {
    'ru': "история в 1 предложении",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_percent = {
    'ru': "💨 5.5%: процент от перепродажи",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_percent = {
    'ru': "роялти: % процент от перепродажи отдельного NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_royalty = {
    'ru': "💨 UQ: роялти адрес",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_royalty = {
    'ru': "адрес для отправки % от перепродажи NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_chk_public = {
    'ru': "Публичная коллекция",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_public = {
    'ru': "любой может отчеканить NFT для этой коллекции",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_send = {
    'ru': "Создать коллекцию",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_collection_edit = {
    'ru': "Редактировать коллекцию",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_index_title = {
    'ru': "Индекс NFT:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_title = {
    'ru': "Адрес NFT:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_editor_title = {
    'ru': "Админ NFT:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_image_nft = {
    'ru': "💨 ссылка на NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_image_nft = {
    'ru': "Контент:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_name_nft = {
    'ru': "💨 Name: название NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_name_nft = {
    'ru': "1-3 слова с заглавной буквы",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_description_nft = {
    'ru': "💨 Desc: описание NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_description_nft = {
    'ru': "история в 1 предложении",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}

l_tonest_nft_type_nft = {
    'ru': "стандартный (nft)",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_type_edit = {
    'ru': "редактируемый (edit)",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_type_sbt = {
    'ru': "подтверждающий (sbt)",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_nft_type = {
    'ru': "тип NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_attribute_name = {
    'ru': "атрибут",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_attribute_value = {
    'ru': "значение",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_attribute_rem = {
    'ru': "Удалить",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_attribute_add = {
    'ru': "Добавить атрибут",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_attribute = {
    'ru': "добавь [атрибут: значение] для каждого NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_mint = {
    'ru': "Отчеканить NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_edit = {
    'ru': "Редактировать NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_nft_revoke_hint = {
    'ru': "рекомендуется отозвать прав админа на: отчеканивание новых NFT и передачу прав владения, а также на редактирование: ссылка на лого, название, описание, роялти",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_address_nft = {
    'ru': "💨 UQ: адрес NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_burn_nft = {
    'ru': "удалить NFT со своего кошелька",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_nft_transfer = {
    'ru': "отправить NFT другому пользователю",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_collection = {
    'ru': "👩🏽‍💻 Создай коллекцию или выбери адрес коллекции/NFT",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_not_editable_nft = {
    'ru': "👩🏽‍💻 NFT не является редактируемым, можно только отправь его новому владельцу",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
# endregion

# region jetton
l_tonest_jetton = {
    'ru': "🪙 <b>Создай</b> <a href='https://t.me/FereyTONestBot/web?startapp=ft_all'>монеты (жетоны)</a> для своего сообщества, чтобы управлять <a href='https://telegra.ph/FereyTONestBot-05-20'>токеномикой</a>",
    'en': "👩🏽‍💻 <b>Here</b> you can select the type of drop-down media notes (/add | /del)",
    'es': "👩🏽‍💻 <b>Aquí</b> puedes seleccionar el tipo de notas multimedia desplegables (/add | /del)",
    'fr': "👩🏽‍💻 <b>Ici</b>, vous pouvez sélectionner le type de notes média déroulantes (/add | /del)",
    'zh': "👩🏽‍💻<b>在这里</b>您可以选择下拉媒体注释的类型（/add | /del）",
    'ar': "👩🏽‍💻 <b>هنا</b> يمكنك تحديد نوع ملاحظات الوسائط المنسدلة (/add | /del)",
}
l_tonest_address_datalist_list_placeholder = {
    'ru': "🔍 UQ: адрес жетона",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_address_datalist_list_value = {
    'ru': "создать новый жетон",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_choose_address_id = {
    'ru': "выбери / вставь адрес",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_image = {
    'ru': "💨 https: загрузи лого или вставь ссылку",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_name = {
    'ru': "💨 Jetton: название жетона",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_name = {
    'ru': "1-3 слова с заглавной буквы",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_symbol = {
    'ru': "💨 JTN: обозначение жетона",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_symbol = {
    'ru': "3-5 заглавных букв",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_decimals = {
    'ru': "💨 9: десятичная точность",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_decimals = {
    'ru': "9 - точность по умолчанию для TON",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_total = {
    'ru': "💨 1000000: количество JTN",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_total = {
    'ru': "начальное количество на кошельке",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_description = {
    'ru': "💨 Desc: описание жетона",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_description = {
    'ru': "история в 1 предложении",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_field_social = {
    'ru': "💨 https: инфо-ресурсы",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_field_social = {
    'ru': "ссылки: вебсайт/социальные сети",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}

l_tonest_ft_send = {
    'ru': "Создать жетон",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_edit = {
    'ru': "Редактировать",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_gen_rand = {
    'ru': "сгенерировать креативные значения",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_copy_div = {
    'ru': "Скопировано",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_total_title = {
    'ru': "Общий баланс:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_balance_title = {
    'ru': "Баланс кошелька:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_admin_title = {
    'ru': "Адрес админа:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_wallet_title = {
    'ru': "Адрес кошелька:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_master_title = {
    'ru': "Адрес мастера:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_owner_title = {
    'ru': "Подключенный кошелек:",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}

l_tonest_ft_revoke = {
    'ru': "Отозвать права",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_revoke_hint = {
    'ru': "рекомендуется отозвать права админа на: отчеканивание новых монет и передачу прав владения, а также на редактирование жетона: ссылка на лого, название, обозначение, описание",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_mint = {
    'ru': "💨 100: количество JTN",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_mint = {
    'ru': "Отчеканить",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_mint = {
    'ru': "создать еще больше монет",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_admin = {
    'ru': "💨 UQ: адрес нового админа",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_admin = {
    'ru': "Передать права",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_admin = {
    'ru': "передать права на редактирование новому админу",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_burn = {
    'ru': "💨 100: количество JTN",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_burn = {
    'ru': "Сжечь",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_burn = {
    'ru': "удалить монеты из оборота со своего кошелька",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_amount = {
    'ru': "1: количество JTN",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_symbol_dt_id = {
    'ru': "JTN: жетон",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_address = {
    'ru': "💨 UQ: адрес кошелька",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_input_comment = {
    'ru': "💨 TXT: коммент",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_ft_transfer = {
    'ru': "Отправить",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_hint_transfer = {
    'ru': "отправить несколько монет другому пользователю",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_instruction = {
    'ru': "инструкция применения жетона",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}

l_tonest_need_ton_connect = {
    'ru': "👩🏽‍💻 Необходимо подключить TON-аккаунт",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_amount = {
    'ru': "количество",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_reload = {
    'ru': "👩🏽‍💻 Ошибка файла загрузи другой или попробуй позже",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_not_correct_link = {
    'ru': "👩🏽‍💻 Не корректная ссылка",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_master = {
    'ru': "👩🏽‍💻 Создай жетон или выбери адрес мастера/кошелька",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_rights = {
    'ru': "👩🏽‍💻 Отсутствуют права на редактирование",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_amount = {
    'ru': "👩🏽‍💻 Введи количество монет",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
l_tonest_need_address = {
    'ru': "👩🏽‍💻 Введи адрес",
    'en': "💨 Subscription",
    'es': "💨 Suscripción",
    'fr': "💨 Abonnement",
    'zh': "💨 订阅",
    'ar': "💨 الاشتراك",
}
# endregion
# endregion
